

/* ---- Module:de_epages.core ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			de_epages.core
 *
 * @revision		$Revision: 1.6 $
 */

jQuery.plugin( 'de_epages.core', 'ep.core', function( $, undefined ){

	var de_epages = ep.sub();

	$.extend(de_epages,{
		// similar to $.extend; if only 1 hash in arguments de_epages will extend with this hash
		extend: function() {
			return $.extend.apply( this, arguments );
		},
		// similar to $.mixin; if only 1 hash in arguments de_epages will mixin with this hash
		mixin: function() {
			return $.mixin.apply( this, arguments );
		}
	});

	// Expose ep to the global object
	window.de_epages = de_epages;

});

/* ---- Module:jQuery.support.cssprefix ---- */

/*
 * @author			Emanuel Vitzthum
 * @copyright		© 2011 jQuery SDK v1.3.1
 * @info			http://www.jquerysdk.com
 *
 * @license			Dual licensed under the MIT (http://www.opensource.org/licenses/mit-license.php) and GPL (http://www.gnu.org/licenses/gpl.html)
 *
 * @plugin			jQuery.support.cssprefix
 */

jQuery.plugin( 'jQuery.support.cssprefix', function( $, undefined ){

	var cssPrefix = '';

	// add browser engine name as class to html tag
	if( (/khtml/i).test(navigator.userAgent) )
		cssPrefix = '-khtml-';

	$.each( {'mozilla':'-moz-', 'msie':'-ms-', 'webkit':'-webkit-', 'opera':'-o-'}, function( i, name ){
		if( $.browser[i] ){
			cssPrefix = name;
			return false;
		}
	});

	$.support.cssPrefix = cssPrefix;
});

/* ---- Module:jQuery.css.borderradius ---- */

/*
 * @author			Emanuel Vitzthum
 * @copyright		© 2011 jQuery SDK v1.3.1
 * @info			http://www.jquerysdk.com
 *
 * @license			Dual licensed under the MIT (http://www.opensource.org/licenses/mit-license.php) and GPL (http://www.gnu.org/licenses/gpl.html)
 *
 * @plugin			jQuery.css.borderradius
 */

jQuery.plugin( 'jQuery.css.borderradius', 'jQuery.support.cssprefix', function( $, undefined ){

	var cssPrefix	= $.support.cssPrefix,
		radiusType	= [ 'border-radius', 'border-top-left-radius', 'border-top-right-radius', 'border-bottom-right-radius',  'border-bottom-left-radius' ];

	if( cssPrefix ){
		// set props and hooks for border radius
		$.each( radiusType, function( i, name ) {
			var origName = $.camelCase(name),
				hookName = $.camelCase(
					cssPrefix + (
						cssPrefix==='-moz-' && name!=='border-radius' ?
							'border-radius-'+name.split('-').splice(1,2).join('') :
							name
					)
				);
			// add to cssprops
			$.cssProps[ origName ] = hookName;
			// add to hooks
			$.cssHooks[ origName ] = {
				get: function( elem, computed, extra ){
					var ret = [];

					if( name==='border-radius' ){
						$.each( radiusType, function( j, type ){
							if( j>0 )
								ret.push( $.css( elem, type ) );
						});
					}
					else{
						var tmp = $.css( elem, hookName );
						ret.push( tmp ? tmp.split(' ')[0] : '0px' );
					}

					return ret.join(' ');
				},
				set: function( elem, value ){
					elem.style[ origName ] = value;
					elem.style[ hookName ] = value;
				}
			};
		});
	}

});

/* ---- Module:ep.fn.busy ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.fn.busy
 *
 * @revision		$Revision: 1.5.68.1 $
 */

jQuery.plugin( 'ep.fn.busy', ['ep.core', 'jQuery.css.borderradius'], function( $, undefined ){

	var stack = [];

	// remove all busy layers on page leave
	$(window)
		.on("unload", function(){
			$(stack)
				.remove();
			stack = [];
		});

	ep.fn.extend({
		busy: function( action ){
			return this.each(function(){
				var elem = $(this),
					layer = elem.find('> .ep-busy');

				if( action==='hide' ){
					var pos = $.data( this, 'epBusyOldposition');

					if( pos === 'static' ){
						$.removeData( this, 'epBusyOldposition' );
						elem.css('position','relative');
					}

					layer.remove();
				}
				else if( !layer.length ){
					var pos = elem.css('position');

					if( pos === 'static' ){
						$.data( this, 'ep-busy-oldposition', pos );
						elem.css('position','relative');
					}

					stack.push( $('<div>')
						.attr('class','ep-busy')
						.css( 'border-radius', elem.css('border-radius') )
						.appendTo( elem )[0] );
				}
			});
		}
	});

});

/* ---- Module:ep.date ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.date
 *
 * @revision		$Revision: 1.9 $
 */

jQuery.plugin( 'ep.date', ['ep.core', 'jQuery.i18n', 'jQuery.class'], function( $, undefined ){

	var noGetExp = /^(UnixTime)/,
		noSetExp = /^(Day|UnixTime)$/,
		noAddExp = /^UTC/,
		proto = {};

	// advanced
	$.extend(proto,{
		Constructor: function( a, b, c, d, e, f, g ){
			switch( arguments.length ) {
				case 1:
					this.date = new Date( (/^-?\d+$/).test(a) ? parseInt(a,10) : a instanceof Date || a instanceof ep.Date ? a.getTime() : a );
				break;
				case 3:
					this.date = new Date( a, b, c );
				break;
				case 6:
					this.date = new Date( a, b, c, d, e, f );
				break;
				case 7:
					this.date = new Date( a, b, c, d, e, f, g );
				break;
				default:
					this.date = new Date();
				break;
			}
		},
		// clone
		clone: function(){
			return new ep.Date( this.getTime() );
		},
		// i18n format
		getFormat: function( format, options ){
			return $.i18n.formatDate( this.date, format, options );
		},
		setFormat: function( value, format, options ){
			var date = $.i18n.parseDate( value, format,  options );

			if( date ){
				this.setTime( date.getTime() );
			}
			return this;
		},
		// leap year
		isLeapYear: function(){
			var year = this.getFullYear();
			return !(year%400) || (!(year%4) && !!(year%100));
		},
		// days of month
		getMonthLength: function(){
			var month = this.getMonth(),
				days = [31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31];

			if( month===1 && this.isLeapYear() ){
				return 29;
			}
			return days[month];
		},
		setFirstMonthDay: function(){
			this.setDate( 1 );
			return this;
		},
		setLastMonthDay: function(){
			this.setDate( this.getMonthLength() );
			return this;
		},
		// day of week
		setDay: function( set ){
			this.setDate( this.getDate() + ( set - this.getDay() ) );
			return this;
		},
		// unix time
		getUnixTime: function(){
			return Math.round( this.getTime() / 1000 );
		},
		setUnixTime: function( set ){
			this.setTime( set * 1000 );
			return this;
		},
		// UTC unix time
		getUTCUnixTime: function(){
			return this.getUnixTime() - this.getTimezoneOffset()*60;
		},
		setUTCUnixTime: function( set ){
			this.setUnixTime(set);
			this.addTime( this.getTimezoneOffset()*60000 );
			return this;
		}
	});

	// compare
	$.each({
		'Date': 'Hours',
		'Time': 'FullYear'
	},function( name, set ){
		proto[ 'compare' + name ] = function( date ){
			if( !date){
				date = new Date();
			}
			var thisDate = new Date( this.getTime() ),
				compDate = new Date( date.getTime() );

			thisDate[ 'set' + set ](0,0,0,0);
			compDate[ 'set' + set ](0,0,0,0);

			var thisTime = thisDate.getTime(),
				compTime = compDate.getTime();

			if( thisTime > compTime ){
				return 1;
			}
			else if( thisTime < compTime ){
				return -1;
			}
			else{
				return 0;
			}
		};
	});

	// get only
	$.each([
		'toGMTString',
		'toLocaleString',
		'getTimezoneOffset'
	],function( i, name ){
		proto[ name ] = function(){
			return this.date[ name ]();
		};
	});

	// add, get, set, diff
	$.each({
		'FullYear':			31536000000,
		'Month':			2592000000,
		'Day':				604800000,
		'Date':				86400000,
		'Hours':			3600000,
		'Minutes':			60000,
		'Seconds':			1000,
		'Milliseconds':		1,
		'Time':				1,
		'UTCDate':			0,
		'UTCFullYear':		0,
		'UTCHours':			0,
		'UTCMilliseconds':	0,
		'UTCMinutes':		0,
		'UTCMonth':			0,
		'UTCSeconds':		0,
		'UnixTime':			1000
	},function( name, math ){
		// get methods
		if( !noGetExp.test(name) ){
			proto[ 'get' + name ] = function(){
				return this.date[ 'get' + name ]();
			};
		}
		// set methods
		if( !noSetExp.test(name) ){
			proto[ 'set' + name ] = function(){
				this.date[ 'set' + name ].apply( this.date, arguments );
				return this;
			};
		}
		if( !noAddExp.test(name) ){
		// add methods
			proto[ 'add' + name ] = function( add ){
				this[ 'set' + name ]( this[ 'get' + name ]() + add );
				return this;
			};
		// diff methods
			proto[ 'diff' + name ] = function( date ){
				if( !date){
					date = new Date();
				}
				return Math.round( ( date.getTime() - this.getTime() ) / math );
			};
		}
	});

	$.Class('ep.Date',proto);

});


/* ---- Module:ep.color ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.color
 *
 * @revision		$Revision: 1.1.48.2 $
 */

jQuery.plugin( 'ep.color', 'ep.core', function( $, undefined ){


	var nameMap = {
			'aliceblue':			'f0f8ff',
			'antiquewhite':			'faebd7',
			'aqua':					'00ffff',
			'aquamarine':			'7fffd4',
			'azure':				'f0ffff',
			'beige':				'f5f5dc',
			'bisque':				'ffe4c4',
			'black':				'000000',
			'blanchedalmond':		'ffebcd',
			'blue':					'0000ff',
			'blueviolet':			'8a2be2',
			'brown':				'a52a2a',
			'burlywood':			'deb887',
			'cadetblue':			'5f9ea0',
			'chartreuse':			'7fff00',
			'chocolate':			'd2691e',
			'coral':				'ff7f50',
			'cornflowerblue':		'6495ed',
			'cornsilk':				'fff8dc',
			'crimson':				'dc143c',
			'cyan':					'00ffff',
			'darkblue':				'00008b',
			'darkcyan':				'008b8b',
			'darkgoldenrod':		'b8860b',
			'darkgray':				'a9a9a9',
			'darkgrey':				'a9a9a9',
			'darkgreen':			'006400',
			'darkkhaki':			'bdb76b',
			'darkmagenta':			'8b008b',
			'darkolivegreen':		'556b2f',
			'darkorange':			'ff8c00',
			'darkorchid':			'9932cc',
			'darkred':				'8b0000',
			'darksalmon':			'e9967a',
			'darkseagreen':			'8fbc8f',
			'darkslateblue':		'483d8b',
			'darkslategray':		'2f4f4f',
			'darkslategrey':		'2f4f4f',
			'darkturquoise':		'00ced1',
			'darkviolet':			'9400d3',
			'deeppink':				'ff1493',
			'deepskyblue':			'00bfff',
			'dimgray':				'696969',
			'dimgrey':				'696969',
			'dodgerblue':			'1e90ff',
			'firebrick':			'b22222',
			'floralwhite':			'fffaf0',
			'forestgreen':			'228b22',
			'fuchsia':				'ff00ff',
			'gainsboro':			'dcdcdc',
			'ghostwhite':			'f8f8ff',
			'gold':					'ffd700',
			'goldenrod':			'daa520',
			'gray':					'808080',
			'grey':					'808080',
			'green':				'008000',
			'greenyellow':			'adff2f',
			'honeydew':				'f0fff0',
			'hotpink':				'ff69b4',
			'indianred':			'cd5c5c',
			'indigo':				'4b0082',
			'ivory':				'fffff0',
			'khaki':				'f0e68c',
			'lavender':				'e6e6fa',
			'lavenderblush':		'fff0f5',
			'lawngreen':			'7cfc00',
			'lemonchiffon':			'fffacd',
			'lightblue':			'add8e6',
			'lightcoral':			'f08080',
			'lightcyan':			'e0ffff',
			'lightgoldenrodyellow':	'fafad2',
			'lightgray':			'd3d3d3',
			'lightgrey':			'd3d3d3',
			'lightgreen':			'90ee90',
			'lightpink':			'ffb6c1',
			'lightsalmon':			'ffa07a',
			'lightseagreen':		'20b2aa',
			'lightskyblue':			'87cefa',
			'lightslategray':		'778899',
			'lightslategrey':		'778899',
			'lightsteelblue':		'b0c4de',
			'lightyellow':			'ffffe0',
			'lime':					'00ff00',
			'limegreen':			'32cd32',
			'linen':				'faf0e6',
			'magenta':				'ff00ff',
			'maroon':				'800000',
			'mediumaquamarine':		'66cdaa',
			'mediumblue':			'0000cd',
			'mediumorchid':			'ba55d3',
			'mediumpurple':			'9370d8',
			'mediumseagreen':		'3cb371',
			'mediumslateblue':		'7b68ee',
			'mediumspringgreen':	'00fa9a',
			'mediumturquoise':		'48d1cc',
			'mediumvioletred':		'c71585',
			'midnightblue':			'191970',
			'mintcream':			'f5fffa',
			'mistyrose':			'ffe4e1',
			'moccasin':				'ffe4b5',
			'navajowhite':			'ffdead',
			'navy':					'000080',
			'oldlace':				'fdf5e6',
			'olive':				'808000',
			'olivedrab':			'6b8e23',
			'orange':				'ffa500',
			'orangered':			'ff4500',
			'orchid':				'da70d6',
			'palegoldenrod':		'eee8aa',
			'palegreen':			'98fb98',
			'paleturquoise':		'afeeee',
			'palevioletred':		'd87093',
			'papayawhip':			'ffefd5',
			'peachpuff':			'ffdab9',
			'peru':					'cd853f',
			'pink':					'ffc0cb',
			'plum':					'dda0dd',
			'powderblue':			'b0e0e6',
			'purple':				'800080',
			'red':					'ff0000',
			'rosybrown':			'bc8f8f',
			'royalblue':			'4169e1',
			'saddlebrown':			'8b4513',
			'salmon':				'fa8072',
			'sandybrown':			'f4a460',
			'seagreen':				'2e8b57',
			'seashell':				'fff5ee',
			'sienna':				'a0522d',
			'silver':				'c0c0c0',
			'skyblue':				'87ceeb',
			'slateblue':			'6a5acd',
			'slategray':			'708090',
			'slategrey':			'708090',
			'snow':					'fffafa',
			'springgreen':			'00ff7f',
			'steelblue':			'4682b4',
			'tan':					'd2b48c',
			'teal':					'008080',
			'thistle':				'd8bfd8',
			'tomato':				'ff6347',
			'turquoise':			'40e0d0',
			'violet':				'ee82ee',
			'wheat':				'f5deb3',
			'white':				'ffffff',
			'whitesmoke':			'f5f5f5',
			'yellow':				'ffff00',
			'yellowgreen':			'9acd32'
		},

		hexMap = null,

		createHexMap = function(){
			hexMap = {};
			for( var i in nameMap ){
				hexMap[ nameMap[i] ] = i;
			}
		},

		toHex = function(c){
			c = parseInt( c, 10 ).toString(16);
			return c.length < 2 ? "0" + c : c;
		};

	$.extend( $.scope('ep.color'),{

		rgbToHex: function( rgb ){
			return rgb.a === 0 ? "transparent" : toHex(rgb.r) + toHex(rgb.g) + toHex(rgb.b);
		},

		rgbToHsb: function(rgb) {
			var min = Math.min( Math.min(rgb.r,rgb.g), rgb.b ),
				max = Math.max( Math.max(rgb.r,rgb.g), rgb.b ),
				delta = (max - min),
				sat = 0,
				lum = 0,
				hue = 0;

			if( max !== 0 ){
				sat = (delta / max) * 100;
				lum = (max / 255) * 100;
			}

			if( delta !== 0 ){
				if( rgb.r===max ){
					hue = (rgb.g - rgb.b) / delta;
				}
				else if( rgb.g===max ){
					hue = 2 + ( (rgb.b - rgb.r) / delta );
				}
				else{
					hue = 4 + ( (rgb.r - rgb.g) / delta );
				}
				hue = (hue * 60);
				hue = hue < 0 ? hue + 360 : hue;
			}

			return {
				h: Math.round(hue),
				s: Math.round(sat),
				b: Math.round(lum)
			};
		},

		rgbToName: function( rgb ){
			var hex = this.rgbToHex(rgb);
			return this.hexToName( hex );
		},

		hexToRgb: function( hex ) {
			hex = hex.toUpperCase();

			var rgb;

			if( /^(transparent|none)$/.test(hex) ){
				return {
					r:255,
					g:255,
					b:255,
					a:0
				};
			}

			hex = hex.charAt(0) === "#" ? hex.substring(1,hex.length) : hex;

			if( hex.length === 6 ){
				rgb = {
					r: parseInt(hex.substring(0,2),16),
					g: parseInt(hex.substring(2,4),16),
					b: parseInt(hex.substring(4,6),16),
					a: 1
				};
			}
			else if( hex.length === 3){
				rgb = {
					r: parseInt(hex.substring(0,1) + hex.substring(0,1),16),
					g: parseInt(hex.substring(1,2) + hex.substring(1,2),16),
					b: parseInt(hex.substring(2,3) + hex.substring(2,3),16),
					a: 1
				};
			}
			else{
				//return white if no hex value was given
				rgb = {
					r: 255,
					g: 255,
					b: 255,
					a: 1
				};
			}

			rgb.r =  isNaN(rgb.r) ? 0 : Math.round(rgb.r);
			rgb.g =  isNaN(rgb.g) ? 0 : Math.round(rgb.g);
			rgb.b =  isNaN(rgb.b) ? 0 : Math.round(rgb.b);

			return rgb;
		},

		hexToHsb: function( hex ){
			return this.rgbToHsb( this.hexToRgb(hex) );
		},

		hexToName: function( hex ){
			hex = hex.charAt(0) === "#" ? hex.substring(1,hex.length) : hex;

			if(!hexMap){
				createHexMap();
			}

			return hexMap[hex];
		},

		hsbToRgb: function(hsb) {
			var rgb = {},
				r = 0,
				g = 0,
				b = 0,
				hue = hsb.h/60,
				sat = hsb.s/100,
				lum = hsb.b/100;

			if( sat === 0 ) {
				r = g = b = lum;
			}
			else {
				var i = parseInt( hue, 10 ),
					p = lum * ( 1.0-sat ),
					q = lum * ( 1.0-sat * (hue-i) ),
					t = lum * ( 1.0-sat * ( 1 - (hue-i) ) );

				switch (i) {
					case 0: r = lum; g = t;   b = p;   break;
					case 1: r = q;   g = lum; b = p;   break;
					case 2: r = p;   g = lum; b = t;   break;
					case 3: r = p;   g = q;   b = lum; break;
					case 4: r = t;   g = p;   b = lum; break;
					case 5: r = lum; g = p;   b = q;   break;
					case 6: r = lum; g = t;   b = p;   break;
				}
			}

			return {
				r: Math.round( r * 255 ),
				g: Math.round( g * 255 ),
				b: Math.round( b * 255 ),
				a: 1
			};
		},

		hsbToHex: function( hsb ){
			return this.rgbToHex( this.hsbToRgb(hsb) );
		},

		hsbToName: function( hsb ){
			return this.hexToName( this.hsbToHex(hsb) );
		},

		nameToHex: function( name ){
			name = $.trim( name.toLowerCase() );
			return (/^(transparent|none)$/).test(name) ? 'transparent' : nameMap[name];
		},

		nameToRgb: function( name ){
			var hex = this.nameToHex(name);
			return hex ? this.hexToRgb( hex ) : hex;
		},

		nameToHsb: function( name ){
			var rgb = this.nameToRgb(name);
			return rgb ? this.rgbToHsb(rgb) : rgb;
		},

		stringToHex: function( string, /* internal */ strict ){
			string = $.trim( string.toLowerCase() );

			var result,
				found;

			if( (/^(transparent|none)$/).test(string) ){
				result = "transparent";
			}
			else if( found = (/^#?([0-9a-f]{6})$/).exec(string) ){
				result = found[1];
			}
			else if( found = (/^#?([0-9a-f])([0-9a-f])([0-9a-f])$/).exec(string) ) {
				result = found[1] + found[1] + found[2] + found[2] + found[3] + found[3];
			}
			else if( found = (/^rgb\(\s*([0-9]{1,3})\s*,\s*([0-9]{1,3})\s*,\s*([0-9]{1,3})\s*\)$/).exec(string) ){
				result = this.rgbToHex( {r: found[1], g: found[2], b: found[3]} );
			}
			else if( found = (/^rgba\(\s*([0-9]{1,3})\s*,\s*([0-9]{1,3})\s*,\s*([0-9]{1,3})\s*,\s*([0-1]{1}(:?\.?[0-9]{1})?)\s*\)$/).exec(string) ){
				result = this.rgbToHex( {r: found[1], g: found[2], b: found[3], a: found[4]} );
			}
			else{
				result = this.nameToHex( string );
			}

			return result===undefined && !strict ? "ffffff" : result;
		},

		stringToRgb: function( string ){
			var hex = this.stringToHex(string);
			return hex ? this.hexToRgb(hex) : hex;
		},

		stringToHsb: function( string ){
			var hex = this.stringToHex(string);
			return hex ? this.hexToHsb(hex) : hex;
		},

		stringToName: function( string ){
			var hex = this.stringToHex(string);
			return hex ? this.hexToName(hex) : hex;
		}
	});

});

/* ---- Module:ep.ui.datepicker ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.ui.datepicker
 *
 * @revision		$Revision: 1.24.4.2 $
 */

jQuery.plugin( 'ep.ui.datepicker', {
	plugin: [
		'ep.core',
		'ep.date',
		'ep.sprite',
		'ep.fn.busy',
		'ep.ui.spinner',
		'jQuery.tmpl'
	],
	tmpl: [
		'ep.ui.datepicker'
	]
}, function( $, undefined ){

/*
 * @dictionary		ep.dict
 *
 * @translation		{Today}
 *					{Done}
 */

	$.widget('ep.ui.Datepicker',ep.ui.Validate,{

		options: {
	// ep.ui.Input
		//	big:				true,
		//	autofocus:			false,
		//	placeholder:		'text',
		//	info:				'text',

	// ep.ui.Validate
		//	accept:				'',
		//	min:				1,
		//	max:				20,
		//	minlength:			1,
		//	maxlength:			4,
		//	pattern:			[\w]+,
		//	required:			true,
		//	valid:				true,
		//	type:				'basic',
		//	format:				'',

	// ep.ui.Datepicker
		//	onAfterSetValue:	undefined					// callback called after value was set
			type:				'date',
			format:				'l',						// format for i18n
			showOn:				'button',					// show datepicker on 'focus' || 'button' || 'both' or 'inline'
			duration:			'normal',					// duration for show and hide effect
			show:				'fadeIn',					// show effect 'show' || 'fadeIn' || 'slideIn'
			hide:				'fadeOut',					// hide effect 'hide' || 'fadeOut' || 'slideOut'
			weekDaysAvailable:	[1,1,1,1,1,1,1],			// which days ar avaible boolean in array
			numberOfMonths:		1,							// display number of month
			showOtherMonth:		true,						// show days from other month
			selectOtherMonth:	false,						// days from other month ar clickable
			changeMonth:		true,						// enable select month
			changeYear:			true,						// enable select year
			region:				$.config.i18n.region,		// region for i18n
			time:				true,						// use as date and time picker
			timeStep:			15,							// step for time spinner in minutes
			min:				undefined,					// min for range miliseconds || dateObj
			max:				undefined					// max for range miliseconds || dateObj
		},

		_create: function(){
			this.Inherited();

			var currentDate = this.options.currentDate,
				date;

			date = currentDate ? new ep.Date(currentDate.year, currentDate.month, currentDate.day) : new ep.Date();
			date
				.setMinutes(30)
				.setSeconds(0)
				.setMilliseconds(0);

			this._date =			date.clone().setHours(0,0,0,0);
			this._dateNow =			this._date.clone();
			this._dateSelected =	this._date.clone();
			this._timeSelected =	date.clone().setFullYear(0,0,0);

			this.domCache = $('<div>');
			this.cal = $.i18n.regions[ this.options.region ].calendar;

			this.elem.on( 'changeValue.uiDatepicker', this.Proxy('_changeElemVal') );

			this.showButton = $('<span>')
				.attr({
					'class':	'ep-uiInput ep-uiInput-base ep-uiInput-button ep-uiDatepicker-showButton'
				})
				.html(
					ep.sprite('calendar','s').addClass('ep-uiInput-buttonSpriteOnly')
				)
				.on( 'click.uiDatepicker', this.Proxy('show') )
				.appendTo( this.domCache );

			this.stack.push( this.domCache[0], this.showButton[0] );

			this._changeElemVal();
		},

		_init: function(){
			this.Inherited();

			var o = this.options;

			if( (/^(focus|both)$/).test(o.showOn) ){
				this.elem
					.off('focus.uiDatepicker')
					.on( 'focus.uiDatepicker', this.Proxy('show') );
			}
			if( (/^(button|both)$/).test(o.showOn) ){
				this.elem.addClass('epWidth-29');

				if( this.placeholder ){
					this.placeholder.addClass('epWidth-29');
				}

				this.showButton
					.insertAfter( this.placeholder || this.elem );
			}
			else{
				this.elem.removeClass('epWidth-29');
				if( this.placeholder ){
					this.placeholder.removeClass('epWidth-29');
				}
				this.showButton
					.appendTo( this.domCache );
			}

			if( this.container ){
				this._initCalCache();

				if( o.time && !this.timeBar ){
					this._createTimeBar();
				}
			}

			this._tooltipInit();

			if( o.showOn === 'inline' ){
				this.show();
			}
		},

		_initCalCache: function(){
			this._calCache = {
				weekDays: arrayRotate( $.merge([],this.cal.days.namesShort), this.cal.firstDay),
				months: $.merge([],this.cal.months.names)
			};
		},

		_tooltipInit: function(){
			this.Inherited(arguments);
			if( this.tooltip && (/^(button|both)$/).test(this.options.showOn) ){
				this.tooltip.uiTooltip( 'option', 'offsetAdjust', [30,-1] );
			}
			else if( this.tooltip ){
				this.tooltip.uiTooltip( 'option', 'offsetAdjust', [3,-2] );
			}
		},

		_createBase: function(){
			var self = this;
			// the datepicker
			this.container = ep('<form>')
				.addClass('epDialog ep-uiDatepicker-container')
				.hide();
			// go to previous month
			this.prevButton = ep('<button type="button">')
				.append( ep.sprite('arrow-l','s').addClass('ep-uiInput-buttonSpriteOnly') )
				.uiInput()
				.uiInput('addClass','ep-uiDatepicker-prev')
				.on( 'click.uiDatepicker', function(){
					self._changeMonth(-1);
				});
			// go to next month
			this.nextButton = ep('<button type="button">')
				.append( ep.sprite('arrow-r','s').addClass('ep-uiInput-buttonSpriteOnly') )
				.uiInput()
				.uiInput('addClass','ep-uiDatepicker-next')
				.on( 'click.uiDatepicker', function(){
					self._changeMonth(1);
				});
			// bar on the bottom
			this.buttonBar = $('<div>')
				.addClass('epDialogButtonBar ep-uiDatepicker-buttonBar')
				.appendTo( this.container );
			// select the current day
			this.todayButton = ep('<button type="button">')
				.text( this.dict.translate('Today') )
				.appendTo( this.buttonBar )
				.uiInput()
				.uiInput('addClass','ep-uiDatepicker-today')
				.on( 'click.uiDatepicker', function(){
					self._date = self._dateNow.clone().setHours(0,0,0,0);
					self._changeDay( self._date.getTime() );
					self._createCalendars();
				});
			// close the datepicker
			this.doneButton = ep('<button type="button">')
				.text( this.dict.translate('Done') )
				.appendTo( this.buttonBar )
				.uiInput()
				.uiInput('addClass','ep-uiDatepicker-done')
				.on( 'click.uiDatepicker', this.Proxy('hide') );
			// live click handler to select a day on click
			this.container
				.on( 'click', 'a.ep-uiDatepicker-dayClick', this.Proxy('_selectDay') )
				.on( 'change', 'select.ep-uiDatepicker-monthSelect,select.ep-uiDatepicker-yearSelect', function(){
					self._changeMonth(parseInt(this.value,10));
				});
			// stack for calendars
			this.calendars = $();
			// reinit
			this._init();
			// add to DOM
			this.container.appendTo('body');
			// save in stack
			this.stack.push(
				this.container[0],
				this.prevButton[0],
				this.nextButton[0],
				this.doneButton[0],
				this.todayButton[0],
				this.buttonBar[0]
			);
		},

		_createTimeBar: function(){
			this.timeBar = $('<div>')
				.addClass('ep-uiDatepicker-timeBar')
				.insertBefore( this.buttonBar );

			this.stack.push( this.timeBar[0] );

			this._createTimeSelect();
		},

		_createTimeSelect: function(){
			this.timeSelect = ep('<input>')
				.attr({
					'class': 'epWidth100',
					'placeholder': '00:00'
				})
				.appendTo( this.timeBar )
				.uiSpinner({
					type:		'date',
					step:		15,
					stepType:	'minutes',
					format:		't',
					region:		this.options.region
				})
				.uiInput('addClass','ep-uiDatepicker-time')
				.on( 'changeValue.uiDatepicker', this.Proxy('_changeTimeVal') );

			this._setTimeVal();

			this.stack.push( this.timeSelect[0]	);
		},

		_createCalendars: function(){
			// set busy layer
			this.container.busy('show');
			// vars
			var o				= this.options,
				calendarsData	= this._calendarData(),
				calendars;
			// build weeks
			$.each( calendarsData, function( i, calendarData){
				while( calendarData.days.length >= 7 ){
					calendarData.weeks.push({days:calendarData.days.splice(0,7)});
				}
			});
			// build calendars
			calendars = $.tmpl( 'ep.ui.datepicker', calendarsData );
			calendars
				.not(':first,:last')
				.addClass('ep-uiDatepicker-calendarMiddle');
			calendars
				.not(':last')
				.first()
				.addClass('ep-uiDatepicker-calendarFirst');
			calendars
				.not(':first')
				.last()
				.addClass('ep-uiDatepicker-calendarLast');
			// place prev button to new calendars and handle range
			this.prevButton
				.attr( 'disabled', !inRange( o.min, this._date.clone().setFirstMonthDay().setHours(0,0,0,-1).getTime() ) )
				.parent()
				.prependTo( calendars.filter(':first').find('.ep-uiDatepicker-titleBar') );
			// place next button to new calendars and handle range
			this.nextButton
				.attr( 'disabled', !inRange( undefined, this._date.clone().setLastMonthDay().setHours(0,0,0,0).addDate(1).getTime(), o.max ) )
				.parent()
				.appendTo( calendars.filter(':last').find('.ep-uiDatepicker-titleBar') );
			// remove old calendars
			this.calendars
				.html('')
				.remove();
			// show new calendars in datepicker
			this.container.prepend(calendars)
				.busy('hide');
			// set new calendars
			this.calendars = calendars;
		},

		_calendarData: function(){
			var o				= this.options,
				baseDate		= this._date.clone().addMonth( - Math.ceil(o.numberOfMonths/2) ),
				nowTime			= this._dateNow.getTime(),
				selectedTime	= this._dateSelected.getTime(),
				region			= {region: this.options.region},
				baseMonth		= this._date.getMonth(),
				changeMonth		= null,
				changeYear		= null,
				data			= [],
				i;

			if( o.changeMonth ){
				changeMonth = [];
				$.each( this._calCache.months, function( i, name ){
					if( name ){
						changeMonth.push({ value: (baseMonth-i)*-1, name: name, currentMonth: baseMonth===i });
					}
				});
			}

			if( o.changeYear ){
				var yDate = this._date.clone();

				changeYear = [{ value: 0, name: yDate.getFormat( "yyyy", region ), currentYear: true }];

				for( i=1 ; i<=10 ; i++ ){
					yDate.addFullYear(-1);
					changeYear.unshift({ value: i*-12, name: yDate.getFormat( "yyyy", region ), currentYear: false });
				}
				yDate.addFullYear(10);
				for( i=1 ; i<=10 ; i++ ){
					yDate.addFullYear(1);
					changeYear.push({ value: i*12, name: yDate.getFormat( "yyyy", region ), currentYear: false });
				}
			}

			for( i=0,iLength=o.numberOfMonths ; i<iLength ; i++ ){
				var date =			baseDate.addMonth(1),
					iDate =			date.clone().setDate(0),
					iFirstDate =	date.clone().setFirstMonthDay(),
					iFirstTime =	iFirstDate.getTime(),
					iLastTime =		date.clone().setLastMonthDay().getTime(),
					iDays =			iFirstDate.getMonthLength(),
					iWeekDay =		iFirstDate.getDay() - this.cal.firstDay,
					add =			{
										year:		iFirstDate.getFormat( "yyyy", region ),
										years:		changeYear,
										month:		iFirstDate.getFormat( "MMMM", region ),
										months:		changeMonth,
										weekDays:	this._calCache.weekDays,
										weeks:		[],
										days:		[]
									};

				if( iWeekDay<0 ){
					iWeekDay = iWeekDay+7;
				}

				iDate.addDate( - iWeekDay );

				for( var j=1,jLength=(Math.ceil( (iWeekDay+iDays) / 7) * 7 ) ; j<=jLength ; j++ ){
					var jDate =			iDate.addDate(1),
						jTime =			jDate.getTime(),
						currentMonth =	inRange( iFirstTime, jTime, iLastTime ),
						clickable =		inRange( o.min, jTime, o.max ) && o.weekDaysAvailable[ jDate.getDay() ];

					add.days.push({
						'date':				jDate.clone(),
						'tstamp':			jTime,
						'day':				jDate.getDate(),
						'currentMonth':		!!currentMonth,
						'clickable':		(currentMonth || o.selectOtherMonth) && clickable,
						'visible':			!!(currentMonth || o.selectOtherMonth || o.showOtherMonth),
						'selected':			jTime===selectedTime,
						'now':				jTime===nowTime
					});
				}

				data.push(add);
			}

			return data;
		},

		_setElemVal: function( noBubbling ){
			var val = new ep.Date(
							this._dateSelected.getFullYear(),
							this._dateSelected.getMonth(),
							this._dateSelected.getDate(),
							isNaN(this._timeSelected.getHours()) ? 0 : this._timeSelected.getHours(),
							isNaN(this._timeSelected.getMinutes()) ? 0 : this._timeSelected.getMinutes(),
							isNaN(this._timeSelected.getSeconds()) ? 0 : this._timeSelected.getSeconds()
						)
						.getFormat(
							this.options.format,
							{region:this.options.region}
						);

			if( noBubbling ){
				this.elem.val( val );
			}
			else{
				this.elem.attr( 'value', val );
			}

			// callback called after value was set
			if(this.options.onAfterSetValue !== undefined){
				this.options.onAfterSetValue(this.elem);
			}
		},

		_getElemVal: function(){
			var date = $.i18n.parseDate( this.elem.val(), this.options.format, {region:this.options.region} );
			return date ? new ep.Date( date.getTime() ) : null;
		},

		_changeElemVal: function(){
			var o = this.options,
				date = this._getElemVal();

			if( date && inRange( o.min, date.clone().setLastMonthDay().getTime() ) && inRange( undefined, date.clone().setFirstMonthDay().getTime(), o.max ) ){
				if( this.elem.is(':focus') ){
					this._date = date.clone().setHours(0,0,0,0);
				}
				this._dateSelected = date.clone().setHours(0,0,0,0);
				this._timeSelected = date.clone().setFullYear(0,0,0);

				if( this.timeSelect ){
					this._setTimeVal();
				}
			}
			if( this.container && this.container.filter(':visible').length ){
				this._createCalendars();
			}
		},

		_setTimeVal: function(){
			if( !this.timeSelect.is(':focus') ){
				this.timeSelect.val( this._timeSelected.getFormat( 't', {region:this.options.region} ) );
			}
		},

		_getTimeVal: function(){
			var date = $.i18n.parseDate( this.timeSelect.val(), 't', {region:this.options.region} );
			return date ? new ep.Date( date.getTime() ) : null;
		},

		_changeTimeVal: function(event){
			var date = this._getTimeVal();

			if( date ){
				this._timeSelected = date.setFullYear(0,0,0);
				this._setElemVal();
			}
		},

		_changeMonth: function( inc ){
			this._date.addMonth(inc);
			this._createCalendars();
		},

		_changeDay: function( tstamp ){
			this._dateSelected = new ep.Date(tstamp);
			this._setElemVal();
		},

		_selectDay: function( event ){
			this._changeDay( parseInt( $(event.target).attr('data-tstamp'), 10 ) );
		},

		_show: function(){
			var o = this.options;

			if( o.showOn !== 'inline' ){
				this.container.contextOrientation( this.elem, 'bottom', [-1,1] ).focus();
				this.container
					.stop(true,true)
					[ $.fn[o.show] ? o.show : 'show' ](o.duration);

				$('html').on( 'keyup', $.proxy(this,'_hide') );
			}
			else{
				this.buttonBar
					.hide();
				this.container
					.insertAfter( this.wrap )
					.css('position','relative')
					.show();
			}
			this.elem.blur();
		},

		show: function(){
			var self = this;

			if( this.elem.is(":disabled") ){
				return;
			}
			if( !this.container ){
				this._createBase();
			}

			this._show();
			this._changeElemVal();
			this._setValidStatus(true);
		},

		_hide: function( event ){
			if( event.keyCode===27 ){
				this.hide();
				this._validate(event);
			}
		},

		hide: function(){
			var o = this.options;

			if( o.showOn !== 'inline' ){
				this.container
					.stop(true,true)
					[ $.fn[o.hide] ? o.hide : 'hide' ](o.duration);

				$('html').off( 'keyup', $.proxy(this,'_hide') );
			}
		},

		getDate: function(){
			return new ep.Date(
							this._dateSelected.getFullYear(),
							this._dateSelected.getMonth(),
							this._dateSelected.getDate(),
							this._timeSelected.getHours(),
							this._timeSelected.getMinutes(),
							this._timeSelected.getSeconds()
						);
		}
	});

	var arrayRotate = function( array, size ){
			var tmp = array.splice( 0, size );

			return array.concat( tmp );
		},

		inRange = function( min, val, max ){
			min = new ep.Date(typeof min === 'object' && min.getTime ? min.getTime() : min).setHours(0,0,0,0).getTime();
			max = new ep.Date(typeof max === 'object' && max.getTime ? max.getTime() : max).setHours(0,0,0,0).getTime();
			return !min || val >= min ? !max || val <= max ? true : false : false;
		};

});


/* ---- Module:jQuery.ui.core ---- */

/*!
 * jQuery UI 1.8.18
 *
 * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * http://docs.jquery.com/UI
 */
jQuery.plugin( 'jQuery.ui.core', function( $, undefined ){

// prevent duplicate loading
// this is only a problem because we proxy existing functions
// and we don't want to double proxy them
$.ui = $.ui || {};
if ( $.ui.version ) {
	return;
}

$.extend( $.ui, {
	version: "1.8.18",

	keyCode: {
		ALT: 18,
		BACKSPACE: 8,
		CAPS_LOCK: 20,
		COMMA: 188,
		COMMAND: 91,
		COMMAND_LEFT: 91, // COMMAND
		COMMAND_RIGHT: 93,
		CONTROL: 17,
		DELETE: 46,
		DOWN: 40,
		END: 35,
		ENTER: 13,
		ESCAPE: 27,
		HOME: 36,
		INSERT: 45,
		LEFT: 37,
		MENU: 93, // COMMAND_RIGHT
		NUMPAD_ADD: 107,
		NUMPAD_DECIMAL: 110,
		NUMPAD_DIVIDE: 111,
		NUMPAD_ENTER: 108,
		NUMPAD_MULTIPLY: 106,
		NUMPAD_SUBTRACT: 109,
		PAGE_DOWN: 34,
		PAGE_UP: 33,
		PERIOD: 190,
		RIGHT: 39,
		SHIFT: 16,
		SPACE: 32,
		TAB: 9,
		UP: 38,
		WINDOWS: 91 // COMMAND
	}
});

// plugins
$.fn.extend({
	propAttr: $.fn.prop || $.fn.attr,

	_focus: $.fn.focus,
	focus: function( delay, fn ) {
		return typeof delay === "number" ?
			this.each(function() {
				var elem = this;
				setTimeout(function() {
					$( elem ).focus();
					if ( fn ) {
						fn.call( elem );
					}
				}, delay );
			}) :
			this._focus.apply( this, arguments );
	},

	scrollParent: function() {
		var scrollParent;
		if (($.browser.msie && (/(static|relative)/).test(this.css('position'))) || (/absolute/).test(this.css('position'))) {
			scrollParent = this.parents().filter(function() {
				return (/(relative|absolute|fixed)/).test($.curCSS(this,'position',1)) && (/(auto|scroll)/).test($.curCSS(this,'overflow',1)+$.curCSS(this,'overflow-y',1)+$.curCSS(this,'overflow-x',1));
			}).eq(0);
		} else {
			scrollParent = this.parents().filter(function() {
				return (/(auto|scroll)/).test($.curCSS(this,'overflow',1)+$.curCSS(this,'overflow-y',1)+$.curCSS(this,'overflow-x',1));
			}).eq(0);
		}

		return (/fixed/).test(this.css('position')) || !scrollParent.length ? $(document) : scrollParent;
	},

	zIndex: function( zIndex ) {
		if ( zIndex !== undefined ) {
			return this.css( "zIndex", zIndex );
		}

		if ( this.length ) {
			var elem = $( this[ 0 ] ), position, value;
			while ( elem.length && elem[ 0 ] !== document ) {
				// Ignore z-index if position is set to a value where z-index is ignored by the browser
				// This makes behavior of this function consistent across browsers
				// WebKit always returns auto if the element is positioned
				position = elem.css( "position" );
				if ( position === "absolute" || position === "relative" || position === "fixed" ) {
					// IE returns 0 when zIndex is not specified
					// other browsers return a string
					// we ignore the case of nested elements with an explicit value of 0
					// <div style="z-index: -10;"><div style="z-index: 0;"></div></div>
					value = parseInt( elem.css( "zIndex" ), 10 );
					if ( !isNaN( value ) && value !== 0 ) {
						return value;
					}
				}
				elem = elem.parent();
			}
		}

		return 0;
	},

	disableSelection: function() {
		return this.bind( ( $.support.selectstart ? "selectstart" : "mousedown" ) +
			".ui-disableSelection", function( event ) {
				event.preventDefault();
			});
	},

	enableSelection: function() {
		return this.unbind( ".ui-disableSelection" );
	}
});

$.each( [ "Width", "Height" ], function( i, name ) {
	var side = name === "Width" ? [ "Left", "Right" ] : [ "Top", "Bottom" ],
		type = name.toLowerCase(),
		orig = {
			innerWidth: $.fn.innerWidth,
			innerHeight: $.fn.innerHeight,
			outerWidth: $.fn.outerWidth,
			outerHeight: $.fn.outerHeight
		};

	function reduce( elem, size, border, margin ) {
		$.each( side, function() {
			size -= parseFloat( $.curCSS( elem, "padding" + this, true) ) || 0;
			if ( border ) {
				size -= parseFloat( $.curCSS( elem, "border" + this + "Width", true) ) || 0;
			}
			if ( margin ) {
				size -= parseFloat( $.curCSS( elem, "margin" + this, true) ) || 0;
			}
		});
		return size;
	}

	$.fn[ "inner" + name ] = function( size ) {
		if ( size === undefined ) {
			return orig[ "inner" + name ].call( this );
		}

		return this.each(function() {
			$( this ).css( type, reduce( this, size ) + "px" );
		});
	};

	$.fn[ "outer" + name] = function( size, margin ) {
		if ( typeof size !== "number" ) {
			return orig[ "outer" + name ].call( this, size );
		}

		return this.each(function() {
			$( this).css( type, reduce( this, size, true, margin ) + "px" );
		});
	};
});

// selectors
function focusable( element, isTabIndexNotNaN ) {
	var nodeName = element.nodeName.toLowerCase();
	if ( "area" === nodeName ) {
		var map = element.parentNode,
			mapName = map.name,
			img;
		if ( !element.href || !mapName || map.nodeName.toLowerCase() !== "map" ) {
			return false;
		}
		img = $( "img[usemap=#" + mapName + "]" )[0];
		return !!img && visible( img );
	}
	return ( /input|select|textarea|button|object/.test( nodeName )
		? !element.disabled
		: "a" == nodeName
			? element.href || isTabIndexNotNaN
			: isTabIndexNotNaN)
		// the element and all of its ancestors must be visible
		&& visible( element );
}

function visible( element ) {
	return !$( element ).parents().andSelf().filter(function() {
		return $.curCSS( this, "visibility" ) === "hidden" ||
			$.expr.filters.hidden( this );
	}).length;
}

$.extend( $.expr[ ":" ], {
	data: function( elem, i, match ) {
		return !!$.data( elem, match[ 3 ] );
	},

	focusable: function( element ) {
		return focusable( element, !isNaN( $.attr( element, "tabindex" ) ) );
	},

	tabbable: function( element ) {
		var tabIndex = $.attr( element, "tabindex" ),
			isTabIndexNaN = isNaN( tabIndex );
		return ( isTabIndexNaN || tabIndex >= 0 ) && focusable( element, !isTabIndexNaN );
	}
});

// support
$(function() {
	var body = document.body,
		div = body.appendChild( div = document.createElement( "div" ) );

	// access offsetHeight before setting the style to prevent a layout bug
	// in IE 9 which causes the elemnt to continue to take up space even
	// after it is removed from the DOM (#8026)
	div.offsetHeight;

	$.extend( div.style, {
		minHeight: "100px",
		height: "auto",
		padding: 0,
		borderWidth: 0
	});

	$.support.minHeight = div.offsetHeight === 100;
	$.support.selectstart = "onselectstart" in div;

	// set display to none to avoid a layout bug in IE
	// http://dev.jquery.com/ticket/4014
	body.removeChild( div ).style.display = "none";
});





// deprecated
$.extend( $.ui, {
	// $.ui.plugin is deprecated.  Use the proxy pattern instead.
	plugin: {
		add: function( module, option, set ) {
			var proto = $.ui[ module ].prototype;
			for ( var i in set ) {
				proto.plugins[ i ] = proto.plugins[ i ] || [];
				proto.plugins[ i ].push( [ option, set[ i ] ] );
			}
		},
		call: function( instance, name, args ) {
			var set = instance.plugins[ name ];
			if ( !set || !instance.element[ 0 ].parentNode ) {
				return;
			}
	
			for ( var i = 0; i < set.length; i++ ) {
				if ( instance.options[ set[ i ][ 0 ] ] ) {
					set[ i ][ 1 ].apply( instance.element, args );
				}
			}
		}
	},
	
	// will be deprecated when we switch to jQuery 1.4 - use jQuery.contains()
	contains: function( a, b ) {
		return document.compareDocumentPosition ?
			a.compareDocumentPosition( b ) & 16 :
			a !== b && a.contains( b );
	},
	
	// only used by resizable
	hasScroll: function( el, a ) {
	
		//If overflow is hidden, the element might have extra content, but the user wants to hide it
		if ( $( el ).css( "overflow" ) === "hidden") {
			return false;
		}
	
		var scroll = ( a && a === "left" ) ? "scrollLeft" : "scrollTop",
			has = false;
	
		if ( el[ scroll ] > 0 ) {
			return true;
		}
	
		// TODO: determine which cases actually cause this to happen
		// if the element doesn't have the scroll set, see if it's possible to
		// set the scroll
		el[ scroll ] = 1;
		has = ( el[ scroll ] > 0 );
		el[ scroll ] = 0;
		return has;
	},
	
	// these are odd functions, fix the API or move into individual plugins
	isOverAxis: function( x, reference, size ) {
		//Determines when x coordinate is over "b" element axis
		return ( x > reference ) && ( x < ( reference + size ) );
	},
	isOver: function( y, x, top, left, height, width ) {
		//Determines when x, y coordinates is over "b" element
		return $.ui.isOverAxis( y, top, height ) && $.ui.isOverAxis( x, left, width );
	}
});

});


/* ---- Module:jQuery.ui.position ---- */

/*
 * jQuery UI Position 1.8.18
 *
 * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * http://docs.jquery.com/UI/Position
 */
jQuery.plugin( 'jQuery.ui.position', function( $, undefined ){

$.ui = $.ui || {};

var horizontalPositions = /left|center|right/,
	verticalPositions = /top|center|bottom/,
	center = "center",
	support = {},
	_position = $.fn.position,
	_offset = $.fn.offset;

$.fn.position = function( options ) {
	if ( !options || !options.of ) {
		return _position.apply( this, arguments );
	}

	// make a copy, we don't want to modify arguments
	options = $.extend( {}, options );

	var target = $( options.of ),
		targetElem = target[0],
		collision = ( options.collision || "flip" ).split( " " ),
		offset = options.offset ? options.offset.split( " " ) : [ 0, 0 ],
		targetWidth,
		targetHeight,
		basePosition;

	if ( targetElem.nodeType === 9 ) {
		targetWidth = target.width();
		targetHeight = target.height();
		basePosition = { top: 0, left: 0 };
	// TODO: use $.isWindow() in 1.9
	} else if ( targetElem.setTimeout ) {
		targetWidth = target.width();
		targetHeight = target.height();
		basePosition = { top: target.scrollTop(), left: target.scrollLeft() };
	} else if ( targetElem.preventDefault ) {
		// force left top to allow flipping
		options.at = "left top";
		targetWidth = targetHeight = 0;
		basePosition = { top: options.of.pageY, left: options.of.pageX };
	} else {
		targetWidth = target.outerWidth();
		targetHeight = target.outerHeight();
		basePosition = target.offset();
	}

	// force my and at to have valid horizontal and veritcal positions
	// if a value is missing or invalid, it will be converted to center 
	$.each( [ "my", "at" ], function() {
		var pos = ( options[this] || "" ).split( " " );
		if ( pos.length === 1) {
			pos = horizontalPositions.test( pos[0] ) ?
				pos.concat( [center] ) :
				verticalPositions.test( pos[0] ) ?
					[ center ].concat( pos ) :
					[ center, center ];
		}
		pos[ 0 ] = horizontalPositions.test( pos[0] ) ? pos[ 0 ] : center;
		pos[ 1 ] = verticalPositions.test( pos[1] ) ? pos[ 1 ] : center;
		options[ this ] = pos;
	});

	// normalize collision option
	if ( collision.length === 1 ) {
		collision[ 1 ] = collision[ 0 ];
	}

	// normalize offset option
	offset[ 0 ] = parseInt( offset[0], 10 ) || 0;
	if ( offset.length === 1 ) {
		offset[ 1 ] = offset[ 0 ];
	}
	offset[ 1 ] = parseInt( offset[1], 10 ) || 0;

	if ( options.at[0] === "right" ) {
		basePosition.left += targetWidth;
	} else if ( options.at[0] === center ) {
		basePosition.left += targetWidth / 2;
	}

	if ( options.at[1] === "bottom" ) {
		basePosition.top += targetHeight;
	} else if ( options.at[1] === center ) {
		basePosition.top += targetHeight / 2;
	}

	basePosition.left += offset[ 0 ];
	basePosition.top += offset[ 1 ];

	return this.each(function() {
		var elem = $( this ),
			elemWidth = elem.outerWidth(),
			elemHeight = elem.outerHeight(),
			marginLeft = parseInt( $.curCSS( this, "marginLeft", true ) ) || 0,
			marginTop = parseInt( $.curCSS( this, "marginTop", true ) ) || 0,
			collisionWidth = elemWidth + marginLeft +
				( parseInt( $.curCSS( this, "marginRight", true ) ) || 0 ),
			collisionHeight = elemHeight + marginTop +
				( parseInt( $.curCSS( this, "marginBottom", true ) ) || 0 ),
			position = $.extend( {}, basePosition ),
			collisionPosition;

		if ( options.my[0] === "right" ) {
			position.left -= elemWidth;
		} else if ( options.my[0] === center ) {
			position.left -= elemWidth / 2;
		}

		if ( options.my[1] === "bottom" ) {
			position.top -= elemHeight;
		} else if ( options.my[1] === center ) {
			position.top -= elemHeight / 2;
		}

		// prevent fractions if jQuery version doesn't support them (see #5280)
		if ( !support.fractions ) {
			position.left = Math.round( position.left );
			position.top = Math.round( position.top );
		}

		collisionPosition = {
			left: position.left - marginLeft,
			top: position.top - marginTop
		};

		$.each( [ "left", "top" ], function( i, dir ) {
			if ( $.ui.position[ collision[i] ] ) {
				$.ui.position[ collision[i] ][ dir ]( position, {
					targetWidth: targetWidth,
					targetHeight: targetHeight,
					elemWidth: elemWidth,
					elemHeight: elemHeight,
					collisionPosition: collisionPosition,
					collisionWidth: collisionWidth,
					collisionHeight: collisionHeight,
					offset: offset,
					my: options.my,
					at: options.at
				});
			}
		});

		if ( $.fn.bgiframe ) {
			elem.bgiframe();
		}
		elem.offset( $.extend( position, { using: options.using } ) );
	});
};

$.ui.position = {
	fit: {
		left: function( position, data ) {
			var win = $( window ),
				over = data.collisionPosition.left + data.collisionWidth - win.width() - win.scrollLeft();
			position.left = over > 0 ? position.left - over : Math.max( position.left - data.collisionPosition.left, position.left );
		},
		top: function( position, data ) {
			var win = $( window ),
				over = data.collisionPosition.top + data.collisionHeight - win.height() - win.scrollTop();
			position.top = over > 0 ? position.top - over : Math.max( position.top - data.collisionPosition.top, position.top );
		}
	},

	flip: {
		left: function( position, data ) {
			if ( data.at[0] === center ) {
				return;
			}
			var win = $( window ),
				over = data.collisionPosition.left + data.collisionWidth - win.width() - win.scrollLeft(),
				myOffset = data.my[ 0 ] === "left" ?
					-data.elemWidth :
					data.my[ 0 ] === "right" ?
						data.elemWidth :
						0,
				atOffset = data.at[ 0 ] === "left" ?
					data.targetWidth :
					-data.targetWidth,
				offset = -2 * data.offset[ 0 ];
			position.left += data.collisionPosition.left < 0 ?
				myOffset + atOffset + offset :
				over > 0 ?
					myOffset + atOffset + offset :
					0;
		},
		top: function( position, data ) {
			if ( data.at[1] === center ) {
				return;
			}
			var win = $( window ),
				over = data.collisionPosition.top + data.collisionHeight - win.height() - win.scrollTop(),
				myOffset = data.my[ 1 ] === "top" ?
					-data.elemHeight :
					data.my[ 1 ] === "bottom" ?
						data.elemHeight :
						0,
				atOffset = data.at[ 1 ] === "top" ?
					data.targetHeight :
					-data.targetHeight,
				offset = -2 * data.offset[ 1 ];
			position.top += data.collisionPosition.top < 0 ?
				myOffset + atOffset + offset :
				over > 0 ?
					myOffset + atOffset + offset :
					0;
		}
	}
};

// offset setter from jQuery 1.4
if ( !$.offset.setOffset ) {
	$.offset.setOffset = function( elem, options ) {
		// set position first, in-case top/left are set even on static elem
		if ( /static/.test( $.curCSS( elem, "position" ) ) ) {
			elem.style.position = "relative";
		}
		var curElem   = $( elem ),
			curOffset = curElem.offset(),
			curTop    = parseInt( $.curCSS( elem, "top",  true ), 10 ) || 0,
			curLeft   = parseInt( $.curCSS( elem, "left", true ), 10)  || 0,
			props     = {
				top:  (options.top  - curOffset.top)  + curTop,
				left: (options.left - curOffset.left) + curLeft
			};
		
		if ( 'using' in options ) {
			options.using.call( elem, props );
		} else {
			curElem.css( props );
		}
	};

	$.fn.offset = function( options ) {
		var elem = this[ 0 ];
		if ( !elem || !elem.ownerDocument ) { return null; }
		if ( options ) { 
			return this.each(function() {
				$.offset.setOffset( this, options );
			});
		}
		return _offset.call( this );
	};
}

// fraction support test (older versions of jQuery don't support fractions)
(function () {
	var body = document.getElementsByTagName( "body" )[ 0 ], 
		div = document.createElement( "div" ),
		testElement, testElementParent, testElementStyle, offset, offsetTotal;

	//Create a "fake body" for testing based on method used in jQuery.support
	testElement = document.createElement( body ? "div" : "body" );
	testElementStyle = {
		visibility: "hidden",
		width: 0,
		height: 0,
		border: 0,
		margin: 0,
		background: "none"
	};
	if ( body ) {
		$.extend( testElementStyle, {
			position: "absolute",
			left: "-1000px",
			top: "-1000px"
		});
	}
	for ( var i in testElementStyle ) {
		testElement.style[ i ] = testElementStyle[ i ];
	}
	testElement.appendChild( div );
	testElementParent = body || document.documentElement;
	testElementParent.insertBefore( testElement, testElementParent.firstChild );

	div.style.cssText = "position: absolute; left: 10.7432222px; top: 10.432325px; height: 30px; width: 201px;";

	offset = $( div ).offset( function( _, offset ) {
		return offset;
	}).offset();

	testElement.innerHTML = "";
	testElementParent.removeChild( testElement );

	offsetTotal = offset.top + offset.left + ( body ? 2000 : 0 );
	support.fractions = offsetTotal > 21 && offsetTotal < 22;
})();

});


/* ---- Module:jQuery.ui.mouse ---- */

/*!
 * jQuery UI Mouse 1.8.18
 *
 * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * http://docs.jquery.com/UI/Mouse
 *
 * Depends:
 *	jquery.ui.widget.js
 */

jQuery.plugin( 'jQuery.ui.mouse', 'jQuery.ui.widget', function( $, undefined ){

var mouseHandled = false;
$( document ).mouseup( function( e ) {
	mouseHandled = false;
});

$.widget("ui.mouse", {
	options: {
		cancel: ':input,option',
		distance: 1,
		delay: 0
	},
	_mouseInit: function() {
		var self = this;

		this.element
			.on('mousedown.'+this.widgetName, function(event) {
				return self._mouseDown(event);
			})
			.on('click.'+this.widgetName, function(event) {
				if (true === $.data(event.target, self.widgetName + '.preventClickEvent')) {
				    $.removeData(event.target, self.widgetName + '.preventClickEvent');
					event.stopImmediatePropagation();
					return false;
				}
			});

		this.started = false;
	},

	// TODO: make sure destroying one instance of mouse doesn't mess with
	// other instances of mouse
	_mouseDestroy: function() {
		this.element.off('.'+this.widgetName);
	},

	_mouseDown: function(event) {
		// don't let more than one widget handle mouseStart
		if( mouseHandled ) { return };

		// we may have missed mouseup (out of window)
		(this._mouseStarted && this._mouseUp(event));

		this._mouseDownEvent = event;

		var self = this,
			btnIsLeft = (event.which == 1),
			// event.target.nodeName works around a bug in IE 8 with
			// disabled inputs (#7620)
			elIsCancel = (typeof this.options.cancel == "string" && event.target.nodeName ? $(event.target).closest(this.options.cancel).length : false);
		if (!btnIsLeft || elIsCancel || !this._mouseCapture(event)) {
			return true;
		}

		this.mouseDelayMet = !this.options.delay;
		if (!this.mouseDelayMet) {
			this._mouseDelayTimer = setTimeout(function() {
				self.mouseDelayMet = true;
			}, this.options.delay);
		}

		if (this._mouseDistanceMet(event) && this._mouseDelayMet(event)) {
			this._mouseStarted = (this._mouseStart(event) !== false);
			if (!this._mouseStarted) {
				event.preventDefault();
				return true;
			}
		}

		// Click event may never have fired (Gecko & Opera)
		if (true === $.data(event.target, this.widgetName + '.preventClickEvent')) {
			$.removeData(event.target, this.widgetName + '.preventClickEvent');
		}

		// these delegates are required to keep context
		this._mouseMoveDelegate = function(event) {
			return self._mouseMove(event);
		};
		this._mouseUpDelegate = function(event) {
			return self._mouseUp(event);
		};
		$(document)
			.on('mousemove.'+this.widgetName, this._mouseMoveDelegate)
			.on('mouseup.'+this.widgetName, this._mouseUpDelegate);

		event.preventDefault();
		
		mouseHandled = true;
		return true;
	},

	_mouseMove: function(event) {
		// IE mouseup check - mouseup happened when mouse was out of window
		if ($.browser.msie && !(document.documentMode >= 9) && !event.button) {
			return this._mouseUp(event);
		}

		if (this._mouseStarted) {
			this._mouseDrag(event);
			return event.preventDefault();
		}

		if (this._mouseDistanceMet(event) && this._mouseDelayMet(event)) {
			this._mouseStarted =
				(this._mouseStart(this._mouseDownEvent, event) !== false);
			(this._mouseStarted ? this._mouseDrag(event) : this._mouseUp(event));
		}

		return !this._mouseStarted;
	},

	_mouseUp: function(event) {
		$(document)
			.off('mousemove.'+this.widgetName, this._mouseMoveDelegate)
			.off('mouseup.'+this.widgetName, this._mouseUpDelegate);

		if (this._mouseStarted) {
			this._mouseStarted = false;

			if (event.target == this._mouseDownEvent.target) {
			    $.data(event.target, this.widgetName + '.preventClickEvent', true);
			}

			this._mouseStop(event);
		}

		return false;
	},

	_mouseDistanceMet: function(event) {
		return (Math.max(
				Math.abs(this._mouseDownEvent.pageX - event.pageX),
				Math.abs(this._mouseDownEvent.pageY - event.pageY)
			) >= this.options.distance
		);
	},

	_mouseDelayMet: function(event) {
		return this.mouseDelayMet;
	},

	// These are placeholder methods, to be overriden by extending plugin
	_mouseStart: function(event) {},
	_mouseDrag: function(event) {},
	_mouseStop: function(event) {},
	_mouseCapture: function(event) { return true; }
});

});


/* ---- Module:jQuery.ui.dialog ---- */

/*
 * jQuery UI Dialog 1.8.18
 *
 * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * http://docs.jquery.com/UI/Dialog
 *
 * Depends:
 *	jquery.ui.core.js
 *	jquery.ui.widget.js
 *  jquery.ui.button.js
 *	jquery.ui.draggable.js
 *	jquery.ui.mouse.js
 *	jquery.ui.position.js
 *	jquery.ui.resizable.js
 */
jQuery.plugin( 'jQuery.ui.dialog', [
	'jQuery.ui.core',
	'jQuery.ui.widget',
//	'jQuery.ui.button',
//	'jQuery.ui.draggable',
//	'jQuery.ui.resizable',
	'jQuery.ui.mouse',
	'jQuery.ui.position'
], function( $, undefined ){

var uiDialogClasses =
		'ui-dialog ' +
		'ui-widget ' +
		'ui-widget-content ' +
		'ui-corner-all ',
	sizeRelatedOptions = {
		buttons: true,
		height: true,
		maxHeight: true,
		maxWidth: true,
		minHeight: true,
		minWidth: true,
		width: true
	},
	resizableRelatedOptions = {
		maxHeight: true,
		maxWidth: true,
		minHeight: true,
		minWidth: true
	},
	// support for jQuery 1.3.2 - handle common attrFn methods for dialog
	attrFn = $.attrFn || {
		val: true,
		css: true,
		html: true,
		text: true,
		data: true,
		width: true,
		height: true,
		offset: true,
		click: true
	};

$.widget("ui.dialog", {
	options: {
		autoOpen: true,
		buttons: {},
		closeOnEscape: true,
		closeText: 'close',
		dialogClass: '',
		draggable: true,
		hide: null,
		height: 'auto',
		maxHeight: false,
		maxWidth: false,
		minHeight: 150,
		minWidth: 150,
		modal: false,
		position: {
			my: 'center',
			at: 'center',
			collision: 'fit',
			// ensure that the titlebar is never outside the document
			using: function(pos) {
				var topOffset = $(this).css(pos).offset().top;
				if (topOffset < 0) {
					$(this).css('top', pos.top - topOffset);
				}
			}
		},
		resizable: true,
		show: null,
		stack: true,
		title: '',
		width: 300,
		zIndex: 1000
	},

	_create: function() {
		this.originalTitle = this.element.attr('title');
		// #5742 - .attr() might return a DOMElement
		if ( typeof this.originalTitle !== "string" ) {
			this.originalTitle = "";
		}

		this.options.title = this.options.title || this.originalTitle;
		var self = this,
			options = self.options,

			title = options.title || '&#160;',
			titleId = $.ui.dialog.getTitleId(self.element),

			uiDialog = (self.uiDialog = $('<div></div>'))
				.appendTo(document.body)
				.hide()
				.addClass(uiDialogClasses + options.dialogClass)
				.css({
					zIndex: options.zIndex
				})
				// setting tabIndex makes the div focusable
				// setting outline to 0 prevents a border on focus in Mozilla
				.attr('tabIndex', -1).css('outline', 0).keydown(function(event) {
					if (options.closeOnEscape && !event.isDefaultPrevented() && event.keyCode &&
						event.keyCode === $.ui.keyCode.ESCAPE) {
						
						self.close(event);
						event.preventDefault();
					}
				})
				.attr({
					role: 'dialog',
					'aria-labelledby': titleId
				})
				.mousedown(function(event) {
					self.moveToTop(false, event);
				}),

			uiDialogContent = self.element
				.show()
				.removeAttr('title')
				.addClass(
					'ui-dialog-content ' +
					'ui-widget-content')
				.appendTo(uiDialog),

			uiDialogTitlebar = (self.uiDialogTitlebar = $('<div></div>'))
				.addClass(
					'ui-dialog-titlebar ' +
					'ui-widget-header ' +
					'ui-corner-all ' +
					'ui-helper-clearfix'
				)
				.prependTo(uiDialog),

			uiDialogTitlebarClose = $('<a href="#"></a>')
				.addClass(
					'ui-dialog-titlebar-close ' +
					'ui-corner-all'
				)
				.attr('role', 'button')
				.hover(
					function() {
						uiDialogTitlebarClose.addClass('ui-state-hover');
					},
					function() {
						uiDialogTitlebarClose.removeClass('ui-state-hover');
					}
				)
				.focus(function() {
					uiDialogTitlebarClose.addClass('ui-state-focus');
				})
				.blur(function() {
					uiDialogTitlebarClose.removeClass('ui-state-focus');
				})
				.click(function(event) {
					self.close(event);
					return false;
				})
				.appendTo(uiDialogTitlebar),

			uiDialogTitlebarCloseText = (self.uiDialogTitlebarCloseText = $('<span></span>'))
				.addClass(
					'ui-icon ' +
					'ui-icon-closethick'
				)
				.text(options.closeText)
				.appendTo(uiDialogTitlebarClose),

			uiDialogTitle = $('<span></span>')
				.addClass('ui-dialog-title')
				.attr('id', titleId)
				.html(title)
				.prependTo(uiDialogTitlebar);

		//handling of deprecated beforeclose (vs beforeClose) option
		//Ticket #4669 http://dev.jqueryui.com/ticket/4669
		//TODO: remove in 1.9pre
		if ($.isFunction(options.beforeclose) && !$.isFunction(options.beforeClose)) {
			options.beforeClose = options.beforeclose;
		}

		uiDialogTitlebar.find("*").add(uiDialogTitlebar).disableSelection();

		if (options.draggable && $.fn.draggable) {
			self._makeDraggable();
		}
		if (options.resizable && $.fn.resizable) {
			self._makeResizable();
		}

		self._createButtons(options.buttons);
		self._isOpen = false;

		if ($.fn.bgiframe) {
			uiDialog.bgiframe();
		}
	},

	_init: function() {
		if ( this.options.autoOpen ) {
			this.open();
		}
	},

	destroy: function() {
		var self = this;
		
		if (self.overlay) {
			self.overlay.destroy();
		}
		self.uiDialog.hide();
		self.element
			.off('.dialog')
			.removeData('dialog')
			.removeClass('ui-dialog-content ui-widget-content')
			.hide().appendTo('body');
		self.uiDialog.remove();

		if (self.originalTitle) {
			self.element.attr('title', self.originalTitle);
		}

		return self;
	},

	widget: function() {
		return this.uiDialog;
	},

	close: function(event) {
		var self = this,
			maxZ, thisZ;
		
		if (false === self._trigger('beforeClose', event)) {
			return;
		}

		if (self.overlay) {
			self.overlay.destroy();
		}
		self.uiDialog.off('keypress.ui-dialog');

		self._isOpen = false;

		if (self.options.hide) {
			self.uiDialog.hide(self.options.hide, function() {
				self._trigger('close', event);
			});
		} else {
			self.uiDialog.hide();
			self._trigger('close', event);
		}

		$.ui.dialog.overlay.resize();

		// adjust the maxZ to allow other modal dialogs to continue to work (see #4309)
		if (self.options.modal) {
			maxZ = 0;
			$('.ui-dialog').each(function() {
				if (this !== self.uiDialog[0]) {
					thisZ = $(this).css('z-index');
					if(!isNaN(thisZ)) {
						maxZ = Math.max(maxZ, thisZ);
					}
				}
			});
			$.ui.dialog.maxZ = maxZ;
		}

		return self;
	},

	isOpen: function() {
		return this._isOpen;
	},

	// the force parameter allows us to move modal dialogs to their correct
	// position on open
	moveToTop: function(force, event) {
		var self = this,
			options = self.options,
			saveScroll;

		if ((options.modal && !force) ||
			(!options.stack && !options.modal)) {
			return self._trigger('focus', event);
		}

		if (options.zIndex > $.ui.dialog.maxZ) {
			$.ui.dialog.maxZ = options.zIndex;
		}
		if (self.overlay) {
			$.ui.dialog.maxZ += 1;
			self.overlay.$el.css('z-index', $.ui.dialog.overlay.maxZ = $.ui.dialog.maxZ);
		}

		//Save and then restore scroll since Opera 9.5+ resets when parent z-Index is changed.
		//  http://ui.jquery.com/bugs/ticket/3193
		saveScroll = { scrollTop: self.element.scrollTop(), scrollLeft: self.element.scrollLeft() };
		$.ui.dialog.maxZ += 1;
		self.uiDialog.css('z-index', $.ui.dialog.maxZ);
		self.element.attr(saveScroll);
		self._trigger('focus', event);

		return self;
	},

	open: function() {
		if (this._isOpen) { return; }

		var self = this,
			options = self.options,
			uiDialog = self.uiDialog;

		self.overlay = options.modal ? new $.ui.dialog.overlay(self) : null;
		self._size();
		self._position(options.position);
		uiDialog.show(options.show);
		self.moveToTop(true);

		// prevent tabbing out of modal dialogs
		if ( options.modal ) {
			uiDialog.on( "keydown.ui-dialog", function( event ) {
				if ( event.keyCode !== $.ui.keyCode.TAB ) {
					return;
				}

				var tabbables = $(':tabbable', this),
					first = tabbables.filter(':first'),
					last  = tabbables.filter(':last');

				if (event.target === last[0] && !event.shiftKey) {
					first.focus(1);
					return false;
				} else if (event.target === first[0] && event.shiftKey) {
					last.focus(1);
					return false;
				}
			});
		}

		// set focus to the first tabbable element in the content area or the first button
		// if there are no tabbable elements, set focus on the dialog itself
		$(self.element.find(':tabbable').get().concat(
			uiDialog.find('.ui-dialog-buttonpane :tabbable').get().concat(
				uiDialog.get()))).eq(0).focus();

		self._isOpen = true;
		self._trigger('open');

		return self;
	},

	_createButtons: function(buttons) {
		var self = this,
			hasButtons = false,
			uiDialogButtonPane = $('<div></div>')
				.addClass(
					'ui-dialog-buttonpane ' +
					'ui-widget-content ' +
					'ui-helper-clearfix'
				),
			uiButtonSet = $( "<div></div>" )
				.addClass( "ui-dialog-buttonset" )
				.appendTo( uiDialogButtonPane );

		// if we already have a button pane, remove it
		self.uiDialog.find('.ui-dialog-buttonpane').remove();

		if (typeof buttons === 'object' && buttons !== null) {
			$.each(buttons, function() {
				return !(hasButtons = true);
			});
		}
		if (hasButtons) {
			$.each(buttons, function(name, props) {
				props = $.isFunction( props ) ?
					{ click: props, text: name } :
					props;
				var button = $('<button type="button"></button>')
					.click(function() {
						props.click.apply(self.element[0], arguments);
					})
					.appendTo(uiButtonSet);
				// can't use .attr( props, true ) with jQuery 1.3.2.
				$.each( props, function( key, value ) {
					if ( key === "click" ) {
						return;
					}
					if ( key in attrFn ) {
						button[ key ]( value );
					} else {
						button.attr( key, value );
					}
				});
				if ($.fn.button) {
					button.button();
				}
			});
			uiDialogButtonPane.appendTo(self.uiDialog);
		}
	},

	_makeDraggable: function() {
		var self = this,
			options = self.options,
			doc = $(document),
			heightBeforeDrag;

		function filteredUi(ui) {
			return {
				position: ui.position,
				offset: ui.offset
			};
		}

		self.uiDialog.draggable({
			cancel: '.ui-dialog-content, .ui-dialog-titlebar-close',
			handle: '.ui-dialog-titlebar',
			containment: 'document',
			start: function(event, ui) {
				heightBeforeDrag = options.height === "auto" ? "auto" : $(this).height();
				$(this).height($(this).height()).addClass("ui-dialog-dragging");
				self._trigger('dragStart', event, filteredUi(ui));
			},
			drag: function(event, ui) {
				self._trigger('drag', event, filteredUi(ui));
			},
			stop: function(event, ui) {
				options.position = [ui.position.left - doc.scrollLeft(),
					ui.position.top - doc.scrollTop()];
				$(this).removeClass("ui-dialog-dragging").height(heightBeforeDrag);
				self._trigger('dragStop', event, filteredUi(ui));
				$.ui.dialog.overlay.resize();
			}
		});
	},

	_makeResizable: function(handles) {
		handles = (handles === undefined ? this.options.resizable : handles);
		var self = this,
			options = self.options,
			// .ui-resizable has position: relative defined in the stylesheet
			// but dialogs have to use absolute or fixed positioning
			position = self.uiDialog.css('position'),
			resizeHandles = (typeof handles === 'string' ?
				handles	:
				'n,e,s,w,se,sw,ne,nw'
			);

		function filteredUi(ui) {
			return {
				originalPosition: ui.originalPosition,
				originalSize: ui.originalSize,
				position: ui.position,
				size: ui.size
			};
		}

		self.uiDialog.resizable({
			cancel: '.ui-dialog-content',
			containment: 'document',
			alsoResize: self.element,
			maxWidth: options.maxWidth,
			maxHeight: options.maxHeight,
			minWidth: options.minWidth,
			minHeight: self._minHeight(),
			handles: resizeHandles,
			start: function(event, ui) {
				$(this).addClass("ui-dialog-resizing");
				self._trigger('resizeStart', event, filteredUi(ui));
			},
			resize: function(event, ui) {
				self._trigger('resize', event, filteredUi(ui));
			},
			stop: function(event, ui) {
				$(this).removeClass("ui-dialog-resizing");
				options.height = $(this).height();
				options.width = $(this).width();
				self._trigger('resizeStop', event, filteredUi(ui));
				$.ui.dialog.overlay.resize();
			}
		})
		.css('position', position)
		.find('.ui-resizable-se').addClass('ui-icon ui-icon-grip-diagonal-se');
	},

	_minHeight: function() {
		var options = this.options;

		if (options.height === 'auto') {
			return options.minHeight;
		} else {
			return Math.min(options.minHeight, options.height);
		}
	},

	_position: function(position) {
		var myAt = [],
			offset = [0, 0],
			isVisible;

		if (position) {
			// deep extending converts arrays to objects in jQuery <= 1.3.2 :-(
	//		if (typeof position == 'string' || $.isArray(position)) {
	//			myAt = $.isArray(position) ? position : position.split(' ');

			if (typeof position === 'string' || (typeof position === 'object' && '0' in position)) {
				myAt = position.split ? position.split(' ') : [position[0], position[1]];
				if (myAt.length === 1) {
					myAt[1] = myAt[0];
				}

				$.each(['left', 'top'], function(i, offsetPosition) {
					if (+myAt[i] === myAt[i]) {
						offset[i] = myAt[i];
						myAt[i] = offsetPosition;
					}
				});

				position = {
					my: myAt.join(" "),
					at: myAt.join(" "),
					offset: offset.join(" ")
				};
			} 

			position = $.extend({}, $.ui.dialog.prototype.options.position, position);
		} else {
			position = $.ui.dialog.prototype.options.position;
		}

		// need to show the dialog to get the actual offset in the position plugin
		isVisible = this.uiDialog.is(':visible');
		if (!isVisible) {
			this.uiDialog.show();
		}
		this.uiDialog
			// workaround for jQuery bug #5781 http://dev.jquery.com/ticket/5781
			.css({ top: 0, left: 0 })
			.position($.extend({ of: window }, position));
		if (!isVisible) {
			this.uiDialog.hide();
		}
	},

	_setOptions: function( options ) {
		var self = this,
			resizableOptions = {},
			resize = false;

		$.each( options, function( key, value ) {
			self._setOption( key, value );
			
			if ( key in sizeRelatedOptions ) {
				resize = true;
			}
			if ( key in resizableRelatedOptions ) {
				resizableOptions[ key ] = value;
			}
		});

		if ( resize ) {
			this._size();
		}
		if ( this.uiDialog.is( ":data(resizable)" ) ) {
			this.uiDialog.resizable( "option", resizableOptions );
		}
	},

	_setOption: function(key, value){
		var self = this,
			uiDialog = self.uiDialog;

		switch (key) {
			//handling of deprecated beforeclose (vs beforeClose) option
			//Ticket #4669 http://dev.jqueryui.com/ticket/4669
			//TODO: remove in 1.9pre
			case "beforeclose":
				key = "beforeClose";
				break;
			case "buttons":
				self._createButtons(value);
				break;
			case "closeText":
				// ensure that we always pass a string
				self.uiDialogTitlebarCloseText.text("" + value);
				break;
			case "dialogClass":
				uiDialog
					.removeClass(self.options.dialogClass)
					.addClass(uiDialogClasses + value);
				break;
			case "disabled":
				if (value) {
					uiDialog.addClass('ui-dialog-disabled');
				} else {
					uiDialog.removeClass('ui-dialog-disabled');
				}
				break;
			case "draggable":
				var isDraggable = uiDialog.is( ":data(draggable)" );
				if ( isDraggable && !value ) {
					uiDialog.draggable( "destroy" );
				}
				
				if ( !isDraggable && value ) {
					self._makeDraggable();
				}
				break;
			case "position":
				self._position(value);
				break;
			case "resizable":
				// currently resizable, becoming non-resizable
				var isResizable = uiDialog.is( ":data(resizable)" );
				if (isResizable && !value) {
					uiDialog.resizable('destroy');
				}

				// currently resizable, changing handles
				if (isResizable && typeof value === 'string') {
					uiDialog.resizable('option', 'handles', value);
				}

				// currently non-resizable, becoming resizable
				if (!isResizable && value !== false) {
					self._makeResizable(value);
				}
				break;
			case "title":
				// convert whatever was passed in o a string, for html() to not throw up
				$(".ui-dialog-title", self.uiDialogTitlebar).html("" + (value || '&#160;'));
				break;
		}

		$.Widget.prototype._setOption.apply(self, arguments);
	},

	_size: function() {
		/* If the user has resized the dialog, the .ui-dialog and .ui-dialog-content
		 * divs will both have width and height set, so we need to reset them
		 */
		var options = this.options,
			nonContentHeight,
			minContentHeight,
			isVisible = this.uiDialog.is( ":visible" );

		// reset content sizing
		this.element.show().css({
			width: 'auto',
			minHeight: 0,
			height: 0
		});

		if (options.minWidth > options.width) {
			options.width = options.minWidth;
		}

		// reset wrapper sizing
		// determine the height of all the non-content elements
		nonContentHeight = this.uiDialog.css({
				height: 'auto',
				width: options.width
			})
			.height();
		minContentHeight = Math.max( 0, options.minHeight - nonContentHeight );
		
		if ( options.height === "auto" ) {
			// only needed for IE6 support
			if ( $.support.minHeight ) {
				this.element.css({
					minHeight: minContentHeight,
					height: "auto"
				});
			} else {
				this.uiDialog.show();
				var autoHeight = this.element.css( "height", "auto" ).height();
				if ( !isVisible ) {
					this.uiDialog.hide();
				}
				this.element.height( Math.max( autoHeight, minContentHeight ) );
			}
		} else {
			this.element.height( Math.max( options.height - nonContentHeight, 0 ) );
		}

		if (this.uiDialog.is(':data(resizable)')) {
			this.uiDialog.resizable('option', 'minHeight', this._minHeight());
		}
	}
});

$.extend($.ui.dialog, {
	version: "1.8.18",

	uuid: 0,
	maxZ: 0,

	getTitleId: function($el) {
		var id = $el.attr('id');
		if (!id) {
			this.uuid += 1;
			id = this.uuid;
		}
		return 'ui-dialog-title-' + id;
	},

	overlay: function(dialog) {
		this.$el = $.ui.dialog.overlay.create(dialog);
	}
});

$.extend($.ui.dialog.overlay, {
	instances: [],
	// reuse old instances due to IE memory leak with alpha transparency (see #5185)
	oldInstances: [],
	maxZ: 0,
	events: $.map('focus,mousedown,mouseup,keydown,keypress,click'.split(','),
		function(event) { return event + '.dialog-overlay'; }).join(' '),
	create: function(dialog) {
		if (this.instances.length === 0) {
			// prevent use of anchors and inputs
			// we use a setTimeout in case the overlay is created from an
			// event that we're going to be cancelling (see #2804)
			setTimeout(function() {
				// handle $(el).dialog().dialog('close') (see #4065)
				if ($.ui.dialog.overlay.instances.length) {
					$(document).on($.ui.dialog.overlay.events, function(event) {
						// stop events if the z-index of the target is < the z-index of the overlay
						// we cannot return true when we don't want to cancel the event (#3523)
						if ($(event.target).zIndex() < $.ui.dialog.overlay.maxZ) {
							return false;
						}
					});
				}
			}, 1);

			// allow closing by pressing the escape key
			$(document).on('keydown.dialog-overlay', function(event) {
				if (dialog.options.closeOnEscape && !event.isDefaultPrevented() && event.keyCode &&
					event.keyCode === $.ui.keyCode.ESCAPE) {
					
					dialog.close(event);
					event.preventDefault();
				}
			});

			// handle window resize
			$(window).on('resize.dialog-overlay', $.ui.dialog.overlay.resize);
		}

		var $el = (this.oldInstances.pop() || $('<div></div>').addClass('ui-widget-overlay'))
			.appendTo(document.body)
			.css({
				width: this.width(),
				height: this.height()
			});

		if ($.fn.bgiframe) {
			$el.bgiframe();
		}

		this.instances.push($el);
		return $el;
	},

	destroy: function($el) {
		var indexOf = $.inArray($el, this.instances);
		if (indexOf != -1){
			this.oldInstances.push(this.instances.splice(indexOf, 1)[0]);
		}

		if (this.instances.length === 0) {
			$([document, window]).off('.dialog-overlay');
		}

		$el.remove();
		
		// adjust the maxZ to allow other modal dialogs to continue to work (see #4309)
		var maxZ = 0;
		$.each(this.instances, function() {
			maxZ = Math.max(maxZ, this.css('z-index'));
		});
		this.maxZ = maxZ;
	},

	height: function() {
		var scrollHeight,
			offsetHeight;
		// handle IE 6
		if ($.browser.msie && $.browser.version < 7) {
			scrollHeight = Math.max(
				document.documentElement.scrollHeight,
				document.body.scrollHeight
			);
			offsetHeight = Math.max(
				document.documentElement.offsetHeight,
				document.body.offsetHeight
			);

			if (scrollHeight < offsetHeight) {
				return $(window).height() + 'px';
			} else {
				return scrollHeight + 'px';
			}
		// handle "good" browsers
		} else {
			return $(document).height() + 'px';
		}
	},

	width: function() {
		var scrollWidth,
			offsetWidth;
		// handle IE
		if ( $.browser.msie ) {
			scrollWidth = Math.max(
				document.documentElement.scrollWidth,
				document.body.scrollWidth
			);
			offsetWidth = Math.max(
				document.documentElement.offsetWidth,
				document.body.offsetWidth
			);

			if (scrollWidth < offsetWidth) {
				return $(window).width() + 'px';
			} else {
				return scrollWidth + 'px';
			}
		// handle "good" browsers
		} else {
			return $(document).width() + 'px';
		}
	},

	resize: function() {
		/* If the dialog is draggable and the user drags it past the
		 * right edge of the window, the document becomes wider so we
		 * need to stretch the overlay. If the user then drags the
		 * dialog back to the left, the document will become narrower,
		 * so we need to shrink the overlay to the appropriate size.
		 * This is handled by shrinking the overlay before setting it
		 * to the full document size.
		 */
		var $overlays = $([]);
		$.each($.ui.dialog.overlay.instances, function() {
			$overlays = $overlays.add(this);
		});

		$overlays.css({
			width: 0,
			height: 0
		}).css({
			width: $.ui.dialog.overlay.width(),
			height: $.ui.dialog.overlay.height()
		});
	}
});

$.extend($.ui.dialog.overlay.prototype, {
	destroy: function() {
		$.ui.dialog.overlay.destroy(this.$el);
	}
});

});


/* ---- Module:ep.ui.dialog ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.ui.dialog
 *
 * @revision		$Revision: 1.15.16.3 $
 */

jQuery.plugin( 'ep.ui.dialog', [ 'ep.core', 'ep.ui.form', 'ep.ui.input', 'jQuery.ui.dialog'], function( $, undefined ){

	$.widget('ep.ui.Dialog',$.ui.dialog,{

		options: {
			resizable:	'se',
			zIndex:		20000
		},

		_create: function(){
			this.Inherited(arguments);

			var self = this,
				o = self.options;

			if( o.form ){
				self._createForm(o.form);
			}

			self.uiDialog
				.removeClass('ui-corner-all')
				.addClass('epDialog');
			self.uiDialogTitlebar
				.removeClass('ui-corner-all')
				.addClass('epDialogTitleBar');

			self._setOption( "closeText", o.closeText );
		},

		_setOption: function( key, value ){
			var self = this;

			switch (key) {
				case 'form':
					if( !self.uiForm ){
						self._createForm(value);
					}
					else{
						self.uiForm.uiForm(value);
					}
				break;
				case 'title':
					$(".ui-dialog-title", self.uiDialogTitlebar)
						.empty()
						.append( self.options.title = (value || '&#160;') );
				break;
				case 'closeText':
					self.uiDialogTitlebar.find(".ui-dialog-titlebar-close").toggle(value !== false);
					value = value === true ? "close" : (value || "");
				default:
					self.Inherited(arguments);
				break;
			}
		},

		_createForm: function( form ){
			this.uiForm = this.options.form = ep('<form>')
				.attr(this.options.form)
				.insertBefore(this.uiDialog)
				.append(this.uiDialog)
				.uiForm();
		},

		_createButtons: function( buttons ) {
			var self = this,
				hasButtons = false,
				uiDialogButtonPane = $('<div>')
					.addClass(
						'ui-dialog-buttonpane ' +
						'ui-widget-content ' +
						'ui-helper-clearfix ' +
						'epDialogButtonBar'
					),
				uiButtonSet = $( "<div>" )
					.addClass( "ui-dialog-buttonset" )
					.appendTo( uiDialogButtonPane );

			// if we already have a button pane, remove it
			self.uiDialog.find('.ui-dialog-buttonpane').remove();

			if( typeof buttons === 'object' && buttons !== null ){
				$.each(buttons, function() {
					return !(hasButtons = true);
				});
			}
			if( hasButtons ){
				$.each(buttons, function(name, props) {
					props = $.extend({
						'type':		'button',
						'text':		name,
						'click':	function(){}
					}, $.isFunction( props ) ? { click: props, text: name } : props );

					// type cann't set with .attr()
					var type = props.type;
					delete(props.type);

					buttons[name] = ep('<button type="'+type+'">')
						.attr( props, true )
						.off('click')
						.appendTo(uiButtonSet)
						.uiInput()
						.on( 'click', function(){
							props.click.apply(self.element[0], arguments);
						});
				});
				uiDialogButtonPane.appendTo(self.uiDialog);
			}
		},

		open: function(){
			this.options.modal && $('body').css('overflow', 'hidden');
			this.Inherited(arguments);
		},

		close: function(){
			this.options.modal && $('body').css('overflow', 'auto');
			this.Inherited(arguments);
		},

		destroy: function(){
			this.Inherited(arguments);

			if( this.uiForm ){
				this.uiForm.remove();
			}
		}

	});

 var overlayCreate = $.ui.dialog.overlay.create;

 $.ui.dialog.overlay.create = function( dialog ){
  var length = this.instances.length,
   ret = overlayCreate.apply( this, arguments );

  if( length === 0 ){
   // allow closing by click the overlay
   $(document).on('click.dialog-overlay', function(event) {
    if( dialog.options.closeOnClickOut && event.originalTarget == dialog.overlay.$el[0] ){
     dialog.close(event);
     event.preventDefault();
    }
   });
  }
  return ret;
 };

});

/* ---- Module:ep.alert ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.alert
 *
 * @revision		$Revision: 1.11 $
 */

jQuery.plugin( 'ep.alert', ['ep.core','ep.ui.dialog','ep.sprite'], function( $, undefined ){

	/*
	 * @dictionary		ep.dict
	 *
	 * @translation		{Notification}
	 *					{Ok}
	 *					{Cancel}
	 */

	ep.extend({
		alert: function( settings ){
			settings = $.extend( {}, ep.alertSettings, settings );

			var dict = ep.dict('ep.dict'),
				dialog = ep('<div>')
					.addClass('ep-uiDialog-alert')
					.append( ep.sprite( 'ico_'+settings.size+'_'+settings.type, settings.size ) )
					.append( '<span class="dialog-content">'+settings.content+'</span>' ),
				options = {
					title:		dict.parse(settings.title),
					modal:		true,
					resizable:	false,
					minWidth:	350,
					buttons:	{},
					close:		function( event ){
						if( settings.close ){
							settings.close(event);
						}
						var originalEvent = event.originalEvent,
							originalTarget = originalEvent ? originalEvent.originalTarget : event.originalTarget,
							buttons = ep(this).uiDialog('option','buttons');

						if( settings.ok && buttons.ok && originalTarget===buttons.ok[0] ){
							settings.ok(event);
						}
						else if( settings.cancel ){
							settings.cancel(event);
						}
					}
				};

			$.each( ['Ok', 'Cancel'], function( i, Name ){
				var name = Name.toLowerCase();
				var buttonName = settings[ name + 'Title' ];
				if( settings[ name ] ){
					options.buttons[ name ] = {
						text:	buttonName ? buttonName : dict.translate( Name ),
						click:	function( event ){
							event.originalTarget = event.target;
							ep(this).uiDialog('close',event);
						}
					};
				}
			});

			return dialog.uiDialog(options);
		},
		alertSettings: {
			title:		'{Notification}',
			type:		'notification',
			size:		'xl',
			content:	'',
			ok:			null,
			cancel:		null,
			close:		null
		}
	});

});


/* ---- Module:de_epages.product.ui.appointmentpicker ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			de_epages.product.ui.appointmentpicker
 *
 * @revision		$Revision: 1.18.2.1 $
 */

jQuery.plugin( 'de_epages.product.ui.appointmentpicker', {
	plugin:	['de_epages.core', 'ep.ui.datepicker', 'ep.alert', 'ep.ajax', 'ep.dict'],
	dict:	'de_epages.product.dictionary'
}, function( $, undefined ){

/*
 * @dictionary		de_epages.product.dictionary
 *
 * @translation		{Loading}
 *					{BookedUp}
					{CALENDAR_DATA_NOT_LOAD}
 */

 	var dict			= ep.dict('de_epages.product.dictionary'),
 		tLoading		= dict.translate('Loading')+'...',
 		tBookedOut		= dict.translate('BookedUp'),
 		tDataNotLoad	= dict.translate('CALENDAR_DATA_NOT_LOAD');

	$.widget('de_epages.product.ui.Appointmentpicker',ep.ui.Datepicker,{

		options: {
	// ep.ui.Input
		//	big:				true,
		//	autofocus:			false,
		//	placeholder:		'text',

	// ep.ui.Validate
		//	accept:				'',
		//	min:				1,
		//	max:				20,
		//	minlength:			1,
		//	maxlength:			4,
		//	pattern:			[\w]+,
		//	required:			true,
		//	tooltipOffset:		[0,-7],
		//	valid:				true,
		//	type:				'basic',
		//	format:				'',

	// ep.ui.Datepicker
		//	type:				'date',
		//	format:				'l',
		//	showOn:				'both',
		//	duration:			'normal',
		//	show:				'fadeIn',
		//	hide:				'fadeOut',
		//	weekDaysAvailable:	[0,0,1,1,1,1,1],
		//	numberOfMonths:		1,
		//	showOtherMonth:		true,
		//	selectOtherMonth:	false,
		//	changeMonth:		true,
		//	changeYear:			true,
		//	positionAdjust:		[-1,2],
		//	region:				ep.config.region,
		//	time:				true,
		//	timeStep:			15,

	//	ep.ui.DatepickerApp
			time:				true,
			currentDate: undefined,
			appointment: {							// hash to perform appointment available
				id:					0,
				quantityMin:		1,
				quantityRequested:	1,
				quantityAvailable:	1,
				minutesRequested:	60
			}
		},

		_create: function(){
			this.Inherited();
			this._appointmentSort = {};
			this._appointmentStack = {};

			this._loadDayList( this._date.clone().addDate(-7), true );
		},

		_createTimeSelect: function(){
			this.timeSelect = ep('<select>')
				.attr({
					'class': 'epWidth100'
				})
				.appendTo( this.timeBar )
				.uiInput()
				.uiInput('addClass','ep-uiDatepicker-time')
				.on( 'changeValue.uiAppointmentpicker', this.Proxy('_changeTimeVal') );

			this.stack.push( this.timeSelect[0]	);
		},

		_createCalendars: function(){
			this.Inherited(arguments);
			this._createTimeSelectData();
		},

		_calendarData: function(){
			var self			= this,
				o				= this.options,
				opt				= o.appointment,
				calendarsData	= this.Inherited(arguments),
				appData			= $.scope( opt.minutesRequested+'', this._appointmentStack ),
				load			= false;

			$.each( calendarsData, function( i, calendarData ){
				$.each( calendarData.days, function( j, day ){
					if( this.clickable ){
						var date = day.date,
							dateString = date.getFormat('S'),
							dayObj = appData[ dateString ];

						if( !dayObj && !load ){
							appData	= self._loadDayList( date.clone() );
							dayObj = appData[ dateString ];
							load = true;
						}

						this.clickable = !!(dayObj && dayObj.IsAvailable);
					}
				});
			});

			return calendarsData;
		},

		_createTimeSelectData: function(){
			var self			= this,
				opt				= this.options.appointment,
				dateString		= this._dateSelected.getFormat('S'),
				appStack		= $.scope(  opt.minutesRequested+'', this._appointmentStack ),
				dayObj			= appStack[ dateString ],
				placeholder		= $('<option/>')
					.attr('disabled', true)
					.text(tLoading);


			self.timeSelect
				.empty()
				.append(placeholder);

			if( dayObj ){
				// load TimeList for selected day if not cached
				if( !dayObj.DayList ){
					self._loadTimeList(self._dateSelected);
					return;
				}

				var region		= {region: self.options.region};

				// add TimeList to select field
				if( dayObj.DayList && dayObj.DayList.length ){
					self.timeSelect.empty();
					$.each( dayObj.DayList, function( i, data ){
						if( (opt.quantityAvailable-data[1]) >= opt.quantityRequested ){
							var date = new ep.Date(data[0]);
							$('<option>')
								.attr( 'value', date.setFullYear(0,0,0).getTime() )
								.text( date.getFormat( 't', region ) )
								.appendTo( self.timeSelect );
						}
					});
				}
				// show times are booked out
				else{
					placeholder.text(tBookedOut);
				}

			}
			else{
				placeholder.text(tBookedOut);
				self.elem.trigger('focus');
			}

			self._setTimeVal();
		},

		_setTimeVal: function(){
			var self			= this,
				selectedTime	= this._timeSelected.getTime()+'',
				selectedNode,
				selectedIndex;

			$.each( this.timeSelect[0].options, function( i, node ){
				if( node.value === selectedTime ){
					node.selected = true;
					selectedNode = node;
					selectedIndex = i;
					return false;
				}
			});

			if( !selectedNode ){
				selectedNode = $(this.timeSelect[0].options).not(':disabled').get(0);
				if( selectedNode ){
					selectedNode.selected = true;
					selectedTime = selectedNode.value;
					selectedIndex = 0;
				}
			}

			if( selectedTime ){
				this._timeSelected = new ep.Date(selectedTime);
			}

			if( !this.elem.is(':focus') ){
				this._setElemVal(true);
			}
		},

		_getTimeVal: function(){
			var opt = this.timeSelect[0].selectedIndex >= 0 ?
						this.timeSelect[0].options[ this.timeSelect[0].selectedIndex ] :
						null,
				date = opt ? new ep.Date(opt.value) : new ep.Date();
			return date.setFullYear(0,0,0);
		},
		// attention the date object will be modified, be sure to use an cloned date object
		_loadDayList: function( date, preload ){
			var self		= this,
				o			= this.options,
				opt			= o.appointment,
				dateStart	= date,
				dateEnd		= dateStart.clone().addMonth( o.numberOfMonths + 2 ),
				ret;


			ep.ajax({
				data: {
					'ViewAction':		'JSON-AppointmentCalendar',
					'ObjectID':			opt.id,
					'StartDate':		dateStart.getFormat('S'),
					'EndDate':			dateEnd.getFormat('S'),
					'RequestedMinutes':	opt.minutesRequested,
					'Available':		opt.quantityAvailable,
					'UseTimestamps':	1,
					'IsAvailableOnly':	1
				},
				async: !!preload,
				dataType: 'json'
			})
			.done(function( data ){
				ret = data;
			})
			.fail(function( xhr, status, error ){
				if( !preload ){
					self.hide();
					ep.alert({
						type:		'error',
						content:	tDataNotLoad
					});
				}
			});

			ret = $.extend( true, $.scope( opt.minutesRequested+'', this._appointmentStack ), ret );
			return ret;
		},

		// attention the date object will be modified, be sure to use an cloned date object
		_loadTimeList: function( date ){
			var self		= this,
				o			= this.options,
				opt			= o.appointment,
				dateStart	= date,
				dateEnd		= dateStart.clone().addDate(1),
				ret;

			ep.ajax({
				data: {
					'ViewAction':		'JSON-AppointmentCalendar',
					'ObjectID':			opt.id,
					'StartDate':		dateStart.getFormat('S'),
					'EndDate':			dateEnd.getFormat('S'),
					'RequestedMinutes':	opt.minutesRequested,
					'Available':		opt.quantityAvailable,
					'UseTimestamps':	1
				},
			//	async:		false,
				dataType:	'json'
			})
			.done(function( data ){
				ret = $.extend( true, $.scope( opt.minutesRequested+'', self._appointmentStack ), data );

				self._createTimeSelectData();
			})
			.fail(function( xhr, status, error ){
				self.hide();
				ep.alert({
					type:		'error',
					content:	tDataNotLoad
				});
			});
		},

		updateAppointment: function( options ){
			$.extend( this.options.appointment, options );
			// preload data
			// this._loadDayList( this._date.clone().addDate(-7), true );
		}
	});
});
