

/* ---- Module:jQuery.core ---- */

/*!
 * jQuery JavaScript Library v1.7.2
 * http://jquery.com/
 *
 * Copyright 2011, John Resig
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * Includes Sizzle.js
 * http://sizzlejs.com/
 * Copyright 2011, The Dojo Foundation
 * Released under the MIT, BSD, and GPL Licenses.
 *
 * Date: Wed Mar 21 12:46:34 2012 -0700
 */
(function( window, undefined ) {

// Use the correct document accordingly with window argument (sandbox)
var document = window.document,
	navigator = window.navigator,
	location = window.location;
var jQuery = (function() {

// Define a local copy of jQuery
var jQuery = function( selector, context ) {
		// The jQuery object is actually just the init constructor 'enhanced'
		return new jQuery.fn.init( selector, context, rootjQuery );
	},

	// Map over jQuery in case of overwrite
	_jQuery = window.jQuery,

	// Map over the $ in case of overwrite
	_$ = window.$,

	// A central reference to the root jQuery(document)
	rootjQuery,

	// A simple way to check for HTML strings or ID strings
	// Prioritize #id over <tag> to avoid XSS via location.hash (#9521)
	quickExpr = /^(?:[^#<]*(<[\w\W]+>)[^>]*$|#([\w\-]*)$)/,

	// Check if a string has a non-whitespace character in it
	rnotwhite = /\S/,

	// Used for trimming whitespace
	trimLeft = /^\s+/,
	trimRight = /\s+$/,

	// Match a standalone tag
	rsingleTag = /^<(\w+)\s*\/?>(?:<\/\1>)?$/,

	// JSON RegExp
	rvalidchars = /^[\],:{}\s]*$/,
	rvalidescape = /\\(?:["\\\/bfnrt]|u[0-9a-fA-F]{4})/g,
	rvalidtokens = /"[^"\\\n\r]*"|true|false|null|-?\d+(?:\.\d*)?(?:[eE][+\-]?\d+)?/g,
	rvalidbraces = /(?:^|:|,)(?:\s*\[)+/g,

	// Useragent RegExp
	rwebkit = /(webkit)[ \/]([\w.]+)/,
	ropera = /(opera)(?:.*version)?[ \/]([\w.]+)/,
	rmsie = /(msie) ([\w.]+)/,
	rmozilla = /(mozilla)(?:.*? rv:([\w.]+))?/,

	// Matches dashed string for camelizing
	rdashAlpha = /-([a-z]|[0-9])/ig,
	rmsPrefix = /^-ms-/,

	// Used by jQuery.camelCase as callback to replace()
	fcamelCase = function( all, letter ) {
		return ( letter + "" ).toUpperCase();
	},

	// Keep a UserAgent string for use with jQuery.browser
	userAgent = navigator.userAgent,

	// For matching the engine and version of the browser
	browserMatch,

	// The deferred used on DOM ready
	readyList,

	// The ready event handler
	DOMContentLoaded,

	// Save a reference to some core methods
	toString = Object.prototype.toString,
	hasOwn = Object.prototype.hasOwnProperty,
	push = Array.prototype.push,
	slice = Array.prototype.slice,
	trim = String.prototype.trim,
	indexOf = Array.prototype.indexOf,

	// [[Class]] -> type pairs
	class2type = {};

jQuery.fn = jQuery.prototype = {
	constructor: jQuery,
	init: function( selector, context, rootjQuery ) {
		var match, elem, ret, doc;

		// Handle $(""), $(null), or $(undefined)
		if ( !selector ) {
			return this;
		}

		// Handle $(DOMElement)
		if ( selector.nodeType ) {
			this.context = this[0] = selector;
			this.length = 1;
			return this;
		}

		// The body element only exists once, optimize finding it
		if ( selector === "body" && !context && document.body ) {
			this.context = document;
			this[0] = document.body;
			this.selector = selector;
			this.length = 1;
			return this;
		}

		// Handle HTML strings
		if ( typeof selector === "string" ) {
			// Are we dealing with HTML string or an ID?
			if ( selector.charAt(0) === "<" && selector.charAt( selector.length - 1 ) === ">" && selector.length >= 3 ) {
				// Assume that strings that start and end with <> are HTML and skip the regex check
				match = [ null, selector, null ];

			} else {
				match = quickExpr.exec( selector );
			}

			// Verify a match, and that no context was specified for #id
			if ( match && (match[1] || !context) ) {

				// HANDLE: $(html) -> $(array)
				if ( match[1] ) {
					context = context instanceof jQuery ? context[0] : context;
					doc = ( context ? context.ownerDocument || context : document );

					// If a single string is passed in and it's a single tag
					// just do a createElement and skip the rest
					ret = rsingleTag.exec( selector );

					if ( ret ) {
						if ( jQuery.isPlainObject( context ) ) {
							selector = [ document.createElement( ret[1] ) ];
							jQuery.fn.attr.call( selector, context, true );

						} else {
							selector = [ doc.createElement( ret[1] ) ];
						}

					} else {
						ret = jQuery.buildFragment( [ match[1] ], [ doc ] );
						selector = ( ret.cacheable ? jQuery.clone(ret.fragment) : ret.fragment ).childNodes;
					}

					return jQuery.merge( this, selector );

				// HANDLE: $("#id")
				} else {
					elem = document.getElementById( match[2] );

					// Check parentNode to catch when Blackberry 4.6 returns
					// nodes that are no longer in the document #6963
					if ( elem && elem.parentNode ) {
						// Handle the case where IE and Opera return items
						// by name instead of ID
						if ( elem.id !== match[2] ) {
							return rootjQuery.find( selector );
						}

						// Otherwise, we inject the element directly into the jQuery object
						this.length = 1;
						this[0] = elem;
					}

					this.context = document;
					this.selector = selector;
					return this;
				}

			// HANDLE: $(expr, $(...))
			} else if ( !context || context.jquery ) {
				return ( context || rootjQuery ).find( selector );

			// HANDLE: $(expr, context)
			// (which is just equivalent to: $(context).find(expr)
			} else {
				return this.constructor( context ).find( selector );
			}

		// HANDLE: $(function)
		// Shortcut for document ready
		} else if ( jQuery.isFunction( selector ) ) {
			return rootjQuery.ready( selector );
		}

		if ( selector.selector !== undefined ) {
			this.selector = selector.selector;
			this.context = selector.context;
		}

		return jQuery.makeArray( selector, this );
	},

	// Start with an empty selector
	selector: "",

	// The current version of jQuery being used
	jquery: "1.7.2",

	// The default length of a jQuery object is 0
	length: 0,

	// The number of elements contained in the matched element set
	size: function() {
		return this.length;
	},

	toArray: function() {
		return slice.call( this, 0 );
	},

	// Get the Nth element in the matched element set OR
	// Get the whole matched element set as a clean array
	get: function( num ) {
		return num == null ?

			// Return a 'clean' array
			this.toArray() :

			// Return just the object
			( num < 0 ? this[ this.length + num ] : this[ num ] );
	},

	// Take an array of elements and push it onto the stack
	// (returning the new matched element set)
	pushStack: function( elems, name, selector ) {
		// Build a new jQuery matched element set
		var ret = this.constructor();

		if ( jQuery.isArray( elems ) ) {
			push.apply( ret, elems );

		} else {
			jQuery.merge( ret, elems );
		}

		// Add the old object onto the stack (as a reference)
		ret.prevObject = this;

		ret.context = this.context;

		if ( name === "find" ) {
			ret.selector = this.selector + ( this.selector ? " " : "" ) + selector;
		} else if ( name ) {
			ret.selector = this.selector + "." + name + "(" + selector + ")";
		}

		// Return the newly-formed element set
		return ret;
	},

	// Execute a callback for every element in the matched set.
	// (You can seed the arguments with an array of args, but this is
	// only used internally.)
	each: function( callback, args ) {
		return jQuery.each( this, callback, args );
	},

	ready: function( fn ) {
		// Attach the listeners
		jQuery.bindReady();

		// Add the callback
		readyList.add( fn );

		return this;
	},

	eq: function( i ) {
		i = +i;
		return i === -1 ?
			this.slice( i ) :
			this.slice( i, i + 1 );
	},

	first: function() {
		return this.eq( 0 );
	},

	last: function() {
		return this.eq( -1 );
	},

	slice: function() {
		return this.pushStack( slice.apply( this, arguments ),
			"slice", slice.call(arguments).join(",") );
	},

	map: function( callback ) {
		return this.pushStack( jQuery.map(this, function( elem, i ) {
			return callback.call( elem, i, elem );
		}));
	},

	end: function() {
		return this.prevObject || this.constructor(null);
	},

	// For internal use only.
	// Behaves like an Array's method, not like a jQuery method.
	push: push,
	sort: [].sort,
	splice: [].splice
};

// Give the init function the jQuery prototype for later instantiation
jQuery.fn.init.prototype = jQuery.fn;

jQuery.extend = jQuery.fn.extend = function() {
	var options, name, src, copy, copyIsArray, clone,
		target = arguments[0] || {},
		i = 1,
		length = arguments.length,
		deep = false;

	// Handle a deep copy situation
	if ( typeof target === "boolean" ) {
		deep = target;
		target = arguments[1] || {};
		// skip the boolean and the target
		i = 2;
	}

	// Handle case when target is a string or something (possible in deep copy)
	if ( typeof target !== "object" && !jQuery.isFunction(target) ) {
		target = {};
	}

	// extend jQuery itself if only one argument is passed
	if ( length === i ) {
		target = this;
		--i;
	}

	for ( ; i < length; i++ ) {
		// Only deal with non-null/undefined values
		if ( (options = arguments[ i ]) != null ) {
			// Extend the base object
			for ( name in options ) {
				src = target[ name ];
				copy = options[ name ];

				// Prevent never-ending loop
				if ( target === copy ) {
					continue;
				}

				// Recurse if we're merging plain objects or arrays
				if ( deep && copy && ( jQuery.isPlainObject(copy) || (copyIsArray = jQuery.isArray(copy)) ) ) {
					if ( copyIsArray ) {
						copyIsArray = false;
						clone = src && jQuery.isArray(src) ? src : [];

					} else {
						clone = src && jQuery.isPlainObject(src) ? src : {};
					}

					// Never move original objects, clone them
					target[ name ] = jQuery.extend( deep, clone, copy );

				// Don't bring in undefined values
				} else if ( copy !== undefined ) {
					target[ name ] = copy;
				}
			}
		}
	}

	// Return the modified object
	return target;
};

jQuery.extend({
	noConflict: function( deep ) {
		if ( window.$ === jQuery ) {
			window.$ = _$;
		}

		if ( deep && window.jQuery === jQuery ) {
			window.jQuery = _jQuery;
		}

		return jQuery;
	},

	// Is the DOM ready to be used? Set to true once it occurs.
	isReady: false,

	// A counter to track how many items to wait for before
	// the ready event fires. See #6781
	readyWait: 1,

	// Hold (or release) the ready event
	holdReady: function( hold ) {
		if ( hold ) {
			jQuery.readyWait++;
		} else {
			jQuery.ready( true );
		}
	},

	// Handle when the DOM is ready
	ready: function( wait ) {
		// Either a released hold or an DOMready/load event and not yet ready
		if ( (wait === true && !--jQuery.readyWait) || (wait !== true && !jQuery.isReady) ) {
			// Make sure body exists, at least, in case IE gets a little overzealous (ticket #5443).
			if ( !document.body ) {
				return setTimeout( jQuery.ready, 1 );
			}

			// Remember that the DOM is ready
			jQuery.isReady = true;

			// If a normal DOM Ready event fired, decrement, and wait if need be
			if ( wait !== true && --jQuery.readyWait > 0 ) {
				return;
			}

			// If there are functions bound, to execute
			readyList.fireWith( document, [ jQuery ] );

			// Trigger any bound ready events
			if ( jQuery.fn.trigger ) {
				jQuery( document ).trigger( "ready" ).off( "ready" );
			}
		}
	},

	bindReady: function() {
		if ( readyList ) {
			return;
		}

		readyList = jQuery.Callbacks( "once memory" );

		// Catch cases where $(document).ready() is called after the
		// browser event has already occurred.
		if ( document.readyState === "complete" ) {
			// Handle it asynchronously to allow scripts the opportunity to delay ready
			return setTimeout( jQuery.ready, 1 );
		}

		// Mozilla, Opera and webkit nightlies currently support this event
		if ( document.addEventListener ) {
			// Use the handy event callback
			document.addEventListener( "DOMContentLoaded", DOMContentLoaded, false );

			// A fallback to window.onload, that will always work
			window.addEventListener( "load", jQuery.ready, false );

		// If IE event model is used
		} else if ( document.attachEvent ) {
			// ensure firing before onload,
			// maybe late but safe also for iframes
			document.attachEvent( "onreadystatechange", DOMContentLoaded );

			// A fallback to window.onload, that will always work
			window.attachEvent( "onload", jQuery.ready );

			// If IE and not a frame
			// continually check to see if the document is ready
			var toplevel = false;

			try {
				toplevel = window.frameElement == null;
			} catch(e) {}

			if ( document.documentElement.doScroll && toplevel ) {
				doScrollCheck();
			}
		}
	},

	// See test/unit/core.js for details concerning isFunction.
	// Since version 1.3, DOM methods and functions like alert
	// aren't supported. They return false on IE (#2968).
	isFunction: function( obj ) {
		return jQuery.type(obj) === "function";
	},

	isArray: Array.isArray || function( obj ) {
		return jQuery.type(obj) === "array";
	},

	isWindow: function( obj ) {
		return obj != null && obj == obj.window;
	},

	isNumeric: function( obj ) {
		return !isNaN( parseFloat(obj) ) && isFinite( obj );
	},

	type: function( obj ) {
		return obj == null ?
			String( obj ) :
			class2type[ toString.call(obj) ] || "object";
	},

	isPlainObject: function( obj ) {
		// Must be an Object.
		// Because of IE, we also have to check the presence of the constructor property.
		// Make sure that DOM nodes and window objects don't pass through, as well
		if ( !obj || jQuery.type(obj) !== "object" || obj.nodeType || jQuery.isWindow( obj ) ) {
			return false;
		}

		try {
			// Not own constructor property must be Object
			if ( obj.constructor &&
				!hasOwn.call(obj, "constructor") &&
				!hasOwn.call(obj.constructor.prototype, "isPrototypeOf") ) {
				return false;
			}
		} catch ( e ) {
			// IE8,9 Will throw exceptions on certain host objects #9897
			return false;
		}

		// Own properties are enumerated firstly, so to speed up,
		// if last one is own, then all properties are own.

		var key;
		for ( key in obj ) {}

		return key === undefined || hasOwn.call( obj, key );
	},

	isEmptyObject: function( obj ) {
		for ( var name in obj ) {
			return false;
		}
		return true;
	},

	error: function( msg ) {
		throw new Error( msg );
	},

	parseJSON: function( data ) {
		if ( typeof data !== "string" || !data ) {
			return null;
		}

		// Make sure leading/trailing whitespace is removed (IE can't handle it)
		data = jQuery.trim( data );

		// Attempt to parse using the native JSON parser first
		if ( window.JSON && window.JSON.parse ) {
			return window.JSON.parse( data );
		}

		// Make sure the incoming data is actual JSON
		// Logic borrowed from http://json.org/json2.js
		if ( rvalidchars.test( data.replace( rvalidescape, "@" )
			.replace( rvalidtokens, "]" )
			.replace( rvalidbraces, "")) ) {

			return ( new Function( "return " + data ) )();

		}
		jQuery.error( "Invalid JSON: " + data );
	},

	// Cross-browser xml parsing
	parseXML: function( data ) {
		if ( typeof data !== "string" || !data ) {
			return null;
		}
		var xml, tmp;
		try {
			if ( window.DOMParser ) { // Standard
				tmp = new DOMParser();
				xml = tmp.parseFromString( data , "text/xml" );
			} else { // IE
				xml = new ActiveXObject( "Microsoft.XMLDOM" );
				xml.async = "false";
				xml.loadXML( data );
			}
		} catch( e ) {
			xml = undefined;
		}
		if ( !xml || !xml.documentElement || xml.getElementsByTagName( "parsererror" ).length ) {
			jQuery.error( "Invalid XML: " + data );
		}
		return xml;
	},

	noop: function() {},

	// Evaluates a script in a global context
	// Workarounds based on findings by Jim Driscoll
	// http://weblogs.java.net/blog/driscoll/archive/2009/09/08/eval-javascript-global-context
	globalEval: function( data ) {
		if ( data && rnotwhite.test( data ) ) {
			// We use execScript on Internet Explorer
			// We use an anonymous function so that context is window
			// rather than jQuery in Firefox
			( window.execScript || function( data ) {
				window[ "eval" ].call( window, data );
			} )( data );
		}
	},

	// Convert dashed to camelCase; used by the css and data modules
	// Microsoft forgot to hump their vendor prefix (#9572)
	camelCase: function( string ) {
		return string.replace( rmsPrefix, "ms-" ).replace( rdashAlpha, fcamelCase );
	},

	nodeName: function( elem, name ) {
		return elem.nodeName && elem.nodeName.toUpperCase() === name.toUpperCase();
	},

	// args is for internal usage only
	each: function( object, callback, args ) {
		var name, i = 0,
			length = object.length,
			isObj = length === undefined || jQuery.isFunction( object );

		if ( args ) {
			if ( isObj ) {
				for ( name in object ) {
					if ( callback.apply( object[ name ], args ) === false ) {
						break;
					}
				}
			} else {
				for ( ; i < length; ) {
					if ( callback.apply( object[ i++ ], args ) === false ) {
						break;
					}
				}
			}

		// A special, fast, case for the most common use of each
		} else {
			if ( isObj ) {
				for ( name in object ) {
					if ( callback.call( object[ name ], name, object[ name ] ) === false ) {
						break;
					}
				}
			} else {
				for ( ; i < length; ) {
					if ( callback.call( object[ i ], i, object[ i++ ] ) === false ) {
						break;
					}
				}
			}
		}

		return object;
	},

	// Use native String.trim function wherever possible
	trim: trim ?
		function( text ) {
			return text == null ?
				"" :
				trim.call( text );
		} :

		// Otherwise use our own trimming functionality
		function( text ) {
			return text == null ?
				"" :
				text.toString().replace( trimLeft, "" ).replace( trimRight, "" );
		},

	// results is for internal usage only
	makeArray: function( array, results ) {
		var ret = results || [];

		if ( array != null ) {
			// The window, strings (and functions) also have 'length'
			// Tweaked logic slightly to handle Blackberry 4.7 RegExp issues #6930
			var type = jQuery.type( array );

			if ( array.length == null || type === "string" || type === "function" || type === "regexp" || jQuery.isWindow( array ) ) {
				push.call( ret, array );
			} else {
				jQuery.merge( ret, array );
			}
		}

		return ret;
	},

	inArray: function( elem, array, i ) {
		var len;

		if ( array ) {
			if ( indexOf ) {
				return indexOf.call( array, elem, i );
			}

			len = array.length;
			i = i ? i < 0 ? Math.max( 0, len + i ) : i : 0;

			for ( ; i < len; i++ ) {
				// Skip accessing in sparse arrays
				if ( i in array && array[ i ] === elem ) {
					return i;
				}
			}
		}

		return -1;
	},

	merge: function( first, second ) {
		var i = first.length,
			j = 0;

		if ( typeof second.length === "number" ) {
			for ( var l = second.length; j < l; j++ ) {
				first[ i++ ] = second[ j ];
			}

		} else {
			while ( second[j] !== undefined ) {
				first[ i++ ] = second[ j++ ];
			}
		}

		first.length = i;

		return first;
	},

	grep: function( elems, callback, inv ) {
		var ret = [], retVal;
		inv = !!inv;

		// Go through the array, only saving the items
		// that pass the validator function
		for ( var i = 0, length = elems.length; i < length; i++ ) {
			retVal = !!callback( elems[ i ], i );
			if ( inv !== retVal ) {
				ret.push( elems[ i ] );
			}
		}

		return ret;
	},

	// arg is for internal usage only
	map: function( elems, callback, arg ) {
		var value, key, ret = [],
			i = 0,
			length = elems.length,
			// jquery objects are treated as arrays
			isArray = elems instanceof jQuery || length !== undefined && typeof length === "number" && ( ( length > 0 && elems[ 0 ] && elems[ length -1 ] ) || length === 0 || jQuery.isArray( elems ) ) ;

		// Go through the array, translating each of the items to their
		if ( isArray ) {
			for ( ; i < length; i++ ) {
				value = callback( elems[ i ], i, arg );

				if ( value != null ) {
					ret[ ret.length ] = value;
				}
			}

		// Go through every key on the object,
		} else {
			for ( key in elems ) {
				value = callback( elems[ key ], key, arg );

				if ( value != null ) {
					ret[ ret.length ] = value;
				}
			}
		}

		// Flatten any nested arrays
		return ret.concat.apply( [], ret );
	},

	// A global GUID counter for objects
	guid: 1,

	// Bind a function to a context, optionally partially applying any
	// arguments.
	proxy: function( fn, context ) {
		if ( typeof context === "string" ) {
			var tmp = fn[ context ];
			context = fn;
			fn = tmp;
		}

		// Quick check to determine if target is callable, in the spec
		// this throws a TypeError, but we will just return undefined.
		if ( !jQuery.isFunction( fn ) ) {
			return undefined;
		}

		// Simulated bind
		var args = slice.call( arguments, 2 ),
			proxy = function() {
				return fn.apply( context, args.concat( slice.call( arguments ) ) );
			};

		// Set the guid of unique handler to the same of original handler, so it can be removed
		proxy.guid = fn.guid = fn.guid || proxy.guid || jQuery.guid++;

		return proxy;
	},

	// Mutifunctional method to get and set values to a collection
	// The value/s can optionally be executed if it's a function
	access: function( elems, fn, key, value, chainable, emptyGet, pass ) {
		var exec,
			bulk = key == null,
			i = 0,
			length = elems.length;

		// Sets many values
		if ( key && typeof key === "object" ) {
			for ( i in key ) {
				jQuery.access( elems, fn, i, key[i], 1, emptyGet, value );
			}
			chainable = 1;

		// Sets one value
		} else if ( value !== undefined ) {
			// Optionally, function values get executed if exec is true
			exec = pass === undefined && jQuery.isFunction( value );

			if ( bulk ) {
				// Bulk operations only iterate when executing function values
				if ( exec ) {
					exec = fn;
					fn = function( elem, key, value ) {
						return exec.call( jQuery( elem ), value );
					};

				// Otherwise they run against the entire set
				} else {
					fn.call( elems, value );
					fn = null;
				}
			}

			if ( fn ) {
				for (; i < length; i++ ) {
					fn( elems[i], key, exec ? value.call( elems[i], i, fn( elems[i], key ) ) : value, pass );
				}
			}

			chainable = 1;
		}

		return chainable ?
			elems :

			// Gets
			bulk ?
				fn.call( elems ) :
				length ? fn( elems[0], key ) : emptyGet;
	},

	now: function() {
		return ( new Date() ).getTime();
	},

	// Use of jQuery.browser is frowned upon.
	// More details: http://docs.jquery.com/Utilities/jQuery.browser
	uaMatch: function( ua ) {
		ua = ua.toLowerCase();

		var match = rwebkit.exec( ua ) ||
			ropera.exec( ua ) ||
			rmsie.exec( ua ) ||
			ua.indexOf("compatible") < 0 && rmozilla.exec( ua ) ||
			[];

		return { browser: match[1] || "", version: match[2] || "0" };
	},

	sub: function() {
		function jQuerySub( selector, context ) {
			return new jQuerySub.fn.init( selector, context );
		}
		jQuery.extend( true, jQuerySub, this );
		jQuerySub.superclass = this;
		jQuerySub.fn = jQuerySub.prototype = this();
		jQuerySub.fn.constructor = jQuerySub;
		jQuerySub.sub = this.sub;
		jQuerySub.fn.init = function init( selector, context ) {
			if ( context && context instanceof jQuery && !(context instanceof jQuerySub) ) {
				context = jQuerySub( context );
			}

			return jQuery.fn.init.call( this, selector, context, rootjQuerySub );
		};
		jQuerySub.fn.init.prototype = jQuerySub.fn;
		var rootjQuerySub = jQuerySub(document);
		return jQuerySub;
	},

	browser: {}
});

// Populate the class2type map
jQuery.each("Boolean Number String Function Array Date RegExp Object".split(" "), function(i, name) {
	class2type[ "[object " + name + "]" ] = name.toLowerCase();
});

browserMatch = jQuery.uaMatch( userAgent );
if ( browserMatch.browser ) {
	jQuery.browser[ browserMatch.browser ] = true;
	jQuery.browser.version = browserMatch.version;
}

// Deprecated, use jQuery.browser.webkit instead
if ( jQuery.browser.webkit ) {
	jQuery.browser.safari = true;
}

// IE doesn't match non-breaking spaces with \s
if ( rnotwhite.test( "\xA0" ) ) {
	trimLeft = /^[\s\xA0]+/;
	trimRight = /[\s\xA0]+$/;
}

// All jQuery objects should point back to these
rootjQuery = jQuery(document);

// Cleanup functions for the document ready method
if ( document.addEventListener ) {
	DOMContentLoaded = function() {
		document.removeEventListener( "DOMContentLoaded", DOMContentLoaded, false );
		jQuery.ready();
	};

} else if ( document.attachEvent ) {
	DOMContentLoaded = function() {
		// Make sure body exists, at least, in case IE gets a little overzealous (ticket #5443).
		if ( document.readyState === "complete" ) {
			document.detachEvent( "onreadystatechange", DOMContentLoaded );
			jQuery.ready();
		}
	};
}

// The DOM ready check for Internet Explorer
function doScrollCheck() {
	if ( jQuery.isReady ) {
		return;
	}

	try {
		// If IE is used, use the trick by Diego Perini
		// http://javascript.nwbox.com/IEContentLoaded/
		document.documentElement.doScroll("left");
	} catch(e) {
		setTimeout( doScrollCheck, 1 );
		return;
	}

	// and execute any waiting functions
	jQuery.ready();
}

return jQuery;

})();


// String to Object flags format cache
var flagsCache = {};

// Convert String-formatted flags into Object-formatted ones and store in cache
function createFlags( flags ) {
	var object = flagsCache[ flags ] = {},
		i, length;
	flags = flags.split( /\s+/ );
	for ( i = 0, length = flags.length; i < length; i++ ) {
		object[ flags[i] ] = true;
	}
	return object;
}

/*
 * Create a callback list using the following parameters:
 *
 *	flags:	an optional list of space-separated flags that will change how
 *			the callback list behaves
 *
 * By default a callback list will act like an event callback list and can be
 * "fired" multiple times.
 *
 * Possible flags:
 *
 *	once:			will ensure the callback list can only be fired once (like a Deferred)
 *
 *	memory:			will keep track of previous values and will call any callback added
 *					after the list has been fired right away with the latest "memorized"
 *					values (like a Deferred)
 *
 *	unique:			will ensure a callback can only be added once (no duplicate in the list)
 *
 *	stopOnFalse:	interrupt callings when a callback returns false
 *
 */
jQuery.Callbacks = function( flags ) {

	// Convert flags from String-formatted to Object-formatted
	// (we check in cache first)
	flags = flags ? ( flagsCache[ flags ] || createFlags( flags ) ) : {};

	var // Actual callback list
		list = [],
		// Stack of fire calls for repeatable lists
		stack = [],
		// Last fire value (for non-forgettable lists)
		memory,
		// Flag to know if list was already fired
		fired,
		// Flag to know if list is currently firing
		firing,
		// First callback to fire (used internally by add and fireWith)
		firingStart,
		// End of the loop when firing
		firingLength,
		// Index of currently firing callback (modified by remove if needed)
		firingIndex,
		// Add one or several callbacks to the list
		add = function( args ) {
			var i,
				length,
				elem,
				type,
				actual;
			for ( i = 0, length = args.length; i < length; i++ ) {
				elem = args[ i ];
				type = jQuery.type( elem );
				if ( type === "array" ) {
					// Inspect recursively
					add( elem );
				} else if ( type === "function" ) {
					// Add if not in unique mode and callback is not in
					if ( !flags.unique || !self.has( elem ) ) {
						list.push( elem );
					}
				}
			}
		},
		// Fire callbacks
		fire = function( context, args ) {
			args = args || [];
			memory = !flags.memory || [ context, args ];
			fired = true;
			firing = true;
			firingIndex = firingStart || 0;
			firingStart = 0;
			firingLength = list.length;
			for ( ; list && firingIndex < firingLength; firingIndex++ ) {
				if ( list[ firingIndex ].apply( context, args ) === false && flags.stopOnFalse ) {
					memory = true; // Mark as halted
					break;
				}
			}
			firing = false;
			if ( list ) {
				if ( !flags.once ) {
					if ( stack && stack.length ) {
						memory = stack.shift();
						self.fireWith( memory[ 0 ], memory[ 1 ] );
					}
				} else if ( memory === true ) {
					self.disable();
				} else {
					list = [];
				}
			}
		},
		// Actual Callbacks object
		self = {
			// Add a callback or a collection of callbacks to the list
			add: function() {
				if ( list ) {
					var length = list.length;
					add( arguments );
					// Do we need to add the callbacks to the
					// current firing batch?
					if ( firing ) {
						firingLength = list.length;
					// With memory, if we're not firing then
					// we should call right away, unless previous
					// firing was halted (stopOnFalse)
					} else if ( memory && memory !== true ) {
						firingStart = length;
						fire( memory[ 0 ], memory[ 1 ] );
					}
				}
				return this;
			},
			// Remove a callback from the list
			remove: function() {
				if ( list ) {
					var args = arguments,
						argIndex = 0,
						argLength = args.length;
					for ( ; argIndex < argLength ; argIndex++ ) {
						for ( var i = 0; i < list.length; i++ ) {
							if ( args[ argIndex ] === list[ i ] ) {
								// Handle firingIndex and firingLength
								if ( firing ) {
									if ( i <= firingLength ) {
										firingLength--;
										if ( i <= firingIndex ) {
											firingIndex--;
										}
									}
								}
								// Remove the element
								list.splice( i--, 1 );
								// If we have some unicity property then
								// we only need to do this once
								if ( flags.unique ) {
									break;
								}
							}
						}
					}
				}
				return this;
			},
			// Control if a given callback is in the list
			has: function( fn ) {
				if ( list ) {
					var i = 0,
						length = list.length;
					for ( ; i < length; i++ ) {
						if ( fn === list[ i ] ) {
							return true;
						}
					}
				}
				return false;
			},
			// Remove all callbacks from the list
			empty: function() {
				list = [];
				return this;
			},
			// Have the list do nothing anymore
			disable: function() {
				list = stack = memory = undefined;
				return this;
			},
			// Is it disabled?
			disabled: function() {
				return !list;
			},
			// Lock the list in its current state
			lock: function() {
				stack = undefined;
				if ( !memory || memory === true ) {
					self.disable();
				}
				return this;
			},
			// Is it locked?
			locked: function() {
				return !stack;
			},
			// Call all callbacks with the given context and arguments
			fireWith: function( context, args ) {
				if ( stack ) {
					if ( firing ) {
						if ( !flags.once ) {
							stack.push( [ context, args ] );
						}
					} else if ( !( flags.once && memory ) ) {
						fire( context, args );
					}
				}
				return this;
			},
			// Call all the callbacks with the given arguments
			fire: function() {
				self.fireWith( this, arguments );
				return this;
			},
			// To know if the callbacks have already been called at least once
			fired: function() {
				return !!fired;
			}
		};

	return self;
};




var // Static reference to slice
	sliceDeferred = [].slice;

jQuery.extend({

	Deferred: function( func ) {
		var doneList = jQuery.Callbacks( "once memory" ),
			failList = jQuery.Callbacks( "once memory" ),
			progressList = jQuery.Callbacks( "memory" ),
			state = "pending",
			lists = {
				resolve: doneList,
				reject: failList,
				notify: progressList
			},
			promise = {
				done: doneList.add,
				fail: failList.add,
				progress: progressList.add,

				state: function() {
					return state;
				},

				// Deprecated
				isResolved: doneList.fired,
				isRejected: failList.fired,

				then: function( doneCallbacks, failCallbacks, progressCallbacks ) {
					deferred.done( doneCallbacks ).fail( failCallbacks ).progress( progressCallbacks );
					return this;
				},
				always: function() {
					deferred.done.apply( deferred, arguments ).fail.apply( deferred, arguments );
					return this;
				},
				pipe: function( fnDone, fnFail, fnProgress ) {
					return jQuery.Deferred(function( newDefer ) {
						jQuery.each( {
							done: [ fnDone, "resolve" ],
							fail: [ fnFail, "reject" ],
							progress: [ fnProgress, "notify" ]
						}, function( handler, data ) {
							var fn = data[ 0 ],
								action = data[ 1 ],
								returned;
							if ( jQuery.isFunction( fn ) ) {
								deferred[ handler ](function() {
									returned = fn.apply( this, arguments );
									if ( returned && jQuery.isFunction( returned.promise ) ) {
										returned.promise().then( newDefer.resolve, newDefer.reject, newDefer.notify );
									} else {
										newDefer[ action + "With" ]( this === deferred ? newDefer : this, [ returned ] );
									}
								});
							} else {
								deferred[ handler ]( newDefer[ action ] );
							}
						});
					}).promise();
				},
				// Get a promise for this deferred
				// If obj is provided, the promise aspect is added to the object
				promise: function( obj ) {
					if ( obj == null ) {
						obj = promise;
					} else {
						for ( var key in promise ) {
							obj[ key ] = promise[ key ];
						}
					}
					return obj;
				}
			},
			deferred = promise.promise({}),
			key;

		for ( key in lists ) {
			deferred[ key ] = lists[ key ].fire;
			deferred[ key + "With" ] = lists[ key ].fireWith;
		}

		// Handle state
		deferred.done( function() {
			state = "resolved";
		}, failList.disable, progressList.lock ).fail( function() {
			state = "rejected";
		}, doneList.disable, progressList.lock );

		// Call given func if any
		if ( func ) {
			func.call( deferred, deferred );
		}

		// All done!
		return deferred;
	},

	// Deferred helper
	when: function( firstParam ) {
		var args = sliceDeferred.call( arguments, 0 ),
			i = 0,
			length = args.length,
			pValues = new Array( length ),
			count = length,
			pCount = length,
			deferred = length <= 1 && firstParam && jQuery.isFunction( firstParam.promise ) ?
				firstParam :
				jQuery.Deferred(),
			promise = deferred.promise();
		function resolveFunc( i ) {
			return function( value ) {
				args[ i ] = arguments.length > 1 ? sliceDeferred.call( arguments, 0 ) : value;
				if ( !( --count ) ) {
					deferred.resolveWith( deferred, args );
				}
			};
		}
		function progressFunc( i ) {
			return function( value ) {
				pValues[ i ] = arguments.length > 1 ? sliceDeferred.call( arguments, 0 ) : value;
				deferred.notifyWith( promise, pValues );
			};
		}
		if ( length > 1 ) {
			for ( ; i < length; i++ ) {
				if ( args[ i ] && args[ i ].promise && jQuery.isFunction( args[ i ].promise ) ) {
					args[ i ].promise().then( resolveFunc(i), deferred.reject, progressFunc(i) );
				} else {
					--count;
				}
			}
			if ( !count ) {
				deferred.resolveWith( deferred, args );
			}
		} else if ( deferred !== firstParam ) {
			deferred.resolveWith( deferred, length ? [ firstParam ] : [] );
		}
		return promise;
	}
});




jQuery.support = (function() {

	var support,
		all,
		a,
		select,
		opt,
		input,
		fragment,
		tds,
		events,
		eventName,
		i,
		isSupported,
		div = document.createElement( "div" ),
		documentElement = document.documentElement;

	// Preliminary tests
	div.setAttribute("className", "t");
	div.innerHTML = "   <link/><table></table><a href='/a' style='top:1px;float:left;opacity:.55;'>a</a><input type='checkbox'/>";

	all = div.getElementsByTagName( "*" );
	a = div.getElementsByTagName( "a" )[ 0 ];

	// Can't get basic test support
	if ( !all || !all.length || !a ) {
		return {};
	}

	// First batch of supports tests
	select = document.createElement( "select" );
	opt = select.appendChild( document.createElement("option") );
	input = div.getElementsByTagName( "input" )[ 0 ];

	support = {
		// IE strips leading whitespace when .innerHTML is used
		leadingWhitespace: ( div.firstChild.nodeType === 3 ),

		// Make sure that tbody elements aren't automatically inserted
		// IE will insert them into empty tables
		tbody: !div.getElementsByTagName("tbody").length,

		// Make sure that link elements get serialized correctly by innerHTML
		// This requires a wrapper element in IE
		htmlSerialize: !!div.getElementsByTagName("link").length,

		// Get the style information from getAttribute
		// (IE uses .cssText instead)
		style: /top/.test( a.getAttribute("style") ),

		// Make sure that URLs aren't manipulated
		// (IE normalizes it by default)
		hrefNormalized: ( a.getAttribute("href") === "/a" ),

		// Make sure that element opacity exists
		// (IE uses filter instead)
		// Use a regex to work around a WebKit issue. See #5145
		opacity: /^0.55/.test( a.style.opacity ),

		// Verify style float existence
		// (IE uses styleFloat instead of cssFloat)
		cssFloat: !!a.style.cssFloat,

		// Make sure that if no value is specified for a checkbox
		// that it defaults to "on".
		// (WebKit defaults to "" instead)
		checkOn: ( input.value === "on" ),

		// Make sure that a selected-by-default option has a working selected property.
		// (WebKit defaults to false instead of true, IE too, if it's in an optgroup)
		optSelected: opt.selected,

		// Test setAttribute on camelCase class. If it works, we need attrFixes when doing get/setAttribute (ie6/7)
		getSetAttribute: div.className !== "t",

		// Tests for enctype support on a form(#6743)
		enctype: !!document.createElement("form").enctype,

		// Makes sure cloning an html5 element does not cause problems
		// Where outerHTML is undefined, this still works
		html5Clone: document.createElement("nav").cloneNode( true ).outerHTML !== "<:nav></:nav>",

		// Will be defined later
		submitBubbles: true,
		changeBubbles: true,
		focusinBubbles: false,
		deleteExpando: true,
		noCloneEvent: true,
		inlineBlockNeedsLayout: false,
		shrinkWrapBlocks: false,
		reliableMarginRight: true,
		pixelMargin: true
	};

	// jQuery.boxModel DEPRECATED in 1.3, use jQuery.support.boxModel instead
	jQuery.boxModel = support.boxModel = (document.compatMode === "CSS1Compat");

	// Make sure checked status is properly cloned
	input.checked = true;
	support.noCloneChecked = input.cloneNode( true ).checked;

	// Make sure that the options inside disabled selects aren't marked as disabled
	// (WebKit marks them as disabled)
	select.disabled = true;
	support.optDisabled = !opt.disabled;

	// Test to see if it's possible to delete an expando from an element
	// Fails in Internet Explorer
	try {
		delete div.test;
	} catch( e ) {
		support.deleteExpando = false;
	}

	if ( !div.addEventListener && div.attachEvent && div.fireEvent ) {
		div.attachEvent( "onclick", function() {
			// Cloning a node shouldn't copy over any
			// bound event handlers (IE does this)
			support.noCloneEvent = false;
		});
		div.cloneNode( true ).fireEvent( "onclick" );
	}

	// Check if a radio maintains its value
	// after being appended to the DOM
	input = document.createElement("input");
	input.value = "t";
	input.setAttribute("type", "radio");
	support.radioValue = input.value === "t";

	input.setAttribute("checked", "checked");

	// #11217 - WebKit loses check when the name is after the checked attribute
	input.setAttribute( "name", "t" );

	div.appendChild( input );
	fragment = document.createDocumentFragment();
	fragment.appendChild( div.lastChild );

	// WebKit doesn't clone checked state correctly in fragments
	support.checkClone = fragment.cloneNode( true ).cloneNode( true ).lastChild.checked;

	// Check if a disconnected checkbox will retain its checked
	// value of true after appended to the DOM (IE6/7)
	support.appendChecked = input.checked;

	fragment.removeChild( input );
	fragment.appendChild( div );

	// Technique from Juriy Zaytsev
	// http://perfectionkills.com/detecting-event-support-without-browser-sniffing/
	// We only care about the case where non-standard event systems
	// are used, namely in IE. Short-circuiting here helps us to
	// avoid an eval call (in setAttribute) which can cause CSP
	// to go haywire. See: https://developer.mozilla.org/en/Security/CSP
	if ( div.attachEvent ) {
		for ( i in {
			submit: 1,
			change: 1,
			focusin: 1
		}) {
			eventName = "on" + i;
			isSupported = ( eventName in div );
			if ( !isSupported ) {
				div.setAttribute( eventName, "return;" );
				isSupported = ( typeof div[ eventName ] === "function" );
			}
			support[ i + "Bubbles" ] = isSupported;
		}
	}

	fragment.removeChild( div );

	// Null elements to avoid leaks in IE
	fragment = select = opt = div = input = null;

	// Run tests that need a body at doc ready
	jQuery(function() {
		var container, outer, inner, table, td, offsetSupport,
			marginDiv, conMarginTop, style, html, positionTopLeftWidthHeight,
			paddingMarginBorderVisibility, paddingMarginBorder,
			body = document.getElementsByTagName("body")[0];

		if ( !body ) {
			// Return for frameset docs that don't have a body
			return;
		}

		conMarginTop = 1;
		paddingMarginBorder = "padding:0;margin:0;border:";
		positionTopLeftWidthHeight = "position:absolute;top:0;left:0;width:1px;height:1px;";
		paddingMarginBorderVisibility = paddingMarginBorder + "0;visibility:hidden;";
		style = "style='" + positionTopLeftWidthHeight + paddingMarginBorder + "5px solid #000;";
		html = "<div " + style + "display:block;'><div style='" + paddingMarginBorder + "0;display:block;overflow:hidden;'></div></div>" +
			"<table " + style + "' cellpadding='0' cellspacing='0'>" +
			"<tr><td></td></tr></table>";

		container = document.createElement("div");
		container.style.cssText = paddingMarginBorderVisibility + "width:0;height:0;position:static;top:0;margin-top:" + conMarginTop + "px";
		body.insertBefore( container, body.firstChild );

		// Construct the test element
		div = document.createElement("div");
		container.appendChild( div );

		// Check if table cells still have offsetWidth/Height when they are set
		// to display:none and there are still other visible table cells in a
		// table row; if so, offsetWidth/Height are not reliable for use when
		// determining if an element has been hidden directly using
		// display:none (it is still safe to use offsets if a parent element is
		// hidden; don safety goggles and see bug #4512 for more information).
		// (only IE 8 fails this test)
		div.innerHTML = "<table><tr><td style='" + paddingMarginBorder + "0;display:none'></td><td>t</td></tr></table>";
		tds = div.getElementsByTagName( "td" );
		isSupported = ( tds[ 0 ].offsetHeight === 0 );

		tds[ 0 ].style.display = "";
		tds[ 1 ].style.display = "none";

		// Check if empty table cells still have offsetWidth/Height
		// (IE <= 8 fail this test)
		support.reliableHiddenOffsets = isSupported && ( tds[ 0 ].offsetHeight === 0 );

		// Check if div with explicit width and no margin-right incorrectly
		// gets computed margin-right based on width of container. For more
		// info see bug #3333
		// Fails in WebKit before Feb 2011 nightlies
		// WebKit Bug 13343 - getComputedStyle returns wrong value for margin-right
		if ( window.getComputedStyle ) {
			div.innerHTML = "";
			marginDiv = document.createElement( "div" );
			marginDiv.style.width = "0";
			marginDiv.style.marginRight = "0";
			div.style.width = "2px";
			div.appendChild( marginDiv );
			support.reliableMarginRight =
				( parseInt( ( window.getComputedStyle( marginDiv, null ) || { marginRight: 0 } ).marginRight, 10 ) || 0 ) === 0;
		}

		if ( typeof div.style.zoom !== "undefined" ) {
			// Check if natively block-level elements act like inline-block
			// elements when setting their display to 'inline' and giving
			// them layout
			// (IE < 8 does this)
			div.innerHTML = "";
			div.style.width = div.style.padding = "1px";
			div.style.border = 0;
			div.style.overflow = "hidden";
			div.style.display = "inline";
			div.style.zoom = 1;
			support.inlineBlockNeedsLayout = ( div.offsetWidth === 3 );

			// Check if elements with layout shrink-wrap their children
			// (IE 6 does this)
			div.style.display = "block";
			div.style.overflow = "visible";
			div.innerHTML = "<div style='width:5px;'></div>";
			support.shrinkWrapBlocks = ( div.offsetWidth !== 3 );
		}

		div.style.cssText = positionTopLeftWidthHeight + paddingMarginBorderVisibility;
		div.innerHTML = html;

		outer = div.firstChild;
		inner = outer.firstChild;
		td = outer.nextSibling.firstChild.firstChild;

		offsetSupport = {
			doesNotAddBorder: ( inner.offsetTop !== 5 ),
			doesAddBorderForTableAndCells: ( td.offsetTop === 5 )
		};

		inner.style.position = "fixed";
		inner.style.top = "20px";

		// safari subtracts parent border width here which is 5px
		offsetSupport.fixedPosition = ( inner.offsetTop === 20 || inner.offsetTop === 15 );
		inner.style.position = inner.style.top = "";

		outer.style.overflow = "hidden";
		outer.style.position = "relative";

		offsetSupport.subtractsBorderForOverflowNotVisible = ( inner.offsetTop === -5 );
		offsetSupport.doesNotIncludeMarginInBodyOffset = ( body.offsetTop !== conMarginTop );

		if ( window.getComputedStyle ) {
			div.style.marginTop = "1%";
			support.pixelMargin = ( window.getComputedStyle( div, null ) || { marginTop: 0 } ).marginTop !== "1%";
		}

		if ( typeof container.style.zoom !== "undefined" ) {
			container.style.zoom = 1;
		}

		body.removeChild( container );
		marginDiv = div = container = null;

		jQuery.extend( support, offsetSupport );
	});

	return support;
})();




var rbrace = /^(?:\{.*\}|\[.*\])$/,
	rmultiDash = /([A-Z])/g;

jQuery.extend({
	cache: {},

	// Please use with caution
	uuid: 0,

	// Unique for each copy of jQuery on the page
	// Non-digits removed to match rinlinejQuery
	expando: "jQuery" + ( jQuery.fn.jquery + Math.random() ).replace( /\D/g, "" ),

	// The following elements throw uncatchable exceptions if you
	// attempt to add expando properties to them.
	noData: {
		"embed": true,
		// Ban all objects except for Flash (which handle expandos)
		"object": "clsid:D27CDB6E-AE6D-11cf-96B8-444553540000",
		"applet": true
	},

	hasData: function( elem ) {
		elem = elem.nodeType ? jQuery.cache[ elem[jQuery.expando] ] : elem[ jQuery.expando ];
		return !!elem && !isEmptyDataObject( elem );
	},

	data: function( elem, name, data, pvt /* Internal Use Only */ ) {
		if ( !jQuery.acceptData( elem ) ) {
			return;
		}

		var privateCache, thisCache, ret,
			internalKey = jQuery.expando,
			getByName = typeof name === "string",

			// We have to handle DOM nodes and JS objects differently because IE6-7
			// can't GC object references properly across the DOM-JS boundary
			isNode = elem.nodeType,

			// Only DOM nodes need the global jQuery cache; JS object data is
			// attached directly to the object so GC can occur automatically
			cache = isNode ? jQuery.cache : elem,

			// Only defining an ID for JS objects if its cache already exists allows
			// the code to shortcut on the same path as a DOM node with no cache
			id = isNode ? elem[ internalKey ] : elem[ internalKey ] && internalKey,
			isEvents = name === "events";

		// Avoid doing any more work than we need to when trying to get data on an
		// object that has no data at all
		if ( (!id || !cache[id] || (!isEvents && !pvt && !cache[id].data)) && getByName && data === undefined ) {
			return;
		}

		if ( !id ) {
			// Only DOM nodes need a new unique ID for each element since their data
			// ends up in the global cache
			if ( isNode ) {
				elem[ internalKey ] = id = ++jQuery.uuid;
			} else {
				id = internalKey;
			}
		}

		if ( !cache[ id ] ) {
			cache[ id ] = {};

			// Avoids exposing jQuery metadata on plain JS objects when the object
			// is serialized using JSON.stringify
			if ( !isNode ) {
				cache[ id ].toJSON = jQuery.noop;
			}
		}

		// An object can be passed to jQuery.data instead of a key/value pair; this gets
		// shallow copied over onto the existing cache
		if ( typeof name === "object" || typeof name === "function" ) {
			if ( pvt ) {
				cache[ id ] = jQuery.extend( cache[ id ], name );
			} else {
				cache[ id ].data = jQuery.extend( cache[ id ].data, name );
			}
		}

		privateCache = thisCache = cache[ id ];

		// jQuery data() is stored in a separate object inside the object's internal data
		// cache in order to avoid key collisions between internal data and user-defined
		// data.
		if ( !pvt ) {
			if ( !thisCache.data ) {
				thisCache.data = {};
			}

			thisCache = thisCache.data;
		}

		if ( data !== undefined ) {
			thisCache[ jQuery.camelCase( name ) ] = data;
		}

		// Users should not attempt to inspect the internal events object using jQuery.data,
		// it is undocumented and subject to change. But does anyone listen? No.
		if ( isEvents && !thisCache[ name ] ) {
			return privateCache.events;
		}

		// Check for both converted-to-camel and non-converted data property names
		// If a data property was specified
		if ( getByName ) {

			// First Try to find as-is property data
			ret = thisCache[ name ];

			// Test for null|undefined property data
			if ( ret == null ) {

				// Try to find the camelCased property
				ret = thisCache[ jQuery.camelCase( name ) ];
			}
		} else {
			ret = thisCache;
		}

		return ret;
	},

	removeData: function( elem, name, pvt /* Internal Use Only */ ) {
		if ( !jQuery.acceptData( elem ) ) {
			return;
		}

		var thisCache, i, l,

			// Reference to internal data cache key
			internalKey = jQuery.expando,

			isNode = elem.nodeType,

			// See jQuery.data for more information
			cache = isNode ? jQuery.cache : elem,

			// See jQuery.data for more information
			id = isNode ? elem[ internalKey ] : internalKey;

		// If there is already no cache entry for this object, there is no
		// purpose in continuing
		if ( !cache[ id ] ) {
			return;
		}

		if ( name ) {

			thisCache = pvt ? cache[ id ] : cache[ id ].data;

			if ( thisCache ) {

				// Support array or space separated string names for data keys
				if ( !jQuery.isArray( name ) ) {

					// try the string as a key before any manipulation
					if ( name in thisCache ) {
						name = [ name ];
					} else {

						// split the camel cased version by spaces unless a key with the spaces exists
						name = jQuery.camelCase( name );
						if ( name in thisCache ) {
							name = [ name ];
						} else {
							name = name.split( " " );
						}
					}
				}

				for ( i = 0, l = name.length; i < l; i++ ) {
					delete thisCache[ name[i] ];
				}

				// If there is no data left in the cache, we want to continue
				// and let the cache object itself get destroyed
				if ( !( pvt ? isEmptyDataObject : jQuery.isEmptyObject )( thisCache ) ) {
					return;
				}
			}
		}

		// See jQuery.data for more information
		if ( !pvt ) {
			delete cache[ id ].data;

			// Don't destroy the parent cache unless the internal data object
			// had been the only thing left in it
			if ( !isEmptyDataObject(cache[ id ]) ) {
				return;
			}
		}

		// Browsers that fail expando deletion also refuse to delete expandos on
		// the window, but it will allow it on all other JS objects; other browsers
		// don't care
		// Ensure that `cache` is not a window object #10080
		if ( jQuery.support.deleteExpando || !cache.setInterval ) {
			delete cache[ id ];
		} else {
			cache[ id ] = null;
		}

		// We destroyed the cache and need to eliminate the expando on the node to avoid
		// false lookups in the cache for entries that no longer exist
		if ( isNode ) {
			// IE does not allow us to delete expando properties from nodes,
			// nor does it have a removeAttribute function on Document nodes;
			// we must handle all of these cases
			if ( jQuery.support.deleteExpando ) {
				delete elem[ internalKey ];
			} else if ( elem.removeAttribute ) {
				elem.removeAttribute( internalKey );
			} else {
				elem[ internalKey ] = null;
			}
		}
	},

	// For internal use only.
	_data: function( elem, name, data ) {
		return jQuery.data( elem, name, data, true );
	},

	// A method for determining if a DOM node can handle the data expando
	acceptData: function( elem ) {
		if ( elem.nodeName ) {
			var match = jQuery.noData[ elem.nodeName.toLowerCase() ];

			if ( match ) {
				return !(match === true || elem.getAttribute("classid") !== match);
			}
		}

		return true;
	}
});

jQuery.fn.extend({
	data: function( key, value ) {
		var parts, part, attr, name, l,
			elem = this[0],
			i = 0,
			data = null;

		// Gets all values
		if ( key === undefined ) {
			if ( this.length ) {
				data = jQuery.data( elem );

				if ( elem.nodeType === 1 && !jQuery._data( elem, "parsedAttrs" ) ) {
					attr = elem.attributes;
					for ( l = attr.length; i < l; i++ ) {
						name = attr[i].name;

						if ( name.indexOf( "data-" ) === 0 ) {
							name = jQuery.camelCase( name.substring(5) );

							dataAttr( elem, name, data[ name ] );
						}
					}
					jQuery._data( elem, "parsedAttrs", true );
				}
			}

			return data;
		}

		// Sets multiple values
		if ( typeof key === "object" ) {
			return this.each(function() {
				jQuery.data( this, key );
			});
		}

		parts = key.split( ".", 2 );
		parts[1] = parts[1] ? "." + parts[1] : "";
		part = parts[1] + "!";

		return jQuery.access( this, function( value ) {

			if ( value === undefined ) {
				data = this.triggerHandler( "getData" + part, [ parts[0] ] );

				// Try to fetch any internally stored data first
				if ( data === undefined && elem ) {
					data = jQuery.data( elem, key );
					data = dataAttr( elem, key, data );
				}

				return data === undefined && parts[1] ?
					this.data( parts[0] ) :
					data;
			}

			parts[1] = value;
			this.each(function() {
				var self = jQuery( this );

				self.triggerHandler( "setData" + part, parts );
				jQuery.data( this, key, value );
				self.triggerHandler( "changeData" + part, parts );
			});
		}, null, value, arguments.length > 1, null, false );
	},

	removeData: function( key ) {
		return this.each(function() {
			jQuery.removeData( this, key );
		});
	}
});

function dataAttr( elem, key, data ) {
	// If nothing was found internally, try to fetch any
	// data from the HTML5 data-* attribute
	if ( data === undefined && elem.nodeType === 1 ) {

		var name = "data-" + key.replace( rmultiDash, "-$1" ).toLowerCase();

		data = elem.getAttribute( name );

		if ( typeof data === "string" ) {
			try {
				data = data === "true" ? true :
				data === "false" ? false :
				data === "null" ? null :
				jQuery.isNumeric( data ) ? +data :
					rbrace.test( data ) ? jQuery.parseJSON( data ) :
					data;
			} catch( e ) {}

			// Make sure we set the data so it isn't changed later
			jQuery.data( elem, key, data );

		} else {
			data = undefined;
		}
	}

	return data;
}

// checks a cache object for emptiness
function isEmptyDataObject( obj ) {
	for ( var name in obj ) {

		// if the public data object is empty, the private is still empty
		if ( name === "data" && jQuery.isEmptyObject( obj[name] ) ) {
			continue;
		}
		if ( name !== "toJSON" ) {
			return false;
		}
	}

	return true;
}




function handleQueueMarkDefer( elem, type, src ) {
	var deferDataKey = type + "defer",
		queueDataKey = type + "queue",
		markDataKey = type + "mark",
		defer = jQuery._data( elem, deferDataKey );
	if ( defer &&
		( src === "queue" || !jQuery._data(elem, queueDataKey) ) &&
		( src === "mark" || !jQuery._data(elem, markDataKey) ) ) {
		// Give room for hard-coded callbacks to fire first
		// and eventually mark/queue something else on the element
		setTimeout( function() {
			if ( !jQuery._data( elem, queueDataKey ) &&
				!jQuery._data( elem, markDataKey ) ) {
				jQuery.removeData( elem, deferDataKey, true );
				defer.fire();
			}
		}, 0 );
	}
}

jQuery.extend({

	_mark: function( elem, type ) {
		if ( elem ) {
			type = ( type || "fx" ) + "mark";
			jQuery._data( elem, type, (jQuery._data( elem, type ) || 0) + 1 );
		}
	},

	_unmark: function( force, elem, type ) {
		if ( force !== true ) {
			type = elem;
			elem = force;
			force = false;
		}
		if ( elem ) {
			type = type || "fx";
			var key = type + "mark",
				count = force ? 0 : ( (jQuery._data( elem, key ) || 1) - 1 );
			if ( count ) {
				jQuery._data( elem, key, count );
			} else {
				jQuery.removeData( elem, key, true );
				handleQueueMarkDefer( elem, type, "mark" );
			}
		}
	},

	queue: function( elem, type, data ) {
		var q;
		if ( elem ) {
			type = ( type || "fx" ) + "queue";
			q = jQuery._data( elem, type );

			// Speed up dequeue by getting out quickly if this is just a lookup
			if ( data ) {
				if ( !q || jQuery.isArray(data) ) {
					q = jQuery._data( elem, type, jQuery.makeArray(data) );
				} else {
					q.push( data );
				}
			}
			return q || [];
		}
	},

	dequeue: function( elem, type ) {
		type = type || "fx";

		var queue = jQuery.queue( elem, type ),
			fn = queue.shift(),
			hooks = {};

		// If the fx queue is dequeued, always remove the progress sentinel
		if ( fn === "inprogress" ) {
			fn = queue.shift();
		}

		if ( fn ) {
			// Add a progress sentinel to prevent the fx queue from being
			// automatically dequeued
			if ( type === "fx" ) {
				queue.unshift( "inprogress" );
			}

			jQuery._data( elem, type + ".run", hooks );
			fn.call( elem, function() {
				jQuery.dequeue( elem, type );
			}, hooks );
		}

		if ( !queue.length ) {
			jQuery.removeData( elem, type + "queue " + type + ".run", true );
			handleQueueMarkDefer( elem, type, "queue" );
		}
	}
});

jQuery.fn.extend({
	queue: function( type, data ) {
		var setter = 2;

		if ( typeof type !== "string" ) {
			data = type;
			type = "fx";
			setter--;
		}

		if ( arguments.length < setter ) {
			return jQuery.queue( this[0], type );
		}

		return data === undefined ?
			this :
			this.each(function() {
				var queue = jQuery.queue( this, type, data );

				if ( type === "fx" && queue[0] !== "inprogress" ) {
					jQuery.dequeue( this, type );
				}
			});
	},
	dequeue: function( type ) {
		return this.each(function() {
			jQuery.dequeue( this, type );
		});
	},
	// Based off of the plugin by Clint Helfers, with permission.
	// http://blindsignals.com/index.php/2009/07/jquery-delay/
	delay: function( time, type ) {
		time = jQuery.fx ? jQuery.fx.speeds[ time ] || time : time;
		type = type || "fx";

		return this.queue( type, function( next, hooks ) {
			var timeout = setTimeout( next, time );
			hooks.stop = function() {
				clearTimeout( timeout );
			};
		});
	},
	clearQueue: function( type ) {
		return this.queue( type || "fx", [] );
	},
	// Get a promise resolved when queues of a certain type
	// are emptied (fx is the type by default)
	promise: function( type, object ) {
		if ( typeof type !== "string" ) {
			object = type;
			type = undefined;
		}
		type = type || "fx";
		var defer = jQuery.Deferred(),
			elements = this,
			i = elements.length,
			count = 1,
			deferDataKey = type + "defer",
			queueDataKey = type + "queue",
			markDataKey = type + "mark",
			tmp;
		function resolve() {
			if ( !( --count ) ) {
				defer.resolveWith( elements, [ elements ] );
			}
		}
		while( i-- ) {
			if (( tmp = jQuery.data( elements[ i ], deferDataKey, undefined, true ) ||
					( jQuery.data( elements[ i ], queueDataKey, undefined, true ) ||
						jQuery.data( elements[ i ], markDataKey, undefined, true ) ) &&
					jQuery.data( elements[ i ], deferDataKey, jQuery.Callbacks( "once memory" ), true ) )) {
				count++;
				tmp.add( resolve );
			}
		}
		resolve();
		return defer.promise( object );
	}
});




var rclass = /[\n\t\r]/g,
	rspace = /\s+/,
	rreturn = /\r/g,
	rtype = /^(?:button|input)$/i,
	rfocusable = /^(?:button|input|object|select|textarea)$/i,
	rclickable = /^a(?:rea)?$/i,
	rboolean = /^(?:autofocus|autoplay|async|checked|controls|defer|disabled|hidden|loop|multiple|open|readonly|required|scoped|selected)$/i,
	getSetAttribute = jQuery.support.getSetAttribute,
	nodeHook, boolHook, fixSpecified;

jQuery.fn.extend({
	attr: function( name, value ) {
		return jQuery.access( this, jQuery.attr, name, value, arguments.length > 1 );
	},

	removeAttr: function( name ) {
		return this.each(function() {
			jQuery.removeAttr( this, name );
		});
	},

	prop: function( name, value ) {
		return jQuery.access( this, jQuery.prop, name, value, arguments.length > 1 );
	},

	removeProp: function( name ) {
		name = jQuery.propFix[ name ] || name;
		return this.each(function() {
			// try/catch handles cases where IE balks (such as removing a property on window)
			try {
				this[ name ] = undefined;
				delete this[ name ];
			} catch( e ) {}
		});
	},

	addClass: function( value ) {
		var classNames, i, l, elem,
			setClass, c, cl;

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( j ) {
				jQuery( this ).addClass( value.call(this, j, this.className) );
			});
		}

		if ( value && typeof value === "string" ) {
			classNames = value.split( rspace );

			for ( i = 0, l = this.length; i < l; i++ ) {
				elem = this[ i ];

				if ( elem.nodeType === 1 ) {
					if ( !elem.className && classNames.length === 1 ) {
						elem.className = value;

					} else {
						setClass = " " + elem.className + " ";

						for ( c = 0, cl = classNames.length; c < cl; c++ ) {
							if ( !~setClass.indexOf( " " + classNames[ c ] + " " ) ) {
								setClass += classNames[ c ] + " ";
							}
						}
						elem.className = jQuery.trim( setClass );
					}
				}
			}
		}

		return this;
	},

	removeClass: function( value ) {
		var classNames, i, l, elem, className, c, cl;

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( j ) {
				jQuery( this ).removeClass( value.call(this, j, this.className) );
			});
		}

		if ( (value && typeof value === "string") || value === undefined ) {
			classNames = ( value || "" ).split( rspace );

			for ( i = 0, l = this.length; i < l; i++ ) {
				elem = this[ i ];

				if ( elem.nodeType === 1 && elem.className ) {
					if ( value ) {
						className = (" " + elem.className + " ").replace( rclass, " " );
						for ( c = 0, cl = classNames.length; c < cl; c++ ) {
							className = className.replace(" " + classNames[ c ] + " ", " ");
						}
						elem.className = jQuery.trim( className );

					} else {
						elem.className = "";
					}
				}
			}
		}

		return this;
	},

	toggleClass: function( value, stateVal ) {
		var type = typeof value,
			isBool = typeof stateVal === "boolean";

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( i ) {
				jQuery( this ).toggleClass( value.call(this, i, this.className, stateVal), stateVal );
			});
		}

		return this.each(function() {
			if ( type === "string" ) {
				// toggle individual class names
				var className,
					i = 0,
					self = jQuery( this ),
					state = stateVal,
					classNames = value.split( rspace );

				while ( (className = classNames[ i++ ]) ) {
					// check each className given, space seperated list
					state = isBool ? state : !self.hasClass( className );
					self[ state ? "addClass" : "removeClass" ]( className );
				}

			} else if ( type === "undefined" || type === "boolean" ) {
				if ( this.className ) {
					// store className if set
					jQuery._data( this, "__className__", this.className );
				}

				// toggle whole className
				this.className = this.className || value === false ? "" : jQuery._data( this, "__className__" ) || "";
			}
		});
	},

	hasClass: function( selector ) {
		var className = " " + selector + " ",
			i = 0,
			l = this.length;
		for ( ; i < l; i++ ) {
			if ( this[i].nodeType === 1 && (" " + this[i].className + " ").replace(rclass, " ").indexOf( className ) > -1 ) {
				return true;
			}
		}

		return false;
	},

	val: function( value ) {
		var hooks, ret, isFunction,
			elem = this[0];

		if ( !arguments.length ) {
			if ( elem ) {
				hooks = jQuery.valHooks[ elem.type ] || jQuery.valHooks[ elem.nodeName.toLowerCase() ];

				if ( hooks && "get" in hooks && (ret = hooks.get( elem, "value" )) !== undefined ) {
					return ret;
				}

				ret = elem.value;

				return typeof ret === "string" ?
					// handle most common string cases
					ret.replace(rreturn, "") :
					// handle cases where value is null/undef or number
					ret == null ? "" : ret;
			}

			return;
		}

		isFunction = jQuery.isFunction( value );

		return this.each(function( i ) {
			var self = jQuery(this), val;

			if ( this.nodeType !== 1 ) {
				return;
			}

			if ( isFunction ) {
				val = value.call( this, i, self.val() );
			} else {
				val = value;
			}

			// Treat null/undefined as ""; convert numbers to string
			if ( val == null ) {
				val = "";
			} else if ( typeof val === "number" ) {
				val += "";
			} else if ( jQuery.isArray( val ) ) {
				val = jQuery.map(val, function ( value ) {
					return value == null ? "" : value + "";
				});
			}

			hooks = jQuery.valHooks[ this.type ] || jQuery.valHooks[ this.nodeName.toLowerCase() ];

			// If set returns undefined, fall back to normal setting
			if ( !hooks || !("set" in hooks) || hooks.set( this, val, "value" ) === undefined ) {
				this.value = val;
			}
		});
	}
});

jQuery.extend({
	valHooks: {
		option: {
			get: function( elem ) {
				// attributes.value is undefined in Blackberry 4.7 but
				// uses .value. See #6932
				var val = elem.attributes.value;
				return !val || val.specified ? elem.value : elem.text;
			}
		},
		select: {
			get: function( elem ) {
				var value, i, max, option,
					index = elem.selectedIndex,
					values = [],
					options = elem.options,
					one = elem.type === "select-one";

				// Nothing was selected
				if ( index < 0 ) {
					return null;
				}

				// Loop through all the selected options
				i = one ? index : 0;
				max = one ? index + 1 : options.length;
				for ( ; i < max; i++ ) {
					option = options[ i ];

					// Don't return options that are disabled or in a disabled optgroup
					if ( option.selected && (jQuery.support.optDisabled ? !option.disabled : option.getAttribute("disabled") === null) &&
							(!option.parentNode.disabled || !jQuery.nodeName( option.parentNode, "optgroup" )) ) {

						// Get the specific value for the option
						value = jQuery( option ).val();

						// We don't need an array for one selects
						if ( one ) {
							return value;
						}

						// Multi-Selects return an array
						values.push( value );
					}
				}

				// Fixes Bug #2551 -- select.val() broken in IE after form.reset()
				if ( one && !values.length && options.length ) {
					return jQuery( options[ index ] ).val();
				}

				return values;
			},

			set: function( elem, value ) {
				var values = jQuery.makeArray( value );

				jQuery(elem).find("option").each(function() {
					this.selected = jQuery.inArray( jQuery(this).val(), values ) >= 0;
				});

				if ( !values.length ) {
					elem.selectedIndex = -1;
				}
				return values;
			}
		}
	},

	attrFn: {
		val: true,
		css: true,
		html: true,
		text: true,
		data: true,
		width: true,
		height: true,
		offset: true
	},

	attr: function( elem, name, value, pass ) {
		var ret, hooks, notxml,
			nType = elem.nodeType;

		// don't get/set attributes on text, comment and attribute nodes
		if ( !elem || nType === 3 || nType === 8 || nType === 2 ) {
			return;
		}

		if ( pass && name in jQuery.attrFn ) {
			return jQuery( elem )[ name ]( value );
		}

		// Fallback to prop when attributes are not supported
		if ( typeof elem.getAttribute === "undefined" ) {
			return jQuery.prop( elem, name, value );
		}

		notxml = nType !== 1 || !jQuery.isXMLDoc( elem );

		// All attributes are lowercase
		// Grab necessary hook if one is defined
		if ( notxml ) {
			name = name.toLowerCase();
			hooks = jQuery.attrHooks[ name ] || ( rboolean.test( name ) ? boolHook : nodeHook );
		}

		if ( value !== undefined ) {

			if ( value === null ) {
				jQuery.removeAttr( elem, name );
				return;

			} else if ( hooks && "set" in hooks && notxml && (ret = hooks.set( elem, value, name )) !== undefined ) {
				return ret;

			} else {
				elem.setAttribute( name, "" + value );
				return value;
			}

		} else if ( hooks && "get" in hooks && notxml && (ret = hooks.get( elem, name )) !== null ) {
			return ret;

		} else {

			ret = elem.getAttribute( name );

			// Non-existent attributes return null, we normalize to undefined
			return ret === null ?
				undefined :
				ret;
		}
	},

	removeAttr: function( elem, value ) {
		var propName, attrNames, name, l, isBool,
			i = 0;

		if ( value && elem.nodeType === 1 ) {
			attrNames = value.toLowerCase().split( rspace );
			l = attrNames.length;

			for ( ; i < l; i++ ) {
				name = attrNames[ i ];

				if ( name ) {
					propName = jQuery.propFix[ name ] || name;
					isBool = rboolean.test( name );

					// See #9699 for explanation of this approach (setting first, then removal)
					// Do not do this for boolean attributes (see #10870)
					if ( !isBool ) {
						jQuery.attr( elem, name, "" );
					}
					elem.removeAttribute( getSetAttribute ? name : propName );

					// Set corresponding property to false for boolean attributes
					if ( isBool && propName in elem ) {
						elem[ propName ] = false;
					}
				}
			}
		}
	},

	attrHooks: {
		type: {
			set: function( elem, value ) {
				// We can't allow the type property to be changed (since it causes problems in IE)
				if ( rtype.test( elem.nodeName ) && elem.parentNode ) {
					jQuery.error( "type property can't be changed" );
				} else if ( !jQuery.support.radioValue && value === "radio" && jQuery.nodeName(elem, "input") ) {
					// Setting the type on a radio button after the value resets the value in IE6-9
					// Reset value to it's default in case type is set after value
					// This is for element creation
					var val = elem.value;
					elem.setAttribute( "type", value );
					if ( val ) {
						elem.value = val;
					}
					return value;
				}
			}
		},
		// Use the value property for back compat
		// Use the nodeHook for button elements in IE6/7 (#1954)
		value: {
			get: function( elem, name ) {
				if ( nodeHook && jQuery.nodeName( elem, "button" ) ) {
					return nodeHook.get( elem, name );
				}
				return name in elem ?
					elem.value :
					null;
			},
			set: function( elem, value, name ) {
				if ( nodeHook && jQuery.nodeName( elem, "button" ) ) {
					return nodeHook.set( elem, value, name );
				}
				// Does not return so that setAttribute is also used
				elem.value = value;
			}
		}
	},

	propFix: {
		tabindex: "tabIndex",
		readonly: "readOnly",
		"for": "htmlFor",
		"class": "className",
		maxlength: "maxLength",
		cellspacing: "cellSpacing",
		cellpadding: "cellPadding",
		rowspan: "rowSpan",
		colspan: "colSpan",
		usemap: "useMap",
		frameborder: "frameBorder",
		contenteditable: "contentEditable"
	},

	prop: function( elem, name, value ) {
		var ret, hooks, notxml,
			nType = elem.nodeType;

		// don't get/set properties on text, comment and attribute nodes
		if ( !elem || nType === 3 || nType === 8 || nType === 2 ) {
			return;
		}

		notxml = nType !== 1 || !jQuery.isXMLDoc( elem );

		if ( notxml ) {
			// Fix name and attach hooks
			name = jQuery.propFix[ name ] || name;
			hooks = jQuery.propHooks[ name ];
		}

		if ( value !== undefined ) {
			if ( hooks && "set" in hooks && (ret = hooks.set( elem, value, name )) !== undefined ) {
				return ret;

			} else {
				return ( elem[ name ] = value );
			}

		} else {
			if ( hooks && "get" in hooks && (ret = hooks.get( elem, name )) !== null ) {
				return ret;

			} else {
				return elem[ name ];
			}
		}
	},

	propHooks: {
		tabIndex: {
			get: function( elem ) {
				// elem.tabIndex doesn't always return the correct value when it hasn't been explicitly set
				// http://fluidproject.org/blog/2008/01/09/getting-setting-and-removing-tabindex-values-with-javascript/
				var attributeNode = elem.getAttributeNode("tabindex");

				return attributeNode && attributeNode.specified ?
					parseInt( attributeNode.value, 10 ) :
					rfocusable.test( elem.nodeName ) || rclickable.test( elem.nodeName ) && elem.href ?
						0 :
						undefined;
			}
		}
	}
});

// Add the tabIndex propHook to attrHooks for back-compat (different case is intentional)
jQuery.attrHooks.tabindex = jQuery.propHooks.tabIndex;

// Hook for boolean attributes
boolHook = {
	get: function( elem, name ) {
		// Align boolean attributes with corresponding properties
		// Fall back to attribute presence where some booleans are not supported
		var attrNode,
			property = jQuery.prop( elem, name );
		return property === true || typeof property !== "boolean" && ( attrNode = elem.getAttributeNode(name) ) && attrNode.nodeValue !== false ?
			name.toLowerCase() :
			undefined;
	},
	set: function( elem, value, name ) {
		var propName;
		if ( value === false ) {
			// Remove boolean attributes when set to false
			jQuery.removeAttr( elem, name );
		} else {
			// value is true since we know at this point it's type boolean and not false
			// Set boolean attributes to the same name and set the DOM property
			propName = jQuery.propFix[ name ] || name;
			if ( propName in elem ) {
				// Only set the IDL specifically if it already exists on the element
				elem[ propName ] = true;
			}

			elem.setAttribute( name, name.toLowerCase() );
		}
		return name;
	}
};

// IE6/7 do not support getting/setting some attributes with get/setAttribute
if ( !getSetAttribute ) {

	fixSpecified = {
		name: true,
		id: true,
		coords: true
	};

	// Use this for any attribute in IE6/7
	// This fixes almost every IE6/7 issue
	nodeHook = jQuery.valHooks.button = {
		get: function( elem, name ) {
			var ret;
			ret = elem.getAttributeNode( name );
			return ret && ( fixSpecified[ name ] ? ret.nodeValue !== "" : ret.specified ) ?
				ret.nodeValue :
				undefined;
		},
		set: function( elem, value, name ) {
			// Set the existing or create a new attribute node
			var ret = elem.getAttributeNode( name );
			if ( !ret ) {
				ret = document.createAttribute( name );
				elem.setAttributeNode( ret );
			}
			return ( ret.nodeValue = value + "" );
		}
	};

	// Apply the nodeHook to tabindex
	jQuery.attrHooks.tabindex.set = nodeHook.set;

	// Set width and height to auto instead of 0 on empty string( Bug #8150 )
	// This is for removals
	jQuery.each([ "width", "height" ], function( i, name ) {
		jQuery.attrHooks[ name ] = jQuery.extend( jQuery.attrHooks[ name ], {
			set: function( elem, value ) {
				if ( value === "" ) {
					elem.setAttribute( name, "auto" );
					return value;
				}
			}
		});
	});

	// Set contenteditable to false on removals(#10429)
	// Setting to empty string throws an error as an invalid value
	jQuery.attrHooks.contenteditable = {
		get: nodeHook.get,
		set: function( elem, value, name ) {
			if ( value === "" ) {
				value = "false";
			}
			nodeHook.set( elem, value, name );
		}
	};
}


// Some attributes require a special call on IE
if ( !jQuery.support.hrefNormalized ) {
	jQuery.each([ "href", "src", "width", "height" ], function( i, name ) {
		jQuery.attrHooks[ name ] = jQuery.extend( jQuery.attrHooks[ name ], {
			get: function( elem ) {
				var ret = elem.getAttribute( name, 2 );
				return ret === null ? undefined : ret;
			}
		});
	});
}

if ( !jQuery.support.style ) {
	jQuery.attrHooks.style = {
		get: function( elem ) {
			// Return undefined in the case of empty string
			// Normalize to lowercase since IE uppercases css property names
			return elem.style.cssText.toLowerCase() || undefined;
		},
		set: function( elem, value ) {
			return ( elem.style.cssText = "" + value );
		}
	};
}

// Safari mis-reports the default selected property of an option
// Accessing the parent's selectedIndex property fixes it
if ( !jQuery.support.optSelected ) {
	jQuery.propHooks.selected = jQuery.extend( jQuery.propHooks.selected, {
		get: function( elem ) {
			var parent = elem.parentNode;

			if ( parent ) {
				parent.selectedIndex;

				// Make sure that it also works with optgroups, see #5701
				if ( parent.parentNode ) {
					parent.parentNode.selectedIndex;
				}
			}
			return null;
		}
	});
}

// IE6/7 call enctype encoding
if ( !jQuery.support.enctype ) {
	jQuery.propFix.enctype = "encoding";
}

// Radios and checkboxes getter/setter
if ( !jQuery.support.checkOn ) {
	jQuery.each([ "radio", "checkbox" ], function() {
		jQuery.valHooks[ this ] = {
			get: function( elem ) {
				// Handle the case where in Webkit "" is returned instead of "on" if a value isn't specified
				return elem.getAttribute("value") === null ? "on" : elem.value;
			}
		};
	});
}
jQuery.each([ "radio", "checkbox" ], function() {
	jQuery.valHooks[ this ] = jQuery.extend( jQuery.valHooks[ this ], {
		set: function( elem, value ) {
			if ( jQuery.isArray( value ) ) {
				return ( elem.checked = jQuery.inArray( jQuery(elem).val(), value ) >= 0 );
			}
		}
	});
});




var rformElems = /^(?:textarea|input|select)$/i,
	rtypenamespace = /^([^\.]*)?(?:\.(.+))?$/,
	rhoverHack = /(?:^|\s)hover(\.\S+)?\b/,
	rkeyEvent = /^key/,
	rmouseEvent = /^(?:mouse|contextmenu)|click/,
	rfocusMorph = /^(?:focusinfocus|focusoutblur)$/,
	rquickIs = /^(\w*)(?:#([\w\-]+))?(?:\.([\w\-]+))?$/,
	quickParse = function( selector ) {
		var quick = rquickIs.exec( selector );
		if ( quick ) {
			//   0  1    2   3
			// [ _, tag, id, class ]
			quick[1] = ( quick[1] || "" ).toLowerCase();
			quick[3] = quick[3] && new RegExp( "(?:^|\\s)" + quick[3] + "(?:\\s|$)" );
		}
		return quick;
	},
	quickIs = function( elem, m ) {
		var attrs = elem.attributes || {};
		return (
			(!m[1] || elem.nodeName.toLowerCase() === m[1]) &&
			(!m[2] || (attrs.id || {}).value === m[2]) &&
			(!m[3] || m[3].test( (attrs[ "class" ] || {}).value ))
		);
	},
	hoverHack = function( events ) {
		return jQuery.event.special.hover ? events : events.replace( rhoverHack, "mouseenter$1 mouseleave$1" );
	};

/*
 * Helper functions for managing events -- not part of the public interface.
 * Props to Dean Edwards' addEvent library for many of the ideas.
 */
jQuery.event = {

	add: function( elem, types, handler, data, selector ) {

		var elemData, eventHandle, events,
			t, tns, type, namespaces, handleObj,
			handleObjIn, quick, handlers, special;

		// Don't attach events to noData or text/comment nodes (allow plain objects tho)
		if ( elem.nodeType === 3 || elem.nodeType === 8 || !types || !handler || !(elemData = jQuery._data( elem )) ) {
			return;
		}

		// Caller can pass in an object of custom data in lieu of the handler
		if ( handler.handler ) {
			handleObjIn = handler;
			handler = handleObjIn.handler;
			selector = handleObjIn.selector;
		}

		// Make sure that the handler has a unique ID, used to find/remove it later
		if ( !handler.guid ) {
			handler.guid = jQuery.guid++;
		}

		// Init the element's event structure and main handler, if this is the first
		events = elemData.events;
		if ( !events ) {
			elemData.events = events = {};
		}
		eventHandle = elemData.handle;
		if ( !eventHandle ) {
			elemData.handle = eventHandle = function( e ) {
				// Discard the second event of a jQuery.event.trigger() and
				// when an event is called after a page has unloaded
				return typeof jQuery !== "undefined" && (!e || jQuery.event.triggered !== e.type) ?
					jQuery.event.dispatch.apply( eventHandle.elem, arguments ) :
					undefined;
			};
			// Add elem as a property of the handle fn to prevent a memory leak with IE non-native events
			eventHandle.elem = elem;
		}

		// Handle multiple events separated by a space
		// jQuery(...).bind("mouseover mouseout", fn);
		types = jQuery.trim( hoverHack(types) ).split( " " );
		for ( t = 0; t < types.length; t++ ) {

			tns = rtypenamespace.exec( types[t] ) || [];
			type = tns[1];
			namespaces = ( tns[2] || "" ).split( "." ).sort();

			// If event changes its type, use the special event handlers for the changed type
			special = jQuery.event.special[ type ] || {};

			// If selector defined, determine special event api type, otherwise given type
			type = ( selector ? special.delegateType : special.bindType ) || type;

			// Update special based on newly reset type
			special = jQuery.event.special[ type ] || {};

			// handleObj is passed to all event handlers
			handleObj = jQuery.extend({
				type: type,
				origType: tns[1],
				data: data,
				handler: handler,
				guid: handler.guid,
				selector: selector,
				quick: selector && quickParse( selector ),
				namespace: namespaces.join(".")
			}, handleObjIn );

			// Init the event handler queue if we're the first
			handlers = events[ type ];
			if ( !handlers ) {
				handlers = events[ type ] = [];
				handlers.delegateCount = 0;

				// Only use addEventListener/attachEvent if the special events handler returns false
				if ( !special.setup || special.setup.call( elem, data, namespaces, eventHandle ) === false ) {
					// Bind the global event handler to the element
					if ( elem.addEventListener ) {
						elem.addEventListener( type, eventHandle, false );

					} else if ( elem.attachEvent ) {
						elem.attachEvent( "on" + type, eventHandle );
					}
				}
			}

			if ( special.add ) {
				special.add.call( elem, handleObj );

				if ( !handleObj.handler.guid ) {
					handleObj.handler.guid = handler.guid;
				}
			}

			// Add to the element's handler list, delegates in front
			if ( selector ) {
				handlers.splice( handlers.delegateCount++, 0, handleObj );
			} else {
				handlers.push( handleObj );
			}

			// Keep track of which events have ever been used, for event optimization
			jQuery.event.global[ type ] = true;
		}

		// Nullify elem to prevent memory leaks in IE
		elem = null;
	},

	global: {},

	// Detach an event or set of events from an element
	remove: function( elem, types, handler, selector, mappedTypes ) {

		var elemData = jQuery.hasData( elem ) && jQuery._data( elem ),
			t, tns, type, origType, namespaces, origCount,
			j, events, special, handle, eventType, handleObj;

		if ( !elemData || !(events = elemData.events) ) {
			return;
		}

		// Once for each type.namespace in types; type may be omitted
		types = jQuery.trim( hoverHack( types || "" ) ).split(" ");
		for ( t = 0; t < types.length; t++ ) {
			tns = rtypenamespace.exec( types[t] ) || [];
			type = origType = tns[1];
			namespaces = tns[2];

			// Unbind all events (on this namespace, if provided) for the element
			if ( !type ) {
				for ( type in events ) {
					jQuery.event.remove( elem, type + types[ t ], handler, selector, true );
				}
				continue;
			}

			special = jQuery.event.special[ type ] || {};
			type = ( selector? special.delegateType : special.bindType ) || type;
			eventType = events[ type ] || [];
			origCount = eventType.length;
			namespaces = namespaces ? new RegExp("(^|\\.)" + namespaces.split(".").sort().join("\\.(?:.*\\.)?") + "(\\.|$)") : null;

			// Remove matching events
			for ( j = 0; j < eventType.length; j++ ) {
				handleObj = eventType[ j ];

				if ( ( mappedTypes || origType === handleObj.origType ) &&
					 ( !handler || handler.guid === handleObj.guid ) &&
					 ( !namespaces || namespaces.test( handleObj.namespace ) ) &&
					 ( !selector || selector === handleObj.selector || selector === "**" && handleObj.selector ) ) {
					eventType.splice( j--, 1 );

					if ( handleObj.selector ) {
						eventType.delegateCount--;
					}
					if ( special.remove ) {
						special.remove.call( elem, handleObj );
					}
				}
			}

			// Remove generic event handler if we removed something and no more handlers exist
			// (avoids potential for endless recursion during removal of special event handlers)
			if ( eventType.length === 0 && origCount !== eventType.length ) {
				if ( !special.teardown || special.teardown.call( elem, namespaces ) === false ) {
					jQuery.removeEvent( elem, type, elemData.handle );
				}

				delete events[ type ];
			}
		}

		// Remove the expando if it's no longer used
		if ( jQuery.isEmptyObject( events ) ) {
			handle = elemData.handle;
			if ( handle ) {
				handle.elem = null;
			}

			// removeData also checks for emptiness and clears the expando if empty
			// so use it instead of delete
			jQuery.removeData( elem, [ "events", "handle" ], true );
		}
	},

	// Events that are safe to short-circuit if no handlers are attached.
	// Native DOM events should not be added, they may have inline handlers.
	customEvent: {
		"getData": true,
		"setData": true,
		"changeData": true
	},

	trigger: function( event, data, elem, onlyHandlers ) {
		// Don't do events on text and comment nodes
		if ( elem && (elem.nodeType === 3 || elem.nodeType === 8) ) {
			return;
		}

		// Event object or event type
		var type = event.type || event,
			namespaces = [],
			cache, exclusive, i, cur, old, ontype, special, handle, eventPath, bubbleType;

		// focus/blur morphs to focusin/out; ensure we're not firing them right now
		if ( rfocusMorph.test( type + jQuery.event.triggered ) ) {
			return;
		}

		if ( type.indexOf( "!" ) >= 0 ) {
			// Exclusive events trigger only for the exact event (no namespaces)
			type = type.slice(0, -1);
			exclusive = true;
		}

		if ( type.indexOf( "." ) >= 0 ) {
			// Namespaced trigger; create a regexp to match event type in handle()
			namespaces = type.split(".");
			type = namespaces.shift();
			namespaces.sort();
		}

		if ( (!elem || jQuery.event.customEvent[ type ]) && !jQuery.event.global[ type ] ) {
			// No jQuery handlers for this event type, and it can't have inline handlers
			return;
		}

		// Caller can pass in an Event, Object, or just an event type string
		event = typeof event === "object" ?
			// jQuery.Event object
			event[ jQuery.expando ] ? event :
			// Object literal
			new jQuery.Event( type, event ) :
			// Just the event type (string)
			new jQuery.Event( type );

		event.type = type;
		event.isTrigger = true;
		event.exclusive = exclusive;
		event.namespace = namespaces.join( "." );
		event.namespace_re = event.namespace? new RegExp("(^|\\.)" + namespaces.join("\\.(?:.*\\.)?") + "(\\.|$)") : null;
		ontype = type.indexOf( ":" ) < 0 ? "on" + type : "";

		// Handle a global trigger
		if ( !elem ) {

			// TODO: Stop taunting the data cache; remove global events and always attach to document
			cache = jQuery.cache;
			for ( i in cache ) {
				if ( cache[ i ].events && cache[ i ].events[ type ] ) {
					jQuery.event.trigger( event, data, cache[ i ].handle.elem, true );
				}
			}
			return;
		}

		// Clean up the event in case it is being reused
		event.result = undefined;
		if ( !event.target ) {
			event.target = elem;
		}

		// Clone any incoming data and prepend the event, creating the handler arg list
		data = data != null ? jQuery.makeArray( data ) : [];
		data.unshift( event );

		// Allow special events to draw outside the lines
		special = jQuery.event.special[ type ] || {};
		if ( special.trigger && special.trigger.apply( elem, data ) === false ) {
			return;
		}

		// Determine event propagation path in advance, per W3C events spec (#9951)
		// Bubble up to document, then to window; watch for a global ownerDocument var (#9724)
		eventPath = [[ elem, special.bindType || type ]];
		if ( !onlyHandlers && !special.noBubble && !jQuery.isWindow( elem ) ) {

			bubbleType = special.delegateType || type;
			cur = rfocusMorph.test( bubbleType + type ) ? elem : elem.parentNode;
			old = null;
			for ( ; cur; cur = cur.parentNode ) {
				eventPath.push([ cur, bubbleType ]);
				old = cur;
			}

			// Only add window if we got to document (e.g., not plain obj or detached DOM)
			if ( old && old === elem.ownerDocument ) {
				eventPath.push([ old.defaultView || old.parentWindow || window, bubbleType ]);
			}
		}

		// Fire handlers on the event path
		for ( i = 0; i < eventPath.length && !event.isPropagationStopped(); i++ ) {

			cur = eventPath[i][0];
			event.type = eventPath[i][1];

			handle = ( jQuery._data( cur, "events" ) || {} )[ event.type ] && jQuery._data( cur, "handle" );
			if ( handle ) {
				handle.apply( cur, data );
			}
			// Note that this is a bare JS function and not a jQuery handler
			handle = ontype && cur[ ontype ];
			if ( handle && jQuery.acceptData( cur ) && handle.apply( cur, data ) === false ) {
				event.preventDefault();
			}
		}
		event.type = type;

		// If nobody prevented the default action, do it now
		if ( !onlyHandlers && !event.isDefaultPrevented() ) {

			if ( (!special._default || special._default.apply( elem.ownerDocument, data ) === false) &&
				!(type === "click" && jQuery.nodeName( elem, "a" )) && jQuery.acceptData( elem ) ) {

				// Call a native DOM method on the target with the same name name as the event.
				// Can't use an .isFunction() check here because IE6/7 fails that test.
				// Don't do default actions on window, that's where global variables be (#6170)
				// IE<9 dies on focus/blur to hidden element (#1486)
				if ( ontype && elem[ type ] && ((type !== "focus" && type !== "blur") || event.target.offsetWidth !== 0) && !jQuery.isWindow( elem ) ) {

					// Don't re-trigger an onFOO event when we call its FOO() method
					old = elem[ ontype ];

					if ( old ) {
						elem[ ontype ] = null;
					}

					// Prevent re-triggering of the same event, since we already bubbled it above
					jQuery.event.triggered = type;
					elem[ type ]();
					jQuery.event.triggered = undefined;

					if ( old ) {
						elem[ ontype ] = old;
					}
				}
			}
		}

		return event.result;
	},

	dispatch: function( event ) {

		// Make a writable jQuery.Event from the native event object
		event = jQuery.event.fix( event || window.event );

		var handlers = ( (jQuery._data( this, "events" ) || {} )[ event.type ] || []),
			delegateCount = handlers.delegateCount,
			args = [].slice.call( arguments, 0 ),
			run_all = !event.exclusive && !event.namespace,
			special = jQuery.event.special[ event.type ] || {},
			handlerQueue = [],
			i, j, cur, jqcur, ret, selMatch, matched, matches, handleObj, sel, related;

		// Use the fix-ed jQuery.Event rather than the (read-only) native event
		args[0] = event;
		event.delegateTarget = this;

		// Call the preDispatch hook for the mapped type, and let it bail if desired
		if ( special.preDispatch && special.preDispatch.call( this, event ) === false ) {
			return;
		}

		// Determine handlers that should run if there are delegated events
		// Avoid non-left-click bubbling in Firefox (#3861)
		if ( delegateCount && !(event.button && event.type === "click") ) {

			// Pregenerate a single jQuery object for reuse with .is()
			jqcur = jQuery(this);
			jqcur.context = this.ownerDocument || this;

			for ( cur = event.target; cur != this; cur = cur.parentNode || this ) {

				// Don't process events on disabled elements (#6911, #8165)
				if ( cur.disabled !== true ) {
					selMatch = {};
					matches = [];
					jqcur[0] = cur;
					for ( i = 0; i < delegateCount; i++ ) {
						handleObj = handlers[ i ];
						sel = handleObj.selector;

						if ( selMatch[ sel ] === undefined ) {
							selMatch[ sel ] = (
								handleObj.quick ? quickIs( cur, handleObj.quick ) : jqcur.is( sel )
							);
						}
						if ( selMatch[ sel ] ) {
							matches.push( handleObj );
						}
					}
					if ( matches.length ) {
						handlerQueue.push({ elem: cur, matches: matches });
					}
				}
			}
		}

		// Add the remaining (directly-bound) handlers
		if ( handlers.length > delegateCount ) {
			handlerQueue.push({ elem: this, matches: handlers.slice( delegateCount ) });
		}

		// Run delegates first; they may want to stop propagation beneath us
		for ( i = 0; i < handlerQueue.length && !event.isPropagationStopped(); i++ ) {
			matched = handlerQueue[ i ];
			event.currentTarget = matched.elem;

			for ( j = 0; j < matched.matches.length && !event.isImmediatePropagationStopped(); j++ ) {
				handleObj = matched.matches[ j ];

				// Triggered event must either 1) be non-exclusive and have no namespace, or
				// 2) have namespace(s) a subset or equal to those in the bound event (both can have no namespace).
				if ( run_all || (!event.namespace && !handleObj.namespace) || event.namespace_re && event.namespace_re.test( handleObj.namespace ) ) {

					event.data = handleObj.data;
					event.handleObj = handleObj;

					ret = ( (jQuery.event.special[ handleObj.origType ] || {}).handle || handleObj.handler )
							.apply( matched.elem, args );

					if ( ret !== undefined ) {
						event.result = ret;
						if ( ret === false ) {
							event.preventDefault();
							event.stopPropagation();
						}
					}
				}
			}
		}

		// Call the postDispatch hook for the mapped type
		if ( special.postDispatch ) {
			special.postDispatch.call( this, event );
		}

		return event.result;
	},

	// Includes some event props shared by KeyEvent and MouseEvent
	// *** attrChange attrName relatedNode srcElement  are not normalized, non-W3C, deprecated, will be removed in 1.8 ***
	props: "attrChange attrName relatedNode srcElement altKey bubbles cancelable ctrlKey currentTarget eventPhase metaKey relatedTarget shiftKey target timeStamp view which".split(" "),

	fixHooks: {},

	keyHooks: {
		props: "char charCode key keyCode".split(" "),
		filter: function( event, original ) {

			// Add which for key events
			if ( event.which == null ) {
				event.which = original.charCode != null ? original.charCode : original.keyCode;
			}

			return event;
		}
	},

	mouseHooks: {
		props: "button buttons clientX clientY fromElement offsetX offsetY pageX pageY screenX screenY toElement".split(" "),
		filter: function( event, original ) {
			var eventDoc, doc, body,
				button = original.button,
				fromElement = original.fromElement;

			// Calculate pageX/Y if missing and clientX/Y available
			if ( event.pageX == null && original.clientX != null ) {
				eventDoc = event.target.ownerDocument || document;
				doc = eventDoc.documentElement;
				body = eventDoc.body;

				event.pageX = original.clientX + ( doc && doc.scrollLeft || body && body.scrollLeft || 0 ) - ( doc && doc.clientLeft || body && body.clientLeft || 0 );
				event.pageY = original.clientY + ( doc && doc.scrollTop  || body && body.scrollTop  || 0 ) - ( doc && doc.clientTop  || body && body.clientTop  || 0 );
			}

			// Add relatedTarget, if necessary
			if ( !event.relatedTarget && fromElement ) {
				event.relatedTarget = fromElement === event.target ? original.toElement : fromElement;
			}

			// Add which for click: 1 === left; 2 === middle; 3 === right
			// Note: button is not normalized, so don't use it
			if ( !event.which && button !== undefined ) {
				event.which = ( button & 1 ? 1 : ( button & 2 ? 3 : ( button & 4 ? 2 : 0 ) ) );
			}

			return event;
		}
	},

	fix: function( event ) {
		if ( event[ jQuery.expando ] ) {
			return event;
		}

		// Create a writable copy of the event object and normalize some properties
		var i, prop,
			originalEvent = event,
			fixHook = jQuery.event.fixHooks[ event.type ] || {},
			copy = fixHook.props ? this.props.concat( fixHook.props ) : this.props;

		event = jQuery.Event( originalEvent );

		for ( i = copy.length; i; ) {
			prop = copy[ --i ];
			event[ prop ] = originalEvent[ prop ];
		}

		// Fix target property, if necessary (#1925, IE 6/7/8 & Safari2)
		if ( !event.target ) {
			event.target = originalEvent.srcElement || document;
		}

		// Target should not be a text node (#504, Safari)
		if ( event.target.nodeType === 3 ) {
			event.target = event.target.parentNode;
		}

		// For mouse/key events; add metaKey if it's not there (#3368, IE6/7/8)
		if ( event.metaKey === undefined ) {
			event.metaKey = event.ctrlKey;
		}

		return fixHook.filter? fixHook.filter( event, originalEvent ) : event;
	},

	special: {
		ready: {
			// Make sure the ready event is setup
			setup: jQuery.bindReady
		},

		load: {
			// Prevent triggered image.load events from bubbling to window.load
			noBubble: true
		},

		focus: {
			delegateType: "focusin"
		},
		blur: {
			delegateType: "focusout"
		},

		beforeunload: {
			setup: function( data, namespaces, eventHandle ) {
				// We only want to do this special case on windows
				if ( jQuery.isWindow( this ) ) {
					this.onbeforeunload = eventHandle;
				}
			},

			teardown: function( namespaces, eventHandle ) {
				if ( this.onbeforeunload === eventHandle ) {
					this.onbeforeunload = null;
				}
			}
		}
	},

	simulate: function( type, elem, event, bubble ) {
		// Piggyback on a donor event to simulate a different one.
		// Fake originalEvent to avoid donor's stopPropagation, but if the
		// simulated event prevents default then we do the same on the donor.
		var e = jQuery.extend(
			new jQuery.Event(),
			event,
			{ type: type,
				isSimulated: true,
				originalEvent: {}
			}
		);
		if ( bubble ) {
			jQuery.event.trigger( e, null, elem );
		} else {
			jQuery.event.dispatch.call( elem, e );
		}
		if ( e.isDefaultPrevented() ) {
			event.preventDefault();
		}
	}
};

// Some plugins are using, but it's undocumented/deprecated and will be removed.
// The 1.7 special event interface should provide all the hooks needed now.
jQuery.event.handle = jQuery.event.dispatch;

jQuery.removeEvent = document.removeEventListener ?
	function( elem, type, handle ) {
		if ( elem.removeEventListener ) {
			elem.removeEventListener( type, handle, false );
		}
	} :
	function( elem, type, handle ) {
		if ( elem.detachEvent ) {
			elem.detachEvent( "on" + type, handle );
		}
	};

jQuery.Event = function( src, props ) {
	// Allow instantiation without the 'new' keyword
	if ( !(this instanceof jQuery.Event) ) {
		return new jQuery.Event( src, props );
	}

	// Event object
	if ( src && src.type ) {
		this.originalEvent = src;
		this.type = src.type;

		// Events bubbling up the document may have been marked as prevented
		// by a handler lower down the tree; reflect the correct value.
		this.isDefaultPrevented = ( src.defaultPrevented || src.returnValue === false ||
			src.getPreventDefault && src.getPreventDefault() ) ? returnTrue : returnFalse;

	// Event type
	} else {
		this.type = src;
	}

	// Put explicitly provided properties onto the event object
	if ( props ) {
		jQuery.extend( this, props );
	}

	// Create a timestamp if incoming event doesn't have one
	this.timeStamp = src && src.timeStamp || jQuery.now();

	// Mark it as fixed
	this[ jQuery.expando ] = true;
};

function returnFalse() {
	return false;
}
function returnTrue() {
	return true;
}

// jQuery.Event is based on DOM3 Events as specified by the ECMAScript Language Binding
// http://www.w3.org/TR/2003/WD-DOM-Level-3-Events-20030331/ecma-script-binding.html
jQuery.Event.prototype = {
	preventDefault: function() {
		this.isDefaultPrevented = returnTrue;

		var e = this.originalEvent;
		if ( !e ) {
			return;
		}

		// if preventDefault exists run it on the original event
		if ( e.preventDefault ) {
			e.preventDefault();

		// otherwise set the returnValue property of the original event to false (IE)
		} else {
			e.returnValue = false;
		}
	},
	stopPropagation: function() {
		this.isPropagationStopped = returnTrue;

		var e = this.originalEvent;
		if ( !e ) {
			return;
		}
		// if stopPropagation exists run it on the original event
		if ( e.stopPropagation ) {
			e.stopPropagation();
		}
		// otherwise set the cancelBubble property of the original event to true (IE)
		e.cancelBubble = true;
	},
	stopImmediatePropagation: function() {
		this.isImmediatePropagationStopped = returnTrue;
		this.stopPropagation();
	},
	isDefaultPrevented: returnFalse,
	isPropagationStopped: returnFalse,
	isImmediatePropagationStopped: returnFalse
};

// Create mouseenter/leave events using mouseover/out and event-time checks
jQuery.each({
	mouseenter: "mouseover",
	mouseleave: "mouseout"
}, function( orig, fix ) {
	jQuery.event.special[ orig ] = {
		delegateType: fix,
		bindType: fix,

		handle: function( event ) {
			var target = this,
				related = event.relatedTarget,
				handleObj = event.handleObj,
				selector = handleObj.selector,
				ret;

			// For mousenter/leave call the handler if related is outside the target.
			// NB: No relatedTarget if the mouse left/entered the browser window
			if ( !related || (related !== target && !jQuery.contains( target, related )) ) {
				event.type = handleObj.origType;
				ret = handleObj.handler.apply( this, arguments );
				event.type = fix;
			}
			return ret;
		}
	};
});

// IE submit delegation
if ( !jQuery.support.submitBubbles ) {

	jQuery.event.special.submit = {
		setup: function() {
			// Only need this for delegated form submit events
			if ( jQuery.nodeName( this, "form" ) ) {
				return false;
			}

			// Lazy-add a submit handler when a descendant form may potentially be submitted
			jQuery.event.add( this, "click._submit keypress._submit", function( e ) {
				// Node name check avoids a VML-related crash in IE (#9807)
				var elem = e.target,
					form = jQuery.nodeName( elem, "input" ) || jQuery.nodeName( elem, "button" ) ? elem.form : undefined;
				if ( form && !form._submit_attached ) {
					jQuery.event.add( form, "submit._submit", function( event ) {
						event._submit_bubble = true;
					});
					form._submit_attached = true;
				}
			});
			// return undefined since we don't need an event listener
		},
		
		postDispatch: function( event ) {
			// If form was submitted by the user, bubble the event up the tree
			if ( event._submit_bubble ) {
				delete event._submit_bubble;
				if ( this.parentNode && !event.isTrigger ) {
					jQuery.event.simulate( "submit", this.parentNode, event, true );
				}
			}
		},

		teardown: function() {
			// Only need this for delegated form submit events
			if ( jQuery.nodeName( this, "form" ) ) {
				return false;
			}

			// Remove delegated handlers; cleanData eventually reaps submit handlers attached above
			jQuery.event.remove( this, "._submit" );
		}
	};
}

// IE change delegation and checkbox/radio fix
if ( !jQuery.support.changeBubbles ) {

	jQuery.event.special.change = {

		setup: function() {

			if ( rformElems.test( this.nodeName ) ) {
				// IE doesn't fire change on a check/radio until blur; trigger it on click
				// after a propertychange. Eat the blur-change in special.change.handle.
				// This still fires onchange a second time for check/radio after blur.
				if ( this.type === "checkbox" || this.type === "radio" ) {
					jQuery.event.add( this, "propertychange._change", function( event ) {
						if ( event.originalEvent.propertyName === "checked" ) {
							this._just_changed = true;
						}
					});
					jQuery.event.add( this, "click._change", function( event ) {
						if ( this._just_changed && !event.isTrigger ) {
							this._just_changed = false;
							jQuery.event.simulate( "change", this, event, true );
						}
					});
				}
				return false;
			}
			// Delegated event; lazy-add a change handler on descendant inputs
			jQuery.event.add( this, "beforeactivate._change", function( e ) {
				var elem = e.target;

				if ( rformElems.test( elem.nodeName ) && !elem._change_attached ) {
					jQuery.event.add( elem, "change._change", function( event ) {
						if ( this.parentNode && !event.isSimulated && !event.isTrigger ) {
							jQuery.event.simulate( "change", this.parentNode, event, true );
						}
					});
					elem._change_attached = true;
				}
			});
		},

		handle: function( event ) {
			var elem = event.target;

			// Swallow native change events from checkbox/radio, we already triggered them above
			if ( this !== elem || event.isSimulated || event.isTrigger || (elem.type !== "radio" && elem.type !== "checkbox") ) {
				return event.handleObj.handler.apply( this, arguments );
			}
		},

		teardown: function() {
			jQuery.event.remove( this, "._change" );

			return rformElems.test( this.nodeName );
		}
	};
}

// Create "bubbling" focus and blur events
if ( !jQuery.support.focusinBubbles ) {
	jQuery.each({ focus: "focusin", blur: "focusout" }, function( orig, fix ) {

		// Attach a single capturing handler while someone wants focusin/focusout
		var attaches = 0,
			handler = function( event ) {
				jQuery.event.simulate( fix, event.target, jQuery.event.fix( event ), true );
			};

		jQuery.event.special[ fix ] = {
			setup: function() {
				if ( attaches++ === 0 ) {
					document.addEventListener( orig, handler, true );
				}
			},
			teardown: function() {
				if ( --attaches === 0 ) {
					document.removeEventListener( orig, handler, true );
				}
			}
		};
	});
}

jQuery.fn.extend({

	on: function( types, selector, data, fn, /*INTERNAL*/ one ) {
		var origFn, type;

		// Types can be a map of types/handlers
		if ( typeof types === "object" ) {
			// ( types-Object, selector, data )
			if ( typeof selector !== "string" ) { // && selector != null
				// ( types-Object, data )
				data = data || selector;
				selector = undefined;
			}
			for ( type in types ) {
				this.on( type, selector, data, types[ type ], one );
			}
			return this;
		}

		if ( data == null && fn == null ) {
			// ( types, fn )
			fn = selector;
			data = selector = undefined;
		} else if ( fn == null ) {
			if ( typeof selector === "string" ) {
				// ( types, selector, fn )
				fn = data;
				data = undefined;
			} else {
				// ( types, data, fn )
				fn = data;
				data = selector;
				selector = undefined;
			}
		}
		if ( fn === false ) {
			fn = returnFalse;
		} else if ( !fn ) {
			return this;
		}

		if ( one === 1 ) {
			origFn = fn;
			fn = function( event ) {
				// Can use an empty set, since event contains the info
				jQuery().off( event );
				return origFn.apply( this, arguments );
			};
			// Use same guid so caller can remove using origFn
			fn.guid = origFn.guid || ( origFn.guid = jQuery.guid++ );
		}
		return this.each( function() {
			jQuery.event.add( this, types, fn, data, selector );
		});
	},
	one: function( types, selector, data, fn ) {
		return this.on( types, selector, data, fn, 1 );
	},
	off: function( types, selector, fn ) {
		if ( types && types.preventDefault && types.handleObj ) {
			// ( event )  dispatched jQuery.Event
			var handleObj = types.handleObj;
			jQuery( types.delegateTarget ).off(
				handleObj.namespace ? handleObj.origType + "." + handleObj.namespace : handleObj.origType,
				handleObj.selector,
				handleObj.handler
			);
			return this;
		}
		if ( typeof types === "object" ) {
			// ( types-object [, selector] )
			for ( var type in types ) {
				this.off( type, selector, types[ type ] );
			}
			return this;
		}
		if ( selector === false || typeof selector === "function" ) {
			// ( types [, fn] )
			fn = selector;
			selector = undefined;
		}
		if ( fn === false ) {
			fn = returnFalse;
		}
		return this.each(function() {
			jQuery.event.remove( this, types, fn, selector );
		});
	},

	bind: function( types, data, fn ) {
		return this.on( types, null, data, fn );
	},
	unbind: function( types, fn ) {
		return this.off( types, null, fn );
	},

	live: function( types, data, fn ) {
		jQuery( this.context ).on( types, this.selector, data, fn );
		return this;
	},
	die: function( types, fn ) {
		jQuery( this.context ).off( types, this.selector || "**", fn );
		return this;
	},

	delegate: function( selector, types, data, fn ) {
		return this.on( types, selector, data, fn );
	},
	undelegate: function( selector, types, fn ) {
		// ( namespace ) or ( selector, types [, fn] )
		return arguments.length == 1? this.off( selector, "**" ) : this.off( types, selector, fn );
	},

	trigger: function( type, data ) {
		return this.each(function() {
			jQuery.event.trigger( type, data, this );
		});
	},
	triggerHandler: function( type, data ) {
		if ( this[0] ) {
			return jQuery.event.trigger( type, data, this[0], true );
		}
	},

	toggle: function( fn ) {
		// Save reference to arguments for access in closure
		var args = arguments,
			guid = fn.guid || jQuery.guid++,
			i = 0,
			toggler = function( event ) {
				// Figure out which function to execute
				var lastToggle = ( jQuery._data( this, "lastToggle" + fn.guid ) || 0 ) % i;
				jQuery._data( this, "lastToggle" + fn.guid, lastToggle + 1 );

				// Make sure that clicks stop
				event.preventDefault();

				// and execute the function
				return args[ lastToggle ].apply( this, arguments ) || false;
			};

		// link all the functions, so any of them can unbind this click handler
		toggler.guid = guid;
		while ( i < args.length ) {
			args[ i++ ].guid = guid;
		}

		return this.click( toggler );
	},

	hover: function( fnOver, fnOut ) {
		return this.mouseenter( fnOver ).mouseleave( fnOut || fnOver );
	}
});

jQuery.each( ("blur focus focusin focusout load resize scroll unload click dblclick " +
	"mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave " +
	"change select submit keydown keypress keyup error contextmenu").split(" "), function( i, name ) {

	// Handle event binding
	jQuery.fn[ name ] = function( data, fn ) {
		if ( fn == null ) {
			fn = data;
			data = null;
		}

		return arguments.length > 0 ?
			this.on( name, null, data, fn ) :
			this.trigger( name );
	};

	if ( jQuery.attrFn ) {
		jQuery.attrFn[ name ] = true;
	}

	if ( rkeyEvent.test( name ) ) {
		jQuery.event.fixHooks[ name ] = jQuery.event.keyHooks;
	}

	if ( rmouseEvent.test( name ) ) {
		jQuery.event.fixHooks[ name ] = jQuery.event.mouseHooks;
	}
});



/*!
 * Sizzle CSS Selector Engine
 *  Copyright 2011, The Dojo Foundation
 *  Released under the MIT, BSD, and GPL Licenses.
 *  More information: http://sizzlejs.com/
 */
(function(){

var chunker = /((?:\((?:\([^()]+\)|[^()]+)+\)|\[(?:\[[^\[\]]*\]|['"][^'"]*['"]|[^\[\]'"]+)+\]|\\.|[^ >+~,(\[\\]+)+|[>+~])(\s*,\s*)?((?:.|\r|\n)*)/g,
	expando = "sizcache" + (Math.random() + '').replace('.', ''),
	done = 0,
	toString = Object.prototype.toString,
	hasDuplicate = false,
	baseHasDuplicate = true,
	rBackslash = /\\/g,
	rReturn = /\r\n/g,
	rNonWord = /\W/;

// Here we check if the JavaScript engine is using some sort of
// optimization where it does not always call our comparision
// function. If that is the case, discard the hasDuplicate value.
//   Thus far that includes Google Chrome.
[0, 0].sort(function() {
	baseHasDuplicate = false;
	return 0;
});

var Sizzle = function( selector, context, results, seed ) {
	results = results || [];
	context = context || document;

	var origContext = context;

	if ( context.nodeType !== 1 && context.nodeType !== 9 ) {
		return [];
	}

	if ( !selector || typeof selector !== "string" ) {
		return results;
	}

	var m, set, checkSet, extra, ret, cur, pop, i,
		prune = true,
		contextXML = Sizzle.isXML( context ),
		parts = [],
		soFar = selector;

	// Reset the position of the chunker regexp (start from head)
	do {
		chunker.exec( "" );
		m = chunker.exec( soFar );

		if ( m ) {
			soFar = m[3];

			parts.push( m[1] );

			if ( m[2] ) {
				extra = m[3];
				break;
			}
		}
	} while ( m );

	if ( parts.length > 1 && origPOS.exec( selector ) ) {

		if ( parts.length === 2 && Expr.relative[ parts[0] ] ) {
			set = posProcess( parts[0] + parts[1], context, seed );

		} else {
			set = Expr.relative[ parts[0] ] ?
				[ context ] :
				Sizzle( parts.shift(), context );

			while ( parts.length ) {
				selector = parts.shift();

				if ( Expr.relative[ selector ] ) {
					selector += parts.shift();
				}

				set = posProcess( selector, set, seed );
			}
		}

	} else {
		// Take a shortcut and set the context if the root selector is an ID
		// (but not if it'll be faster if the inner selector is an ID)
		if ( !seed && parts.length > 1 && context.nodeType === 9 && !contextXML &&
				Expr.match.ID.test(parts[0]) && !Expr.match.ID.test(parts[parts.length - 1]) ) {

			ret = Sizzle.find( parts.shift(), context, contextXML );
			context = ret.expr ?
				Sizzle.filter( ret.expr, ret.set )[0] :
				ret.set[0];
		}

		if ( context ) {
			ret = seed ?
				{ expr: parts.pop(), set: makeArray(seed) } :
				Sizzle.find( parts.pop(), parts.length === 1 && (parts[0] === "~" || parts[0] === "+") && context.parentNode ? context.parentNode : context, contextXML );

			set = ret.expr ?
				Sizzle.filter( ret.expr, ret.set ) :
				ret.set;

			if ( parts.length > 0 ) {
				checkSet = makeArray( set );

			} else {
				prune = false;
			}

			while ( parts.length ) {
				cur = parts.pop();
				pop = cur;

				if ( !Expr.relative[ cur ] ) {
					cur = "";
				} else {
					pop = parts.pop();
				}

				if ( pop == null ) {
					pop = context;
				}

				Expr.relative[ cur ]( checkSet, pop, contextXML );
			}

		} else {
			checkSet = parts = [];
		}
	}

	if ( !checkSet ) {
		checkSet = set;
	}

	if ( !checkSet ) {
		Sizzle.error( cur || selector );
	}

	if ( toString.call(checkSet) === "[object Array]" ) {
		if ( !prune ) {
			results.push.apply( results, checkSet );

		} else if ( context && context.nodeType === 1 ) {
			for ( i = 0; checkSet[i] != null; i++ ) {
				if ( checkSet[i] && (checkSet[i] === true || checkSet[i].nodeType === 1 && Sizzle.contains(context, checkSet[i])) ) {
					results.push( set[i] );
				}
			}

		} else {
			for ( i = 0; checkSet[i] != null; i++ ) {
				if ( checkSet[i] && checkSet[i].nodeType === 1 ) {
					results.push( set[i] );
				}
			}
		}

	} else {
		makeArray( checkSet, results );
	}

	if ( extra ) {
		Sizzle( extra, origContext, results, seed );
		Sizzle.uniqueSort( results );
	}

	return results;
};

Sizzle.uniqueSort = function( results ) {
	if ( sortOrder ) {
		hasDuplicate = baseHasDuplicate;
		results.sort( sortOrder );

		if ( hasDuplicate ) {
			for ( var i = 1; i < results.length; i++ ) {
				if ( results[i] === results[ i - 1 ] ) {
					results.splice( i--, 1 );
				}
			}
		}
	}

	return results;
};

Sizzle.matches = function( expr, set ) {
	return Sizzle( expr, null, null, set );
};

Sizzle.matchesSelector = function( node, expr ) {
	return Sizzle( expr, null, null, [node] ).length > 0;
};

Sizzle.find = function( expr, context, isXML ) {
	var set, i, len, match, type, left;

	if ( !expr ) {
		return [];
	}

	for ( i = 0, len = Expr.order.length; i < len; i++ ) {
		type = Expr.order[i];

		if ( (match = Expr.leftMatch[ type ].exec( expr )) ) {
			left = match[1];
			match.splice( 1, 1 );

			if ( left.substr( left.length - 1 ) !== "\\" ) {
				match[1] = (match[1] || "").replace( rBackslash, "" );
				set = Expr.find[ type ]( match, context, isXML );

				if ( set != null ) {
					expr = expr.replace( Expr.match[ type ], "" );
					break;
				}
			}
		}
	}

	if ( !set ) {
		set = typeof context.getElementsByTagName !== "undefined" ?
			context.getElementsByTagName( "*" ) :
			[];
	}

	return { set: set, expr: expr };
};

Sizzle.filter = function( expr, set, inplace, not ) {
	var match, anyFound,
		type, found, item, filter, left,
		i, pass,
		old = expr,
		result = [],
		curLoop = set,
		isXMLFilter = set && set[0] && Sizzle.isXML( set[0] );

	while ( expr && set.length ) {
		for ( type in Expr.filter ) {
			if ( (match = Expr.leftMatch[ type ].exec( expr )) != null && match[2] ) {
				filter = Expr.filter[ type ];
				left = match[1];

				anyFound = false;

				match.splice(1,1);

				if ( left.substr( left.length - 1 ) === "\\" ) {
					continue;
				}

				if ( curLoop === result ) {
					result = [];
				}

				if ( Expr.preFilter[ type ] ) {
					match = Expr.preFilter[ type ]( match, curLoop, inplace, result, not, isXMLFilter );

					if ( !match ) {
						anyFound = found = true;

					} else if ( match === true ) {
						continue;
					}
				}

				if ( match ) {
					for ( i = 0; (item = curLoop[i]) != null; i++ ) {
						if ( item ) {
							found = filter( item, match, i, curLoop );
							pass = not ^ found;

							if ( inplace && found != null ) {
								if ( pass ) {
									anyFound = true;

								} else {
									curLoop[i] = false;
								}

							} else if ( pass ) {
								result.push( item );
								anyFound = true;
							}
						}
					}
				}

				if ( found !== undefined ) {
					if ( !inplace ) {
						curLoop = result;
					}

					expr = expr.replace( Expr.match[ type ], "" );

					if ( !anyFound ) {
						return [];
					}

					break;
				}
			}
		}

		// Improper expression
		if ( expr === old ) {
			if ( anyFound == null ) {
				Sizzle.error( expr );

			} else {
				break;
			}
		}

		old = expr;
	}

	return curLoop;
};

Sizzle.error = function( msg ) {
	throw new Error( "Syntax error, unrecognized expression: " + msg );
};

/**
 * Utility function for retreiving the text value of an array of DOM nodes
 * @param {Array|Element} elem
 */
var getText = Sizzle.getText = function( elem ) {
    var i, node,
		nodeType = elem.nodeType,
		ret = "";

	if ( nodeType ) {
		if ( nodeType === 1 || nodeType === 9 || nodeType === 11 ) {
			// Use textContent || innerText for elements
			if ( typeof elem.textContent === 'string' ) {
				return elem.textContent;
			} else if ( typeof elem.innerText === 'string' ) {
				// Replace IE's carriage returns
				return elem.innerText.replace( rReturn, '' );
			} else {
				// Traverse it's children
				for ( elem = elem.firstChild; elem; elem = elem.nextSibling) {
					ret += getText( elem );
				}
			}
		} else if ( nodeType === 3 || nodeType === 4 ) {
			return elem.nodeValue;
		}
	} else {

		// If no nodeType, this is expected to be an array
		for ( i = 0; (node = elem[i]); i++ ) {
			// Do not traverse comment nodes
			if ( node.nodeType !== 8 ) {
				ret += getText( node );
			}
		}
	}
	return ret;
};

var Expr = Sizzle.selectors = {
	order: [ "ID", "NAME", "TAG" ],

	match: {
		ID: /#((?:[\w\u00c0-\uFFFF\-]|\\.)+)/,
		CLASS: /\.((?:[\w\u00c0-\uFFFF\-]|\\.)+)/,
		NAME: /\[name=['"]*((?:[\w\u00c0-\uFFFF\-]|\\.)+)['"]*\]/,
		ATTR: /\[\s*((?:[\w\u00c0-\uFFFF\-]|\\.)+)\s*(?:(\S?=)\s*(?:(['"])(.*?)\3|(#?(?:[\w\u00c0-\uFFFF\-]|\\.)*)|)|)\s*\]/,
		TAG: /^((?:[\w\u00c0-\uFFFF\*\-]|\\.)+)/,
		CHILD: /:(only|nth|last|first)-child(?:\(\s*(even|odd|(?:[+\-]?\d+|(?:[+\-]?\d*)?n\s*(?:[+\-]\s*\d+)?))\s*\))?/,
		POS: /:(nth|eq|gt|lt|first|last|even|odd)(?:\((\d*)\))?(?=[^\-]|$)/,
		PSEUDO: /:((?:[\w\u00c0-\uFFFF\-]|\\.)+)(?:\((['"]?)((?:\([^\)]+\)|[^\(\)]*)+)\2\))?/
	},

	leftMatch: {},

	attrMap: {
		"class": "className",
		"for": "htmlFor"
	},

	attrHandle: {
		href: function( elem ) {
			return elem.getAttribute( "href" );
		},
		type: function( elem ) {
			return elem.getAttribute( "type" );
		}
	},

	relative: {
		"+": function(checkSet, part){
			var isPartStr = typeof part === "string",
				isTag = isPartStr && !rNonWord.test( part ),
				isPartStrNotTag = isPartStr && !isTag;

			if ( isTag ) {
				part = part.toLowerCase();
			}

			for ( var i = 0, l = checkSet.length, elem; i < l; i++ ) {
				if ( (elem = checkSet[i]) ) {
					while ( (elem = elem.previousSibling) && elem.nodeType !== 1 ) {}

					checkSet[i] = isPartStrNotTag || elem && elem.nodeName.toLowerCase() === part ?
						elem || false :
						elem === part;
				}
			}

			if ( isPartStrNotTag ) {
				Sizzle.filter( part, checkSet, true );
			}
		},

		">": function( checkSet, part ) {
			var elem,
				isPartStr = typeof part === "string",
				i = 0,
				l = checkSet.length;

			if ( isPartStr && !rNonWord.test( part ) ) {
				part = part.toLowerCase();

				for ( ; i < l; i++ ) {
					elem = checkSet[i];

					if ( elem ) {
						var parent = elem.parentNode;
						checkSet[i] = parent.nodeName.toLowerCase() === part ? parent : false;
					}
				}

			} else {
				for ( ; i < l; i++ ) {
					elem = checkSet[i];

					if ( elem ) {
						checkSet[i] = isPartStr ?
							elem.parentNode :
							elem.parentNode === part;
					}
				}

				if ( isPartStr ) {
					Sizzle.filter( part, checkSet, true );
				}
			}
		},

		"": function(checkSet, part, isXML){
			var nodeCheck,
				doneName = done++,
				checkFn = dirCheck;

			if ( typeof part === "string" && !rNonWord.test( part ) ) {
				part = part.toLowerCase();
				nodeCheck = part;
				checkFn = dirNodeCheck;
			}

			checkFn( "parentNode", part, doneName, checkSet, nodeCheck, isXML );
		},

		"~": function( checkSet, part, isXML ) {
			var nodeCheck,
				doneName = done++,
				checkFn = dirCheck;

			if ( typeof part === "string" && !rNonWord.test( part ) ) {
				part = part.toLowerCase();
				nodeCheck = part;
				checkFn = dirNodeCheck;
			}

			checkFn( "previousSibling", part, doneName, checkSet, nodeCheck, isXML );
		}
	},

	find: {
		ID: function( match, context, isXML ) {
			if ( typeof context.getElementById !== "undefined" && !isXML ) {
				var m = context.getElementById(match[1]);
				// Check parentNode to catch when Blackberry 4.6 returns
				// nodes that are no longer in the document #6963
				return m && m.parentNode ? [m] : [];
			}
		},

		NAME: function( match, context ) {
			if ( typeof context.getElementsByName !== "undefined" ) {
				var ret = [],
					results = context.getElementsByName( match[1] );

				for ( var i = 0, l = results.length; i < l; i++ ) {
					if ( results[i].getAttribute("name") === match[1] ) {
						ret.push( results[i] );
					}
				}

				return ret.length === 0 ? null : ret;
			}
		},

		TAG: function( match, context ) {
			if ( typeof context.getElementsByTagName !== "undefined" ) {
				return context.getElementsByTagName( match[1] );
			}
		}
	},
	preFilter: {
		CLASS: function( match, curLoop, inplace, result, not, isXML ) {
			match = " " + match[1].replace( rBackslash, "" ) + " ";

			if ( isXML ) {
				return match;
			}

			for ( var i = 0, elem; (elem = curLoop[i]) != null; i++ ) {
				if ( elem ) {
					if ( not ^ (elem.className && (" " + elem.className + " ").replace(/[\t\n\r]/g, " ").indexOf(match) >= 0) ) {
						if ( !inplace ) {
							result.push( elem );
						}

					} else if ( inplace ) {
						curLoop[i] = false;
					}
				}
			}

			return false;
		},

		ID: function( match ) {
			return match[1].replace( rBackslash, "" );
		},

		TAG: function( match, curLoop ) {
			return match[1].replace( rBackslash, "" ).toLowerCase();
		},

		CHILD: function( match ) {
			if ( match[1] === "nth" ) {
				if ( !match[2] ) {
					Sizzle.error( match[0] );
				}

				match[2] = match[2].replace(/^\+|\s*/g, '');

				// parse equations like 'even', 'odd', '5', '2n', '3n+2', '4n-1', '-n+6'
				var test = /(-?)(\d*)(?:n([+\-]?\d*))?/.exec(
					match[2] === "even" && "2n" || match[2] === "odd" && "2n+1" ||
					!/\D/.test( match[2] ) && "0n+" + match[2] || match[2]);

				// calculate the numbers (first)n+(last) including if they are negative
				match[2] = (test[1] + (test[2] || 1)) - 0;
				match[3] = test[3] - 0;
			}
			else if ( match[2] ) {
				Sizzle.error( match[0] );
			}

			// TODO: Move to normal caching system
			match[0] = done++;

			return match;
		},

		ATTR: function( match, curLoop, inplace, result, not, isXML ) {
			var name = match[1] = match[1].replace( rBackslash, "" );

			if ( !isXML && Expr.attrMap[name] ) {
				match[1] = Expr.attrMap[name];
			}

			// Handle if an un-quoted value was used
			match[4] = ( match[4] || match[5] || "" ).replace( rBackslash, "" );

			if ( match[2] === "~=" ) {
				match[4] = " " + match[4] + " ";
			}

			return match;
		},

		PSEUDO: function( match, curLoop, inplace, result, not ) {
			if ( match[1] === "not" ) {
				// If we're dealing with a complex expression, or a simple one
				if ( ( chunker.exec(match[3]) || "" ).length > 1 || /^\w/.test(match[3]) ) {
					match[3] = Sizzle(match[3], null, null, curLoop);

				} else {
					var ret = Sizzle.filter(match[3], curLoop, inplace, true ^ not);

					if ( !inplace ) {
						result.push.apply( result, ret );
					}

					return false;
				}

			} else if ( Expr.match.POS.test( match[0] ) || Expr.match.CHILD.test( match[0] ) ) {
				return true;
			}

			return match;
		},

		POS: function( match ) {
			match.unshift( true );

			return match;
		}
	},

	filters: {
		enabled: function( elem ) {
			return elem.disabled === false && elem.type !== "hidden";
		},

		disabled: function( elem ) {
			return elem.disabled === true;
		},

		checked: function( elem ) {
			return elem.checked === true;
		},

		selected: function( elem ) {
			// Accessing this property makes selected-by-default
			// options in Safari work properly
			if ( elem.parentNode ) {
				elem.parentNode.selectedIndex;
			}

			return elem.selected === true;
		},

		parent: function( elem ) {
			return !!elem.firstChild;
		},

		empty: function( elem ) {
			return !elem.firstChild;
		},

		has: function( elem, i, match ) {
			return !!Sizzle( match[3], elem ).length;
		},

		header: function( elem ) {
			return (/h\d/i).test( elem.nodeName );
		},

		text: function( elem ) {
			var attr = elem.getAttribute( "type" ), type = elem.type;
			// IE6 and 7 will map elem.type to 'text' for new HTML5 types (search, etc)
			// use getAttribute instead to test this case
			return elem.nodeName.toLowerCase() === "input" && "text" === type && ( attr === type || attr === null );
		},

		radio: function( elem ) {
			return elem.nodeName.toLowerCase() === "input" && "radio" === elem.type;
		},

		checkbox: function( elem ) {
			return elem.nodeName.toLowerCase() === "input" && "checkbox" === elem.type;
		},

		file: function( elem ) {
			return elem.nodeName.toLowerCase() === "input" && "file" === elem.type;
		},

		password: function( elem ) {
			return elem.nodeName.toLowerCase() === "input" && "password" === elem.type;
		},

		submit: function( elem ) {
			var name = elem.nodeName.toLowerCase();
			return (name === "input" || name === "button") && "submit" === elem.type;
		},

		image: function( elem ) {
			return elem.nodeName.toLowerCase() === "input" && "image" === elem.type;
		},

		reset: function( elem ) {
			var name = elem.nodeName.toLowerCase();
			return (name === "input" || name === "button") && "reset" === elem.type;
		},

		button: function( elem ) {
			var name = elem.nodeName.toLowerCase();
			return name === "input" && "button" === elem.type || name === "button";
		},

		input: function( elem ) {
			return (/input|select|textarea|button/i).test( elem.nodeName );
		},

		focus: function( elem ) {
			return elem === elem.ownerDocument.activeElement;
		}
	},
	setFilters: {
		first: function( elem, i ) {
			return i === 0;
		},

		last: function( elem, i, match, array ) {
			return i === array.length - 1;
		},

		even: function( elem, i ) {
			return i % 2 === 0;
		},

		odd: function( elem, i ) {
			return i % 2 === 1;
		},

		lt: function( elem, i, match ) {
			return i < match[3] - 0;
		},

		gt: function( elem, i, match ) {
			return i > match[3] - 0;
		},

		nth: function( elem, i, match ) {
			return match[3] - 0 === i;
		},

		eq: function( elem, i, match ) {
			return match[3] - 0 === i;
		}
	},
	filter: {
		PSEUDO: function( elem, match, i, array ) {
			var name = match[1],
				filter = Expr.filters[ name ];

			if ( filter ) {
				return filter( elem, i, match, array );

			} else if ( name === "contains" ) {
				return (elem.textContent || elem.innerText || getText([ elem ]) || "").indexOf(match[3]) >= 0;

			} else if ( name === "not" ) {
				var not = match[3];

				for ( var j = 0, l = not.length; j < l; j++ ) {
					if ( not[j] === elem ) {
						return false;
					}
				}

				return true;

			} else {
				Sizzle.error( name );
			}
		},

		CHILD: function( elem, match ) {
			var first, last,
				doneName, parent, cache,
				count, diff,
				type = match[1],
				node = elem;

			switch ( type ) {
				case "only":
				case "first":
					while ( (node = node.previousSibling) ) {
						if ( node.nodeType === 1 ) {
							return false;
						}
					}

					if ( type === "first" ) {
						return true;
					}

					node = elem;

					/* falls through */
				case "last":
					while ( (node = node.nextSibling) ) {
						if ( node.nodeType === 1 ) {
							return false;
						}
					}

					return true;

				case "nth":
					first = match[2];
					last = match[3];

					if ( first === 1 && last === 0 ) {
						return true;
					}

					doneName = match[0];
					parent = elem.parentNode;

					if ( parent && (parent[ expando ] !== doneName || !elem.nodeIndex) ) {
						count = 0;

						for ( node = parent.firstChild; node; node = node.nextSibling ) {
							if ( node.nodeType === 1 ) {
								node.nodeIndex = ++count;
							}
						}

						parent[ expando ] = doneName;
					}

					diff = elem.nodeIndex - last;

					if ( first === 0 ) {
						return diff === 0;

					} else {
						return ( diff % first === 0 && diff / first >= 0 );
					}
			}
		},

		ID: function( elem, match ) {
			return elem.nodeType === 1 && elem.getAttribute("id") === match;
		},

		TAG: function( elem, match ) {
			return (match === "*" && elem.nodeType === 1) || !!elem.nodeName && elem.nodeName.toLowerCase() === match;
		},

		CLASS: function( elem, match ) {
			return (" " + (elem.className || elem.getAttribute("class")) + " ")
				.indexOf( match ) > -1;
		},

		ATTR: function( elem, match ) {
			var name = match[1],
				result = Sizzle.attr ?
					Sizzle.attr( elem, name ) :
					Expr.attrHandle[ name ] ?
					Expr.attrHandle[ name ]( elem ) :
					elem[ name ] != null ?
						elem[ name ] :
						elem.getAttribute( name ),
				value = result + "",
				type = match[2],
				check = match[4];

			return result == null ?
				type === "!=" :
				!type && Sizzle.attr ?
				result != null :
				type === "=" ?
				value === check :
				type === "*=" ?
				value.indexOf(check) >= 0 :
				type === "~=" ?
				(" " + value + " ").indexOf(check) >= 0 :
				!check ?
				value && result !== false :
				type === "!=" ?
				value !== check :
				type === "^=" ?
				value.indexOf(check) === 0 :
				type === "$=" ?
				value.substr(value.length - check.length) === check :
				type === "|=" ?
				value === check || value.substr(0, check.length + 1) === check + "-" :
				false;
		},

		POS: function( elem, match, i, array ) {
			var name = match[2],
				filter = Expr.setFilters[ name ];

			if ( filter ) {
				return filter( elem, i, match, array );
			}
		}
	}
};

var origPOS = Expr.match.POS,
	fescape = function(all, num){
		return "\\" + (num - 0 + 1);
	};

for ( var type in Expr.match ) {
	Expr.match[ type ] = new RegExp( Expr.match[ type ].source + (/(?![^\[]*\])(?![^\(]*\))/.source) );
	Expr.leftMatch[ type ] = new RegExp( /(^(?:.|\r|\n)*?)/.source + Expr.match[ type ].source.replace(/\\(\d+)/g, fescape) );
}
// Expose origPOS
// "global" as in regardless of relation to brackets/parens
Expr.match.globalPOS = origPOS;

var makeArray = function( array, results ) {
	array = Array.prototype.slice.call( array, 0 );

	if ( results ) {
		results.push.apply( results, array );
		return results;
	}

	return array;
};

// Perform a simple check to determine if the browser is capable of
// converting a NodeList to an array using builtin methods.
// Also verifies that the returned array holds DOM nodes
// (which is not the case in the Blackberry browser)
try {
	Array.prototype.slice.call( document.documentElement.childNodes, 0 )[0].nodeType;

// Provide a fallback method if it does not work
} catch( e ) {
	makeArray = function( array, results ) {
		var i = 0,
			ret = results || [];

		if ( toString.call(array) === "[object Array]" ) {
			Array.prototype.push.apply( ret, array );

		} else {
			if ( typeof array.length === "number" ) {
				for ( var l = array.length; i < l; i++ ) {
					ret.push( array[i] );
				}

			} else {
				for ( ; array[i]; i++ ) {
					ret.push( array[i] );
				}
			}
		}

		return ret;
	};
}

var sortOrder, siblingCheck;

if ( document.documentElement.compareDocumentPosition ) {
	sortOrder = function( a, b ) {
		if ( a === b ) {
			hasDuplicate = true;
			return 0;
		}

		if ( !a.compareDocumentPosition || !b.compareDocumentPosition ) {
			return a.compareDocumentPosition ? -1 : 1;
		}

		return a.compareDocumentPosition(b) & 4 ? -1 : 1;
	};

} else {
	sortOrder = function( a, b ) {
		// The nodes are identical, we can exit early
		if ( a === b ) {
			hasDuplicate = true;
			return 0;

		// Fallback to using sourceIndex (in IE) if it's available on both nodes
		} else if ( a.sourceIndex && b.sourceIndex ) {
			return a.sourceIndex - b.sourceIndex;
		}

		var al, bl,
			ap = [],
			bp = [],
			aup = a.parentNode,
			bup = b.parentNode,
			cur = aup;

		// If the nodes are siblings (or identical) we can do a quick check
		if ( aup === bup ) {
			return siblingCheck( a, b );

		// If no parents were found then the nodes are disconnected
		} else if ( !aup ) {
			return -1;

		} else if ( !bup ) {
			return 1;
		}

		// Otherwise they're somewhere else in the tree so we need
		// to build up a full list of the parentNodes for comparison
		while ( cur ) {
			ap.unshift( cur );
			cur = cur.parentNode;
		}

		cur = bup;

		while ( cur ) {
			bp.unshift( cur );
			cur = cur.parentNode;
		}

		al = ap.length;
		bl = bp.length;

		// Start walking down the tree looking for a discrepancy
		for ( var i = 0; i < al && i < bl; i++ ) {
			if ( ap[i] !== bp[i] ) {
				return siblingCheck( ap[i], bp[i] );
			}
		}

		// We ended someplace up the tree so do a sibling check
		return i === al ?
			siblingCheck( a, bp[i], -1 ) :
			siblingCheck( ap[i], b, 1 );
	};

	siblingCheck = function( a, b, ret ) {
		if ( a === b ) {
			return ret;
		}

		var cur = a.nextSibling;

		while ( cur ) {
			if ( cur === b ) {
				return -1;
			}

			cur = cur.nextSibling;
		}

		return 1;
	};
}

// Check to see if the browser returns elements by name when
// querying by getElementById (and provide a workaround)
(function(){
	// We're going to inject a fake input element with a specified name
	var form = document.createElement("div"),
		id = "script" + (new Date()).getTime(),
		root = document.documentElement;

	form.innerHTML = "<a name='" + id + "'/>";

	// Inject it into the root element, check its status, and remove it quickly
	root.insertBefore( form, root.firstChild );

	// The workaround has to do additional checks after a getElementById
	// Which slows things down for other browsers (hence the branching)
	if ( document.getElementById( id ) ) {
		Expr.find.ID = function( match, context, isXML ) {
			if ( typeof context.getElementById !== "undefined" && !isXML ) {
				var m = context.getElementById(match[1]);

				return m ?
					m.id === match[1] || typeof m.getAttributeNode !== "undefined" && m.getAttributeNode("id").nodeValue === match[1] ?
						[m] :
						undefined :
					[];
			}
		};

		Expr.filter.ID = function( elem, match ) {
			var node = typeof elem.getAttributeNode !== "undefined" && elem.getAttributeNode("id");

			return elem.nodeType === 1 && node && node.nodeValue === match;
		};
	}

	root.removeChild( form );

	// release memory in IE
	root = form = null;
})();

(function(){
	// Check to see if the browser returns only elements
	// when doing getElementsByTagName("*")

	// Create a fake element
	var div = document.createElement("div");
	div.appendChild( document.createComment("") );

	// Make sure no comments are found
	if ( div.getElementsByTagName("*").length > 0 ) {
		Expr.find.TAG = function( match, context ) {
			var results = context.getElementsByTagName( match[1] );

			// Filter out possible comments
			if ( match[1] === "*" ) {
				var tmp = [];

				for ( var i = 0; results[i]; i++ ) {
					if ( results[i].nodeType === 1 ) {
						tmp.push( results[i] );
					}
				}

				results = tmp;
			}

			return results;
		};
	}

	// Check to see if an attribute returns normalized href attributes
	div.innerHTML = "<a href='#'></a>";

	if ( div.firstChild && typeof div.firstChild.getAttribute !== "undefined" &&
			div.firstChild.getAttribute("href") !== "#" ) {

		Expr.attrHandle.href = function( elem ) {
			return elem.getAttribute( "href", 2 );
		};
	}

	// release memory in IE
	div = null;
})();

if ( document.querySelectorAll ) {
	(function(){
		var oldSizzle = Sizzle,
			div = document.createElement("div"),
			id = "__sizzle__";

		div.innerHTML = "<p class='TEST'></p>";

		// Safari can't handle uppercase or unicode characters when
		// in quirks mode.
		if ( div.querySelectorAll && div.querySelectorAll(".TEST").length === 0 ) {
			return;
		}

		Sizzle = function( query, context, extra, seed ) {
			context = context || document;

			// Only use querySelectorAll on non-XML documents
			// (ID selectors don't work in non-HTML documents)
			if ( !seed && !Sizzle.isXML(context) ) {
				// See if we find a selector to speed up
				var match = /^(\w+$)|^\.([\w\-]+$)|^#([\w\-]+$)/.exec( query );

				if ( match && (context.nodeType === 1 || context.nodeType === 9) ) {
					// Speed-up: Sizzle("TAG")
					if ( match[1] ) {
						return makeArray( context.getElementsByTagName( query ), extra );

					// Speed-up: Sizzle(".CLASS")
					} else if ( match[2] && Expr.find.CLASS && context.getElementsByClassName ) {
						return makeArray( context.getElementsByClassName( match[2] ), extra );
					}
				}

				if ( context.nodeType === 9 ) {
					// Speed-up: Sizzle("body")
					// The body element only exists once, optimize finding it
					if ( query === "body" && context.body ) {
						return makeArray( [ context.body ], extra );

					// Speed-up: Sizzle("#ID")
					} else if ( match && match[3] ) {
						var elem = context.getElementById( match[3] );

						// Check parentNode to catch when Blackberry 4.6 returns
						// nodes that are no longer in the document #6963
						if ( elem && elem.parentNode ) {
							// Handle the case where IE and Opera return items
							// by name instead of ID
							if ( elem.id === match[3] ) {
								return makeArray( [ elem ], extra );
							}

						} else {
							return makeArray( [], extra );
						}
					}

					try {
						return makeArray( context.querySelectorAll(query), extra );
					} catch(qsaError) {}

				// qSA works strangely on Element-rooted queries
				// We can work around this by specifying an extra ID on the root
				// and working up from there (Thanks to Andrew Dupont for the technique)
				// IE 8 doesn't work on object elements
				} else if ( context.nodeType === 1 && context.nodeName.toLowerCase() !== "object" ) {
					var oldContext = context,
						old = context.getAttribute( "id" ),
						nid = old || id,
						hasParent = context.parentNode,
						relativeHierarchySelector = /^\s*[+~]/.test( query );

					if ( !old ) {
						context.setAttribute( "id", nid );
					} else {
						nid = nid.replace( /'/g, "\\$&" );
					}
					if ( relativeHierarchySelector && hasParent ) {
						context = context.parentNode;
					}

					try {
						if ( !relativeHierarchySelector || hasParent ) {
							return makeArray( context.querySelectorAll( "[id='" + nid + "'] " + query ), extra );
						}

					} catch(pseudoError) {
					} finally {
						if ( !old ) {
							oldContext.removeAttribute( "id" );
						}
					}
				}
			}

			return oldSizzle(query, context, extra, seed);
		};

		for ( var prop in oldSizzle ) {
			Sizzle[ prop ] = oldSizzle[ prop ];
		}

		// release memory in IE
		div = null;
	})();
}

(function(){
	var html = document.documentElement,
		matches = html.matchesSelector || html.mozMatchesSelector || html.webkitMatchesSelector || html.msMatchesSelector;

	if ( matches ) {
		// Check to see if it's possible to do matchesSelector
		// on a disconnected node (IE 9 fails this)
		var disconnectedMatch = !matches.call( document.createElement( "div" ), "div" ),
			pseudoWorks = false;

		try {
			// This should fail with an exception
			// Gecko does not error, returns false instead
			matches.call( document.documentElement, "[test!='']:sizzle" );

		} catch( pseudoError ) {
			pseudoWorks = true;
		}

		Sizzle.matchesSelector = function( node, expr ) {
			// Make sure that attribute selectors are quoted
			expr = expr.replace(/\=\s*([^'"\]]*)\s*\]/g, "='$1']");

			if ( !Sizzle.isXML( node ) ) {
				try {
					if ( pseudoWorks || !Expr.match.PSEUDO.test( expr ) && !/!=/.test( expr ) ) {
						var ret = matches.call( node, expr );

						// IE 9's matchesSelector returns false on disconnected nodes
						if ( ret || !disconnectedMatch ||
								// As well, disconnected nodes are said to be in a document
								// fragment in IE 9, so check for that
								node.document && node.document.nodeType !== 11 ) {
							return ret;
						}
					}
				} catch(e) {}
			}

			return Sizzle(expr, null, null, [node]).length > 0;
		};
	}
})();

(function(){
	var div = document.createElement("div");

	div.innerHTML = "<div class='test e'></div><div class='test'></div>";

	// Opera can't find a second classname (in 9.6)
	// Also, make sure that getElementsByClassName actually exists
	if ( !div.getElementsByClassName || div.getElementsByClassName("e").length === 0 ) {
		return;
	}

	// Safari caches class attributes, doesn't catch changes (in 3.2)
	div.lastChild.className = "e";

	if ( div.getElementsByClassName("e").length === 1 ) {
		return;
	}

	Expr.order.splice(1, 0, "CLASS");
	Expr.find.CLASS = function( match, context, isXML ) {
		if ( typeof context.getElementsByClassName !== "undefined" && !isXML ) {
			return context.getElementsByClassName(match[1]);
		}
	};

	// release memory in IE
	div = null;
})();

function dirNodeCheck( dir, cur, doneName, checkSet, nodeCheck, isXML ) {
	for ( var i = 0, l = checkSet.length; i < l; i++ ) {
		var elem = checkSet[i];

		if ( elem ) {
			var match = false;

			elem = elem[dir];

			while ( elem ) {
				if ( elem[ expando ] === doneName ) {
					match = checkSet[elem.sizset];
					break;
				}

				if ( elem.nodeType === 1 && !isXML ){
					elem[ expando ] = doneName;
					elem.sizset = i;
				}

				if ( elem.nodeName.toLowerCase() === cur ) {
					match = elem;
					break;
				}

				elem = elem[dir];
			}

			checkSet[i] = match;
		}
	}
}

function dirCheck( dir, cur, doneName, checkSet, nodeCheck, isXML ) {
	for ( var i = 0, l = checkSet.length; i < l; i++ ) {
		var elem = checkSet[i];

		if ( elem ) {
			var match = false;

			elem = elem[dir];

			while ( elem ) {
				if ( elem[ expando ] === doneName ) {
					match = checkSet[elem.sizset];
					break;
				}

				if ( elem.nodeType === 1 ) {
					if ( !isXML ) {
						elem[ expando ] = doneName;
						elem.sizset = i;
					}

					if ( typeof cur !== "string" ) {
						if ( elem === cur ) {
							match = true;
							break;
						}

					} else if ( Sizzle.filter( cur, [elem] ).length > 0 ) {
						match = elem;
						break;
					}
				}

				elem = elem[dir];
			}

			checkSet[i] = match;
		}
	}
}

if ( document.documentElement.contains ) {
	Sizzle.contains = function( a, b ) {
		return a !== b && (a.contains ? a.contains(b) : true);
	};

} else if ( document.documentElement.compareDocumentPosition ) {
	Sizzle.contains = function( a, b ) {
		return !!(a.compareDocumentPosition(b) & 16);
	};

} else {
	Sizzle.contains = function() {
		return false;
	};
}

Sizzle.isXML = function( elem ) {
	// documentElement is verified for cases where it doesn't yet exist
	// (such as loading iframes in IE - #4833)
	var documentElement = (elem ? elem.ownerDocument || elem : 0).documentElement;

	return documentElement ? documentElement.nodeName !== "HTML" : false;
};

var posProcess = function( selector, context, seed ) {
	var match,
		tmpSet = [],
		later = "",
		root = context.nodeType ? [context] : context;

	// Position selectors must be done after the filter
	// And so must :not(positional) so we move all PSEUDOs to the end
	while ( (match = Expr.match.PSEUDO.exec( selector )) ) {
		later += match[0];
		selector = selector.replace( Expr.match.PSEUDO, "" );
	}

	selector = Expr.relative[selector] ? selector + "*" : selector;

	for ( var i = 0, l = root.length; i < l; i++ ) {
		Sizzle( selector, root[i], tmpSet, seed );
	}

	return Sizzle.filter( later, tmpSet );
};

// EXPOSE
// Override sizzle attribute retrieval
Sizzle.attr = jQuery.attr;
Sizzle.selectors.attrMap = {};
jQuery.find = Sizzle;
jQuery.expr = Sizzle.selectors;
jQuery.expr[":"] = jQuery.expr.filters;
jQuery.unique = Sizzle.uniqueSort;
jQuery.text = Sizzle.getText;
jQuery.isXMLDoc = Sizzle.isXML;
jQuery.contains = Sizzle.contains;


})();


var runtil = /Until$/,
	rparentsprev = /^(?:parents|prevUntil|prevAll)/,
	// Note: This RegExp should be improved, or likely pulled from Sizzle
	rmultiselector = /,/,
	isSimple = /^.[^:#\[\.,]*$/,
	slice = Array.prototype.slice,
	POS = jQuery.expr.match.globalPOS,
	// methods guaranteed to produce a unique set when starting from a unique set
	guaranteedUnique = {
		children: true,
		contents: true,
		next: true,
		prev: true
	};

jQuery.fn.extend({
	find: function( selector ) {
		var self = this,
			i, l;

		if ( typeof selector !== "string" ) {
			return jQuery( selector ).filter(function() {
				for ( i = 0, l = self.length; i < l; i++ ) {
					if ( jQuery.contains( self[ i ], this ) ) {
						return true;
					}
				}
			});
		}

		var ret = this.pushStack( "", "find", selector ),
			length, n, r;

		for ( i = 0, l = this.length; i < l; i++ ) {
			length = ret.length;
			jQuery.find( selector, this[i], ret );

			if ( i > 0 ) {
				// Make sure that the results are unique
				for ( n = length; n < ret.length; n++ ) {
					for ( r = 0; r < length; r++ ) {
						if ( ret[r] === ret[n] ) {
							ret.splice(n--, 1);
							break;
						}
					}
				}
			}
		}

		return ret;
	},

	has: function( target ) {
		var targets = jQuery( target );
		return this.filter(function() {
			for ( var i = 0, l = targets.length; i < l; i++ ) {
				if ( jQuery.contains( this, targets[i] ) ) {
					return true;
				}
			}
		});
	},

	not: function( selector ) {
		return this.pushStack( winnow(this, selector, false), "not", selector);
	},

	filter: function( selector ) {
		return this.pushStack( winnow(this, selector, true), "filter", selector );
	},

	is: function( selector ) {
		return !!selector && (
			typeof selector === "string" ?
				// If this is a positional selector, check membership in the returned set
				// so $("p:first").is("p:last") won't return true for a doc with two "p".
				POS.test( selector ) ?
					jQuery( selector, this.context ).index( this[0] ) >= 0 :
					jQuery.filter( selector, this ).length > 0 :
				this.filter( selector ).length > 0 );
	},

	closest: function( selectors, context ) {
		var ret = [], i, l, cur = this[0];

		// Array (deprecated as of jQuery 1.7)
		if ( jQuery.isArray( selectors ) ) {
			var level = 1;

			while ( cur && cur.ownerDocument && cur !== context ) {
				for ( i = 0; i < selectors.length; i++ ) {

					if ( jQuery( cur ).is( selectors[ i ] ) ) {
						ret.push({ selector: selectors[ i ], elem: cur, level: level });
					}
				}

				cur = cur.parentNode;
				level++;
			}

			return ret;
		}

		// String
		var pos = POS.test( selectors ) || typeof selectors !== "string" ?
				jQuery( selectors, context || this.context ) :
				0;

		for ( i = 0, l = this.length; i < l; i++ ) {
			cur = this[i];

			while ( cur ) {
				if ( pos ? pos.index(cur) > -1 : jQuery.find.matchesSelector(cur, selectors) ) {
					ret.push( cur );
					break;

				} else {
					cur = cur.parentNode;
					if ( !cur || !cur.ownerDocument || cur === context || cur.nodeType === 11 ) {
						break;
					}
				}
			}
		}

		ret = ret.length > 1 ? jQuery.unique( ret ) : ret;

		return this.pushStack( ret, "closest", selectors );
	},

	// Determine the position of an element within
	// the matched set of elements
	index: function( elem ) {

		// No argument, return index in parent
		if ( !elem ) {
			return ( this[0] && this[0].parentNode ) ? this.prevAll().length : -1;
		}

		// index in selector
		if ( typeof elem === "string" ) {
			return jQuery.inArray( this[0], jQuery( elem ) );
		}

		// Locate the position of the desired element
		return jQuery.inArray(
			// If it receives a jQuery object, the first element is used
			elem.jquery ? elem[0] : elem, this );
	},

	add: function( selector, context ) {
		var set = typeof selector === "string" ?
				jQuery( selector, context ) :
				jQuery.makeArray( selector && selector.nodeType ? [ selector ] : selector ),
			all = jQuery.merge( this.get(), set );

		return this.pushStack( isDisconnected( set[0] ) || isDisconnected( all[0] ) ?
			all :
			jQuery.unique( all ) );
	},

	andSelf: function() {
		return this.add( this.prevObject );
	}
});

// A painfully simple check to see if an element is disconnected
// from a document (should be improved, where feasible).
function isDisconnected( node ) {
	return !node || !node.parentNode || node.parentNode.nodeType === 11;
}

jQuery.each({
	parent: function( elem ) {
		var parent = elem.parentNode;
		return parent && parent.nodeType !== 11 ? parent : null;
	},
	parents: function( elem ) {
		return jQuery.dir( elem, "parentNode" );
	},
	parentsUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "parentNode", until );
	},
	next: function( elem ) {
		return jQuery.nth( elem, 2, "nextSibling" );
	},
	prev: function( elem ) {
		return jQuery.nth( elem, 2, "previousSibling" );
	},
	nextAll: function( elem ) {
		return jQuery.dir( elem, "nextSibling" );
	},
	prevAll: function( elem ) {
		return jQuery.dir( elem, "previousSibling" );
	},
	nextUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "nextSibling", until );
	},
	prevUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "previousSibling", until );
	},
	siblings: function( elem ) {
		return jQuery.sibling( ( elem.parentNode || {} ).firstChild, elem );
	},
	children: function( elem ) {
		return jQuery.sibling( elem.firstChild );
	},
	contents: function( elem ) {
		return jQuery.nodeName( elem, "iframe" ) ?
			elem.contentDocument || elem.contentWindow.document :
			jQuery.makeArray( elem.childNodes );
	}
}, function( name, fn ) {
	jQuery.fn[ name ] = function( until, selector ) {
		var ret = jQuery.map( this, fn, until );

		if ( !runtil.test( name ) ) {
			selector = until;
		}

		if ( selector && typeof selector === "string" ) {
			ret = jQuery.filter( selector, ret );
		}

		ret = this.length > 1 && !guaranteedUnique[ name ] ? jQuery.unique( ret ) : ret;

		if ( (this.length > 1 || rmultiselector.test( selector )) && rparentsprev.test( name ) ) {
			ret = ret.reverse();
		}

		return this.pushStack( ret, name, slice.call( arguments ).join(",") );
	};
});

jQuery.extend({
	filter: function( expr, elems, not ) {
		if ( not ) {
			expr = ":not(" + expr + ")";
		}

		return elems.length === 1 ?
			jQuery.find.matchesSelector(elems[0], expr) ? [ elems[0] ] : [] :
			jQuery.find.matches(expr, elems);
	},

	dir: function( elem, dir, until ) {
		var matched = [],
			cur = elem[ dir ];

		while ( cur && cur.nodeType !== 9 && (until === undefined || cur.nodeType !== 1 || !jQuery( cur ).is( until )) ) {
			if ( cur.nodeType === 1 ) {
				matched.push( cur );
			}
			cur = cur[dir];
		}
		return matched;
	},

	nth: function( cur, result, dir, elem ) {
		result = result || 1;
		var num = 0;

		for ( ; cur; cur = cur[dir] ) {
			if ( cur.nodeType === 1 && ++num === result ) {
				break;
			}
		}

		return cur;
	},

	sibling: function( n, elem ) {
		var r = [];

		for ( ; n; n = n.nextSibling ) {
			if ( n.nodeType === 1 && n !== elem ) {
				r.push( n );
			}
		}

		return r;
	}
});

// Implement the identical functionality for filter and not
function winnow( elements, qualifier, keep ) {

	// Can't pass null or undefined to indexOf in Firefox 4
	// Set to 0 to skip string check
	qualifier = qualifier || 0;

	if ( jQuery.isFunction( qualifier ) ) {
		return jQuery.grep(elements, function( elem, i ) {
			var retVal = !!qualifier.call( elem, i, elem );
			return retVal === keep;
		});

	} else if ( qualifier.nodeType ) {
		return jQuery.grep(elements, function( elem, i ) {
			return ( elem === qualifier ) === keep;
		});

	} else if ( typeof qualifier === "string" ) {
		var filtered = jQuery.grep(elements, function( elem ) {
			return elem.nodeType === 1;
		});

		if ( isSimple.test( qualifier ) ) {
			return jQuery.filter(qualifier, filtered, !keep);
		} else {
			qualifier = jQuery.filter( qualifier, filtered );
		}
	}

	return jQuery.grep(elements, function( elem, i ) {
		return ( jQuery.inArray( elem, qualifier ) >= 0 ) === keep;
	});
}




function createSafeFragment( document ) {
	var list = nodeNames.split( "|" ),
	safeFrag = document.createDocumentFragment();

	if ( safeFrag.createElement ) {
		while ( list.length ) {
			safeFrag.createElement(
				list.pop()
			);
		}
	}
	return safeFrag;
}

var nodeNames = "abbr|article|aside|audio|bdi|canvas|data|datalist|details|figcaption|figure|footer|" +
		"header|hgroup|mark|meter|nav|output|progress|section|summary|time|video",
	rinlinejQuery = / jQuery\d+="(?:\d+|null)"/g,
	rleadingWhitespace = /^\s+/,
	rxhtmlTag = /<(?!area|br|col|embed|hr|img|input|link|meta|param)(([\w:]+)[^>]*)\/>/ig,
	rtagName = /<([\w:]+)/,
	rtbody = /<tbody/i,
	rhtml = /<|&#?\w+;/,
	rnoInnerhtml = /<(?:script|style)/i,
	rnocache = /<(?:script|object|embed|option|style)/i,
	rnoshimcache = new RegExp("<(?:" + nodeNames + ")[\\s/>]", "i"),
	// checked="checked" or checked
	rchecked = /checked\s*(?:[^=]|=\s*.checked.)/i,
	rscriptType = /\/(java|ecma)script/i,
	rcleanScript = /^\s*<!(?:\[CDATA\[|\-\-)/,
	wrapMap = {
		option: [ 1, "<select multiple='multiple'>", "</select>" ],
		legend: [ 1, "<fieldset>", "</fieldset>" ],
		thead: [ 1, "<table>", "</table>" ],
		tr: [ 2, "<table><tbody>", "</tbody></table>" ],
		td: [ 3, "<table><tbody><tr>", "</tr></tbody></table>" ],
		col: [ 2, "<table><tbody></tbody><colgroup>", "</colgroup></table>" ],
		area: [ 1, "<map>", "</map>" ],
		_default: [ 0, "", "" ]
	},
	safeFragment = createSafeFragment( document );

wrapMap.optgroup = wrapMap.option;
wrapMap.tbody = wrapMap.tfoot = wrapMap.colgroup = wrapMap.caption = wrapMap.thead;
wrapMap.th = wrapMap.td;

// IE can't serialize <link> and <script> tags normally
if ( !jQuery.support.htmlSerialize ) {
	wrapMap._default = [ 1, "div<div>", "</div>" ];
}

jQuery.fn.extend({
	text: function( value ) {
		return jQuery.access( this, function( value ) {
			return value === undefined ?
				jQuery.text( this ) :
				this.empty().append( ( this[0] && this[0].ownerDocument || document ).createTextNode( value ) );
		}, null, value, arguments.length );
	},

	wrapAll: function( html ) {
		if ( jQuery.isFunction( html ) ) {
			return this.each(function(i) {
				jQuery(this).wrapAll( html.call(this, i) );
			});
		}

		if ( this[0] ) {
			// The elements to wrap the target around
			var wrap = jQuery( html, this[0].ownerDocument ).eq(0).clone(true);

			if ( this[0].parentNode ) {
				wrap.insertBefore( this[0] );
			}

			wrap.map(function() {
				var elem = this;

				while ( elem.firstChild && elem.firstChild.nodeType === 1 ) {
					elem = elem.firstChild;
				}

				return elem;
			}).append( this );
		}

		return this;
	},

	wrapInner: function( html ) {
		if ( jQuery.isFunction( html ) ) {
			return this.each(function(i) {
				jQuery(this).wrapInner( html.call(this, i) );
			});
		}

		return this.each(function() {
			var self = jQuery( this ),
				contents = self.contents();

			if ( contents.length ) {
				contents.wrapAll( html );

			} else {
				self.append( html );
			}
		});
	},

	wrap: function( html ) {
		var isFunction = jQuery.isFunction( html );

		return this.each(function(i) {
			jQuery( this ).wrapAll( isFunction ? html.call(this, i) : html );
		});
	},

	unwrap: function() {
		return this.parent().each(function() {
			if ( !jQuery.nodeName( this, "body" ) ) {
				jQuery( this ).replaceWith( this.childNodes );
			}
		}).end();
	},

	append: function() {
		return this.domManip(arguments, true, function( elem ) {
			if ( this.nodeType === 1 ) {
				this.appendChild( elem );
			}
		});
	},

	prepend: function() {
		return this.domManip(arguments, true, function( elem ) {
			if ( this.nodeType === 1 ) {
				this.insertBefore( elem, this.firstChild );
			}
		});
	},

	before: function() {
		if ( this[0] && this[0].parentNode ) {
			return this.domManip(arguments, false, function( elem ) {
				this.parentNode.insertBefore( elem, this );
			});
		} else if ( arguments.length ) {
			var set = jQuery.clean( arguments );
			set.push.apply( set, this.toArray() );
			return this.pushStack( set, "before", arguments );
		}
	},

	after: function() {
		if ( this[0] && this[0].parentNode ) {
			return this.domManip(arguments, false, function( elem ) {
				this.parentNode.insertBefore( elem, this.nextSibling );
			});
		} else if ( arguments.length ) {
			var set = this.pushStack( this, "after", arguments );
			set.push.apply( set, jQuery.clean(arguments) );
			return set;
		}
	},

	// keepData is for internal use only--do not document
	remove: function( selector, keepData ) {
		for ( var i = 0, elem; (elem = this[i]) != null; i++ ) {
			if ( !selector || jQuery.filter( selector, [ elem ] ).length ) {
				if ( !keepData && elem.nodeType === 1 ) {
					jQuery.cleanData( elem.getElementsByTagName("*") );
					jQuery.cleanData( [ elem ] );
				}

				if ( elem.parentNode ) {
					elem.parentNode.removeChild( elem );
				}
			}
		}

		return this;
	},

	empty: function() {
		for ( var i = 0, elem; (elem = this[i]) != null; i++ ) {
			// Remove element nodes and prevent memory leaks
			if ( elem.nodeType === 1 ) {
				jQuery.cleanData( elem.getElementsByTagName("*") );
			}

			// Remove any remaining nodes
			while ( elem.firstChild ) {
				elem.removeChild( elem.firstChild );
			}
		}

		return this;
	},

	clone: function( dataAndEvents, deepDataAndEvents ) {
		dataAndEvents = dataAndEvents == null ? false : dataAndEvents;
		deepDataAndEvents = deepDataAndEvents == null ? dataAndEvents : deepDataAndEvents;

		return this.map( function () {
			return jQuery.clone( this, dataAndEvents, deepDataAndEvents );
		});
	},

	html: function( value ) {
		return jQuery.access( this, function( value ) {
			var elem = this[0] || {},
				i = 0,
				l = this.length;

			if ( value === undefined ) {
				return elem.nodeType === 1 ?
					elem.innerHTML.replace( rinlinejQuery, "" ) :
					null;
			}


			if ( typeof value === "string" && !rnoInnerhtml.test( value ) &&
				( jQuery.support.leadingWhitespace || !rleadingWhitespace.test( value ) ) &&
				!wrapMap[ ( rtagName.exec( value ) || ["", ""] )[1].toLowerCase() ] ) {

				value = value.replace( rxhtmlTag, "<$1></$2>" );

				try {
					for (; i < l; i++ ) {
						// Remove element nodes and prevent memory leaks
						elem = this[i] || {};
						if ( elem.nodeType === 1 ) {
							jQuery.cleanData( elem.getElementsByTagName( "*" ) );
							elem.innerHTML = value;
						}
					}

					elem = 0;

				// If using innerHTML throws an exception, use the fallback method
				} catch(e) {}
			}

			if ( elem ) {
				this.empty().append( value );
			}
		}, null, value, arguments.length );
	},

	replaceWith: function( value ) {
		if ( this[0] && this[0].parentNode ) {
			// Make sure that the elements are removed from the DOM before they are inserted
			// this can help fix replacing a parent with child elements
			if ( jQuery.isFunction( value ) ) {
				return this.each(function(i) {
					var self = jQuery(this), old = self.html();
					self.replaceWith( value.call( this, i, old ) );
				});
			}

			if ( typeof value !== "string" ) {
				value = jQuery( value ).detach();
			}

			return this.each(function() {
				var next = this.nextSibling,
					parent = this.parentNode;

				jQuery( this ).remove();

				if ( next ) {
					jQuery(next).before( value );
				} else {
					jQuery(parent).append( value );
				}
			});
		} else {
			return this.length ?
				this.pushStack( jQuery(jQuery.isFunction(value) ? value() : value), "replaceWith", value ) :
				this;
		}
	},

	detach: function( selector ) {
		return this.remove( selector, true );
	},

	domManip: function( args, table, callback ) {
		var results, first, fragment, parent,
			value = args[0],
			scripts = [];

		// We can't cloneNode fragments that contain checked, in WebKit
		if ( !jQuery.support.checkClone && arguments.length === 3 && typeof value === "string" && rchecked.test( value ) ) {
			return this.each(function() {
				jQuery(this).domManip( args, table, callback, true );
			});
		}

		if ( jQuery.isFunction(value) ) {
			return this.each(function(i) {
				var self = jQuery(this);
				args[0] = value.call(this, i, table ? self.html() : undefined);
				self.domManip( args, table, callback );
			});
		}

		if ( this[0] ) {
			parent = value && value.parentNode;

			// If we're in a fragment, just use that instead of building a new one
			if ( jQuery.support.parentNode && parent && parent.nodeType === 11 && parent.childNodes.length === this.length ) {
				results = { fragment: parent };

			} else {
				results = jQuery.buildFragment( args, this, scripts );
			}

			fragment = results.fragment;

			if ( fragment.childNodes.length === 1 ) {
				first = fragment = fragment.firstChild;
			} else {
				first = fragment.firstChild;
			}

			if ( first ) {
				table = table && jQuery.nodeName( first, "tr" );

				for ( var i = 0, l = this.length, lastIndex = l - 1; i < l; i++ ) {
					callback.call(
						table ?
							root(this[i], first) :
							this[i],
						// Make sure that we do not leak memory by inadvertently discarding
						// the original fragment (which might have attached data) instead of
						// using it; in addition, use the original fragment object for the last
						// item instead of first because it can end up being emptied incorrectly
						// in certain situations (Bug #8070).
						// Fragments from the fragment cache must always be cloned and never used
						// in place.
						results.cacheable || ( l > 1 && i < lastIndex ) ?
							jQuery.clone( fragment, true, true ) :
							fragment
					);
				}
			}

			if ( scripts.length ) {
				jQuery.each( scripts, function( i, elem ) {
					if ( elem.src ) {
						jQuery.ajax({
							type: "GET",
							global: false,
							url: elem.src,
							async: false,
							dataType: "script"
						});
					} else {
						jQuery.globalEval( ( elem.text || elem.textContent || elem.innerHTML || "" ).replace( rcleanScript, "/*$0*/" ) );
					}

					if ( elem.parentNode ) {
						elem.parentNode.removeChild( elem );
					}
				});
			}
		}

		return this;
	}
});

function root( elem, cur ) {
	return jQuery.nodeName(elem, "table") ?
		(elem.getElementsByTagName("tbody")[0] ||
		elem.appendChild(elem.ownerDocument.createElement("tbody"))) :
		elem;
}

function cloneCopyEvent( src, dest ) {

	if ( dest.nodeType !== 1 || !jQuery.hasData( src ) ) {
		return;
	}

	var type, i, l,
		oldData = jQuery._data( src ),
		curData = jQuery._data( dest, oldData ),
		events = oldData.events;

	if ( events ) {
		delete curData.handle;
		curData.events = {};

		for ( type in events ) {
			for ( i = 0, l = events[ type ].length; i < l; i++ ) {
				jQuery.event.add( dest, type, events[ type ][ i ] );
			}
		}
	}

	// make the cloned public data object a copy from the original
	if ( curData.data ) {
		curData.data = jQuery.extend( {}, curData.data );
	}
}

function cloneFixAttributes( src, dest ) {
	var nodeName;

	// We do not need to do anything for non-Elements
	if ( dest.nodeType !== 1 ) {
		return;
	}

	// clearAttributes removes the attributes, which we don't want,
	// but also removes the attachEvent events, which we *do* want
	if ( dest.clearAttributes ) {
		dest.clearAttributes();
	}

	// mergeAttributes, in contrast, only merges back on the
	// original attributes, not the events
	if ( dest.mergeAttributes ) {
		dest.mergeAttributes( src );
	}

	nodeName = dest.nodeName.toLowerCase();

	// IE6-8 fail to clone children inside object elements that use
	// the proprietary classid attribute value (rather than the type
	// attribute) to identify the type of content to display
	if ( nodeName === "object" ) {
		dest.outerHTML = src.outerHTML;

	} else if ( nodeName === "input" && (src.type === "checkbox" || src.type === "radio") ) {
		// IE6-8 fails to persist the checked state of a cloned checkbox
		// or radio button. Worse, IE6-7 fail to give the cloned element
		// a checked appearance if the defaultChecked value isn't also set
		if ( src.checked ) {
			dest.defaultChecked = dest.checked = src.checked;
		}

		// IE6-7 get confused and end up setting the value of a cloned
		// checkbox/radio button to an empty string instead of "on"
		if ( dest.value !== src.value ) {
			dest.value = src.value;
		}

	// IE6-8 fails to return the selected option to the default selected
	// state when cloning options
	} else if ( nodeName === "option" ) {
		dest.selected = src.defaultSelected;

	// IE6-8 fails to set the defaultValue to the correct value when
	// cloning other types of input fields
	} else if ( nodeName === "input" || nodeName === "textarea" ) {
		dest.defaultValue = src.defaultValue;

	// IE blanks contents when cloning scripts
	} else if ( nodeName === "script" && dest.text !== src.text ) {
		dest.text = src.text;
	}

	// Event data gets referenced instead of copied if the expando
	// gets copied too
	dest.removeAttribute( jQuery.expando );

	// Clear flags for bubbling special change/submit events, they must
	// be reattached when the newly cloned events are first activated
	dest.removeAttribute( "_submit_attached" );
	dest.removeAttribute( "_change_attached" );
}

jQuery.buildFragment = function( args, nodes, scripts ) {
	var fragment, cacheable, cacheresults, doc,
	first = args[ 0 ];

	// nodes may contain either an explicit document object,
	// a jQuery collection or context object.
	// If nodes[0] contains a valid object to assign to doc
	if ( nodes && nodes[0] ) {
		doc = nodes[0].ownerDocument || nodes[0];
	}

	// Ensure that an attr object doesn't incorrectly stand in as a document object
	// Chrome and Firefox seem to allow this to occur and will throw exception
	// Fixes #8950
	if ( !doc.createDocumentFragment ) {
		doc = document;
	}

	// Only cache "small" (1/2 KB) HTML strings that are associated with the main document
	// Cloning options loses the selected state, so don't cache them
	// IE 6 doesn't like it when you put <object> or <embed> elements in a fragment
	// Also, WebKit does not clone 'checked' attributes on cloneNode, so don't cache
	// Lastly, IE6,7,8 will not correctly reuse cached fragments that were created from unknown elems #10501
	if ( args.length === 1 && typeof first === "string" && first.length < 512 && doc === document &&
		first.charAt(0) === "<" && !rnocache.test( first ) &&
		(jQuery.support.checkClone || !rchecked.test( first )) &&
		(jQuery.support.html5Clone || !rnoshimcache.test( first )) ) {

		cacheable = true;

		cacheresults = jQuery.fragments[ first ];
		if ( cacheresults && cacheresults !== 1 ) {
			fragment = cacheresults;
		}
	}

	if ( !fragment ) {
		fragment = doc.createDocumentFragment();
		jQuery.clean( args, doc, fragment, scripts );
	}

	if ( cacheable ) {
		jQuery.fragments[ first ] = cacheresults ? fragment : 1;
	}

	return { fragment: fragment, cacheable: cacheable };
};

jQuery.fragments = {};

jQuery.each({
	appendTo: "append",
	prependTo: "prepend",
	insertBefore: "before",
	insertAfter: "after",
	replaceAll: "replaceWith"
}, function( name, original ) {
	jQuery.fn[ name ] = function( selector ) {
		var ret = [],
			insert = jQuery( selector ),
			parent = this.length === 1 && this[0].parentNode;

		if ( parent && parent.nodeType === 11 && parent.childNodes.length === 1 && insert.length === 1 ) {
			insert[ original ]( this[0] );
			return this;

		} else {
			for ( var i = 0, l = insert.length; i < l; i++ ) {
				var elems = ( i > 0 ? this.clone(true) : this ).get();
				jQuery( insert[i] )[ original ]( elems );
				ret = ret.concat( elems );
			}

			return this.pushStack( ret, name, insert.selector );
		}
	};
});

function getAll( elem ) {
	if ( typeof elem.getElementsByTagName !== "undefined" ) {
		return elem.getElementsByTagName( "*" );

	} else if ( typeof elem.querySelectorAll !== "undefined" ) {
		return elem.querySelectorAll( "*" );

	} else {
		return [];
	}
}

// Used in clean, fixes the defaultChecked property
function fixDefaultChecked( elem ) {
	if ( elem.type === "checkbox" || elem.type === "radio" ) {
		elem.defaultChecked = elem.checked;
	}
}
// Finds all inputs and passes them to fixDefaultChecked
function findInputs( elem ) {
	var nodeName = ( elem.nodeName || "" ).toLowerCase();
	if ( nodeName === "input" ) {
		fixDefaultChecked( elem );
	// Skip scripts, get other children
	} else if ( nodeName !== "script" && typeof elem.getElementsByTagName !== "undefined" ) {
		jQuery.grep( elem.getElementsByTagName("input"), fixDefaultChecked );
	}
}

// Derived From: http://www.iecss.com/shimprove/javascript/shimprove.1-0-1.js
function shimCloneNode( elem ) {
	var div = document.createElement( "div" );
	safeFragment.appendChild( div );

	div.innerHTML = elem.outerHTML;
	return div.firstChild;
}

jQuery.extend({
	clone: function( elem, dataAndEvents, deepDataAndEvents ) {
		var srcElements,
			destElements,
			i,
			// IE<=8 does not properly clone detached, unknown element nodes
			clone = jQuery.support.html5Clone || jQuery.isXMLDoc(elem) || !rnoshimcache.test( "<" + elem.nodeName + ">" ) ?
				elem.cloneNode( true ) :
				shimCloneNode( elem );

		if ( (!jQuery.support.noCloneEvent || !jQuery.support.noCloneChecked) &&
				(elem.nodeType === 1 || elem.nodeType === 11) && !jQuery.isXMLDoc(elem) ) {
			// IE copies events bound via attachEvent when using cloneNode.
			// Calling detachEvent on the clone will also remove the events
			// from the original. In order to get around this, we use some
			// proprietary methods to clear the events. Thanks to MooTools
			// guys for this hotness.

			cloneFixAttributes( elem, clone );

			// Using Sizzle here is crazy slow, so we use getElementsByTagName instead
			srcElements = getAll( elem );
			destElements = getAll( clone );

			// Weird iteration because IE will replace the length property
			// with an element if you are cloning the body and one of the
			// elements on the page has a name or id of "length"
			for ( i = 0; srcElements[i]; ++i ) {
				// Ensure that the destination node is not null; Fixes #9587
				if ( destElements[i] ) {
					cloneFixAttributes( srcElements[i], destElements[i] );
				}
			}
		}

		// Copy the events from the original to the clone
		if ( dataAndEvents ) {
			cloneCopyEvent( elem, clone );

			if ( deepDataAndEvents ) {
				srcElements = getAll( elem );
				destElements = getAll( clone );

				for ( i = 0; srcElements[i]; ++i ) {
					cloneCopyEvent( srcElements[i], destElements[i] );
				}
			}
		}

		srcElements = destElements = null;

		// Return the cloned set
		return clone;
	},

	clean: function( elems, context, fragment, scripts ) {
		var checkScriptType, script, j,
				ret = [];

		context = context || document;

		// !context.createElement fails in IE with an error but returns typeof 'object'
		if ( typeof context.createElement === "undefined" ) {
			context = context.ownerDocument || context[0] && context[0].ownerDocument || document;
		}

		for ( var i = 0, elem; (elem = elems[i]) != null; i++ ) {
			if ( typeof elem === "number" ) {
				elem += "";
			}

			if ( !elem ) {
				continue;
			}

			// Convert html string into DOM nodes
			if ( typeof elem === "string" ) {
				if ( !rhtml.test( elem ) ) {
					elem = context.createTextNode( elem );
				} else {
					// Fix "XHTML"-style tags in all browsers
					elem = elem.replace(rxhtmlTag, "<$1></$2>");

					// Trim whitespace, otherwise indexOf won't work as expected
					var tag = ( rtagName.exec( elem ) || ["", ""] )[1].toLowerCase(),
						wrap = wrapMap[ tag ] || wrapMap._default,
						depth = wrap[0],
						div = context.createElement("div"),
						safeChildNodes = safeFragment.childNodes,
						remove;

					// Append wrapper element to unknown element safe doc fragment
					if ( context === document ) {
						// Use the fragment we've already created for this document
						safeFragment.appendChild( div );
					} else {
						// Use a fragment created with the owner document
						createSafeFragment( context ).appendChild( div );
					}

					// Go to html and back, then peel off extra wrappers
					div.innerHTML = wrap[1] + elem + wrap[2];

					// Move to the right depth
					while ( depth-- ) {
						div = div.lastChild;
					}

					// Remove IE's autoinserted <tbody> from table fragments
					if ( !jQuery.support.tbody ) {

						// String was a <table>, *may* have spurious <tbody>
						var hasBody = rtbody.test(elem),
							tbody = tag === "table" && !hasBody ?
								div.firstChild && div.firstChild.childNodes :

								// String was a bare <thead> or <tfoot>
								wrap[1] === "<table>" && !hasBody ?
									div.childNodes :
									[];

						for ( j = tbody.length - 1; j >= 0 ; --j ) {
							if ( jQuery.nodeName( tbody[ j ], "tbody" ) && !tbody[ j ].childNodes.length ) {
								tbody[ j ].parentNode.removeChild( tbody[ j ] );
							}
						}
					}

					// IE completely kills leading whitespace when innerHTML is used
					if ( !jQuery.support.leadingWhitespace && rleadingWhitespace.test( elem ) ) {
						div.insertBefore( context.createTextNode( rleadingWhitespace.exec(elem)[0] ), div.firstChild );
					}

					elem = div.childNodes;

					// Clear elements from DocumentFragment (safeFragment or otherwise)
					// to avoid hoarding elements. Fixes #11356
					if ( div ) {
						div.parentNode.removeChild( div );

						// Guard against -1 index exceptions in FF3.6
						if ( safeChildNodes.length > 0 ) {
							remove = safeChildNodes[ safeChildNodes.length - 1 ];

							if ( remove && remove.parentNode ) {
								remove.parentNode.removeChild( remove );
							}
						}
					}
				}
			}

			// Resets defaultChecked for any radios and checkboxes
			// about to be appended to the DOM in IE 6/7 (#8060)
			var len;
			if ( !jQuery.support.appendChecked ) {
				if ( elem[0] && typeof (len = elem.length) === "number" ) {
					for ( j = 0; j < len; j++ ) {
						findInputs( elem[j] );
					}
				} else {
					findInputs( elem );
				}
			}

			if ( elem.nodeType ) {
				ret.push( elem );
			} else {
				ret = jQuery.merge( ret, elem );
			}
		}

		if ( fragment ) {
			checkScriptType = function( elem ) {
				return !elem.type || rscriptType.test( elem.type );
			};
			for ( i = 0; ret[i]; i++ ) {
				script = ret[i];
				if ( scripts && jQuery.nodeName( script, "script" ) && (!script.type || rscriptType.test( script.type )) ) {
					scripts.push( script.parentNode ? script.parentNode.removeChild( script ) : script );

				} else {
					if ( script.nodeType === 1 ) {
						var jsTags = jQuery.grep( script.getElementsByTagName( "script" ), checkScriptType );

						ret.splice.apply( ret, [i + 1, 0].concat( jsTags ) );
					}
					fragment.appendChild( script );
				}
			}
		}

		return ret;
	},

	cleanData: function( elems ) {
		var data, id,
			cache = jQuery.cache,
			special = jQuery.event.special,
			deleteExpando = jQuery.support.deleteExpando;

		for ( var i = 0, elem; (elem = elems[i]) != null; i++ ) {
			if ( elem.nodeName && jQuery.noData[elem.nodeName.toLowerCase()] ) {
				continue;
			}

			id = elem[ jQuery.expando ];

			if ( id ) {
				data = cache[ id ];

				if ( data && data.events ) {
					for ( var type in data.events ) {
						if ( special[ type ] ) {
							jQuery.event.remove( elem, type );

						// This is a shortcut to avoid jQuery.event.remove's overhead
						} else {
							jQuery.removeEvent( elem, type, data.handle );
						}
					}

					// Null the DOM reference to avoid IE6/7/8 leak (#7054)
					if ( data.handle ) {
						data.handle.elem = null;
					}
				}

				if ( deleteExpando ) {
					delete elem[ jQuery.expando ];

				} else if ( elem.removeAttribute ) {
					elem.removeAttribute( jQuery.expando );
				}

				delete cache[ id ];
			}
		}
	}
});




var ralpha = /alpha\([^)]*\)/i,
	ropacity = /opacity=([^)]*)/,
	// fixed for IE9, see #8346
	rupper = /([A-Z]|^ms)/g,
	rnum = /^[\-+]?(?:\d*\.)?\d+$/i,
	rnumnonpx = /^-?(?:\d*\.)?\d+(?!px)[^\d\s]+$/i,
	rrelNum = /^([\-+])=([\-+.\de]+)/,
	rmargin = /^margin/,

	cssShow = { position: "absolute", visibility: "hidden", display: "block" },

	// order is important!
	cssExpand = [ "Top", "Right", "Bottom", "Left" ],

	curCSS,

	getComputedStyle,
	currentStyle;

jQuery.fn.css = function( name, value ) {
	return jQuery.access( this, function( elem, name, value ) {
		return value !== undefined ?
			jQuery.style( elem, name, value ) :
			jQuery.css( elem, name );
	}, name, value, arguments.length > 1 );
};

jQuery.extend({
	// Add in style property hooks for overriding the default
	// behavior of getting and setting a style property
	cssHooks: {
		opacity: {
			get: function( elem, computed ) {
				if ( computed ) {
					// We should always get a number back from opacity
					var ret = curCSS( elem, "opacity" );
					return ret === "" ? "1" : ret;

				} else {
					return elem.style.opacity;
				}
			}
		}
	},

	// Exclude the following css properties to add px
	cssNumber: {
		"fillOpacity": true,
		"fontWeight": true,
		"lineHeight": true,
		"opacity": true,
		"orphans": true,
		"widows": true,
		"zIndex": true,
		"zoom": true
	},

	// Add in properties whose names you wish to fix before
	// setting or getting the value
	cssProps: {
		// normalize float css property
		"float": jQuery.support.cssFloat ? "cssFloat" : "styleFloat"
	},

	// Get and set the style property on a DOM Node
	style: function( elem, name, value, extra ) {
		// Don't set styles on text and comment nodes
		if ( !elem || elem.nodeType === 3 || elem.nodeType === 8 || !elem.style ) {
			return;
		}

		// Make sure that we're working with the right name
		var ret, type, origName = jQuery.camelCase( name ),
			style = elem.style, hooks = jQuery.cssHooks[ origName ];

		name = jQuery.cssProps[ origName ] || origName;

		// Check if we're setting a value
		if ( value !== undefined ) {
			type = typeof value;

			// convert relative number strings (+= or -=) to relative numbers. #7345
			if ( type === "string" && (ret = rrelNum.exec( value )) ) {
				value = ( +( ret[1] + 1) * +ret[2] ) + parseFloat( jQuery.css( elem, name ) );
				// Fixes bug #9237
				type = "number";
			}

			// Make sure that NaN and null values aren't set. See: #7116
			if ( value == null || type === "number" && isNaN( value ) ) {
				return;
			}

			// If a number was passed in, add 'px' to the (except for certain CSS properties)
			if ( type === "number" && !jQuery.cssNumber[ origName ] ) {
				value += "px";
			}

			// If a hook was provided, use that value, otherwise just set the specified value
			if ( !hooks || !("set" in hooks) || (value = hooks.set( elem, value )) !== undefined ) {
				// Wrapped to prevent IE from throwing errors when 'invalid' values are provided
				// Fixes bug #5509
				try {
					style[ name ] = value;
				} catch(e) {}
			}

		} else {
			// If a hook was provided get the non-computed value from there
			if ( hooks && "get" in hooks && (ret = hooks.get( elem, false, extra )) !== undefined ) {
				return ret;
			}

			// Otherwise just get the value from the style object
			return style[ name ];
		}
	},

	css: function( elem, name, extra ) {
		var ret, hooks;

		// Make sure that we're working with the right name
		name = jQuery.camelCase( name );
		hooks = jQuery.cssHooks[ name ];
		name = jQuery.cssProps[ name ] || name;

		// cssFloat needs a special treatment
		if ( name === "cssFloat" ) {
			name = "float";
		}

		// If a hook was provided get the computed value from there
		if ( hooks && "get" in hooks && (ret = hooks.get( elem, true, extra )) !== undefined ) {
			return ret;

		// Otherwise, if a way to get the computed value exists, use that
		} else if ( curCSS ) {
			return curCSS( elem, name );
		}
	},

	// A method for quickly swapping in/out CSS properties to get correct calculations
	swap: function( elem, options, callback ) {
		var old = {},
			ret, name;

		// Remember the old values, and insert the new ones
		for ( name in options ) {
			old[ name ] = elem.style[ name ];
			elem.style[ name ] = options[ name ];
		}

		ret = callback.call( elem );

		// Revert the old values
		for ( name in options ) {
			elem.style[ name ] = old[ name ];
		}

		return ret;
	}
});

// DEPRECATED in 1.3, Use jQuery.css() instead
jQuery.curCSS = jQuery.css;

if ( document.defaultView && document.defaultView.getComputedStyle ) {
	getComputedStyle = function( elem, name ) {
		var ret, defaultView, computedStyle, width,
			style = elem.style;

		name = name.replace( rupper, "-$1" ).toLowerCase();

		if ( (defaultView = elem.ownerDocument.defaultView) &&
				(computedStyle = defaultView.getComputedStyle( elem, null )) ) {

			ret = computedStyle.getPropertyValue( name );
			if ( ret === "" && !jQuery.contains( elem.ownerDocument.documentElement, elem ) ) {
				ret = jQuery.style( elem, name );
			}
		}

		// A tribute to the "awesome hack by Dean Edwards"
		// WebKit uses "computed value (percentage if specified)" instead of "used value" for margins
		// which is against the CSSOM draft spec: http://dev.w3.org/csswg/cssom/#resolved-values
		if ( !jQuery.support.pixelMargin && computedStyle && rmargin.test( name ) && rnumnonpx.test( ret ) ) {
			width = style.width;
			style.width = ret;
			ret = computedStyle.width;
			style.width = width;
		}

		return ret;
	};
}

if ( document.documentElement.currentStyle ) {
	currentStyle = function( elem, name ) {
		var left, rsLeft, uncomputed,
			ret = elem.currentStyle && elem.currentStyle[ name ],
			style = elem.style;

		// Avoid setting ret to empty string here
		// so we don't default to auto
		if ( ret == null && style && (uncomputed = style[ name ]) ) {
			ret = uncomputed;
		}

		// From the awesome hack by Dean Edwards
		// http://erik.eae.net/archives/2007/07/27/18.54.15/#comment-102291

		// If we're not dealing with a regular pixel number
		// but a number that has a weird ending, we need to convert it to pixels
		if ( rnumnonpx.test( ret ) ) {

			// Remember the original values
			left = style.left;
			rsLeft = elem.runtimeStyle && elem.runtimeStyle.left;

			// Put in the new values to get a computed value out
			if ( rsLeft ) {
				elem.runtimeStyle.left = elem.currentStyle.left;
			}
			style.left = name === "fontSize" ? "1em" : ret;
			ret = style.pixelLeft + "px";

			// Revert the changed values
			style.left = left;
			if ( rsLeft ) {
				elem.runtimeStyle.left = rsLeft;
			}
		}

		return ret === "" ? "auto" : ret;
	};
}

curCSS = getComputedStyle || currentStyle;

function getWidthOrHeight( elem, name, extra ) {

	// Start with offset property
	var val = name === "width" ? elem.offsetWidth : elem.offsetHeight,
		i = name === "width" ? 1 : 0,
		len = 4;

	if ( val > 0 ) {
		if ( extra !== "border" ) {
			for ( ; i < len; i += 2 ) {
				if ( !extra ) {
					val -= parseFloat( jQuery.css( elem, "padding" + cssExpand[ i ] ) ) || 0;
				}
				if ( extra === "margin" ) {
					val += parseFloat( jQuery.css( elem, extra + cssExpand[ i ] ) ) || 0;
				} else {
					val -= parseFloat( jQuery.css( elem, "border" + cssExpand[ i ] + "Width" ) ) || 0;
				}
			}
		}

		return val + "px";
	}

	// Fall back to computed then uncomputed css if necessary
	val = curCSS( elem, name );
	if ( val < 0 || val == null ) {
		val = elem.style[ name ];
	}

	// Computed unit is not pixels. Stop here and return.
	if ( rnumnonpx.test(val) ) {
		return val;
	}

	// Normalize "", auto, and prepare for extra
	val = parseFloat( val ) || 0;

	// Add padding, border, margin
	if ( extra ) {
		for ( ; i < len; i += 2 ) {
			val += parseFloat( jQuery.css( elem, "padding" + cssExpand[ i ] ) ) || 0;
			if ( extra !== "padding" ) {
				val += parseFloat( jQuery.css( elem, "border" + cssExpand[ i ] + "Width" ) ) || 0;
			}
			if ( extra === "margin" ) {
				val += parseFloat( jQuery.css( elem, extra + cssExpand[ i ]) ) || 0;
			}
		}
	}

	return val + "px";
}

jQuery.each([ "height", "width" ], function( i, name ) {
	jQuery.cssHooks[ name ] = {
		get: function( elem, computed, extra ) {
			if ( computed ) {
				if ( elem.offsetWidth !== 0 ) {
					return getWidthOrHeight( elem, name, extra );
				} else {
					return jQuery.swap( elem, cssShow, function() {
						return getWidthOrHeight( elem, name, extra );
					});
				}
			}
		},

		set: function( elem, value ) {
			return rnum.test( value ) ?
				value + "px" :
				value;
		}
	};
});

if ( !jQuery.support.opacity ) {
	jQuery.cssHooks.opacity = {
		get: function( elem, computed ) {
			// IE uses filters for opacity
			return ropacity.test( (computed && elem.currentStyle ? elem.currentStyle.filter : elem.style.filter) || "" ) ?
				( parseFloat( RegExp.$1 ) / 100 ) + "" :
				computed ? "1" : "";
		},

		set: function( elem, value ) {
			var style = elem.style,
				currentStyle = elem.currentStyle,
				opacity = jQuery.isNumeric( value ) ? "alpha(opacity=" + value * 100 + ")" : "",
				filter = currentStyle && currentStyle.filter || style.filter || "";

			// IE has trouble with opacity if it does not have layout
			// Force it by setting the zoom level
			style.zoom = 1;

			// if setting opacity to 1, and no other filters exist - attempt to remove filter attribute #6652
			if ( value >= 1 && jQuery.trim( filter.replace( ralpha, "" ) ) === "" ) {

				// Setting style.filter to null, "" & " " still leave "filter:" in the cssText
				// if "filter:" is present at all, clearType is disabled, we want to avoid this
				// style.removeAttribute is IE Only, but so apparently is this code path...
				style.removeAttribute( "filter" );

				// if there there is no filter style applied in a css rule, we are done
				if ( currentStyle && !currentStyle.filter ) {
					return;
				}
			}

			// otherwise, set new filter values
			style.filter = ralpha.test( filter ) ?
				filter.replace( ralpha, opacity ) :
				filter + " " + opacity;
		}
	};
}

jQuery(function() {
	// This hook cannot be added until DOM ready because the support test
	// for it is not run until after DOM ready
	if ( !jQuery.support.reliableMarginRight ) {
		jQuery.cssHooks.marginRight = {
			get: function( elem, computed ) {
				// WebKit Bug 13343 - getComputedStyle returns wrong value for margin-right
				// Work around by temporarily setting element display to inline-block
				return jQuery.swap( elem, { "display": "inline-block" }, function() {
					if ( computed ) {
						return curCSS( elem, "margin-right" );
					} else {
						return elem.style.marginRight;
					}
				});
			}
		};
	}
});

if ( jQuery.expr && jQuery.expr.filters ) {
	jQuery.expr.filters.hidden = function( elem ) {
		var width = elem.offsetWidth,
			height = elem.offsetHeight;

		return ( width === 0 && height === 0 ) || (!jQuery.support.reliableHiddenOffsets && ((elem.style && elem.style.display) || jQuery.css( elem, "display" )) === "none");
	};

	jQuery.expr.filters.visible = function( elem ) {
		return !jQuery.expr.filters.hidden( elem );
	};
}

// These hooks are used by animate to expand properties
jQuery.each({
	margin: "",
	padding: "",
	border: "Width"
}, function( prefix, suffix ) {

	jQuery.cssHooks[ prefix + suffix ] = {
		expand: function( value ) {
			var i,

				// assumes a single number if not a string
				parts = typeof value === "string" ? value.split(" ") : [ value ],
				expanded = {};

			for ( i = 0; i < 4; i++ ) {
				expanded[ prefix + cssExpand[ i ] + suffix ] =
					parts[ i ] || parts[ i - 2 ] || parts[ 0 ];
			}

			return expanded;
		}
	};
});




var r20 = /%20/g,
	rbracket = /\[\]$/,
	rCRLF = /\r?\n/g,
	rhash = /#.*$/,
	rheaders = /^(.*?):[ \t]*([^\r\n]*)\r?$/mg, // IE leaves an \r character at EOL
	rinput = /^(?:color|date|datetime|datetime-local|email|hidden|month|number|password|range|search|tel|text|time|url|week)$/i,
	// #7653, #8125, #8152: local protocol detection
	rlocalProtocol = /^(?:about|app|app\-storage|.+\-extension|file|res|widget):$/,
	rnoContent = /^(?:GET|HEAD)$/,
	rprotocol = /^\/\//,
	rquery = /\?/,
	rscript = /<script\b[^<]*(?:(?!<\/script>)<[^<]*)*<\/script>/gi,
	rselectTextarea = /^(?:select|textarea)/i,
	rspacesAjax = /\s+/,
	rts = /([?&])_=[^&]*/,
	rurl = /^([\w\+\.\-]+:)(?:\/\/([^\/?#:]*)(?::(\d+))?)?/,

	// Keep a copy of the old load method
	_load = jQuery.fn.load,

	/* Prefilters
	 * 1) They are useful to introduce custom dataTypes (see ajax/jsonp.js for an example)
	 * 2) These are called:
	 *    - BEFORE asking for a transport
	 *    - AFTER param serialization (s.data is a string if s.processData is true)
	 * 3) key is the dataType
	 * 4) the catchall symbol "*" can be used
	 * 5) execution will start with transport dataType and THEN continue down to "*" if needed
	 */
	prefilters = {},

	/* Transports bindings
	 * 1) key is the dataType
	 * 2) the catchall symbol "*" can be used
	 * 3) selection will start with transport dataType and THEN go to "*" if needed
	 */
	transports = {},

	// Document location
	ajaxLocation,

	// Document location segments
	ajaxLocParts,

	// Avoid comment-prolog char sequence (#10098); must appease lint and evade compression
	allTypes = ["*/"] + ["*"];

// #8138, IE may throw an exception when accessing
// a field from window.location if document.domain has been set
try {
	ajaxLocation = location.href;
} catch( e ) {
	// Use the href attribute of an A element
	// since IE will modify it given document.location
	ajaxLocation = document.createElement( "a" );
	ajaxLocation.href = "";
	ajaxLocation = ajaxLocation.href;
}

// Segment location into parts
ajaxLocParts = rurl.exec( ajaxLocation.toLowerCase() ) || [];

// Base "constructor" for jQuery.ajaxPrefilter and jQuery.ajaxTransport
function addToPrefiltersOrTransports( structure ) {

	// dataTypeExpression is optional and defaults to "*"
	return function( dataTypeExpression, func ) {

		if ( typeof dataTypeExpression !== "string" ) {
			func = dataTypeExpression;
			dataTypeExpression = "*";
		}

		if ( jQuery.isFunction( func ) ) {
			var dataTypes = dataTypeExpression.toLowerCase().split( rspacesAjax ),
				i = 0,
				length = dataTypes.length,
				dataType,
				list,
				placeBefore;

			// For each dataType in the dataTypeExpression
			for ( ; i < length; i++ ) {
				dataType = dataTypes[ i ];
				// We control if we're asked to add before
				// any existing element
				placeBefore = /^\+/.test( dataType );
				if ( placeBefore ) {
					dataType = dataType.substr( 1 ) || "*";
				}
				list = structure[ dataType ] = structure[ dataType ] || [];
				// then we add to the structure accordingly
				list[ placeBefore ? "unshift" : "push" ]( func );
			}
		}
	};
}

// Base inspection function for prefilters and transports
function inspectPrefiltersOrTransports( structure, options, originalOptions, jqXHR,
		dataType /* internal */, inspected /* internal */ ) {

	dataType = dataType || options.dataTypes[ 0 ];
	inspected = inspected || {};

	inspected[ dataType ] = true;

	var list = structure[ dataType ],
		i = 0,
		length = list ? list.length : 0,
		executeOnly = ( structure === prefilters ),
		selection;

	for ( ; i < length && ( executeOnly || !selection ); i++ ) {
		selection = list[ i ]( options, originalOptions, jqXHR );
		// If we got redirected to another dataType
		// we try there if executing only and not done already
		if ( typeof selection === "string" ) {
			if ( !executeOnly || inspected[ selection ] ) {
				selection = undefined;
			} else {
				options.dataTypes.unshift( selection );
				selection = inspectPrefiltersOrTransports(
						structure, options, originalOptions, jqXHR, selection, inspected );
			}
		}
	}
	// If we're only executing or nothing was selected
	// we try the catchall dataType if not done already
	if ( ( executeOnly || !selection ) && !inspected[ "*" ] ) {
		selection = inspectPrefiltersOrTransports(
				structure, options, originalOptions, jqXHR, "*", inspected );
	}
	// unnecessary when only executing (prefilters)
	// but it'll be ignored by the caller in that case
	return selection;
}

// A special extend for ajax options
// that takes "flat" options (not to be deep extended)
// Fixes #9887
function ajaxExtend( target, src ) {
	var key, deep,
		flatOptions = jQuery.ajaxSettings.flatOptions || {};
	for ( key in src ) {
		if ( src[ key ] !== undefined ) {
			( flatOptions[ key ] ? target : ( deep || ( deep = {} ) ) )[ key ] = src[ key ];
		}
	}
	if ( deep ) {
		jQuery.extend( true, target, deep );
	}
}

jQuery.fn.extend({
	load: function( url, params, callback ) {
		if ( typeof url !== "string" && _load ) {
			return _load.apply( this, arguments );

		// Don't do a request if no elements are being requested
		} else if ( !this.length ) {
			return this;
		}

		var off = url.indexOf( " " );
		if ( off >= 0 ) {
			var selector = url.slice( off, url.length );
			url = url.slice( 0, off );
		}

		// Default to a GET request
		var type = "GET";

		// If the second parameter was provided
		if ( params ) {
			// If it's a function
			if ( jQuery.isFunction( params ) ) {
				// We assume that it's the callback
				callback = params;
				params = undefined;

			// Otherwise, build a param string
			} else if ( typeof params === "object" ) {
				params = jQuery.param( params, jQuery.ajaxSettings.traditional );
				type = "POST";
			}
		}

		var self = this;

		// Request the remote document
		jQuery.ajax({
			url: url,
			type: type,
			dataType: "html",
			data: params,
			// Complete callback (responseText is used internally)
			complete: function( jqXHR, status, responseText ) {
				// Store the response as specified by the jqXHR object
				responseText = jqXHR.responseText;
				// If successful, inject the HTML into all the matched elements
				if ( jqXHR.isResolved() ) {
					// #4825: Get the actual response in case
					// a dataFilter is present in ajaxSettings
					jqXHR.done(function( r ) {
						responseText = r;
					});
					// See if a selector was specified
					self.html( selector ?
						// Create a dummy div to hold the results
						jQuery("<div>")
							// inject the contents of the document in, removing the scripts
							// to avoid any 'Permission Denied' errors in IE
							.append(responseText.replace(rscript, ""))

							// Locate the specified elements
							.find(selector) :

						// If not, just inject the full result
						responseText );
				}

				if ( callback ) {
					self.each( callback, [ responseText, status, jqXHR ] );
				}
			}
		});

		return this;
	},

	serialize: function() {
		return jQuery.param( this.serializeArray() );
	},

	serializeArray: function() {
		return this.map(function(){
			return this.elements ? jQuery.makeArray( this.elements ) : this;
		})
		.filter(function(){
			return this.name && !this.disabled &&
				( this.checked || rselectTextarea.test( this.nodeName ) ||
					rinput.test( this.type ) );
		})
		.map(function( i, elem ){
			var val = jQuery( this ).val();

			return val == null ?
				null :
				jQuery.isArray( val ) ?
					jQuery.map( val, function( val, i ){
						return { name: elem.name, value: val.replace( rCRLF, "\r\n" ) };
					}) :
					{ name: elem.name, value: val.replace( rCRLF, "\r\n" ) };
		}).get();
	}
});

// Attach a bunch of functions for handling common AJAX events
jQuery.each( "ajaxStart ajaxStop ajaxComplete ajaxError ajaxSuccess ajaxSend".split( " " ), function( i, o ){
	jQuery.fn[ o ] = function( f ){
		return this.on( o, f );
	};
});

jQuery.each( [ "get", "post" ], function( i, method ) {
	jQuery[ method ] = function( url, data, callback, type ) {
		// shift arguments if data argument was omitted
		if ( jQuery.isFunction( data ) ) {
			type = type || callback;
			callback = data;
			data = undefined;
		}

		return jQuery.ajax({
			type: method,
			url: url,
			data: data,
			success: callback,
			dataType: type
		});
	};
});

jQuery.extend({

	getScript: function( url, callback ) {
		return jQuery.get( url, undefined, callback, "script" );
	},

	getJSON: function( url, data, callback ) {
		return jQuery.get( url, data, callback, "json" );
	},

	// Creates a full fledged settings object into target
	// with both ajaxSettings and settings fields.
	// If target is omitted, writes into ajaxSettings.
	ajaxSetup: function( target, settings ) {
		if ( settings ) {
			// Building a settings object
			ajaxExtend( target, jQuery.ajaxSettings );
		} else {
			// Extending ajaxSettings
			settings = target;
			target = jQuery.ajaxSettings;
		}
		ajaxExtend( target, settings );
		return target;
	},

	ajaxSettings: {
		url: ajaxLocation,
		isLocal: rlocalProtocol.test( ajaxLocParts[ 1 ] ),
		global: true,
		type: "GET",
		contentType: "application/x-www-form-urlencoded; charset=UTF-8",
		processData: true,
		async: true,
		/*
		timeout: 0,
		data: null,
		dataType: null,
		username: null,
		password: null,
		cache: null,
		traditional: false,
		headers: {},
		*/

		accepts: {
			xml: "application/xml, text/xml",
			html: "text/html",
			text: "text/plain",
			json: "application/json, text/javascript",
			"*": allTypes
		},

		contents: {
			xml: /xml/,
			html: /html/,
			json: /json/
		},

		responseFields: {
			xml: "responseXML",
			text: "responseText"
		},

		// List of data converters
		// 1) key format is "source_type destination_type" (a single space in-between)
		// 2) the catchall symbol "*" can be used for source_type
		converters: {

			// Convert anything to text
			"* text": window.String,

			// Text to html (true = no transformation)
			"text html": true,

			// Evaluate text as a json expression
			"text json": jQuery.parseJSON,

			// Parse text as xml
			"text xml": jQuery.parseXML
		},

		// For options that shouldn't be deep extended:
		// you can add your own custom options here if
		// and when you create one that shouldn't be
		// deep extended (see ajaxExtend)
		flatOptions: {
			context: true,
			url: true
		}
	},

	ajaxPrefilter: addToPrefiltersOrTransports( prefilters ),
	ajaxTransport: addToPrefiltersOrTransports( transports ),

	// Main method
	ajax: function( url, options ) {

		// If url is an object, simulate pre-1.5 signature
		if ( typeof url === "object" ) {
			options = url;
			url = undefined;
		}

		// Force options to be an object
		options = options || {};

		var // Create the final options object
			s = jQuery.ajaxSetup( {}, options ),
			// Callbacks context
			callbackContext = s.context || s,
			// Context for global events
			// It's the callbackContext if one was provided in the options
			// and if it's a DOM node or a jQuery collection
			globalEventContext = callbackContext !== s &&
				( callbackContext.nodeType || callbackContext instanceof jQuery ) ?
						jQuery( callbackContext ) : jQuery.event,
			// Deferreds
			deferred = jQuery.Deferred(),
			completeDeferred = jQuery.Callbacks( "once memory" ),
			// Status-dependent callbacks
			statusCode = s.statusCode || {},
			// ifModified key
			ifModifiedKey,
			// Headers (they are sent all at once)
			requestHeaders = {},
			requestHeadersNames = {},
			// Response headers
			responseHeadersString,
			responseHeaders,
			// transport
			transport,
			// timeout handle
			timeoutTimer,
			// Cross-domain detection vars
			parts,
			// The jqXHR state
			state = 0,
			// To know if global events are to be dispatched
			fireGlobals,
			// Loop variable
			i,
			// Fake xhr
			jqXHR = {

				readyState: 0,

				// Caches the header
				setRequestHeader: function( name, value ) {
					if ( !state ) {
						var lname = name.toLowerCase();
						name = requestHeadersNames[ lname ] = requestHeadersNames[ lname ] || name;
						requestHeaders[ name ] = value;
					}
					return this;
				},

				// Raw string
				getAllResponseHeaders: function() {
					return state === 2 ? responseHeadersString : null;
				},

				// Builds headers hashtable if needed
				getResponseHeader: function( key ) {
					var match;
					if ( state === 2 ) {
						if ( !responseHeaders ) {
							responseHeaders = {};
							while( ( match = rheaders.exec( responseHeadersString ) ) ) {
								responseHeaders[ match[1].toLowerCase() ] = match[ 2 ];
							}
						}
						match = responseHeaders[ key.toLowerCase() ];
					}
					return match === undefined ? null : match;
				},

				// Overrides response content-type header
				overrideMimeType: function( type ) {
					if ( !state ) {
						s.mimeType = type;
					}
					return this;
				},

				// Cancel the request
				abort: function( statusText ) {
					statusText = statusText || "abort";
					if ( transport ) {
						transport.abort( statusText );
					}
					done( 0, statusText );
					return this;
				}
			};

		// Callback for when everything is done
		// It is defined here because jslint complains if it is declared
		// at the end of the function (which would be more logical and readable)
		function done( status, nativeStatusText, responses, headers ) {

			// Called once
			if ( state === 2 ) {
				return;
			}

			// State is "done" now
			state = 2;

			// Clear timeout if it exists
			if ( timeoutTimer ) {
				clearTimeout( timeoutTimer );
			}

			// Dereference transport for early garbage collection
			// (no matter how long the jqXHR object will be used)
			transport = undefined;

			// Cache response headers
			responseHeadersString = headers || "";

			// Set readyState
			jqXHR.readyState = status > 0 ? 4 : 0;

			var isSuccess,
				success,
				error,
				statusText = nativeStatusText,
				response = responses ? ajaxHandleResponses( s, jqXHR, responses ) : undefined,
				lastModified,
				etag;

			// If successful, handle type chaining
			if ( status >= 200 && status < 300 || status === 304 ) {

				// Set the If-Modified-Since and/or If-None-Match header, if in ifModified mode.
				if ( s.ifModified ) {

					if ( ( lastModified = jqXHR.getResponseHeader( "Last-Modified" ) ) ) {
						jQuery.lastModified[ ifModifiedKey ] = lastModified;
					}
					if ( ( etag = jqXHR.getResponseHeader( "Etag" ) ) ) {
						jQuery.etag[ ifModifiedKey ] = etag;
					}
				}

				// If not modified
				if ( status === 304 ) {

					statusText = "notmodified";
					isSuccess = true;

				// If we have data
				} else {

					try {
						success = ajaxConvert( s, response );
						statusText = "success";
						isSuccess = true;
					} catch(e) {
						// We have a parsererror
						statusText = "parsererror";
						error = e;
					}
				}
			} else {
				// We extract error from statusText
				// then normalize statusText and status for non-aborts
				error = statusText;
				if ( !statusText || status ) {
					statusText = "error";
					if ( status < 0 ) {
						status = 0;
					}
				}
			}

			// Set data for the fake xhr object
			jqXHR.status = status;
			jqXHR.statusText = "" + ( nativeStatusText || statusText );

			// Success/Error
			if ( isSuccess ) {
				deferred.resolveWith( callbackContext, [ success, statusText, jqXHR ] );
			} else {
				deferred.rejectWith( callbackContext, [ jqXHR, statusText, error ] );
			}

			// Status-dependent callbacks
			jqXHR.statusCode( statusCode );
			statusCode = undefined;

			if ( fireGlobals ) {
				globalEventContext.trigger( "ajax" + ( isSuccess ? "Success" : "Error" ),
						[ jqXHR, s, isSuccess ? success : error ] );
			}

			// Complete
			completeDeferred.fireWith( callbackContext, [ jqXHR, statusText ] );

			if ( fireGlobals ) {
				globalEventContext.trigger( "ajaxComplete", [ jqXHR, s ] );
				// Handle the global AJAX counter
				if ( !( --jQuery.active ) ) {
					jQuery.event.trigger( "ajaxStop" );
				}
			}
		}

		// Attach deferreds
		deferred.promise( jqXHR );
		jqXHR.success = jqXHR.done;
		jqXHR.error = jqXHR.fail;
		jqXHR.complete = completeDeferred.add;

		// Status-dependent callbacks
		jqXHR.statusCode = function( map ) {
			if ( map ) {
				var tmp;
				if ( state < 2 ) {
					for ( tmp in map ) {
						statusCode[ tmp ] = [ statusCode[tmp], map[tmp] ];
					}
				} else {
					tmp = map[ jqXHR.status ];
					jqXHR.then( tmp, tmp );
				}
			}
			return this;
		};

		// Remove hash character (#7531: and string promotion)
		// Add protocol if not provided (#5866: IE7 issue with protocol-less urls)
		// We also use the url parameter if available
		s.url = ( ( url || s.url ) + "" ).replace( rhash, "" ).replace( rprotocol, ajaxLocParts[ 1 ] + "//" );

		// Extract dataTypes list
		s.dataTypes = jQuery.trim( s.dataType || "*" ).toLowerCase().split( rspacesAjax );

		// Determine if a cross-domain request is in order
		if ( s.crossDomain == null ) {
			parts = rurl.exec( s.url.toLowerCase() );
			s.crossDomain = !!( parts &&
				( parts[ 1 ] != ajaxLocParts[ 1 ] || parts[ 2 ] != ajaxLocParts[ 2 ] ||
					( parts[ 3 ] || ( parts[ 1 ] === "http:" ? 80 : 443 ) ) !=
						( ajaxLocParts[ 3 ] || ( ajaxLocParts[ 1 ] === "http:" ? 80 : 443 ) ) )
			);
		}

		// Convert data if not already a string
		if ( s.data && s.processData && typeof s.data !== "string" ) {
			s.data = jQuery.param( s.data, s.traditional );
		}

		// Apply prefilters
		inspectPrefiltersOrTransports( prefilters, s, options, jqXHR );

		// If request was aborted inside a prefilter, stop there
		if ( state === 2 ) {
			return false;
		}

		// We can fire global events as of now if asked to
		fireGlobals = s.global;

		// Uppercase the type
		s.type = s.type.toUpperCase();

		// Determine if request has content
		s.hasContent = !rnoContent.test( s.type );

		// Watch for a new set of requests
		if ( fireGlobals && jQuery.active++ === 0 ) {
			jQuery.event.trigger( "ajaxStart" );
		}

		// More options handling for requests with no content
		if ( !s.hasContent ) {

			// If data is available, append data to url
			if ( s.data ) {
				s.url += ( rquery.test( s.url ) ? "&" : "?" ) + s.data;
				// #9682: remove data so that it's not used in an eventual retry
				delete s.data;
			}

			// Get ifModifiedKey before adding the anti-cache parameter
			ifModifiedKey = s.url;

			// Add anti-cache in url if needed
			if ( s.cache === false ) {

				var ts = jQuery.now(),
					// try replacing _= if it is there
					ret = s.url.replace( rts, "$1_=" + ts );

				// if nothing was replaced, add timestamp to the end
				s.url = ret + ( ( ret === s.url ) ? ( rquery.test( s.url ) ? "&" : "?" ) + "_=" + ts : "" );
			}
		}

		// Set the correct header, if data is being sent
		if ( s.data && s.hasContent && s.contentType !== false || options.contentType ) {
			jqXHR.setRequestHeader( "Content-Type", s.contentType );
		}

		// Set the If-Modified-Since and/or If-None-Match header, if in ifModified mode.
		if ( s.ifModified ) {
			ifModifiedKey = ifModifiedKey || s.url;
			if ( jQuery.lastModified[ ifModifiedKey ] ) {
				jqXHR.setRequestHeader( "If-Modified-Since", jQuery.lastModified[ ifModifiedKey ] );
			}
			if ( jQuery.etag[ ifModifiedKey ] ) {
				jqXHR.setRequestHeader( "If-None-Match", jQuery.etag[ ifModifiedKey ] );
			}
		}

		// Set the Accepts header for the server, depending on the dataType
		jqXHR.setRequestHeader(
			"Accept",
			s.dataTypes[ 0 ] && s.accepts[ s.dataTypes[0] ] ?
				s.accepts[ s.dataTypes[0] ] + ( s.dataTypes[ 0 ] !== "*" ? ", " + allTypes + "; q=0.01" : "" ) :
				s.accepts[ "*" ]
		);

		// Check for headers option
		for ( i in s.headers ) {
			jqXHR.setRequestHeader( i, s.headers[ i ] );
		}

		// Allow custom headers/mimetypes and early abort
		if ( s.beforeSend && ( s.beforeSend.call( callbackContext, jqXHR, s ) === false || state === 2 ) ) {
				// Abort if not done already
				jqXHR.abort();
				return false;

		}

		// Install callbacks on deferreds
		for ( i in { success: 1, error: 1, complete: 1 } ) {
			jqXHR[ i ]( s[ i ] );
		}

		// Get transport
		transport = inspectPrefiltersOrTransports( transports, s, options, jqXHR );

		// If no transport, we auto-abort
		if ( !transport ) {
			done( -1, "No Transport" );
		} else {
			jqXHR.readyState = 1;
			// Send global event
			if ( fireGlobals ) {
				globalEventContext.trigger( "ajaxSend", [ jqXHR, s ] );
			}
			// Timeout
			if ( s.async && s.timeout > 0 ) {
				timeoutTimer = setTimeout( function(){
					jqXHR.abort( "timeout" );
				}, s.timeout );
			}

			try {
				state = 1;
				transport.send( requestHeaders, done );
			} catch (e) {
				// Propagate exception as error if not done
				if ( state < 2 ) {
					done( -1, e );
				// Simply rethrow otherwise
				} else {
					throw e;
				}
			}
		}

		return jqXHR;
	},

	// Serialize an array of form elements or a set of
	// key/values into a query string
	param: function( a, traditional ) {
		var s = [],
			add = function( key, value ) {
				// If value is a function, invoke it and return its value
				value = jQuery.isFunction( value ) ? value() : value;
				s[ s.length ] = encodeURIComponent( key ) + "=" + encodeURIComponent( value );
			};

		// Set traditional to true for jQuery <= 1.3.2 behavior.
		if ( traditional === undefined ) {
			traditional = jQuery.ajaxSettings.traditional;
		}

		// If an array was passed in, assume that it is an array of form elements.
		if ( jQuery.isArray( a ) || ( a.jquery && !jQuery.isPlainObject( a ) ) ) {
			// Serialize the form elements
			jQuery.each( a, function() {
				add( this.name, this.value );
			});

		} else {
			// If traditional, encode the "old" way (the way 1.3.2 or older
			// did it), otherwise encode params recursively.
			for ( var prefix in a ) {
				buildParams( prefix, a[ prefix ], traditional, add );
			}
		}

		// Return the resulting serialization
		return s.join( "&" ).replace( r20, "+" );
	}
});

function buildParams( prefix, obj, traditional, add ) {
	if ( jQuery.isArray( obj ) ) {
		// Serialize array item.
		jQuery.each( obj, function( i, v ) {
			if ( traditional || rbracket.test( prefix ) ) {
				// Treat each array item as a scalar.
				add( prefix, v );

			} else {
				// If array item is non-scalar (array or object), encode its
				// numeric index to resolve deserialization ambiguity issues.
				// Note that rack (as of 1.0.0) can't currently deserialize
				// nested arrays properly, and attempting to do so may cause
				// a server error. Possible fixes are to modify rack's
				// deserialization algorithm or to provide an option or flag
				// to force array serialization to be shallow.
				buildParams( prefix + "[" + ( typeof v === "object" ? i : "" ) + "]", v, traditional, add );
			}
		});

	} else if ( !traditional && jQuery.type( obj ) === "object" ) {
		// Serialize object item.
		for ( var name in obj ) {
			buildParams( prefix + "[" + name + "]", obj[ name ], traditional, add );
		}

	} else {
		// Serialize scalar item.
		add( prefix, obj );
	}
}

// This is still on the jQuery object... for now
// Want to move this to jQuery.ajax some day
jQuery.extend({

	// Counter for holding the number of active queries
	active: 0,

	// Last-Modified header cache for next request
	lastModified: {},
	etag: {}

});

/* Handles responses to an ajax request:
 * - sets all responseXXX fields accordingly
 * - finds the right dataType (mediates between content-type and expected dataType)
 * - returns the corresponding response
 */
function ajaxHandleResponses( s, jqXHR, responses ) {

	var contents = s.contents,
		dataTypes = s.dataTypes,
		responseFields = s.responseFields,
		ct,
		type,
		finalDataType,
		firstDataType;

	// Fill responseXXX fields
	for ( type in responseFields ) {
		if ( type in responses ) {
			jqXHR[ responseFields[type] ] = responses[ type ];
		}
	}

	// Remove auto dataType and get content-type in the process
	while( dataTypes[ 0 ] === "*" ) {
		dataTypes.shift();
		if ( ct === undefined ) {
			ct = s.mimeType || jqXHR.getResponseHeader( "content-type" );
		}
	}

	// Check if we're dealing with a known content-type
	if ( ct ) {
		for ( type in contents ) {
			if ( contents[ type ] && contents[ type ].test( ct ) ) {
				dataTypes.unshift( type );
				break;
			}
		}
	}

	// Check to see if we have a response for the expected dataType
	if ( dataTypes[ 0 ] in responses ) {
		finalDataType = dataTypes[ 0 ];
	} else {
		// Try convertible dataTypes
		for ( type in responses ) {
			if ( !dataTypes[ 0 ] || s.converters[ type + " " + dataTypes[0] ] ) {
				finalDataType = type;
				break;
			}
			if ( !firstDataType ) {
				firstDataType = type;
			}
		}
		// Or just use first one
		finalDataType = finalDataType || firstDataType;
	}

	// If we found a dataType
	// We add the dataType to the list if needed
	// and return the corresponding response
	if ( finalDataType ) {
		if ( finalDataType !== dataTypes[ 0 ] ) {
			dataTypes.unshift( finalDataType );
		}
		return responses[ finalDataType ];
	}
}

// Chain conversions given the request and the original response
function ajaxConvert( s, response ) {

	// Apply the dataFilter if provided
	if ( s.dataFilter ) {
		response = s.dataFilter( response, s.dataType );
	}

	var dataTypes = s.dataTypes,
		converters = {},
		i,
		key,
		length = dataTypes.length,
		tmp,
		// Current and previous dataTypes
		current = dataTypes[ 0 ],
		prev,
		// Conversion expression
		conversion,
		// Conversion function
		conv,
		// Conversion functions (transitive conversion)
		conv1,
		conv2;

	// For each dataType in the chain
	for ( i = 1; i < length; i++ ) {

		// Create converters map
		// with lowercased keys
		if ( i === 1 ) {
			for ( key in s.converters ) {
				if ( typeof key === "string" ) {
					converters[ key.toLowerCase() ] = s.converters[ key ];
				}
			}
		}

		// Get the dataTypes
		prev = current;
		current = dataTypes[ i ];

		// If current is auto dataType, update it to prev
		if ( current === "*" ) {
			current = prev;
		// If no auto and dataTypes are actually different
		} else if ( prev !== "*" && prev !== current ) {

			// Get the converter
			conversion = prev + " " + current;
			conv = converters[ conversion ] || converters[ "* " + current ];

			// If there is no direct converter, search transitively
			if ( !conv ) {
				conv2 = undefined;
				for ( conv1 in converters ) {
					tmp = conv1.split( " " );
					if ( tmp[ 0 ] === prev || tmp[ 0 ] === "*" ) {
						conv2 = converters[ tmp[1] + " " + current ];
						if ( conv2 ) {
							conv1 = converters[ conv1 ];
							if ( conv1 === true ) {
								conv = conv2;
							} else if ( conv2 === true ) {
								conv = conv1;
							}
							break;
						}
					}
				}
			}
			// If we found no converter, dispatch an error
			if ( !( conv || conv2 ) ) {
				jQuery.error( "No conversion from " + conversion.replace(" "," to ") );
			}
			// If found converter is not an equivalence
			if ( conv !== true ) {
				// Convert with 1 or 2 converters accordingly
				response = conv ? conv( response ) : conv2( conv1(response) );
			}
		}
	}
	return response;
}




var jsc = jQuery.now(),
	jsre = /(\=)\?(&|$)|\?\?/i;

// Default jsonp settings
jQuery.ajaxSetup({
	jsonp: "callback",
	jsonpCallback: function() {
		return jQuery.expando + "_" + ( jsc++ );
	}
});

// Detect, normalize options and install callbacks for jsonp requests
jQuery.ajaxPrefilter( "json jsonp", function( s, originalSettings, jqXHR ) {

	var inspectData = ( typeof s.data === "string" ) && /^application\/x\-www\-form\-urlencoded/.test( s.contentType );

	if ( s.dataTypes[ 0 ] === "jsonp" ||
		s.jsonp !== false && ( jsre.test( s.url ) ||
				inspectData && jsre.test( s.data ) ) ) {

		var responseContainer,
			jsonpCallback = s.jsonpCallback =
				jQuery.isFunction( s.jsonpCallback ) ? s.jsonpCallback() : s.jsonpCallback,
			previous = window[ jsonpCallback ],
			url = s.url,
			data = s.data,
			replace = "$1" + jsonpCallback + "$2";

		if ( s.jsonp !== false ) {
			url = url.replace( jsre, replace );
			if ( s.url === url ) {
				if ( inspectData ) {
					data = data.replace( jsre, replace );
				}
				if ( s.data === data ) {
					// Add callback manually
					url += (/\?/.test( url ) ? "&" : "?") + s.jsonp + "=" + jsonpCallback;
				}
			}
		}

		s.url = url;
		s.data = data;

		// Install callback
		window[ jsonpCallback ] = function( response ) {
			responseContainer = [ response ];
		};

		// Clean-up function
		jqXHR.always(function() {
			// Set callback back to previous value
			window[ jsonpCallback ] = previous;
			// Call if it was a function and we have a response
			if ( responseContainer && jQuery.isFunction( previous ) ) {
				window[ jsonpCallback ]( responseContainer[ 0 ] );
			}
		});

		// Use data converter to retrieve json after script execution
		s.converters["script json"] = function() {
			if ( !responseContainer ) {
				jQuery.error( jsonpCallback + " was not called" );
			}
			return responseContainer[ 0 ];
		};

		// force json dataType
		s.dataTypes[ 0 ] = "json";

		// Delegate to script
		return "script";
	}
});




// Install script dataType
jQuery.ajaxSetup({
	accepts: {
		script: "text/javascript, application/javascript, application/ecmascript, application/x-ecmascript"
	},
	contents: {
		script: /javascript|ecmascript/
	},
	converters: {
		"text script": function( text ) {
			jQuery.globalEval( text );
			return text;
		}
	}
});

// Handle cache's special case and global
jQuery.ajaxPrefilter( "script", function( s ) {
	if ( s.cache === undefined ) {
		s.cache = false;
	}
	if ( s.crossDomain ) {
		s.type = "GET";
		s.global = false;
	}
});

// Bind script tag hack transport
jQuery.ajaxTransport( "script", function(s) {

	// This transport only deals with cross domain requests
	if ( s.crossDomain ) {

		var script,
			head = document.head || document.getElementsByTagName( "head" )[0] || document.documentElement;

		return {

			send: function( _, callback ) {

				script = document.createElement( "script" );

				script.async = "async";

				if ( s.scriptCharset ) {
					script.charset = s.scriptCharset;
				}

				script.src = s.url;

				// Attach handlers for all browsers
				script.onload = script.onreadystatechange = function( _, isAbort ) {

					if ( isAbort || !script.readyState || /loaded|complete/.test( script.readyState ) ) {

						// Handle memory leak in IE
						script.onload = script.onreadystatechange = null;

						// Remove the script
						if ( head && script.parentNode ) {
							head.removeChild( script );
						}

						// Dereference the script
						script = undefined;

						// Callback if not abort
						if ( !isAbort ) {
							callback( 200, "success" );
						}
					}
				};
				// Use insertBefore instead of appendChild  to circumvent an IE6 bug.
				// This arises when a base node is used (#2709 and #4378).
				head.insertBefore( script, head.firstChild );
			},

			abort: function() {
				if ( script ) {
					script.onload( 0, 1 );
				}
			}
		};
	}
});




var // #5280: Internet Explorer will keep connections alive if we don't abort on unload
	xhrOnUnloadAbort = window.ActiveXObject ? function() {
		// Abort all pending requests
		for ( var key in xhrCallbacks ) {
			xhrCallbacks[ key ]( 0, 1 );
		}
	} : false,
	xhrId = 0,
	xhrCallbacks;

// Functions to create xhrs
function createStandardXHR() {
	try {
		return new window.XMLHttpRequest();
	} catch( e ) {}
}

function createActiveXHR() {
	try {
		return new window.ActiveXObject( "Microsoft.XMLHTTP" );
	} catch( e ) {}
}

// Create the request object
// (This is still attached to ajaxSettings for backward compatibility)
jQuery.ajaxSettings.xhr = window.ActiveXObject ?
	/* Microsoft failed to properly
	 * implement the XMLHttpRequest in IE7 (can't request local files),
	 * so we use the ActiveXObject when it is available
	 * Additionally XMLHttpRequest can be disabled in IE7/IE8 so
	 * we need a fallback.
	 */
	function() {
		return !this.isLocal && createStandardXHR() || createActiveXHR();
	} :
	// For all other browsers, use the standard XMLHttpRequest object
	createStandardXHR;

// Determine support properties
(function( xhr ) {
	jQuery.extend( jQuery.support, {
		ajax: !!xhr,
		cors: !!xhr && ( "withCredentials" in xhr )
	});
})( jQuery.ajaxSettings.xhr() );

// Create transport if the browser can provide an xhr
if ( jQuery.support.ajax ) {

	jQuery.ajaxTransport(function( s ) {
		// Cross domain only allowed if supported through XMLHttpRequest
		if ( !s.crossDomain || jQuery.support.cors ) {

			var callback;

			return {
				send: function( headers, complete ) {

					// Get a new xhr
					var xhr = s.xhr(),
						handle,
						i;

					// Open the socket
					// Passing null username, generates a login popup on Opera (#2865)
					if ( s.username ) {
						xhr.open( s.type, s.url, s.async, s.username, s.password );
					} else {
						xhr.open( s.type, s.url, s.async );
					}

					// Apply custom fields if provided
					if ( s.xhrFields ) {
						for ( i in s.xhrFields ) {
							xhr[ i ] = s.xhrFields[ i ];
						}
					}

					// Override mime type if needed
					if ( s.mimeType && xhr.overrideMimeType ) {
						xhr.overrideMimeType( s.mimeType );
					}

					// X-Requested-With header
					// For cross-domain requests, seeing as conditions for a preflight are
					// akin to a jigsaw puzzle, we simply never set it to be sure.
					// (it can always be set on a per-request basis or even using ajaxSetup)
					// For same-domain requests, won't change header if already provided.
					if ( !s.crossDomain && !headers["X-Requested-With"] ) {
						headers[ "X-Requested-With" ] = "XMLHttpRequest";
					}

					// Need an extra try/catch for cross domain requests in Firefox 3
					try {
						for ( i in headers ) {
							xhr.setRequestHeader( i, headers[ i ] );
						}
					} catch( _ ) {}

					// Do send the request
					// This may raise an exception which is actually
					// handled in jQuery.ajax (so no try/catch here)
					xhr.send( ( s.hasContent && s.data ) || null );

					// Listener
					callback = function( _, isAbort ) {

						var status,
							statusText,
							responseHeaders,
							responses,
							xml;

						// Firefox throws exceptions when accessing properties
						// of an xhr when a network error occured
						// http://helpful.knobs-dials.com/index.php/Component_returned_failure_code:_0x80040111_(NS_ERROR_NOT_AVAILABLE)
						try {

							// Was never called and is aborted or complete
							if ( callback && ( isAbort || xhr.readyState === 4 ) ) {

								// Only called once
								callback = undefined;

								// Do not keep as active anymore
								if ( handle ) {
									xhr.onreadystatechange = jQuery.noop;
									if ( xhrOnUnloadAbort ) {
										delete xhrCallbacks[ handle ];
									}
								}

								// If it's an abort
								if ( isAbort ) {
									// Abort it manually if needed
									if ( xhr.readyState !== 4 ) {
										xhr.abort();
									}
								} else {
									status = xhr.status;
									responseHeaders = xhr.getAllResponseHeaders();
									responses = {};
									xml = xhr.responseXML;

									// Construct response list
									if ( xml && xml.documentElement /* #4958 */ ) {
										responses.xml = xml;
									}

									// When requesting binary data, IE6-9 will throw an exception
									// on any attempt to access responseText (#11426)
									try {
										responses.text = xhr.responseText;
									} catch( _ ) {
									}

									// Firefox throws an exception when accessing
									// statusText for faulty cross-domain requests
									try {
										statusText = xhr.statusText;
									} catch( e ) {
										// We normalize with Webkit giving an empty statusText
										statusText = "";
									}

									// Filter status for non standard behaviors

									// If the request is local and we have data: assume a success
									// (success with no data won't get notified, that's the best we
									// can do given current implementations)
									if ( !status && s.isLocal && !s.crossDomain ) {
										status = responses.text ? 200 : 404;
									// IE - #1450: sometimes returns 1223 when it should be 204
									} else if ( status === 1223 ) {
										status = 204;
									}
								}
							}
						} catch( firefoxAccessException ) {
							if ( !isAbort ) {
								complete( -1, firefoxAccessException );
							}
						}

						// Call complete if needed
						if ( responses ) {
							complete( status, statusText, responses, responseHeaders );
						}
					};

					// if we're in sync mode or it's in cache
					// and has been retrieved directly (IE6 & IE7)
					// we need to manually fire the callback
					if ( !s.async || xhr.readyState === 4 ) {
						callback();
					} else {
						handle = ++xhrId;
						if ( xhrOnUnloadAbort ) {
							// Create the active xhrs callbacks list if needed
							// and attach the unload handler
							if ( !xhrCallbacks ) {
								xhrCallbacks = {};
								jQuery( window ).unload( xhrOnUnloadAbort );
							}
							// Add to list of active xhrs callbacks
							xhrCallbacks[ handle ] = callback;
						}
						xhr.onreadystatechange = callback;
					}
				},

				abort: function() {
					if ( callback ) {
						callback(0,1);
					}
				}
			};
		}
	});
}




var elemdisplay = {},
	iframe, iframeDoc,
	rfxtypes = /^(?:toggle|show|hide)$/,
	rfxnum = /^([+\-]=)?([\d+.\-]+)([a-z%]*)$/i,
	timerId,
	fxAttrs = [
		// height animations
		[ "height", "marginTop", "marginBottom", "paddingTop", "paddingBottom" ],
		// width animations
		[ "width", "marginLeft", "marginRight", "paddingLeft", "paddingRight" ],
		// opacity animations
		[ "opacity" ]
	],
	fxNow;

jQuery.fn.extend({
	show: function( speed, easing, callback ) {
		var elem, display;

		if ( speed || speed === 0 ) {
			return this.animate( genFx("show", 3), speed, easing, callback );

		} else {
			for ( var i = 0, j = this.length; i < j; i++ ) {
				elem = this[ i ];

				if ( elem.style ) {
					display = elem.style.display;

					// Reset the inline display of this element to learn if it is
					// being hidden by cascaded rules or not
					if ( !jQuery._data(elem, "olddisplay") && display === "none" ) {
						display = elem.style.display = "";
					}

					// Set elements which have been overridden with display: none
					// in a stylesheet to whatever the default browser style is
					// for such an element
					if ( (display === "" && jQuery.css(elem, "display") === "none") ||
						!jQuery.contains( elem.ownerDocument.documentElement, elem ) ) {
						jQuery._data( elem, "olddisplay", defaultDisplay(elem.nodeName) );
					}
				}
			}

			// Set the display of most of the elements in a second loop
			// to avoid the constant reflow
			for ( i = 0; i < j; i++ ) {
				elem = this[ i ];

				if ( elem.style ) {
					display = elem.style.display;

					if ( display === "" || display === "none" ) {
						elem.style.display = jQuery._data( elem, "olddisplay" ) || "";
					}
				}
			}

			return this;
		}
	},

	hide: function( speed, easing, callback ) {
		if ( speed || speed === 0 ) {
			return this.animate( genFx("hide", 3), speed, easing, callback);

		} else {
			var elem, display,
				i = 0,
				j = this.length;

			for ( ; i < j; i++ ) {
				elem = this[i];
				if ( elem.style ) {
					display = jQuery.css( elem, "display" );

					if ( display !== "none" && !jQuery._data( elem, "olddisplay" ) ) {
						jQuery._data( elem, "olddisplay", display );
					}
				}
			}

			// Set the display of the elements in a second loop
			// to avoid the constant reflow
			for ( i = 0; i < j; i++ ) {
				if ( this[i].style ) {
					this[i].style.display = "none";
				}
			}

			return this;
		}
	},

	// Save the old toggle function
	_toggle: jQuery.fn.toggle,

	toggle: function( fn, fn2, callback ) {
		var bool = typeof fn === "boolean";

		if ( jQuery.isFunction(fn) && jQuery.isFunction(fn2) ) {
			this._toggle.apply( this, arguments );

		} else if ( fn == null || bool ) {
			this.each(function() {
				var state = bool ? fn : jQuery(this).is(":hidden");
				jQuery(this)[ state ? "show" : "hide" ]();
			});

		} else {
			this.animate(genFx("toggle", 3), fn, fn2, callback);
		}

		return this;
	},

	fadeTo: function( speed, to, easing, callback ) {
		return this.filter(":hidden").css("opacity", 0).show().end()
					.animate({opacity: to}, speed, easing, callback);
	},

	animate: function( prop, speed, easing, callback ) {
		var optall = jQuery.speed( speed, easing, callback );

		if ( jQuery.isEmptyObject( prop ) ) {
			return this.each( optall.complete, [ false ] );
		}

		// Do not change referenced properties as per-property easing will be lost
		prop = jQuery.extend( {}, prop );

		function doAnimation() {
			// XXX 'this' does not always have a nodeName when running the
			// test suite

			if ( optall.queue === false ) {
				jQuery._mark( this );
			}

			var opt = jQuery.extend( {}, optall ),
				isElement = this.nodeType === 1,
				hidden = isElement && jQuery(this).is(":hidden"),
				name, val, p, e, hooks, replace,
				parts, start, end, unit,
				method;

			// will store per property easing and be used to determine when an animation is complete
			opt.animatedProperties = {};

			// first pass over propertys to expand / normalize
			for ( p in prop ) {
				name = jQuery.camelCase( p );
				if ( p !== name ) {
					prop[ name ] = prop[ p ];
					delete prop[ p ];
				}

				if ( ( hooks = jQuery.cssHooks[ name ] ) && "expand" in hooks ) {
					replace = hooks.expand( prop[ name ] );
					delete prop[ name ];

					// not quite $.extend, this wont overwrite keys already present.
					// also - reusing 'p' from above because we have the correct "name"
					for ( p in replace ) {
						if ( ! ( p in prop ) ) {
							prop[ p ] = replace[ p ];
						}
					}
				}
			}

			for ( name in prop ) {
				val = prop[ name ];
				// easing resolution: per property > opt.specialEasing > opt.easing > 'swing' (default)
				if ( jQuery.isArray( val ) ) {
					opt.animatedProperties[ name ] = val[ 1 ];
					val = prop[ name ] = val[ 0 ];
				} else {
					opt.animatedProperties[ name ] = opt.specialEasing && opt.specialEasing[ name ] || opt.easing || 'swing';
				}

				if ( val === "hide" && hidden || val === "show" && !hidden ) {
					return opt.complete.call( this );
				}

				if ( isElement && ( name === "height" || name === "width" ) ) {
					// Make sure that nothing sneaks out
					// Record all 3 overflow attributes because IE does not
					// change the overflow attribute when overflowX and
					// overflowY are set to the same value
					opt.overflow = [ this.style.overflow, this.style.overflowX, this.style.overflowY ];

					// Set display property to inline-block for height/width
					// animations on inline elements that are having width/height animated
					if ( jQuery.css( this, "display" ) === "inline" &&
							jQuery.css( this, "float" ) === "none" ) {

						// inline-level elements accept inline-block;
						// block-level elements need to be inline with layout
						if ( !jQuery.support.inlineBlockNeedsLayout || defaultDisplay( this.nodeName ) === "inline" ) {
							this.style.display = "inline-block";

						} else {
							this.style.zoom = 1;
						}
					}
				}
			}

			if ( opt.overflow != null ) {
				this.style.overflow = "hidden";
			}

			for ( p in prop ) {
				e = new jQuery.fx( this, opt, p );
				val = prop[ p ];

				if ( rfxtypes.test( val ) ) {

					// Tracks whether to show or hide based on private
					// data attached to the element
					method = jQuery._data( this, "toggle" + p ) || ( val === "toggle" ? hidden ? "show" : "hide" : 0 );
					if ( method ) {
						jQuery._data( this, "toggle" + p, method === "show" ? "hide" : "show" );
						e[ method ]();
					} else {
						e[ val ]();
					}

				} else {
					parts = rfxnum.exec( val );
					start = e.cur();

					if ( parts ) {
						end = parseFloat( parts[2] );
						unit = parts[3] || ( jQuery.cssNumber[ p ] ? "" : "px" );

						// We need to compute starting value
						if ( unit !== "px" ) {
							jQuery.style( this, p, (end || 1) + unit);
							start = ( (end || 1) / e.cur() ) * start;
							jQuery.style( this, p, start + unit);
						}

						// If a +=/-= token was provided, we're doing a relative animation
						if ( parts[1] ) {
							end = ( (parts[ 1 ] === "-=" ? -1 : 1) * end ) + start;
						}

						e.custom( start, end, unit );

					} else {
						e.custom( start, val, "" );
					}
				}
			}

			// For JS strict compliance
			return true;
		}

		return optall.queue === false ?
			this.each( doAnimation ) :
			this.queue( optall.queue, doAnimation );
	},

	stop: function( type, clearQueue, gotoEnd ) {
		if ( typeof type !== "string" ) {
			gotoEnd = clearQueue;
			clearQueue = type;
			type = undefined;
		}
		if ( clearQueue && type !== false ) {
			this.queue( type || "fx", [] );
		}

		return this.each(function() {
			var index,
				hadTimers = false,
				timers = jQuery.timers,
				data = jQuery._data( this );

			// clear marker counters if we know they won't be
			if ( !gotoEnd ) {
				jQuery._unmark( true, this );
			}

			function stopQueue( elem, data, index ) {
				var hooks = data[ index ];
				jQuery.removeData( elem, index, true );
				hooks.stop( gotoEnd );
			}

			if ( type == null ) {
				for ( index in data ) {
					if ( data[ index ] && data[ index ].stop && index.indexOf(".run") === index.length - 4 ) {
						stopQueue( this, data, index );
					}
				}
			} else if ( data[ index = type + ".run" ] && data[ index ].stop ){
				stopQueue( this, data, index );
			}

			for ( index = timers.length; index--; ) {
				if ( timers[ index ].elem === this && (type == null || timers[ index ].queue === type) ) {
					if ( gotoEnd ) {

						// force the next step to be the last
						timers[ index ]( true );
					} else {
						timers[ index ].saveState();
					}
					hadTimers = true;
					timers.splice( index, 1 );
				}
			}

			// start the next in the queue if the last step wasn't forced
			// timers currently will call their complete callbacks, which will dequeue
			// but only if they were gotoEnd
			if ( !( gotoEnd && hadTimers ) ) {
				jQuery.dequeue( this, type );
			}
		});
	}

});

// Animations created synchronously will run synchronously
function createFxNow() {
	setTimeout( clearFxNow, 0 );
	return ( fxNow = jQuery.now() );
}

function clearFxNow() {
	fxNow = undefined;
}

// Generate parameters to create a standard animation
function genFx( type, num ) {
	var obj = {};

	jQuery.each( fxAttrs.concat.apply([], fxAttrs.slice( 0, num )), function() {
		obj[ this ] = type;
	});

	return obj;
}

// Generate shortcuts for custom animations
jQuery.each({
	slideDown: genFx( "show", 1 ),
	slideUp: genFx( "hide", 1 ),
	slideToggle: genFx( "toggle", 1 ),
	fadeIn: { opacity: "show" },
	fadeOut: { opacity: "hide" },
	fadeToggle: { opacity: "toggle" }
}, function( name, props ) {
	jQuery.fn[ name ] = function( speed, easing, callback ) {
		return this.animate( props, speed, easing, callback );
	};
});

jQuery.extend({
	speed: function( speed, easing, fn ) {
		var opt = speed && typeof speed === "object" ? jQuery.extend( {}, speed ) : {
			complete: fn || !fn && easing ||
				jQuery.isFunction( speed ) && speed,
			duration: speed,
			easing: fn && easing || easing && !jQuery.isFunction( easing ) && easing
		};

		opt.duration = jQuery.fx.off ? 0 : typeof opt.duration === "number" ? opt.duration :
			opt.duration in jQuery.fx.speeds ? jQuery.fx.speeds[ opt.duration ] : jQuery.fx.speeds._default;

		// normalize opt.queue - true/undefined/null -> "fx"
		if ( opt.queue == null || opt.queue === true ) {
			opt.queue = "fx";
		}

		// Queueing
		opt.old = opt.complete;

		opt.complete = function( noUnmark ) {
			if ( jQuery.isFunction( opt.old ) ) {
				opt.old.call( this );
			}

			if ( opt.queue ) {
				jQuery.dequeue( this, opt.queue );
			} else if ( noUnmark !== false ) {
				jQuery._unmark( this );
			}
		};

		return opt;
	},

	easing: {
		linear: function( p ) {
			return p;
		},
		swing: function( p ) {
			return ( -Math.cos( p*Math.PI ) / 2 ) + 0.5;
		}
	},

	timers: [],

	fx: function( elem, options, prop ) {
		this.options = options;
		this.elem = elem;
		this.prop = prop;

		options.orig = options.orig || {};
	}

});

jQuery.fx.prototype = {
	// Simple function for setting a style value
	update: function() {
		if ( this.options.step ) {
			this.options.step.call( this.elem, this.now, this );
		}

		( jQuery.fx.step[ this.prop ] || jQuery.fx.step._default )( this );
	},

	// Get the current size
	cur: function() {
		if ( this.elem[ this.prop ] != null && (!this.elem.style || this.elem.style[ this.prop ] == null) ) {
			return this.elem[ this.prop ];
		}

		var parsed,
			r = jQuery.css( this.elem, this.prop );
		// Empty strings, null, undefined and "auto" are converted to 0,
		// complex values such as "rotate(1rad)" are returned as is,
		// simple values such as "10px" are parsed to Float.
		return isNaN( parsed = parseFloat( r ) ) ? !r || r === "auto" ? 0 : r : parsed;
	},

	// Start an animation from one number to another
	custom: function( from, to, unit ) {
		var self = this,
			fx = jQuery.fx;

		this.startTime = fxNow || createFxNow();
		this.end = to;
		this.now = this.start = from;
		this.pos = this.state = 0;
		this.unit = unit || this.unit || ( jQuery.cssNumber[ this.prop ] ? "" : "px" );

		function t( gotoEnd ) {
			return self.step( gotoEnd );
		}

		t.queue = this.options.queue;
		t.elem = this.elem;
		t.saveState = function() {
			if ( jQuery._data( self.elem, "fxshow" + self.prop ) === undefined ) {
				if ( self.options.hide ) {
					jQuery._data( self.elem, "fxshow" + self.prop, self.start );
				} else if ( self.options.show ) {
					jQuery._data( self.elem, "fxshow" + self.prop, self.end );
				}
			}
		};

		if ( t() && jQuery.timers.push(t) && !timerId ) {
			timerId = setInterval( fx.tick, fx.interval );
		}
	},

	// Simple 'show' function
	show: function() {
		var dataShow = jQuery._data( this.elem, "fxshow" + this.prop );

		// Remember where we started, so that we can go back to it later
		this.options.orig[ this.prop ] = dataShow || jQuery.style( this.elem, this.prop );
		this.options.show = true;

		// Begin the animation
		// Make sure that we start at a small width/height to avoid any flash of content
		if ( dataShow !== undefined ) {
			// This show is picking up where a previous hide or show left off
			this.custom( this.cur(), dataShow );
		} else {
			this.custom( this.prop === "width" || this.prop === "height" ? 1 : 0, this.cur() );
		}

		// Start by showing the element
		jQuery( this.elem ).show();
	},

	// Simple 'hide' function
	hide: function() {
		// Remember where we started, so that we can go back to it later
		this.options.orig[ this.prop ] = jQuery._data( this.elem, "fxshow" + this.prop ) || jQuery.style( this.elem, this.prop );
		this.options.hide = true;

		// Begin the animation
		this.custom( this.cur(), 0 );
	},

	// Each step of an animation
	step: function( gotoEnd ) {
		var p, n, complete,
			t = fxNow || createFxNow(),
			done = true,
			elem = this.elem,
			options = this.options;

		if ( gotoEnd || t >= options.duration + this.startTime ) {
			this.now = this.end;
			this.pos = this.state = 1;
			this.update();

			options.animatedProperties[ this.prop ] = true;

			for ( p in options.animatedProperties ) {
				if ( options.animatedProperties[ p ] !== true ) {
					done = false;
				}
			}

			if ( done ) {
				// Reset the overflow
				if ( options.overflow != null && !jQuery.support.shrinkWrapBlocks ) {

					jQuery.each( [ "", "X", "Y" ], function( index, value ) {
						elem.style[ "overflow" + value ] = options.overflow[ index ];
					});
				}

				// Hide the element if the "hide" operation was done
				if ( options.hide ) {
					jQuery( elem ).hide();
				}

				// Reset the properties, if the item has been hidden or shown
				if ( options.hide || options.show ) {
					for ( p in options.animatedProperties ) {
						jQuery.style( elem, p, options.orig[ p ] );
						jQuery.removeData( elem, "fxshow" + p, true );
						// Toggle data is no longer needed
						jQuery.removeData( elem, "toggle" + p, true );
					}
				}

				// Execute the complete function
				// in the event that the complete function throws an exception
				// we must ensure it won't be called twice. #5684

				complete = options.complete;
				if ( complete ) {

					options.complete = false;
					complete.call( elem );
				}
			}

			return false;

		} else {
			// classical easing cannot be used with an Infinity duration
			if ( options.duration == Infinity ) {
				this.now = t;
			} else {
				n = t - this.startTime;
				this.state = n / options.duration;

				// Perform the easing function, defaults to swing
				this.pos = jQuery.easing[ options.animatedProperties[this.prop] ]( this.state, n, 0, 1, options.duration );
				this.now = this.start + ( (this.end - this.start) * this.pos );
			}
			// Perform the next step of the animation
			this.update();
		}

		return true;
	}
};

jQuery.extend( jQuery.fx, {
	tick: function() {
		var timer,
			timers = jQuery.timers,
			i = 0;

		for ( ; i < timers.length; i++ ) {
			timer = timers[ i ];
			// Checks the timer has not already been removed
			if ( !timer() && timers[ i ] === timer ) {
				timers.splice( i--, 1 );
			}
		}

		if ( !timers.length ) {
			jQuery.fx.stop();
		}
	},

	interval: 13,

	stop: function() {
		clearInterval( timerId );
		timerId = null;
	},

	speeds: {
		slow: 600,
		fast: 200,
		// Default speed
		_default: 400
	},

	step: {
		opacity: function( fx ) {
			jQuery.style( fx.elem, "opacity", fx.now );
		},

		_default: function( fx ) {
			if ( fx.elem.style && fx.elem.style[ fx.prop ] != null ) {
				fx.elem.style[ fx.prop ] = fx.now + fx.unit;
			} else {
				fx.elem[ fx.prop ] = fx.now;
			}
		}
	}
});

// Ensure props that can't be negative don't go there on undershoot easing
jQuery.each( fxAttrs.concat.apply( [], fxAttrs ), function( i, prop ) {
	// exclude marginTop, marginLeft, marginBottom and marginRight from this list
	if ( prop.indexOf( "margin" ) ) {
		jQuery.fx.step[ prop ] = function( fx ) {
			jQuery.style( fx.elem, prop, Math.max(0, fx.now) + fx.unit );
		};
	}
});

if ( jQuery.expr && jQuery.expr.filters ) {
	jQuery.expr.filters.animated = function( elem ) {
		return jQuery.grep(jQuery.timers, function( fn ) {
			return elem === fn.elem;
		}).length;
	};
}

// Try to restore the default display value of an element
function defaultDisplay( nodeName ) {

	if ( !elemdisplay[ nodeName ] ) {

		var body = document.body,
			elem = jQuery( "<" + nodeName + ">" ).appendTo( body ),
			display = elem.css( "display" );
		elem.remove();

		// If the simple way fails,
		// get element's real default display by attaching it to a temp iframe
		if ( display === "none" || display === "" ) {
			// No iframe to use yet, so create it
			if ( !iframe ) {
				iframe = document.createElement( "iframe" );
				iframe.frameBorder = iframe.width = iframe.height = 0;
			}

			body.appendChild( iframe );

			// Create a cacheable copy of the iframe document on first call.
			// IE and Opera will allow us to reuse the iframeDoc without re-writing the fake HTML
			// document to it; WebKit & Firefox won't allow reusing the iframe document.
			if ( !iframeDoc || !iframe.createElement ) {
				iframeDoc = ( iframe.contentWindow || iframe.contentDocument ).document;
				iframeDoc.write( ( jQuery.support.boxModel ? "<!doctype html>" : "" ) + "<html><body>" );
				iframeDoc.close();
			}

			elem = iframeDoc.createElement( nodeName );

			iframeDoc.body.appendChild( elem );

			display = jQuery.css( elem, "display" );
			body.removeChild( iframe );
		}

		// Store the correct default display
		elemdisplay[ nodeName ] = display;
	}

	return elemdisplay[ nodeName ];
}




var getOffset,
	rtable = /^t(?:able|d|h)$/i,
	rroot = /^(?:body|html)$/i;

if ( "getBoundingClientRect" in document.documentElement ) {
	getOffset = function( elem, doc, docElem, box ) {
		try {
			box = elem.getBoundingClientRect();
		} catch(e) {}

		// Make sure we're not dealing with a disconnected DOM node
		if ( !box || !jQuery.contains( docElem, elem ) ) {
			return box ? { top: box.top, left: box.left } : { top: 0, left: 0 };
		}

		var body = doc.body,
			win = getWindow( doc ),
			clientTop  = docElem.clientTop  || body.clientTop  || 0,
			clientLeft = docElem.clientLeft || body.clientLeft || 0,
			scrollTop  = win.pageYOffset || jQuery.support.boxModel && docElem.scrollTop  || body.scrollTop,
			scrollLeft = win.pageXOffset || jQuery.support.boxModel && docElem.scrollLeft || body.scrollLeft,
			top  = box.top  + scrollTop  - clientTop,
			left = box.left + scrollLeft - clientLeft;

		return { top: top, left: left };
	};

} else {
	getOffset = function( elem, doc, docElem ) {
		var computedStyle,
			offsetParent = elem.offsetParent,
			prevOffsetParent = elem,
			body = doc.body,
			defaultView = doc.defaultView,
			prevComputedStyle = defaultView ? defaultView.getComputedStyle( elem, null ) : elem.currentStyle,
			top = elem.offsetTop,
			left = elem.offsetLeft;

		while ( (elem = elem.parentNode) && elem !== body && elem !== docElem ) {
			if ( jQuery.support.fixedPosition && prevComputedStyle.position === "fixed" ) {
				break;
			}

			computedStyle = defaultView ? defaultView.getComputedStyle(elem, null) : elem.currentStyle;
			top  -= elem.scrollTop;
			left -= elem.scrollLeft;

			if ( elem === offsetParent ) {
				top  += elem.offsetTop;
				left += elem.offsetLeft;

				if ( jQuery.support.doesNotAddBorder && !(jQuery.support.doesAddBorderForTableAndCells && rtable.test(elem.nodeName)) ) {
					top  += parseFloat( computedStyle.borderTopWidth  ) || 0;
					left += parseFloat( computedStyle.borderLeftWidth ) || 0;
				}

				prevOffsetParent = offsetParent;
				offsetParent = elem.offsetParent;
			}

			if ( jQuery.support.subtractsBorderForOverflowNotVisible && computedStyle.overflow !== "visible" ) {
				top  += parseFloat( computedStyle.borderTopWidth  ) || 0;
				left += parseFloat( computedStyle.borderLeftWidth ) || 0;
			}

			prevComputedStyle = computedStyle;
		}

		if ( prevComputedStyle.position === "relative" || prevComputedStyle.position === "static" ) {
			top  += body.offsetTop;
			left += body.offsetLeft;
		}

		if ( jQuery.support.fixedPosition && prevComputedStyle.position === "fixed" ) {
			top  += Math.max( docElem.scrollTop, body.scrollTop );
			left += Math.max( docElem.scrollLeft, body.scrollLeft );
		}

		return { top: top, left: left };
	};
}

jQuery.fn.offset = function( options ) {
	if ( arguments.length ) {
		return options === undefined ?
			this :
			this.each(function( i ) {
				jQuery.offset.setOffset( this, options, i );
			});
	}

	var elem = this[0],
		doc = elem && elem.ownerDocument;

	if ( !doc ) {
		return null;
	}

	if ( elem === doc.body ) {
		return jQuery.offset.bodyOffset( elem );
	}

	return getOffset( elem, doc, doc.documentElement );
};

jQuery.offset = {

	bodyOffset: function( body ) {
		var top = body.offsetTop,
			left = body.offsetLeft;

		if ( jQuery.support.doesNotIncludeMarginInBodyOffset ) {
			top  += parseFloat( jQuery.css(body, "marginTop") ) || 0;
			left += parseFloat( jQuery.css(body, "marginLeft") ) || 0;
		}

		return { top: top, left: left };
	},

	setOffset: function( elem, options, i ) {
		var position = jQuery.css( elem, "position" );

		// set position first, in-case top/left are set even on static elem
		if ( position === "static" ) {
			elem.style.position = "relative";
		}

		var curElem = jQuery( elem ),
			curOffset = curElem.offset(),
			curCSSTop = jQuery.css( elem, "top" ),
			curCSSLeft = jQuery.css( elem, "left" ),
			calculatePosition = ( position === "absolute" || position === "fixed" ) && jQuery.inArray("auto", [curCSSTop, curCSSLeft]) > -1,
			props = {}, curPosition = {}, curTop, curLeft;

		// need to be able to calculate position if either top or left is auto and position is either absolute or fixed
		if ( calculatePosition ) {
			curPosition = curElem.position();
			curTop = curPosition.top;
			curLeft = curPosition.left;
		} else {
			curTop = parseFloat( curCSSTop ) || 0;
			curLeft = parseFloat( curCSSLeft ) || 0;
		}

		if ( jQuery.isFunction( options ) ) {
			options = options.call( elem, i, curOffset );
		}

		if ( options.top != null ) {
			props.top = ( options.top - curOffset.top ) + curTop;
		}
		if ( options.left != null ) {
			props.left = ( options.left - curOffset.left ) + curLeft;
		}

		if ( "using" in options ) {
			options.using.call( elem, props );
		} else {
			curElem.css( props );
		}
	}
};


jQuery.fn.extend({

	position: function() {
		if ( !this[0] ) {
			return null;
		}

		var elem = this[0],

		// Get *real* offsetParent
		offsetParent = this.offsetParent(),

		// Get correct offsets
		offset       = this.offset(),
		parentOffset = rroot.test(offsetParent[0].nodeName) ? { top: 0, left: 0 } : offsetParent.offset();

		// Subtract element margins
		// note: when an element has margin: auto the offsetLeft and marginLeft
		// are the same in Safari causing offset.left to incorrectly be 0
		offset.top  -= parseFloat( jQuery.css(elem, "marginTop") ) || 0;
		offset.left -= parseFloat( jQuery.css(elem, "marginLeft") ) || 0;

		// Add offsetParent borders
		parentOffset.top  += parseFloat( jQuery.css(offsetParent[0], "borderTopWidth") ) || 0;
		parentOffset.left += parseFloat( jQuery.css(offsetParent[0], "borderLeftWidth") ) || 0;

		// Subtract the two offsets
		return {
			top:  offset.top  - parentOffset.top,
			left: offset.left - parentOffset.left
		};
	},

	offsetParent: function() {
		return this.map(function() {
			var offsetParent = this.offsetParent || document.body;
			while ( offsetParent && (!rroot.test(offsetParent.nodeName) && jQuery.css(offsetParent, "position") === "static") ) {
				offsetParent = offsetParent.offsetParent;
			}
			return offsetParent;
		});
	}
});


// Create scrollLeft and scrollTop methods
jQuery.each( {scrollLeft: "pageXOffset", scrollTop: "pageYOffset"}, function( method, prop ) {
	var top = /Y/.test( prop );

	jQuery.fn[ method ] = function( val ) {
		return jQuery.access( this, function( elem, method, val ) {
			var win = getWindow( elem );

			if ( val === undefined ) {
				return win ? (prop in win) ? win[ prop ] :
					jQuery.support.boxModel && win.document.documentElement[ method ] ||
						win.document.body[ method ] :
					elem[ method ];
			}

			if ( win ) {
				win.scrollTo(
					!top ? val : jQuery( win ).scrollLeft(),
					 top ? val : jQuery( win ).scrollTop()
				);

			} else {
				elem[ method ] = val;
			}
		}, method, val, arguments.length, null );
	};
});

function getWindow( elem ) {
	return jQuery.isWindow( elem ) ?
		elem :
		elem.nodeType === 9 ?
			elem.defaultView || elem.parentWindow :
			false;
}




// Create width, height, innerHeight, innerWidth, outerHeight and outerWidth methods
jQuery.each( { Height: "height", Width: "width" }, function( name, type ) {
	var clientProp = "client" + name,
		scrollProp = "scroll" + name,
		offsetProp = "offset" + name;

	// innerHeight and innerWidth
	jQuery.fn[ "inner" + name ] = function() {
		var elem = this[0];
		return elem ?
			elem.style ?
			parseFloat( jQuery.css( elem, type, "padding" ) ) :
			this[ type ]() :
			null;
	};

	// outerHeight and outerWidth
	jQuery.fn[ "outer" + name ] = function( margin ) {
		var elem = this[0];
		return elem ?
			elem.style ?
			parseFloat( jQuery.css( elem, type, margin ? "margin" : "border" ) ) :
			this[ type ]() :
			null;
	};

	jQuery.fn[ type ] = function( value ) {
		return jQuery.access( this, function( elem, type, value ) {
			var doc, docElemProp, orig, ret;

			if ( jQuery.isWindow( elem ) ) {
				// 3rd condition allows Nokia support, as it supports the docElem prop but not CSS1Compat
				doc = elem.document;
				docElemProp = doc.documentElement[ clientProp ];
				return jQuery.support.boxModel && docElemProp ||
					doc.body && doc.body[ clientProp ] || docElemProp;
			}

			// Get document width or height
			if ( elem.nodeType === 9 ) {
				// Either scroll[Width/Height] or offset[Width/Height], whichever is greater
				doc = elem.documentElement;

				// when a window > document, IE6 reports a offset[Width/Height] > client[Width/Height]
				// so we can't use max, as it'll choose the incorrect offset[Width/Height]
				// instead we use the correct client[Width/Height]
				// support:IE6
				if ( doc[ clientProp ] >= doc[ scrollProp ] ) {
					return doc[ clientProp ];
				}

				return Math.max(
					elem.body[ scrollProp ], doc[ scrollProp ],
					elem.body[ offsetProp ], doc[ offsetProp ]
				);
			}

			// Get width or height on the element
			if ( value === undefined ) {
				orig = jQuery.css( elem, type );
				ret = parseFloat( orig );
				return jQuery.isNumeric( ret ) ? ret : orig;
			}

			// Set the width or height on the element
			jQuery( elem ).css( type, value );
		}, type, value, arguments.length, null );
	};
});




// Expose jQuery to the global object
window.jQuery = window.$ = jQuery;

// Expose jQuery as an AMD module, but only for AMD loaders that
// understand the issues with loading multiple versions of jQuery
// in a page that all might call define(). The loader will indicate
// they have special allowances for multiple jQuery versions by
// specifying define.amd.jQuery = true. Register as a named module,
// since jQuery can be concatenated with other files that may use define,
// but not use a proper concatenation script that understands anonymous
// AMD modules. A named AMD is safest and most robust way to register.
// Lowercase jquery is used because AMD module names are derived from
// file names, and jQuery is normally delivered in a lowercase file name.
// Do this after creating the global so that if an AMD module wants to call
// noConflict to hide this version of jQuery, it will work.
if ( typeof define === "function" && define.amd && define.amd.jQuery ) {
	define( "jquery", [], function () { return jQuery; } );
}

/*!
 * @author			Emanuel Vitzthum
 * @copyright		© 2011 jQuery SDK v1.3.1
 * @info			http://www.jquerysdk.com
 *
 * @license			Dual licensed under the MIT (http://www.opensource.org/licenses/mit-license.php) and GPL (http://www.gnu.org/licenses/gpl.html)
 */
/* @desc			jQuery SDK includes
 *					- .jquerysdk				Version
 *					- .sub						Chaining subclass switch
 *					- jQuery.config				Configuration vars
 *					- jQuery.debug				Base property for debug tools
 *					- jQuery.debug.warn			Developer warnings
 *					- jQuery.scope				Contextual scope
 *					- jQuery.dependRegister		Dependencies controller
 *					- jQuery.plugin				Dependencies controller
 *					- jQuery.provide			Dependencies controller
 *					- jQuery.ready				Dependencies controller
 *					- jQuery.ready				DOM ready
 */

(function(){

		// save original method
	var ready = jQuery.ready,

		// config from script
		scriptConfig = window.jQueryConfig && !window.jQueryConfig.nodeName ? window.jQueryConfig : undefined,

		// config from meta tag
		metaConfig = jQuery('meta[name=jQueryConfig]').attr('content'),

		// jQuery.config
		config = jQuery.extend( !0, {}, scriptConfig, (metaConfig ? eval('('+metaConfig+')') : undefined) ),

		// type of dependencies ready data
		typeExp = /^(string|object|array)$/,

		// type of plugin dependencies
		pluginExp = /(string|array)/,

		// count for ready calls
		readyCount = 0,

		// name of the property set to deferred object whether dependHandle is called
		isDependHandled = '--depend--controlled--',

		// settings of dependencies controller
		dependSettings,

		// type groups of the deferred objects
		dependStack,

		// type groups of the results promise objects
		whenStack = {},

		// stack of deferred objects waiting for type handle
		waitForHandleStack = {},

		// handles of the dependencies controller
		dependHandle,

		// add dependencies to control
		dependControl = function( depends, callback, type, name, addToExisting ){
				// return promise object
			var	promise = whenStack[ type ] ? whenStack[ type ][ name ] : (whenStack[ type ] = {})[ name ];

			if( promise )
				return addToExisting ? promise.done(callback) : promise;

				// dependencies ready deferred
			var	whenDeferred = jQuery.Deferred(),

				// self ready deferred
				selfDeferred = dependStack[ type ][ name ] || (dependStack[ type ][ name ] = dependSetHandled(jQuery.Deferred())),

				// stack of deferred object, first object is jQuery to receive it as argument in .done() callbacks
				deferredStack = [jQuery],

				// object type of dependencies
				dependsType = jQuery.type(depends);

			if( dependsType==='function' ){
				// if no dependencies
				callback = depends;
				depends = {};
			}
			else if( pluginExp.test(dependsType) ){
				// if only plugins dependent
				depends = { plugin: depends };
			}

			// add dependencies to deferredStack
			jQuery.each( depends, function( dependType, dependTypeDepends ){
				if( dependType == 'provide' )
					dependType = 'script';

				var dependTypeStack = dependStack[ dependType ] || (dependStack[ dependType ] = {});

				jQuery.each( jQuery.isArray(dependTypeDepends) ? dependTypeDepends : [dependTypeDepends], function( i, depend ){
					deferredStack.push(
						dependHandleCall(
							dependType,
							depend,
							(dependTypeStack[ depend ] = dependTypeStack[ depend ] || jQuery.Deferred()),
							whenDeferred
						)
					);
				});
			});

			// return promise object
			return (whenStack[ type ][ name ] = jQuery.when.apply( jQuery, deferredStack ))
				.done(function(){
					whenDeferred.resolve();
					if( callback )
						callback(jQuery);
					selfDeferred.resolve();
				});
		},

		dependSetHandled = function( deferred ){
			deferred[ isDependHandled ] = !0;
			return deferred;
		},

		// call the registered dependHandle
		dependHandleCall = function( dependType, depend, deferred, when ){
			var dependTypeHandle = dependHandle[ dependType ];

			if( !deferred[ isDependHandled ] && !deferred.isResolved() && dependTypeHandle ){
				dependTypeHandle( depend, dependSetHandled(deferred), when );
			}
			else if( !dependTypeHandle ){
				(waitForHandleStack[ dependType ] || (waitForHandleStack[ dependType ] = [])).push([depend, deferred, when]);
			}

			return deferred;
		},

		// deferred object which is already resolved
		ResolvedDeferred = dependSetHandled(jQuery.Deferred()).resolve(jQuery),

		// deferred object for Document Object Model ready state
		DOMReadyDeferred = dependSetHandled(jQuery.Deferred()),

		// when object for Document Object Model ready state
		DOMReadyWhen = DOMReadyDeferred.promise();

	// bind deferred on DOM ready event
	jQuery.fn.ready(function(){
		DOMReadyDeferred.resolve(jQuery);
	});

	// set jQueryConfig map to undefined (delete doesn't fully work in IE < 9)
	if( scriptConfig )
		jQueryConfig = undefined;

	// run config for ajax
	jQuery.extend( jQuery.ajaxSettings, config.ajax );

	// run config for noConflict mode
	if( config.noConflict ){
		var alias = jQuery.noConflict();
		if( typeof config.noConflict === 'string' )
			window[ config.noConflict ] = alias;
	}

	jQuery.fn.extend({
		// .jquerysdk --> Version
		jquerysdk: '1.3.1',
		// .sub() --> provide subclass switch as prototype method
		sub: function( jQuerySubclass ){
			return (typeof jQuerySubclass === 'string' ? window[ jQuerySubclass ] : jQuerySubclass)( this );
		}
	});

	jQuery.extend({
		// jQuery.config
		config: config,

		// jQuery.debug
		debug: {
		// jQuery.debug.warn()
			warn: window.console && jQuery.isFunction(console.warn) ? function(){ console.warn.apply( console, arguments ) } : jQuery.noop
		},
		
		// create contextual scope 
		scope: function( scope, context ) {
			context = context || window;

			var parts = scope ? scope.split(/\./) : [];

			for( var i=0,l=parts.length ; i<l ; i++ ){
				context = context[parts[i]] || (context[parts[i]] = {});
			}

			return context;
		},

		// jQuery.dependSettings
		dependSettings: (dependSettings = jQuery.extend(
			{
				minify:			!1,
				jsonp:			!1,
				pluginRoot:		'script'
			},
			config.depend
		)),

		// jQuery.dependStack
		dependStack: (dependStack = {
			ready:	{},
			script:	{},
			plugin:	{
				'jQuery.core':	ResolvedDeferred
			},
			DOM:	{
				'true':			DOMReadyDeferred,
				'false':		ResolvedDeferred
			},
			// raw depends for debug
			_plugin: {},
			_script: {},
			_ready:	{}
		}),

		// jQuery.dependHandle
		dependHandle: (dependHandle = {
		/* don't depend anything on ready
			ready: function( depend, deferred ){

			},
		*/

		/* script will not load from anywhere, so the dependController handle it on provide a script
			script: function( depend, deferred ){

			},
		*/

		/* deferred objects are already defined
			DOM: function( depend, deferred ){

			},
		*/

			plugin: function( depend, deferred /*, when*/ ){
				var ajax = {
						url:		dependSettings.pluginRoot+'/'+depend.replace(/\./g,'/')+(dependSettings.minify?'.min':'')+'.js',
						dataType:	'script',
						type:		'get',
						asnyc:		!0,
						cache:		!0
					};

				jQuery
					.ajax(
						dependSettings.jsonp ?
						jQuery.extend(ajax,{
							dataType:		'jsonp',
							jsonp:			jQuery.type(dependSettings.jsonp)==='string' ? dependSettings.jsonp : undefined,
							jsonpCallback:	'jsonp.depend.plugin('+depend+')'
						}) :
						ajax
					);
			}
		}),

		// jQuery.dependRegister() --> register an handle for dependencies controller
		dependRegister: function( dependType, handle ){
			dependHandle[ dependType ] = handle;
			jQuery.each( waitForHandleStack[ dependType ] || [], function( i, wait ){
				dependHandleCall( dependType, wait[0], wait[1], wait[2] );
			});
		},

		// jQuery.ready() --> call a function on dependencies ready
		ready: function( depends, callback ){
			var type = jQuery.type(depends),
				name;

			if( typeExp.test(type) ){
				name = (pluginExp.test(type) ?
					depends.join ?
						(depends.sort().join(' ')) :
						depends.toString() :
					 ++readyCount);

				// save depends for debug
				dependStack._ready[ name ] = depends;

				return dependControl( depends, callback, 'ready', name, true );
			}
			else{
				return type === 'function' ?
					DOMReadyWhen.done(depends) :
					ready(depends);
			}
		},

		// jQuery.provide()
		provide: function( name, depends, callback ){
			// save depends for debug
			dependStack._script[ name ] = depends;

			return dependControl( depends, callback, 'script', name );
		},

		// jQuery.plugin()
		plugin: function( name, depends, callback ){
			// save depends for debug
			dependStack._plugin[ name ] = depends;

			return dependControl( depends, callback, 'plugin', name );
		}
	});

})();

})( window );

/* ---- Module:jQuery.support.placeholder ---- */

/*
 * @author			Emanuel Vitzthum
 * @copyright		© 2011 jQuery SDK v1.3.1
 * @info			http://www.jquerysdk.com
 *
 * @license			Dual licensed under the MIT (http://www.opensource.org/licenses/mit-license.php) and GPL (http://www.gnu.org/licenses/gpl.html)
 *
 * @plugin			jQuery.support.placerholder
 */

jQuery.plugin( 'jQuery.support.placeholder', function( $, undefined ){

	var file = document.createElement('input');

	$.support.placeholder =	Object.prototype.hasOwnProperty.call( file, 'placeholder' );

});

/* ---- Module:jQuery.fn.class ---- */

/*
 * @author			Emanuel Vitzthum
 * @copyright		© 2011 jQuery SDK v1.3.1
 * @info			http://www.jquerysdk.com
 *
 * @license			Dual licensed under the MIT (http://www.opensource.org/licenses/mit-license.php) and GPL (http://www.gnu.org/licenses/gpl.html)
 *
 * @plugin			jQuery.fn.class
 */

jQuery.plugin( 'jQuery.fn.class', function( $, undefined ){

	var _hasClass = $.fn.hasClass,
		_removeClass = $.fn.removeClass;

	$.fn.extend({
		hasClass: function( classes ) {
			if( $.type(classes) === 'regexp' ){
				return classes.test( $(this[0]).attr('class') || '' );
			}
			else{
				return _hasClass.call( this, classes );
			}
		},
		removeClass: function( classes ) {
			if( $.type(classes) === 'regexp' ){
				this.each(function(){
					var elem = $(this);

					$.each( (elem.attr('class')||'').split(/\s+/g), function( i, name ){
						if( classes.test(name) )
							_removeClass.call( elem, name );
					});

				});
			}
			else{
				_removeClass.call( this, classes );
			}

			return this;
		}
	});

});

/* ---- Module:jQuery.tmpl ---- */

/*
 * @author			Emanuel Vitzthum
 * @copyright		© 2011 jQuery SDK v1.3.1
 * @info			http://www.jquerysdk.com
 *
 * @license			Dual licensed under the MIT (http://www.opensource.org/licenses/mit-license.php) and GPL (http://www.gnu.org/licenses/gpl.html)
 *
 * @based			$ Templating Plugin by John Resig (https://github.com/jquery/jquery-tmpl) license (Dual licensed under the MIT or GPL Version 2 licenses.)
 *
 * @plugin			jQuery.string
 */

jQuery.plugin( 'jQuery.tmpl', function( $, undefined ){

	var oldManip = $.fn.domManip,
		tmplItmAtt = "_tmplitem",
		htmlExpr = /^[^<]*(<[\w\W]+>)[^>]*$|\{\{\! /,
		newTmplItems = {},
		wrappedItems = {},
		appendToTmplItems,
		topTmplItem = { key: 0, data: {} },
		itemKey = 0,
		cloneIndex = 0,
		stack = [],
		unshift = Array.prototype.unshift;

	function newTmplItem( options, parentItem, fn, data ) {
		// Returns a template item data structure for a new rendered instance of a template (a 'template item').
		// The content field is a hierarchical array of strings and nested items (to be
		// removed and replaced by nodes field of dom elements, once inserted in DOM).
		var newItem = {
			data: data || (parentItem ? parentItem.data : {}),
			_wrap: parentItem ? parentItem._wrap : null,
			tmpl: null,
			parent: parentItem || null,
			nodes: [],
			calls: tiCalls,
			nest: tiNest,
			wrap: tiWrap,
			html: tiHtml,
			update: tiUpdate
		};
		if ( options ) {
			$.extend( newItem, options, { nodes: [], parent: parentItem } );
		}
		if ( fn ) {
			// Build the hierarchical content to be used during insertion into DOM
			newItem.tmpl = fn;
			newItem._ctnt = newItem._ctnt || newItem.tmpl( $, newItem );
			newItem.key = ++itemKey;
			// Keep track of new template item, until it is stored as $ Data on DOM element
			(stack.length ? wrappedItems : newTmplItems)[itemKey] = newItem;
		}
		return newItem;
	}

	// Override appendTo etc., in order to provide support for targeting multiple elements. (This code would disappear if integrated in jquery core).
	$.each({
		appendTo: "append",
		prependTo: "prepend",
		insertBefore: "before",
		insertAfter: "after",
		replaceAll: "replaceWith"
	}, function( name, original ) {
		$.fn[ name ] = function( selector ) {
			var ret = [], insert = $( selector ), elems, i, l, tmplItems,
				parent = this.length === 1 && this[0].parentNode;

			appendToTmplItems = newTmplItems || {};
			if ( parent && parent.nodeType === 11 && parent.childNodes.length === 1 && insert.length === 1 ) {
				insert[ original ]( this[0] );
				ret = this;
			} else {
				for ( i = 0, l = insert.length; i < l; i++ ) {
					cloneIndex = i;
					elems = (i > 0 ? this.clone(true) : this).get();
					$.fn[ original ].apply( $(insert[i]), elems );
					ret = ret.concat( elems );
				}
				cloneIndex = 0;
				ret = this.pushStack( ret, name, insert.selector );
			}
			tmplItems = appendToTmplItems;
			appendToTmplItems = null;
			$.tmpl.complete( tmplItems );
			return ret;
		};
	});

	$.fn.extend({
		// Use first wrapped element as template markup.
		// Return wrapped set of template items, obtained by rendering template against data.
		tmpl: function( data, options, parentItem ) {
			return $.tmpl( this[0], data, options, parentItem );
		},

		// Find which rendered template item the first wrapped DOM element belongs to
		tmplItem: function( key ) {
			return $.tmplItem( this[0], key );
		},

		// Consider the first wrapped element as a template declaration, and get the compiled template or store it as a named template.
		template: function( name ) {
			return $.template( name, this[0] );
		},

		domManip: function( args, table, callback, options ) {
			// This appears to be a bug in the appendTo, etc. implementation
			// it should be doing .call() instead of .apply(). See #6227
			if ( args[0] && args[0].nodeType ) {
				var dmArgs = $.makeArray( arguments ), argsLength = args.length, i = 0, tmplItem;
				while ( i < argsLength && !(tmplItem = $.data( args[i++], "tmplItem" ))) {}
				if ( argsLength > 1 ) {
					dmArgs[0] = [$.makeArray( args )];
				}
				if ( tmplItem && cloneIndex ) {
					dmArgs[2] = function( fragClone ) {
						// Handler called by oldManip when rendered template has been inserted into DOM.
						$.tmpl.afterManip( this, fragClone, callback );
					};
				}
				oldManip.apply( this, dmArgs );
			} else {
				oldManip.apply( this, arguments );
			}
			cloneIndex = 0;
			if ( !appendToTmplItems ) {
				$.tmpl.complete( newTmplItems );
			}
			return this;
		}
	});

	$.extend({
		// Return wrapped set of template items, obtained by rendering template against data.
		tmpl: function( tmpl, data, options, parentItem ) {
			var ret, topLevel = !parentItem;
			if ( topLevel ) {
				// This is a top-level tmpl call (not from a nested template using {{tmpl}})
				parentItem = topTmplItem;
				tmpl = $.template[tmpl] || $.template( null, tmpl );
				wrappedItems = {}; // Any wrapped items will be rebuilt, since this is top level
			} else if ( !tmpl ) {
				// The template item is already associated with DOM - this is a refresh.
				// Re-evaluate rendered template for the parentItem
				tmpl = parentItem.tmpl;
				newTmplItems[parentItem.key] = parentItem;
				parentItem.nodes = [];
				if ( parentItem.wrapped ) {
					updateWrapped( parentItem, parentItem.wrapped );
				}
				// Rebuild, without creating a new template item
				return $( build( parentItem, null, parentItem.tmpl( $, parentItem ) ));
			}
			if ( !tmpl ) {
				return []; // Could throw...
			}
			if ( typeof data === "function" ) {
				data = data.call( parentItem || {} );
			}
			if ( options && options.wrapped ) {
				updateWrapped( options, options.wrapped );
			}
			ret = $.isArray( data ) ?
				$.map( data, function( dataItem ) {
					return dataItem ? newTmplItem( options, parentItem, tmpl, dataItem ) : null;
				}) :
				[ newTmplItem( options, parentItem, tmpl, data ) ];
			return topLevel ? $( build( parentItem, null, ret ) ) : ret;
		},

		// Return rendered template item for an element.
		tmplItem: function( elem, key ) {
			var tmplItem;
			if ( elem instanceof $ ) {
				elem = elem[0];
			}
			while ( elem && elem.nodeType === 1 && !(tmplItem = $.data( elem, "tmplItem" )) && (elem = elem.parentNode) ) {}
			return key ? (tmplItem || topTmplItem)[ key ] : tmplItem || topTmplItem;
		},

		// Set:
		// Use $.template( name, tmpl ) to cache a named template,
		// where tmpl is a template string, a script element or a $ instance wrapping a script element, etc.
		// Use $( "selector" ).template( name ) to provide access by name to a script block template declaration.

		// Get:
		// Use $.template( name ) to access a cached template.
		// Also $( selectorToScriptBlock ).template(), or $.template( null, templateString )
		// will return the compiled template, without adding a name reference.
		// If templateString includes at least one HTML tag, $.template( templateString ) is equivalent
		// to $.template( null, templateString )
		template: function( name, tmpl ) {
			if (tmpl) {
				// Compile template and associate with name
				if ( typeof tmpl === "string" ) {
					// This is an HTML string being passed directly in.
					tmpl = buildTmplFn( tmpl )
				} else if ( tmpl instanceof $ ) {
					tmpl = tmpl[0] || {};
				}
				if ( tmpl.nodeType ) {
					// If this is a template block, use cached copy, or generate tmpl function and cache.
					tmpl = $.data( tmpl, "tmpl" ) || $.data( tmpl, "tmpl", buildTmplFn( tmpl.innerHTML ));
				}
				return typeof name === "string" ? ($.template[name] = tmpl) : tmpl;
			}
			// Return named compiled template
			return name ? (typeof name !== "string" ? $.template( null, name ):
				($.template[name] ||
					// If not in map, treat as a selector. (If integrated with core, use quickExpr.exec)
					$.template( null, htmlExpr.test( name ) ? name : $( name )))) : null;
		},

		encode: function( text ) {
			// Do HTML encoding replacing < > & and ' and " by corresponding entities.
			return ("" + text).split("<").join("&lt;").split(">").join("&gt;").split('"').join("&#34;").split("'").join("&#39;");
		}
	});

	$.extend( $.tmpl, {
		tag: {
			"tmpl": {
				_default: { $2: "null" },
				open: "if($notnull_1){_=_.concat($item.nest($1,$2));}"
				// tmpl target parameter can be of type function, so use $1, not $1a (so not auto detection of functions)
				// This means that {{tmpl foo}} treats foo as a template (which IS a function).
				// Explicit parens can be used if foo is a function that returns a template: {{tmpl foo()}}.
			},
			"wrap": {
				_default: { $2: "null" },
				open: "$item.calls(_,$1,$2);_=[];",
				close: "call=$item.calls();_=call._.concat($item.wrap(call,_));"
			},
			"each": {
				_default: { $2: "$index, $value" },
				open: "if($notnull_1){$.each($1a,function($2){with(this){",
				close: "}});}"
			},
			"if": {
				open: "if(($notnull_1) && $1a){",
				close: "}"
			},
			"else": {
				_default: { $1: "true" },
				open: "}else if(($notnull_1) && $1a){"
			},
			"html": {
				// Unecoded expression evaluation.
				open: "if($notnull_1){_.push($1a);}"
			},
			"=": {
				// Encoded expression evaluation. Abbreviated form is ${}.
				_default: { $1: "$data" },
				open: "if($notnull_1){_.push($.encode($1a));}"
			},
			"!": {
				// Comment tag. Skipped by parser
				open: ""
			},
			"elem": {
				_default: { $2: "jQuery" },
				open: "if($notnull_1){_.push(' _tmplclass=\"$2\" _tmplelement=\"'+$.encode($1a)+'\"');}"
			}
		},

		// This stub can be overridden, e.g. in jquery.tmplPlus for providing rendered events
		complete: function( items ) {
			newTmplItems = {};
		},

		// Call this from code which overrides domManip, or equivalent
		// Manage cloning/storing template items etc.
		afterManip: function afterManip( elem, fragClone, callback ) {
			// Provides cloned fragment ready for fixup prior to and after insertion into DOM
			var content = fragClone.nodeType === 11 ?
				$.makeArray(fragClone.childNodes) :
				fragClone.nodeType === 1 ? [fragClone] : [];

			// Return fragment to original caller (e.g. append) for DOM insertion
			callback.call( elem, fragClone );

			// Fragment has been inserted:- Add inserted nodes to tmplItem data structure. Replace inserted element annotations by $.data.
			storeTmplItems( content );
			cloneIndex++;
		}
	});

	//========================== Private helper functions, used by code above ==========================

	function build( tmplItem, nested, content ) {
		// Convert hierarchical content into flat string array
		// and finally return array of fragments ready for DOM insertion
		var frag, ret = content ? $.map( content, function( item ) {
			return (typeof item === "string") ?
				// Insert template item annotations, to be converted to $.data( "tmplItem" ) when elems are inserted into DOM.
				(tmplItem.key ? item.replace( /(<\w+)(?=[\s>])(?![^>]*_tmplitem)([^>]*)/g, "$1 " + tmplItmAtt + "=\"" + tmplItem.key + "\" $2" ) : item) :
				// This is a child template item. Build nested template.
				build( item, tmplItem, item._ctnt );
		}) :
		// If content is not defined, insert tmplItem directly. Not a template item. May be a string, or a string array, e.g. from {{html $item.html()}}.
		tmplItem;
		if ( nested ) {
			return ret;
		}

		// top-level template
		ret = ret.join("");

		// Support templates which have initial or final text nodes, or consist only of text
		// Also support HTML entities within the HTML markup.
		ret.replace( /^\s*([^<\s][^<]*)?(<[\w\W]+>)([^>]*[^>\s])?\s*$/, function( all, before, middle, after) {
			frag = $( middle ).get();

			storeTmplItems( frag );
			if ( before ) {
				frag = unencode( before ).concat(frag);
			}
			if ( after ) {
				frag = frag.concat(unencode( after ));
			}
		});

		return frag ? frag : unencode( ret );
	}

	function unencode( text ) {
		// Use createElement, since createTextNode will not render HTML entities correctly
		var el = document.createElement( "div" );
		el.innerHTML = text;
		return $.makeArray(el.childNodes);
	}

	// Generate a reusable function that will serve to render a template against data
	function buildTmplFn( markup ) {
		return new Function("$","$item",
			"var $=$,call,_=[],$data=$item.data;" +

			// Introduce the data as local variables using with(){}
			"with($data){_.push('" +

			// Convert the template into pure JavaScript
			$.trim(markup)
				.replace( /([\\'])/g, "\\$1" )
				.replace( /[\r\t\n]/g, " " )
				.replace( /\$\{([^\}]*)\}/g, "{{= $1}}" )
				.replace( /\{\{(\/?)(\w+|.)(?:\(((?:[^\}]|\}(?!\}))*?)?\))?(?:\s+(.*?)?)?(\(((?:[^\}]|\}(?!\}))*?)\))?\s*\}\}/g,
				function( all, slash, type, fnargs, target, parens, args ) {
					var tag = $.tmpl.tag[ type ], def, expr, exprAutoFnDetect;
					if ( !tag ) {
						throw "Template command not found: " + type;
					}
					def = tag._default || [];
					if ( parens && !/\w$/.test(target)) {
						target += parens;
						parens = "";
					}
					if ( target ) {
						target = unescape( target );
						args = args ? ("," + unescape( args ) + ")") : (parens ? ")" : "");
						// Support for target being things like a.toLowerCase();
						// In that case don't call with template item as 'this' pointer. Just evaluate...
						expr = parens ? (target.indexOf(".") > -1 ? target + parens : ("(" + target + ").call($item" + args)) : target;
						exprAutoFnDetect = parens ? expr : "(typeof(" + target + ")==='function'?(" + target + ").call($item):(" + target + "))";
					} else {
						exprAutoFnDetect = expr = def.$1 || "null";
					}
					fnargs = unescape( fnargs );
					return "');" +
						tag[ slash ? "close" : "open" ]
							.split( "$notnull_1" ).join( target ? "typeof(" + target + ")!=='undefined' && (" + target + ")!=null" : "true" )
							.split( "$1a" ).join( exprAutoFnDetect )
							.split( "$1" ).join( expr )
							.split( "$2" ).join( fnargs ?
								fnargs.replace( /\s*([^\(]+)\s*(\((.*?)\))?/g, function( all, name, parens, params ) {
									params = params ? ("," + params + ")") : (parens ? ")" : "");
									return params ? ("(" + name + ").call($item" + params) : all;
								})
								: (def.$2||"")
							) +
						"_.push('";
				}) +
			"');}return _;"
		);
	}
	function updateWrapped( options, wrapped ) {
		// Build the wrapped content.
		options._wrap = build( options, true,
			// Suport imperative scenario in which options.wrapped can be set to a selector or an HTML string.
			$.isArray( wrapped ) ? wrapped : [htmlExpr.test( wrapped ) ? wrapped : $( wrapped ).html()]
		).join("");
	}

	function unescape( args ) {
		return args ? args.replace( /\\'/g, "'").replace(/\\\\/g, "\\" ) : null;
	}
	function outerHtml( elem ) {
		var div = document.createElement("div");
		div.appendChild( elem.cloneNode(true) );
		return div.innerHTML;
	}

	// Store template items in $.data(), ensuring a unique tmplItem data data structure for each rendered template instance.
	function storeTmplItems( content ) {
		var keySuffix = "_" + cloneIndex, elem, elems, newClonedItems = {}, i, l, m, tmplElements;
		for ( i = 0, l = content.length; i < l; i++ ) {
			if ( (elem = content[i]).nodeType !== 1 ) {
				continue;
			}
			elems = elem.getElementsByTagName("*");
			tmplElements = {};
			for ( m = elems.length - 1; m >= 0; m-- ) {
				processItemKey( elems[m] );
			}
			processItemKey( elem );
		}
		function processItemKey( el ) {

			var pntKey, pntNode = el, pntItem, tmplItem, key;
			// Ensure that each rendered template inserted into the DOM has its own template item,
			if ( (key = el.getAttribute( tmplItmAtt ))) {
				while ( pntNode.parentNode && (pntNode = pntNode.parentNode).nodeType === 1 && !(pntKey = pntNode.getAttribute( tmplItmAtt ))) { }
				if ( pntKey !== key ) {
					// The next ancestor with a _tmplitem expando is on a different key than this one.
					// So this is a top-level element within this template item
					// Set pntNode to the key of the parentNode, or to 0 if pntNode.parentNode is null, or pntNode is a fragment.
					pntNode = pntNode.parentNode ? (pntNode.nodeType === 11 ? 0 : (pntNode.getAttribute( tmplItmAtt ) || 0)) : 0;
					if ( !(tmplItem = newTmplItems[key]) ) {
						// The item is for wrapped content, and was copied from the temporary parent wrappedItem.
						tmplItem = wrappedItems[key];
						tmplItem = newTmplItem( tmplItem, newTmplItems[pntNode]||wrappedItems[pntNode], null, true );
						tmplItem.key = ++itemKey;
						newTmplItems[itemKey] = tmplItem;
					}
					if ( cloneIndex ) {
						cloneTmplItem( key );
					}
				}
				// push elements by identifier to elements stack of template item
				if( (key = el.getAttribute('_tmplelement')) ){
					if( tmplElements[ key ] )
						unshift.call( tmplElements[ key ], el );
					else
						tmplElements[ key ] = (window[ el.getAttribute('_tmplclass') ] || $)(el);
					el.removeAttribute('_tmplelement');
					el.removeAttribute('_tmplclass');
				}
				el.removeAttribute( tmplItmAtt );
			} else if ( cloneIndex && (tmplItem = $.data( el, "tmplItem" )) ) {
				// This was a rendered element, cloned during append or appendTo etc.
				// TmplItem stored in $ data has already been cloned in cloneCopyEvent. We must replace it with a fresh cloned tmplItem.
				cloneTmplItem( tmplItem.key );
				newTmplItems[tmplItem.key] = tmplItem;
				pntNode = $.data( el.parentNode, "tmplItem" );
				pntNode = pntNode ? pntNode.key : 0;
			}
			if ( tmplItem ) {
				pntItem = tmplItem;
				// add elements to template item data
				tmplItem.elements = tmplElements;
				// Find the template item of the parent element.
				// (Using !=, not !==, since pntItem.key is number, and pntNode may be a string)
				while ( pntItem && pntItem.key != pntNode ) {
					// Add this element as a top-level node for this rendered template item, as well as for any
					// ancestor items between this item and the item of its parent element
					pntItem.nodes.push( el );
					pntItem = pntItem.parent;
				}
				// Delete content built during rendering - reduce API surface area and memory use, and avoid exposing of stale data after rendering...
				delete tmplItem._ctnt;
				delete tmplItem._wrap;
				// Store template item as $ data on the element
				$.data( el, "tmplItem", tmplItem );
			}
			function cloneTmplItem( key ) {
				key = key + keySuffix;
				tmplItem = newClonedItems[key] =
					(newClonedItems[key] || newTmplItem( tmplItem, newTmplItems[tmplItem.parent.key + keySuffix] || tmplItem.parent, null, true ));
			}
		}
	}

	//---- Helper functions for template item ----

	function tiCalls( content, tmpl, data, options ) {
		if ( !content ) {
			return stack.pop();
		}
		stack.push({ _: content, tmpl: tmpl, item:this, data: data, options: options });
	}

	function tiNest( tmpl, data, options ) {
		// nested template, using {{tmpl}} tag
		return $.tmpl( $.template( tmpl ), data, options, this );
	}

	function tiWrap( call, wrapped ) {
		// nested template, using {{wrap}} tag
		var options = call.options || {};
		options.wrapped = wrapped;
		// Apply the template, which may incorporate wrapped content,
		return $.tmpl( $.template( call.tmpl ), call.data, options, call.item );
	}

	function tiHtml( filter, textOnly ) {
		var wrapped = this._wrap;
		return $.map(
			$( $.isArray( wrapped ) ? wrapped.join("") : wrapped ).filter( filter || "*" ),
			function(e) {
				return textOnly ?
					e.innerText || e.textContent :
					e.outerHTML || outerHtml(e);
			});
	}

	function tiUpdate() {
		var coll = this.nodes;
		$.tmpl( null, null, null, this).insertBefore( coll[0] );
		$( coll ).remove();
	}



	// extend the dependencies controller
	var dependSettings = $.dependSettings;

	if( !dependSettings.tmplRoot )
		dependSettings.tmplRoot = dependSettings.pluginRoot;

	$.dependRegister( 'tmpl', function( depend, deferred ){
		if( $.template[ depend ] ){
			deferred.resolve();
		}
		else{
			var ajax = {
					url:		dependSettings.tmplRoot+'/'+depend.replace(/\./g,'/')+'.tmpl'+(dependSettings.minify?'.min':'')+'.html',
					dataType:	'text',
					type:		'get',
					asnyc:		true,
					cache:		true
				};

			$.ajax(
				dependSettings.jsonp ?
				$.extend(ajax,{
					dataType:		'jsonp',
					jsonp:			dependSettings.jsonp!==true ? dependSettings.jsonp : undefined,
					jsonpCallback:	'jsonp.dependHandle.tmpl('+depend+')'
				}) :
				ajax
			)
			.done(function( data ){
				$.template( depend, data );
				deferred.resolve();
			});
		}
	});

	$.template('ep.ui.datepicker','<div class=\"ep-uiDatepicker-calendar\">\n	<div class=\"epDialogTitleBar ep-uiDatepicker-titleBar\">\n		<span class=\"ep-uiDatepicker-title\">\n			<span class=\"ep-uiDatepicker-month\"><span class=\"label-month\">${month}<\/span>\n			{{if months}}\n				<select class=\"ep-uiDatepicker-monthSelect\">\n				{{each months}}\n					<option value=\"${$value.value}\" {{if $value.currentMonth}}selected=\"selected\"{{/if}} >${$value.name}<\/option>\n				{{/each}}\n				<\/select>\n			{{/if}}\n			<\/span>\n			<span class=\"ep-uiDatepicker-year\"><span class=\"label-year\">${year}<\/span>\n			{{if years}}\n				<select class=\"ep-uiDatepicker-yearSelect\">\n				{{each years}}\n					<option value=\"${$value.value}\" {{if $value.currentYear}}selected=\"selected\"{{/if}} >${$value.name}<\/option>\n				{{/each}}\n				<\/select>\n			{{/if}}\n			<\/span>\n		<\/span>\n	<\/div>\n	<table class=\"ep-uiDatepicker-content\">\n		<thead>\n			<tr>\n			{{each weekDays}}\n				<th class=\"ep-uiDatepicker-day\">\n					<span>${$value}<\/a>\n				<\/th>\n			{{/each}}\n			<\/tr>\n		<\/thead>\n		<tbody>\n		{{each weeks}}\n			<tr>\n			{{each $value.days}}\n				<td class=\"ep-uiDatepicker-{{if $value.currentMonth}}current{{else}}other{{/if}}Month ep-uiDatepicker-day{{if !$value.visible}} ep-uiDatepicker-dayHidden{{/if}}{{if $value.selected && $value.clickable}} ep-uiDatepicker-daySelected{{/if}}{{if $value.now}} ep-uiDatepicker-dayToday{{/if}}\">\n				{{if $value.clickable}}\n					<a href=\"javascript:;\" class=\"ep-uiDatepicker-dayClick\" data-tstamp=\"${$value.tstamp}\">${$value.day}<\/a>\n				{{else}}\n					<span>${$value.day}<\/span>\n				{{/if}}\n				<\/td>\n			{{/each}}\n			<\/tr>\n		{{/each}}\n		<\/tbody>\n	<\/table>\n<\/div>\n');
$.template('de_epages.presentation.ui.uploaderError','<ul class=\"de_epages-presentationUiUploader-errorList\">\n{{each(i, data) items}}\n  {{if data.ERROR}}\n  <li class=\"{{if $item.even()}}even{{else}}odd{{/if}}\">\n    <span class=\"ep-sprite ep-sprite-s ico_s_warning de_epages-presentationUiUploader-errorIcon\"><\/span>\n    <p class=\"de_epages-presentationUiUploader-errorFile\">${$item.scrunch(data.item.fileName)}<\/p>\n    <p class=\"de_epages-presentationUiUploader-errorThrown\">${$item.translate(data.ERROR.errorThrown)}<\/p>\n  <\/li>\n  {{/if}}\n{{/each}}\n<\/ul>');
$.template('de_epages.presentation.ui.uploaderProgress','<ul class=\"de_epages-presentationUiUploader-progressList\">\n  <li>\n    <div class=\"de_epages-presentationUiUploader-progressBar\"><\/div>\n    <div class=\"de_epages-presentationUiUploader-progressText\"><\/div>\n  <\/li>\n  <li>\n    <div class=\"de_epages-presentationUiUploader-progressBar\"><\/div>\n    <div class=\"de_epages-presentationUiUploader-progressText\"><\/div>\n  <\/li>\n<\/ul>');
$.template('de_epages.presentation.ui.uploaderReplace','<ul class=\"de_epages-presentationUiUploader-errorList\">\n{{each(i, item) items}}\n  <li class=\"{{if $item.even()}}even{{else}}odd{{/if}}\">\n    <span class=\"ep-sprite ep-sprite-s ico_s_warning de_epages-presentationUiUploader-errorIcon\"><\/span>\n    <p class=\"de_epages-presentationUiUploader-errorFile\" title=\"${item}\">${$item.scrunch(item)}<\/p>\n    <p class=\"de_epages-presentationUiUploader-errorThrown\">${tAlreadyExists}<\/p>\n  <\/li>\n{{/each}}\n<\/ul>');
$.template('de_epages.shop.ui.userBlogWidget','{{each items}}\n<a href=\"${$value.link}\" target=\"_blank\" class=\"dashboardCommunityLayer\">\n  <span class=\"ep-shopUiUserBlogWidget-item\">\n    <span class=\"ep-shopUiUserBlogWidget-itemContent\">\n      <span class=\"ep-shopUiUserBlogWidget-itemTitle\">${$value.title}<\/span>\n      <span class=\"ep-shopUiUserBlogWidget-itemText\">${$value.text}<\/span>\n    <\/span>\n    <span class=\"ep-shopUiUserBlogWidget-itemTooltip\">\n      <span class=\"ep-shopUiUserBlogWidget-itemTooltipTitle\">${$value.tooltipTitle}<\/span><span class=\"ep-shopUiUserBlogWidget-itemTooltipDate\">${$value.tooltipDate}<\/span>\n      <span class=\"ep-shopUiUserBlogWidget-itemTooltipText\">{{html $value.tooltipText}}<\/span>\n    <\/span>\n  <\/span>\n<\/a>\n{{/each}}');
$.template('de_epages.shop.ui.userCommunityWidget','{{each items}}\n<a href=\"${$value.link}\" target=\"_blank\">\n  <span class=\"ep-shopUiUserCommunityWidget-item\">\n    <span class=\"ep-shopUiUserCommunityWidget-itemTitle\">${$value.title}<\/span>\n    <span class=\"ep-shopUiUserCommunityWidget-itemText\">${$value.text}<\/span>\n  <\/span>\n<\/a>\n{{/each}}');
$.template('de_epages.seo.ui.seoGaugeWidget','<div class=\"de_epages-seoUiSeoGaugeWidget-item ${statusClass}\">\n  <div class=\"de_epages-seoUiSeoGaugeWidget-itemCaption FloatLeft\">{{html caption}}<\/div>\n  <div class=\"seoStatusBar\">\n    <span class=\"${percentageClass}\" style=\"width:${percentage}%\"><\/span>\n  <\/div>\n  <span class=\"de_epages-seoUiSeoGaugeWidget-itemPercentage\">${percentage}%<\/span>\n  <span class=\"de_epages-seoUiSeoGaugeWidget-itemStatus ${statusDisplay}\"><\/span>\n<\/div>\n');


});

/* ---- Module:jQuery.each ---- */

/*
 * @author			Emanuel Vitzthum
 * @copyright		© 2011 jQuery SDK v1.3.1
 * @info			http://www.jquerysdk.com
 *
 * @license			Dual licensed under the MIT (http://www.opensource.org/licenses/mit-license.php) and GPL (http://www.gnu.org/licenses/gpl.html)
 *
 * @plugin			jQuery.each
 */

jQuery.plugin( 'jQuery.each', function( $, undefined ){

	// enable overwrite "this" with the return value
	$.extend({
		// args is for internal usage only
		each: function( object, callback, args ) {
			var overwrite;
			if( callback === true ) {
				overwrite = callback;
				callback = args;
				args = arguments[3];
			}
			var name, i = 0,
				length = object.length,
				isObj = length === undefined || $.isFunction(object),
				ret;

			if ( args ) {
				if ( isObj ) {
					for ( name in object ) {
						ret = callback.apply( object[ name ], args );
						if( ret === false ) {
							break;
						}
						else if( overwrite && ret!==undefined ) {
							object[ name ] = ret;
						}
					}
				} else {
					for ( ; i < length; ) {
						ret = callback.apply( object[ i++ ], args );
						if( ret === false ) {
							break;
						}
						else if( overwrite && ret!==undefined ) {
							object[ i ] = ret;
						}
					}
				}

			// A special, fast, case for the most common use of each
			} else {
				if ( isObj ) {
					for ( name in object ) {
						ret = callback.call( object[ name ], name, object[ name ] );
						if( ret === false ) {
							break;
						}
						else if( overwrite && ret!==undefined ) {
							object[ name ] = ret;
						}
					}
				} else {
					for ( var value = object[0],ret=true ; i < length && ret !== false; value = object[++i] ) {
						ret = callback.call( value, i, value );

						if( overwrite && ret!==undefined ) {
							object[ i ] = ret;
						}
					}
				}
			}

			return object;
		}
	});

	// enable overwrite "this" with the return value
	$.fn.extend({
		each: function( overwrite, callback, args ) {
			return $.each( this, overwrite, callback, args );
		}
	});

});

/* ---- Module:jQuery.class ---- */

/*
 * @author			Emanuel Vitzthum
 * @copyright		© 2011 jQuery SDK v1.3.1
 * @info			http://www.jquerysdk.com
 *
 * @license			Dual licensed under the MIT (http://www.opensource.org/licenses/mit-license.php) and GPL (http://www.gnu.org/licenses/gpl.html)
 *
 * @plugin			jQuery.class
 */

jQuery.plugin( 'jQuery.class', function( $, undefined ){

	// base class, all classes based on this
	var _Class = function(){};
	$.extend(_Class.prototype,{
		Constructor: function(){
		},
		Proxy: function( fn ){
			return typeof fn === 'string' ? $.proxy( this, fn ) :  $.proxy( fn, this );
		}
	});

		// while initializing a new class
	var initializing = false,

		// inherit from super-class, sets up the Inherited method, and extend the options hash
		inheritProps = function( newPrototype, extPrototype, prototype ){
			for(var name in newPrototype) {
				// Check if we're overwriting an existing function
				prototype[name] =
					$.isFunction(newPrototype[name]) && $.isFunction(extPrototype[name]) && !/^(Constructor|Setup|Proxy|Inherited|Class)$/.test(name) ?
						(function(name, fn){
							return function() {
								var tmp = this.Inherited,
									ret;
								// Add a new Inherited() method that is the same method, but on the super-class
								this.Inherited = function(args){
									return extPrototype[name].apply(this,args||[]);
								};
								// executing method
								ret = fn.apply(this, arguments);
								// The method only need to be bound temporarily, so we, remove it after executing method
								this.Inherited = tmp;
								// return value of method
								return ret;
							};
						})(name, newPrototype[name]) :
						newPrototype[name];
			}

			return prototype;
		},

		classCreator = function( Classname, Extend, Prototype ){

			Prototype = Prototype || {};

			var parts     = Classname.split(/\./),
				fullName  = Classname,
				shortName = parts.pop(),
				namespace = parts.join('.'),

				// All construction is actually done in the init method
				Class     = $.scope( namespace, namespace.match(/^jQueryClass/) ? cache : undefined )[shortName] = function() {
					if(initializing){
						return;
					}
					else{
						return this.Constructor.apply( this, arguments );
					}
				},
				prototype;

			// init instance of Extend as prototype
			initializing = true;
			prototype = new Extend();
			initializing = false;

			// Copy the properties over onto the new prototype
			prototype = inheritProps(Prototype, Extend.prototype, prototype);
			// make sure Class cant'overwritten
			prototype.Class = Class;
			// make sure the inherited Constructor will execute too
			prototype.Constructor = (function(self){
				return function() {
					var args;
					if( $.isFunction(self.Setup) ){
						args = self.Setup.apply( this, arguments );
					}
					if( Extend.prototype.Constructor ){
						Extend.prototype.Constructor.apply( this, arguments);
					}

					return $.isFunction(self.Constructor) ? self.Constructor.apply( this, args || arguments ) : undefined;
				};
			})(Prototype);

			// set things that can't be overwritten
			$.extend(Class,{
				prototype:   prototype,
				inherited:   Extend.prototype,
				constructor: Class,
				fullName:    fullName,
				shortName:   shortName
			});

			return Class;
		},

		// cache classes for multiple extends
		cache = {},

		// count cached classes
		uid = 0;

	$.extend({
		// create a new class
		Class: function( Classname , Extends , Prototype ) {
			if( !Prototype ) {
				return classCreator( Classname , _Class , Extends );
			}
			else if( $.isArray(Extends) ){
				var Extend = Extends.shift();
				var Proto;
				var Name;

				for( var i=0,l=Extends.length ; i<l ; i++ ) {
					Name = 'jQueryClass'+(uid++);
					Proto = Extends.shift().prototype;
					Extend = classCreator( Name, Extend, Proto );
					Extend.fullName = Proto.Class.fullName;
					Extend.shortName = Proto.Class.shortName;
				}

				return classCreator( Classname, Extend, Prototype );
			}
			else {
				return classCreator( Classname , Extends , Prototype );
			}
		},
		// check is object a class, strict sure it was build with $.Class
		isClass: function( obj, strict ){
			return $.isFunction(obj) && !$.isEmptyObject(obj.prototype) && (strict ? !!obj.prototype.Class : true);
		}
	});


});

/* ---- Module:jQuery.ui.widget ---- */

/*
 * @author          Emanuel Vitzthum
 * @copyright       © 2011 jQuery SDK v1.3.1
 * @info            http://www.jquerysdk.com
 *
 * @license         Dual licensed under the MIT (http://www.opensource.org/licenses/mit-license.php) and GPL (http://www.gnu.org/licenses/gpl.html)
 *
 * @based			jQuery UI Widget (http://docs.jquery.com/UI/Widget) license (http://jquery.org/license)
 *
 * @plugin			jQuery.ui.widget
 */

jQuery.plugin( 'jQuery.ui.widget', ['jQuery.class', 'jQuery.each'], function( $, undefined ){


var _cleanData = $.cleanData;
$.cleanData = function( elems ) {
	for ( var i = 0, elem; (elem = elems[i]) != null; i++ ) {
		$( elem ).triggerHandler( "remove" );
	}
	_cleanData( elems );
};

$.widget = function( name, base , prototype ) {
	var part		= name.split( "." ),
		namespace	= part.shift(),
		subclass	= "jQuery",
		classname	= subclass+'.'+name,
		fullName	= "",
		data		= "";

	if( part.length >= 2 ){
		subclass	= namespace;
		classname	= name;
		namespace	= part.shift();

		if( subclass!=="jQuery" ){
			fullName = subclass + "-";
			data = subclass + "-";
/*
 * ePages: BEGIN
 */
			part.unshift(namespace);
			namespace = subclass;
			fullName = "";
/*
 * ePages: END
 */
		}
	}

	name = $.camelCase( part.join('-') );
	fullName += namespace + "-" + name;
	data += name;

	if ( !prototype ) {
		prototype = base;
		base = $.Widget;
	}

	// create selector for plugin
	$.expr[ ":" ][ fullName ] = function( elem ) {
		return !!$.data( elem, data );
	};

	var object = $.Class( classname, base, prototype );
	$.extend( object.prototype, {
		namespace: namespace,
		widgetData: data,
		widgetName: name,
		widgetEventPrefix: object.prototype.widgetEventPrefix || name,
		widgetBaseClass: fullName
	});

	$.widget.bridge( name, object, subclass );
};

$.widget.bridge = function( name, object, subclass ){

	window[ subclass ].fn[ name ] = function( options ) {
		var isMethodCall = typeof options === "string",
			args = Array.prototype.slice.call( arguments, 1 ),
			returnValue = this,
			data = object.prototype.widgetData;

		// allow multiple hashes to be passed on init
		options = !isMethodCall && args.length ?
			$.extend.apply( null, [ true, options ].concat(args) ) :
			options;

		// prevent calls to internal methods
		if ( isMethodCall && /^[A-Z_]/.test(options) && options!='Instance' ) {
			return returnValue;
		}

		if ( isMethodCall ) {
			this.each(function() {
				var instance = $.data( this, data ),
					methodValue = instance && $.isFunction( instance[options] ) ?
						instance[ options ].apply( instance, args ) :
						instance;
				// TODO: add this back in 1.9 and use $.error() (see #5972)
//				if ( !instance ) {
//					throw "cannot call methods on " + name + " prior to initialization; " +
//						"attempted to call method '" + options + "'";
//				}
				if( options==='Instance' ){
					returnValue = instance;
					return false;
				}
//				if ( !$.isFunction( instance[options] ) ) {
//					throw "no such method '" + options + "' for " + name + " widget instance";
//				}
//				var methodValue = instance[ options ].apply( instance, args );
				if ( methodValue !== instance && methodValue !== undefined ) {
					returnValue = methodValue;
					return false;
				}
			});
		} else {
			this.each( true, function() {
				var instance = $.data( this, data );
				if ( instance ) {
					instance.option( options || {} )._init();
				} else {
					var instance = new object( options, this );
					$.data( this, data, instance );
					return instance.element[0];
				}
			});
		}

		return returnValue;
	};
};

$.Class( 'jQuery.Widget', {

	widgetName: "widget",
	widgetEventPrefix: "",

	options: {
		disabled: false
	},

	Constructor: function( options, element ) {
		// $.widget.bridge stores the plugin instance, but we do it anyway
		// so that it's stored even before the _create function runs
		$.data( element, this.widgetData, this );
		this.element = $( element );

		// recursive inherited options extend
		var o = [ this.options, this._getCreateOptions(), options ],
			inh = this.Class.inherited,
			cur;
		while( inh ){
			cur = inh;
			inh = (cur.Class||{}).inherited;
			o.unshift( cur.options )
		}
		o.unshift({});
		o.unshift(true);

		this.options = $.extend.apply( $, o );

		var self = this;
		this.element.on( "remove." + this.widgetName, function() {
			self.destroy();
		});

		this._create();
		this._trigger( "create" );
		this._init();
	},
	_getCreateOptions: function() {
		return $.metadata && $.metadata.get( this.element[0] )[ this.widgetName ];
	},
	_create: function() {},
	_init: function() {},

	destroy: function() {
		this.element
			.off( "." + this.widgetName )
			.removeData( this.widgetName );
		this.widget()
			.off( "." + this.widgetName )
			.removeAttr( "aria-disabled" )
			.removeClass(
				this.widgetBaseClass + "-disabled " +
				"ui-state-disabled" );
	},

	widget: function() {
		return this.element;
	},

	option: function( key, value ) {
		var options = key;

		if ( arguments.length === 0 ) {
			// don't return a reference to the internal hash
			return $.extend( {}, this.options );
		}

		if  (typeof key === "string" ) {
			if ( value === undefined ) {
				return this.options[ key ];
			}
			options = {};
			options[ key ] = value;
		}

		this._setOptions( options );

		return this;
	},
	_setOptions: function( options ) {
		var self = this;
		$.each( options, function( key, value ) {
			self._setOption( key, value );
		});

		return this;
	},
	_setOption: function( key, value ) {
		this.options[ key ] = value;

		if ( key === "disabled" ) {
			this.widget()
				[ value ? "addClass" : "removeClass"](
					this.widgetBaseClass + "-disabled" + " " +
					"ui-state-disabled" )
				.attr( "aria-disabled", value );
		}

		return this;
	},

	enable: function() {
		return this._setOption( "disabled", false );
	},
	disable: function() {
		return this._setOption( "disabled", true );
	},

	_trigger: function( type, event, data ) {
		var prop, orig,
			callback = this.options[ type ];

		data = data || {};
		event = $.Event( event );
		event.type = ( type === this.widgetEventPrefix ?
			type :
			this.widgetEventPrefix + type ).toLowerCase();
		// the original event may come from any element
		// so we need to reset the target on the new event
		event.target = this.element[ 0 ];

		// copy original event properties over to the new event
		orig = event.originalEvent;
		if ( orig ) {
			for ( prop in orig ) {
				if ( !( prop in event ) ) {
					event[ prop ] = orig[ prop ];
				}
			}
		}

		this.element.trigger( event, data );

		return !( $.isFunction(callback) &&
			callback.call( this.element[0], event, data ) === false ||
			event.isDefaultPrevented() );
	}
});

});


/* ---- Module:ep.modify ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.modify
 *
 * @revision		$Revision: 1.11 $
 */

jQuery.plugin( 'ep.modify', function( $, undefined ){

// modify $.attr + $.removeAttr for event

		// save original methods
	var _attr = $.fn.attr,
		_removeAttr = $.fn.removeAttr
		_trigger = $.event.trigger,

		isVisible = $.expr.filters.visible,

		onEventExpr = /^on/,
		nativeEventExpr = /^(blur|change|click|dblclick|error|focus|keydown|keypress|keyup|load|mousedown|mousemove|mouseout|mouseover|mouseup|resize|select|unload)$/,
		mouseEventExpr = /^(click|dblclick|mousedown|mousemove|mouseout|mouseover|mouseup)$/;

	// handle for event trigger
	function attrEvent( obj, name, value ){
		var attr;

		if( typeof name === 'object' ){
			attr = name;
		}
		else if( value !== undefined ){
			(attr = {})[ name ] = value;
		}

		if( attr ){
			obj.trigger('changeAttr',attr);
		}
	}
//#JSCOVERAGE_IF false
	// overwrite trigger for dojo connect
	$.event.trigger = function( event, data, elem, onlyHandlers ){
		if( event.dojoconnect ){
			var type = event.type,
				eventObj;
			// break if no element given
			if( !elem ){
				return;
			}
			// remove exclusive option
			if ( type.indexOf("!") >= 0 ) {
				type = type.slice(0, -1);
			}
			// remove namespace
			if ( type.indexOf(".") >= 0 ) {
				type = type.split(".")[0];
			}
			// remove on prefix
			type = onEventExpr.test(type) ? type.slice(2) : type;

			if( nativeEventExpr.test(type) && !onlyHandlers ){
				if( elem.fireEvent ){
					try{
						elem.fireEvent( 'on' + type );
					}
					catch( error ){

					}
				}
				else{
					if( mouseEventExpr.test(type) ){ // create mouse events
						eventObj = document.createEvent('MouseEvents');
						eventObj.initMouseEvent(
							type,
							!!event.canBubble,
							!!event.cancelable,
							window,
							event.detail || 0,
							event.screenX || 0,
							event.screenY || 0,
							event || 0,
							event.clientY || 0,
							!!event.ctrlKey,
							!!event.altKey,
							!!event.shiftKey,
							!!event.metaKey,
							event.button || 0,
							event.relatedTarget || null
						);
					}
					else{										// create html events
						eventObj = document.createEvent('HTMLEvents');
						eventObj.initEvent(
							type,
							!!event.canBubble,
							!!event.cancelable
						);
					}
					elem.dispatchEvent(eventObj);
				}
				return;
			}
		}

		return _trigger.apply( this, arguments );
	};
//#JSCOVERAGE_ENDIF

	// overwrite methods
	$.fn.extend({
		attr: function( name, value ){
			var ret = _attr.apply(this,arguments);
			attrEvent( this, name, value );
			return ret;
		},
		removeAttr: function( name ){
			var ret = _removeAttr.apply(this,arguments);
			attrEvent( this, name, null );
			return ret;
		}
	});

	// special pseudo selector for input fields
	$.extend( $.expr[':'],{
		'invalid': function( elem ){
			return !!elem.formInvalid && !elem.disabled && (elem.type==='hidden' || isVisible(elem));
		}
	});

});

/* ---- Module:jQuery.support.multipleUpload ---- */

/*
 * @author			Emanuel Vitzthum
 * @copyright		© 2011 jQuery SDK v1.3.1
 * @info			http://www.jquerysdk.com
 *
 * @license			Dual licensed under the MIT (http://www.opensource.org/licenses/mit-license.php) and GPL (http://www.gnu.org/licenses/gpl.html)
 *
 * @plugin			jQuery.support.multipleUpload
 */

jQuery.plugin( 'jQuery.support.multipleUpload', function( $, undefined ){

	var file = document.createElement('input');

	file.setAttribute('type','file');

	$.support.multipleUpload = !!file.files;

});

/* ---- Module:jQuery.mime ---- */

/*
 * @author			Emanuel Vitzthum
 * @copyright		© 2011 jQuery SDK v1.3.1
 * @info			http://www.jquerysdk.com
 *
 * @license			Dual licensed under the MIT (http://www.opensource.org/licenses/mit-license.php) and GPL (http://www.gnu.org/licenses/gpl.html)
 *
 * @plugin			jQuery.mime
 */

jQuery.plugin( 'jQuery.mime', function( $, undefined ){

	var regxGroups = /([a-z]+\/\*)/gi,

		regxGroup = /([a-z]+\/\*)/i,

		regxMime = /\//,

		replaceGroup = function( string, found ){
			return $.mimeSettings.groups[found] || found;
		},

		replaceGroups = function( mime ){
			return mime.replace( regxGroups, replaceGroup );
		},

		getBySuffix = function( suffix ){
			var ret = $.mimeSettings.unknow;
			$.each( $.mimeSettings.mimeRegxMap, function( i, name ){
				if( name.test(suffix) ) {
					ret = i;
					return false;
				}
			});
			return ret;
		};

	$.extend({
		mimeSettings: $.extend(
			true,
			{
				mimeRegxMap: {
					// image
					'image/png':																	/^(png)$/i,
					'image/jpeg':																	/^(jpe|jpeg|jpg)$/i,
					'image/gif':																	/^(gif)$/i,
					'image/bmp':																	/^(bmp)$/i,
					'image/vnd.microsoft.icon':														/^(ico)$/i,
					'image/tiff':																	/^(tif|tif)$/i,
					'image/svg+xml':																/^(svg|svgz)$/i,
					'image/x-win-bitmap':															/^(cur)$/i,
					// audio/video
					'audio/basic':																	/^(au)$/i,
					'audio/mpeg':																	/^(mp3)$/i,
					'audio/mp4a-latm':																/^(m4p|m4b|m4a)$/i,
					'audio/x-wav':																	/^(wav)$/i,
					'audio/ogg':																	/^(ogg|oga|spx)$/i,
					'audio/flac':																	/^(flac)$/i,
					'audio/x-ms-wma':																/^(wma)$/i,
					'audio/x-pn-realaudio':															/^(ra|ram)$/i,
					'application/vnd.rn-realmedia':													/^(rm)$/i,
					'video/ogg':																	/^(ogv)$/i,
					'video/mp4':																	/^(mp4)$/i,
					'video/mpeg':																	/^(mpe|mpg|mpeg|mpga)$/i,
					'video/quicktime':																/^(qt|mov)$/i,
					'video/x-msvideo':																/^(avi)$/i,
					'video/x-flv':																	/^(flv)$/i,
					'video/x-ms-wmv':																/^(wmv)$/i,
					// web
					'text/plain':																	/^(txt)$/i,
					'text/html':																	/^(htm|html|shtml|php|php4)$/i,
					'text/css':																		/^(css)$/i,
					'text/x-actionscript':															/^(as)$/i,
					'application/javascript':														/^(js)$/i,
					'application/json':																/^(json)$/i,
					'application/xml':																/^(xml|plist)$/i,
					'application/x-shockwave-flash':												/^(swf)$/i,
					// archives
					'application/zip':																/^(zip)$/i,
					'application/gzip':																/^(gz)$/i,
					'application/x-tar':															/^(tar)$/i,
					'application/x-rar-compressed':													/^(rar)$/i,
					'application/x-msdownload':														/^(exe|msi)$/i,
					'application/vnd.ms-cab-compressed':											/^(cab)$/i,
					// adobe
					'application/pdf':																/^(pdf)$/i,
					'image/vnd.adobe.photoshop':													/^(psd)$/i,
					'application/postscript':														/^(ai|eps|ps)$/i,
					// ms office
					'application/msword':															/^(doc)$/i,
					'application/x-dot':															/^(dot)$/i,
					'application/rtf':																/^(rtf)$/i,
					'application/vnd.ms-excel':														/^(xls|xla)$/i,
					'application/vnd.ms-powerpoint':												/^(ppt)$/i,
					'application/vnd.openxmlformats-officedocument.wordprocessingml.document':		/^(docx)$/i,
					'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet':			/^(xlsx)$/i,
					// other
					'application/x-director':														/^(cdr)$/i
				},
				groups: {
					'previewable/*':		'image/png,image/jpeg,image/jpg,image/gif,image/vnd.microsoft.icon'
				},
				unknow:					'application/octet-stream'
			},
			$.config.mime
		),

		mime: function( mime, accept ){
			// group replace
			if( regxGroup.test(mime) ){
				return replaceGroups( mime );
			}
			// detect mime by suffix
			if( !regxMime.test(mime) ){
				mime = getBySuffix( mime );
			}
			// check
			if( regxMime.test(accept) ){
				accept = replaceGroups( accept ).split(',');

				var ret = false;
				$.each( accept, function( i, name ){
					name = $.trim(name);
					if( (regxGroup.test(name) && mime.split('/')[0]===name.split('/')[0]) || mime===name || name==='*/*' ){
						ret = true
						return false;
					}
				});
				mime = ret;
			}

			return mime;
		}
	});

});

/* ---- Module:jQuery.mixin ---- */

/*
 * @author			Emanuel Vitzthum
 * @copyright		© 2011 jQuery SDK v1.3.1
 * @info			http://www.jquerysdk.com
 *
 * @license			Dual licensed under the MIT (http://www.opensource.org/licenses/mit-license.php) and GPL (http://www.gnu.org/licenses/gpl.html)
 *
 * @plugin			jQuery.mixin
 */

jQuery.plugin( 'jQuery.mixin', function( $, undefined ){

	var own = Object.prototype.hasOwnProperty;

	$.extend({
		/*
		 * @name			$.mixin
		 * @description		similar to $.extendbut only works on objects (!prototype)
		 */
		mixin: function() {
			// copy reference to target object
			var target = arguments[0] || {},
				i = 1,
				length = arguments.length,
				deep = false,
				option,
				s,
				name,
				src,
				copy;

			// Handle a deep copy situation
			if ( typeof target === "boolean" ) {
				deep = target;
				target = arguments[1] || {};
				// skip the boolean and the target
				i = 2;
			}

			// Handle case when target is a string or something (possible in deep copy)
			if ( typeof target !== "object" && !$.isFunction(target) ) {
				target = {};
			}

			// return target if only one argument is passed
			if ( length === i ) {
				return target;
			}

			for ( ; i < length; i++ ) {
				// Only deal with non-null/undefined values
				if ( (options = arguments[ i ]) != null ) {
					// Extend the base object
					for ( name in options ) {
						src = target[ name ];
						copy = options[ name ];

						// Prevent never-ending loop
						if ( target === copy || !own.call( options, name ) ) {
							continue;
						}
						// Recurse if we're merging object literal values or arrays
						if ( deep && copy && ( $.isPlainObject(copy) || $.isArray(copy) ) ) {
							var clone = src && ( $.isPlainObject(src) || $.isArray(src) ) ? src
								: $.isArray(copy) ? [] : {};

							// Never move original objects, clone them
							target[ name ] = $.extend( deep, clone, copy );

						// Don't bring in undefined values
						} else if ( copy !== undefined ) {
							target[ name ] = copy;
						}
					}
				}
			}

			// Return the modified object
			return target;
		}
	});

});

/* ---- Module:jQuery.event.fix ---- */

/*
 * @author			Emanuel Vitzthum
 * @copyright		© 2011 jQuery SDK v1.3.1
 * @info			http://www.jquerysdk.com
 *
 * @license			Dual licensed under the MIT (http://www.opensource.org/licenses/mit-license.php) and GPL (http://www.gnu.org/licenses/gpl.html)
 *
 * @plugin			jQuery.event.fix
 */

jQuery.plugin( 'jQuery.event.fix', function( $, undefined ){

	var _fix = $.event.fix;

	$.extend( $.event, {
		fix: function( event ) {
			var originalEvent;
			
			// run  the original fix method
			event = _fix.call( $.event, event );

			// get the original event
			if( !(originalEvent = event.originalEvent) )
				return event;

			// Add originalTarget, if necessary
			if ( !event.originalTarget )
				event.originalTarget = originalEvent.srcElement || event.target;

			// be sure touches isn't undefined
			// Calculate pageX/Y if missing and touches[0] available
			if( (event.touches = originalEvent.touches || {length:0}).length ){
				event.pageX = event.touches[0].pageX;
				event.pageY = event.touches[0].pageY;
			}
			// Calculate pageX/Y and touches[0] if missing and touch available
			else if( originalEvent.touch ){
				event.touches = { 0: originalEvent.touch, length: 1 };
				event.pageX = originalEvent.touch.pageX;
				event.pageY = originalEvent.touch.pageY;
			}

			return event;
		}
	});

});

/* ---- Module:ep.core ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.core
 *
 * @revision		$Revision: 1.12.4.1 $
 */

jQuery.plugin( 'ep.core', [
	'ep.modify',
	'jQuery.each',
	'jQuery.mixin',
	'jQuery.event.fix'
], function( $, undefined ){

	// subclass of jQuery
	var ep = $.sub();

	// merge config params
	ep.config = $.extend(
		{
			debugLevel:					0,
   			version:					'',
   			webRoot:					'',
   			storeWebRoot:				'',
   			storeRoot:					'',
   			storeTypeRoot:				'',
   			siteRoot:					'',
   			siteId:						'0',
  			baseUrl:					undefined,
   			iconsRoot:					'',
   			objectId:					'0',
   			viewAction:					'',
   			storeFrontUrl:				'',
   			requestProtocolAndServer:	'',
   			maxContentLength:			'',
   			currency:					'',
   			autoMetaparse:				true
		},
		window.epConfig
	);

	var splice = Array.prototype.splice,
		push = Array.prototype.push,
		extend = $.extend,
		mixin = $.mixin,
		ready = $.fn.ready,
		browser = $.browser,
		browserClass = (/khtml/i).test(navigator.userAgent) ? 'khtml' : '';

	// add browser engine name as class to html tag
	$.each( ['mozilla', 'msie', 'webkit', 'opera'], function( i, name ){
		if( browser[name] ){
			browserClass = name;
			return false;
		}
	});
	$('html').addClass( browserClass );

	$.extend(ep,{
		// similar to $.extend; if only 1 hash in arguments ep will extend with this hash
		extend: function() {
			return extend.apply( this, arguments );
		},
		// similar to $.mixin; if only 1 hash in arguments ep will mixin with this hash
		mixin: function() {
			return mixin.apply( this, arguments );
		}
	});

	ep.extend({
		// find a key by the givn value in a hash
		inHash: function( val, obj ){
			var ret;
			if( !$.isPlainObject(obj) ){
				return ret;
			}
			$.each( obj, function( key, value ){
				if( value === val ){
					ret = key;
					return false;
				}
			});
			return ret;
		},
		// return array of keys, values or keys and values from hash
		hashToArray: function( obj, type ){
			var keys = [],
				values = [];
			$.each( obj, function( key, value ){
				keys.push( key );
				values.push( value );
			});
			return (/^k/i).test(type) ? keys : ( (/^v/i).test(type) ? values : [keys,values] );
		},
		// build a hash from 2 arrays (keys values)
		arrayToHash: function( keys, values ){
			if( !values ){
				values = keys;
				keys = [];
			}

			var hash = {};
			$.each( values, function( i, elm ){
				hash[ keys[i] || i ] = elm;
			});
			return hash;
		},
		// add item(s) to an array or array-like object at an indexed position without overwrite existing items
		insert: function( target, insert, index ){
			index = typeof index !== 'number' ? target.length : index;

			var end = splice.call( target, index, target.length-index );

			if( $.isArray(insert) ){
				push.apply( target, insert );
			}
			else if( typeof insert === 'object' && typeof insert.length === 'number' ){
				$.merge( target, insert );
			}
			else{
				push.call( target, insert );
			}

			return $.merge( target, end );
		},
		// escape string to use it for RegExp
		escapeExpStr: function( string, except ){
			return string.replace(/([\.$?*|{}\(\)\[\]\\\/\+^])/g, function(ch){
				if(except && except.indexOf(ch) !== -1){
					return ch;
				}
				return "\\" + ch;
			});
		},
		// scrunch a string [ fulltext... , full...text , ...fulltext ]
		scrunch: function( string, length, options ) {
			if( typeof length === 'object' ){
				options = length;
				length = 30;
			}
			var opt = $.extend({
					length:	length || 30,
					ratio:		1,
					cut:	true,
					spacer:	'...'
				},options);
			opt.length -= opt.spacer.length;

			var strLength = string.length;

			if( strLength <= opt.length ){
				return string;
			}
			else if( opt.ratio===0 ) {
				string = string.substr( strLength-opt.length, opt.length );
				if(!opt.cut) {
					string = string.substr( string.indexOf(" "), string.length );
				}
				return opt.spacer + string;
			}
			else if( opt.ratio===1 ){
				string = string.substr( 0, opt.length );
				if(!opt.cut) {
					string = string.substr( 0, string.lastIndexOf(" ")+1 );
				}
				return string + opt.spacer;
			}
			else{
				var aLength = Math.floor( opt.length * opt.ratio ),
					bLength = Math.floor( opt.length * (1-opt.ratio) ),
					cLength = opt.length - (aLength + bLength);

				return string.substr( 0, aLength ) + opt.spacer + string.substr( Math.max( 0, strLength-bLength-cLength ), strLength );
			}
		},
		// reverse a string or number or array
		reverse: function( string ) {
			if( $.isArray(string) ){
				return string.reverse();
			}

			var ret = '';
			(string+'').replace(/(.{1})/g,function(s) {
				ret = s+ret;
			});
			return ret;
		},
		// remove xml/xhtml/html tags
		stripTags: function( string ) {
			return string.replace(/<.[^<>]*?>/g, ' ');
		},
		// hash to address functions as global object in inline scripts
		local:{}
	});

	// Expose ep to the global object
	window.ep = ep;

});

/* ---- Module:ep.ajax ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.ajax
 *
 * @revision		$Revision: 1.14 $
 */

jQuery.plugin( 'ep.ajax', 'ep.core', function( $, undefined ){

	ep.extend({
		ajax: function( settings ){

			var jqXHR;

			if( !settings.url ){
				settings.url = ep.config.baseUrl;
			}

			if( settings.dataType === 'json' ){
				var _beforeSend = settings.beforeSend;

				// add special header for epages
				$.extend(settings,{
					beforeSend: function( xhr, s ){
						xhr.setRequestHeader("Accept", "application/json");
						if( _beforeSend ){
							_beforeSend( xhr, s );
						}
					}
				});

				// save deprecated properties as locals
				var success	= settings.success,
					error	= settings.error,
					complete= settings.complete;

				// delete deprecated properties
				settings.success = settings.error = settings.complete = undefined;

				// create AJAX object
				jqXHR = $.ajax(settings);

				// init
				var context		= settings.context || jqXHR,
					deferred	= $.Deferred(),
					complete	= $.Deferred(),
				// save original deferrd methods
					originalDone = jqXHR.done,
					originalFail = jqXHR.fail;

				// set bridge for .done() calls
				originalDone(function( data, status, jqXHR ){
					if( data && data.Errors ){
						var errorThrown = data.Errors;
						jqXHR.status = 400;
						jqXHR.statusText = status = "error";
						deferred.rejectWith( context, [jqXHR, status, errorThrown] );
					}
					else{
						deferred.resolveWith( context, [data, status, jqXHR] );
					}
				});

				// set bridge for .fail() calls
				originalFail(function( jqXHR, status, errorThrown ){
					deferred.rejectWith( context, [jqXHR, status, errorThrown] );
				});

				// set bridge for .always() calls
				deferred.always(function(){
					complete.resolveWith( context, [jqXHR] );
				});

				// map .done() to own deferrd
				jqXHR.done = function(){
					deferred.done.apply( deferred, arguments );
					return jqXHR;
				};

				// map .fail() to own deferrd
				jqXHR.fail = function(){
					deferred.fail.apply( deferred, arguments );
					return jqXHR;
				};

				// map .always() to own deferrd
				jqXHR.always = function(){
					complete.done.apply( complete, arguments );
					return jqXHR;
				};

				// restore deprecated properties from locals
				if( success ){
					jqXHR.done(success);
				}
				if( error ){
					jqXHR.fail(error);
				}
				if( complete ){
					jqXHR.always(complete);
				}
			}
			else{
				jqXHR = $.ajax(settings);
			}

			return jqXHR;
		}
	});



});


/* ---- Module:ep.fn.sprite ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.fn.sprite
 *
 * @revision		$Revision: 1.7 $
 */

jQuery.plugin( 'ep.fn.sprite', ['ep.core', 'jQuery.fn.class'], function( $, undefined ){

	var spriteExprMap = {
			'ico_image':		/^(image\/png|image\/jpeg|image\/jpg|image\/gif|image\/bmp|image\/vnd.microsoft.icon|image\/tiff|image\/svg+xml|image\/x-win-bitmap)$/i,
			'ico_box':			/^(application\/octet-stream|text\/x-actionscript|audio\/basic|audio\/x-wav|audio\/mpeg|audio\/x-ms-wma|audio\/ogg|audio\/flac|application\/msword|application\/x-dot|application\/vnd.ms-excel|application\/vnd.ms-powerpoint|text\/plain|text\/css|application\/javascript|application\/json|application\/xml)$/i,
			'ico_file_avi':		/^(video\/x-msvideo|video\/mpeg|video\/mp4)$/i,
			'ico_file_wmv':		/^(video\/x-ms-wmv)$/i,
			'ico_file_swf':		/^(video\/x-flv|application\/x-shockwave-flash)$/i,
			'ico_file_mov':		/^(video\/quicktime|video\/ogg)$/i,
			'ico_file_rm':		/^(application\/vnd.rn-realmedia)$/i,
			'ico_file_ram':		/^(audio\/x-pn-realaudio)$/i,
			'ico_file_dcr':		/^(application\/x-director)$/i,
			'ico_file_pdf':		/^(application\/pdf)$/i,
			'ico_file_htm':		/^(text\/html)$/i,
			'ico_folder':		/^(application\/zip|application\/x-rar-compressed|application\/gzip|application\/x-tar)$/i
		},

		removeExpr = /(ep-sprite[\w\d-]*|[^\s]*ico_[^\s]*)/;

	ep.fn.extend({
		addSprite: function( name, size ){

			// get name by mimetype
			if(/\//.test(name)){
				var mime = name;
				$.each( spriteExprMap, function( i, expr ){
					if( expr.test(mime) ){
						mime = i;
						return false;
					}
				});
				name = mime===name ? 'unknow' : mime;
			}

			size = size || 'm';

			return this.each(function(){
				$(this)
					.removeClass(removeExpr)
					.addClass( 'ep-sprite ep-sprite-'+size + ( (/[^\s]*ico_[^\s]*/).test(name) ? ' '+name : ' ep-sprite-'+name ) );
			});
		},
		removeSprite: function(){
			return this.removeClass(removeExpr);
		},
		hasSprite: function( name ){
			return this.hasClass( 'ep-sprite' + (name ? '-'+name : '') );
		}
	});

});

/* ---- Module:ep.sprite ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.sprite
 *
 * @revision		$Revision: 1.4 $
 */

jQuery.plugin( 'ep.sprite', ['ep.core','ep.fn.sprite'], function( $, undefined ){

	ep.extend({
		sprite: function( name, size ){
			return ep('<span>').addSprite( name, size );
		}
	});

});

/* ---- Module:ep.color ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.color
 *
 * @revision		$Revision: 1.1.48.2 $
 */

jQuery.plugin( 'ep.color', 'ep.core', function( $, undefined ){


	var nameMap = {
			'aliceblue':			'f0f8ff',
			'antiquewhite':			'faebd7',
			'aqua':					'00ffff',
			'aquamarine':			'7fffd4',
			'azure':				'f0ffff',
			'beige':				'f5f5dc',
			'bisque':				'ffe4c4',
			'black':				'000000',
			'blanchedalmond':		'ffebcd',
			'blue':					'0000ff',
			'blueviolet':			'8a2be2',
			'brown':				'a52a2a',
			'burlywood':			'deb887',
			'cadetblue':			'5f9ea0',
			'chartreuse':			'7fff00',
			'chocolate':			'd2691e',
			'coral':				'ff7f50',
			'cornflowerblue':		'6495ed',
			'cornsilk':				'fff8dc',
			'crimson':				'dc143c',
			'cyan':					'00ffff',
			'darkblue':				'00008b',
			'darkcyan':				'008b8b',
			'darkgoldenrod':		'b8860b',
			'darkgray':				'a9a9a9',
			'darkgrey':				'a9a9a9',
			'darkgreen':			'006400',
			'darkkhaki':			'bdb76b',
			'darkmagenta':			'8b008b',
			'darkolivegreen':		'556b2f',
			'darkorange':			'ff8c00',
			'darkorchid':			'9932cc',
			'darkred':				'8b0000',
			'darksalmon':			'e9967a',
			'darkseagreen':			'8fbc8f',
			'darkslateblue':		'483d8b',
			'darkslategray':		'2f4f4f',
			'darkslategrey':		'2f4f4f',
			'darkturquoise':		'00ced1',
			'darkviolet':			'9400d3',
			'deeppink':				'ff1493',
			'deepskyblue':			'00bfff',
			'dimgray':				'696969',
			'dimgrey':				'696969',
			'dodgerblue':			'1e90ff',
			'firebrick':			'b22222',
			'floralwhite':			'fffaf0',
			'forestgreen':			'228b22',
			'fuchsia':				'ff00ff',
			'gainsboro':			'dcdcdc',
			'ghostwhite':			'f8f8ff',
			'gold':					'ffd700',
			'goldenrod':			'daa520',
			'gray':					'808080',
			'grey':					'808080',
			'green':				'008000',
			'greenyellow':			'adff2f',
			'honeydew':				'f0fff0',
			'hotpink':				'ff69b4',
			'indianred':			'cd5c5c',
			'indigo':				'4b0082',
			'ivory':				'fffff0',
			'khaki':				'f0e68c',
			'lavender':				'e6e6fa',
			'lavenderblush':		'fff0f5',
			'lawngreen':			'7cfc00',
			'lemonchiffon':			'fffacd',
			'lightblue':			'add8e6',
			'lightcoral':			'f08080',
			'lightcyan':			'e0ffff',
			'lightgoldenrodyellow':	'fafad2',
			'lightgray':			'd3d3d3',
			'lightgrey':			'd3d3d3',
			'lightgreen':			'90ee90',
			'lightpink':			'ffb6c1',
			'lightsalmon':			'ffa07a',
			'lightseagreen':		'20b2aa',
			'lightskyblue':			'87cefa',
			'lightslategray':		'778899',
			'lightslategrey':		'778899',
			'lightsteelblue':		'b0c4de',
			'lightyellow':			'ffffe0',
			'lime':					'00ff00',
			'limegreen':			'32cd32',
			'linen':				'faf0e6',
			'magenta':				'ff00ff',
			'maroon':				'800000',
			'mediumaquamarine':		'66cdaa',
			'mediumblue':			'0000cd',
			'mediumorchid':			'ba55d3',
			'mediumpurple':			'9370d8',
			'mediumseagreen':		'3cb371',
			'mediumslateblue':		'7b68ee',
			'mediumspringgreen':	'00fa9a',
			'mediumturquoise':		'48d1cc',
			'mediumvioletred':		'c71585',
			'midnightblue':			'191970',
			'mintcream':			'f5fffa',
			'mistyrose':			'ffe4e1',
			'moccasin':				'ffe4b5',
			'navajowhite':			'ffdead',
			'navy':					'000080',
			'oldlace':				'fdf5e6',
			'olive':				'808000',
			'olivedrab':			'6b8e23',
			'orange':				'ffa500',
			'orangered':			'ff4500',
			'orchid':				'da70d6',
			'palegoldenrod':		'eee8aa',
			'palegreen':			'98fb98',
			'paleturquoise':		'afeeee',
			'palevioletred':		'd87093',
			'papayawhip':			'ffefd5',
			'peachpuff':			'ffdab9',
			'peru':					'cd853f',
			'pink':					'ffc0cb',
			'plum':					'dda0dd',
			'powderblue':			'b0e0e6',
			'purple':				'800080',
			'red':					'ff0000',
			'rosybrown':			'bc8f8f',
			'royalblue':			'4169e1',
			'saddlebrown':			'8b4513',
			'salmon':				'fa8072',
			'sandybrown':			'f4a460',
			'seagreen':				'2e8b57',
			'seashell':				'fff5ee',
			'sienna':				'a0522d',
			'silver':				'c0c0c0',
			'skyblue':				'87ceeb',
			'slateblue':			'6a5acd',
			'slategray':			'708090',
			'slategrey':			'708090',
			'snow':					'fffafa',
			'springgreen':			'00ff7f',
			'steelblue':			'4682b4',
			'tan':					'd2b48c',
			'teal':					'008080',
			'thistle':				'd8bfd8',
			'tomato':				'ff6347',
			'turquoise':			'40e0d0',
			'violet':				'ee82ee',
			'wheat':				'f5deb3',
			'white':				'ffffff',
			'whitesmoke':			'f5f5f5',
			'yellow':				'ffff00',
			'yellowgreen':			'9acd32'
		},

		hexMap = null,

		createHexMap = function(){
			hexMap = {};
			for( var i in nameMap ){
				hexMap[ nameMap[i] ] = i;
			}
		},

		toHex = function(c){
			c = parseInt( c, 10 ).toString(16);
			return c.length < 2 ? "0" + c : c;
		};

	$.extend( $.scope('ep.color'),{

		rgbToHex: function( rgb ){
			return rgb.a === 0 ? "transparent" : toHex(rgb.r) + toHex(rgb.g) + toHex(rgb.b);
		},

		rgbToHsb: function(rgb) {
			var min = Math.min( Math.min(rgb.r,rgb.g), rgb.b ),
				max = Math.max( Math.max(rgb.r,rgb.g), rgb.b ),
				delta = (max - min),
				sat = 0,
				lum = 0,
				hue = 0;

			if( max !== 0 ){
				sat = (delta / max) * 100;
				lum = (max / 255) * 100;
			}

			if( delta !== 0 ){
				if( rgb.r===max ){
					hue = (rgb.g - rgb.b) / delta;
				}
				else if( rgb.g===max ){
					hue = 2 + ( (rgb.b - rgb.r) / delta );
				}
				else{
					hue = 4 + ( (rgb.r - rgb.g) / delta );
				}
				hue = (hue * 60);
				hue = hue < 0 ? hue + 360 : hue;
			}

			return {
				h: Math.round(hue),
				s: Math.round(sat),
				b: Math.round(lum)
			};
		},

		rgbToName: function( rgb ){
			var hex = this.rgbToHex(rgb);
			return this.hexToName( hex );
		},

		hexToRgb: function( hex ) {
			hex = hex.toUpperCase();

			var rgb;

			if( /^(transparent|none)$/.test(hex) ){
				return {
					r:255,
					g:255,
					b:255,
					a:0
				};
			}

			hex = hex.charAt(0) === "#" ? hex.substring(1,hex.length) : hex;

			if( hex.length === 6 ){
				rgb = {
					r: parseInt(hex.substring(0,2),16),
					g: parseInt(hex.substring(2,4),16),
					b: parseInt(hex.substring(4,6),16),
					a: 1
				};
			}
			else if( hex.length === 3){
				rgb = {
					r: parseInt(hex.substring(0,1) + hex.substring(0,1),16),
					g: parseInt(hex.substring(1,2) + hex.substring(1,2),16),
					b: parseInt(hex.substring(2,3) + hex.substring(2,3),16),
					a: 1
				};
			}
			else{
				//return white if no hex value was given
				rgb = {
					r: 255,
					g: 255,
					b: 255,
					a: 1
				};
			}

			rgb.r =  isNaN(rgb.r) ? 0 : Math.round(rgb.r);
			rgb.g =  isNaN(rgb.g) ? 0 : Math.round(rgb.g);
			rgb.b =  isNaN(rgb.b) ? 0 : Math.round(rgb.b);

			return rgb;
		},

		hexToHsb: function( hex ){
			return this.rgbToHsb( this.hexToRgb(hex) );
		},

		hexToName: function( hex ){
			hex = hex.charAt(0) === "#" ? hex.substring(1,hex.length) : hex;

			if(!hexMap){
				createHexMap();
			}

			return hexMap[hex];
		},

		hsbToRgb: function(hsb) {
			var rgb = {},
				r = 0,
				g = 0,
				b = 0,
				hue = hsb.h/60,
				sat = hsb.s/100,
				lum = hsb.b/100;

			if( sat === 0 ) {
				r = g = b = lum;
			}
			else {
				var i = parseInt( hue, 10 ),
					p = lum * ( 1.0-sat ),
					q = lum * ( 1.0-sat * (hue-i) ),
					t = lum * ( 1.0-sat * ( 1 - (hue-i) ) );

				switch (i) {
					case 0: r = lum; g = t;   b = p;   break;
					case 1: r = q;   g = lum; b = p;   break;
					case 2: r = p;   g = lum; b = t;   break;
					case 3: r = p;   g = q;   b = lum; break;
					case 4: r = t;   g = p;   b = lum; break;
					case 5: r = lum; g = p;   b = q;   break;
					case 6: r = lum; g = t;   b = p;   break;
				}
			}

			return {
				r: Math.round( r * 255 ),
				g: Math.round( g * 255 ),
				b: Math.round( b * 255 ),
				a: 1
			};
		},

		hsbToHex: function( hsb ){
			return this.rgbToHex( this.hsbToRgb(hsb) );
		},

		hsbToName: function( hsb ){
			return this.hexToName( this.hsbToHex(hsb) );
		},

		nameToHex: function( name ){
			name = $.trim( name.toLowerCase() );
			return (/^(transparent|none)$/).test(name) ? 'transparent' : nameMap[name];
		},

		nameToRgb: function( name ){
			var hex = this.nameToHex(name);
			return hex ? this.hexToRgb( hex ) : hex;
		},

		nameToHsb: function( name ){
			var rgb = this.nameToRgb(name);
			return rgb ? this.rgbToHsb(rgb) : rgb;
		},

		stringToHex: function( string, /* internal */ strict ){
			string = $.trim( string.toLowerCase() );

			var result,
				found;

			if( (/^(transparent|none)$/).test(string) ){
				result = "transparent";
			}
			else if( found = (/^#?([0-9a-f]{6})$/).exec(string) ){
				result = found[1];
			}
			else if( found = (/^#?([0-9a-f])([0-9a-f])([0-9a-f])$/).exec(string) ) {
				result = found[1] + found[1] + found[2] + found[2] + found[3] + found[3];
			}
			else if( found = (/^rgb\(\s*([0-9]{1,3})\s*,\s*([0-9]{1,3})\s*,\s*([0-9]{1,3})\s*\)$/).exec(string) ){
				result = this.rgbToHex( {r: found[1], g: found[2], b: found[3]} );
			}
			else if( found = (/^rgba\(\s*([0-9]{1,3})\s*,\s*([0-9]{1,3})\s*,\s*([0-9]{1,3})\s*,\s*([0-1]{1}(:?\.?[0-9]{1})?)\s*\)$/).exec(string) ){
				result = this.rgbToHex( {r: found[1], g: found[2], b: found[3], a: found[4]} );
			}
			else{
				result = this.nameToHex( string );
			}

			return result===undefined && !strict ? "ffffff" : result;
		},

		stringToRgb: function( string ){
			var hex = this.stringToHex(string);
			return hex ? this.hexToRgb(hex) : hex;
		},

		stringToHsb: function( string ){
			var hex = this.stringToHex(string);
			return hex ? this.hexToHsb(hex) : hex;
		},

		stringToName: function( string ){
			var hex = this.stringToHex(string);
			return hex ? this.hexToName(hex) : hex;
		}
	});

});

/* ---- Module:jQuery.dict ---- */

/*
 * @author			Emanuel Vitzthum
 * @copyright		© 2011 jQuery SDK v1.3.1
 * @info			http://www.jquerysdk.com
 *
 * @license			Dual licensed under the MIT (http://www.opensource.org/licenses/mit-license.php) and GPL (http://www.gnu.org/licenses/gpl.html)
 *
 * @plugin			jQuery.dict
 */

jQuery.plugin( 'jQuery.dict', function( $, undefined ){

		// split name to dict informations
	var dictInfo = function( dict ){
			var temp = dict.split(':'),
				info = {
					dict:	dict,
					region:	temp[1] ? temp.shift() : $.dictSettings.region,
					name:	temp.join(':')
				};

			info.id = info.region+':'+info.name;

			return info;
		},

		// text replace
		parseNode = function( node, dict, deep ){
			if( node.nodeType===3 )
				node.nodeValue = dict.parse( node.nodeValue );
			else if( deep )
				$.each( node.childNodes, function(){
					parseNode( this, dict, deep );
				});
		};

		// local scope of dependencies controller settings
		dependSettings = $.dependSettings;

	$.extend({
		// call dict instance
		dict: function( dict, options ) {
			var o,
				info,
				data;

			if( typeof dict === 'string' ){
				info = dictInfo(dict);
				o = $.extend( {}, $.dictSettings, {region:info.region}, options );
				data = $.dict[ o.region+':'+info.name ] || {};
			}
			else{
				o = $.extend( {}, $.dictSettings, options );
				data = dict || {};
			}

			return new $.Dictionary( data, o );
		},
		// build dict hash
		dictionary: function( dict, data ){
			var mix = [{}],
				ret = {},
				info = {};

			// anonymous dict
			if( data===undefined ){
				data = dict;
			}
			// named dict
			else{
				info = dictInfo(dict);
				mix = [ $.dict[ info.id ] || {} ];
			}

			// create stack
			$.each( $.isArray(data) ? data : [data], function( i, data ){
				if( $.isPlainObject(data) ){
					mix.push( data );
				}
				else if( typeof data==='string' ){
					var dataInfo = dictInfo(data);
					mix.push( $.dict[ (info.region || dataInfo.region)+':'+dataInfo.name ] || {} );
				}
				else if( data instanceof $.Dictionary ){
					mix.push( data.dict );
				}
			});

			// merge stack
			ret = $.extend.apply( {}, mix );

			return info.id ? ($.dict[ info.id ] = ret) : ret;
		},
		// dict settings
		dictSettings: $.extend(
			{
				parser: /(?:^|[^\{\$])(\{(.*?[^\\])\})/g,
				region: 'en'
			},
			$.config.dict
		),
		// dict Class
		Dictionary: function( dict, settings ){
			this.dict = dict;
			this.settings = settings;
		}
	});

	// Class methods of dict
	$.extend( $.Dictionary.prototype, {
		translate: function( key ){
			return this.dict[ key ] || this.parse(key);
		},
		parse: function( string ) {
			var dict = this.dict;
			return string.replace( this.settings.parser, function( all, $1, $2 ){
					var ret = dict[ $2 ];
					return ret===undefined ? all : all.replace($1,ret);
				});
		}

	});

	// add dict as dom manipulation method
	$.fn.extend({
		dictParse: function( dict, deep, options ){
			// init dict object
			dict = dict instanceof $.Dictionary ? dict : $.dict( dict, options );
			// init recursive parsing
			if( typeof deep !== 'boolean' ){
				options = deep;
				deep = false;
			}
			// parse DOM content
			this.contents()
				.each(function(){
					parseNode( this, dict, deep );
				});
			return this;
		}
	});

	// set dict root directory
	if( !dependSettings.dictRoot )
		dependSettings.dictRoot = dependSettings.pluginRoot;

	// register dict for dependencies control
	$.dependRegister( 'dict', function( depend, deferred ){
		var info = dictInfo(depend),
			dependId = info.id,
			dict = $.dict[ dependId ];

		if( dict || (depend != dependId && $.dependStack.dict[ dependId ]) ){
			deferred.resolve();
		}
		else{
			var ajax = {
					url:		dependSettings.dictRoot+'/'+info.name.replace(/\./g,'/')+'.'+info.region+(dependSettings.minify?'.min':'')+'.json',
					dataType:	'json',
					type:		'get',
					asnyc:		true,
					cache:		true
				};

			$.ajax(
				dependSettings.jsonp ?
				$.extend(ajax,{
					dataType:		'jsonp',
					jsonp:			dependSettings.jsonp!==true ? dependSettings.jsonp : undefined,
					jsonpCallback:	'jsonp.dependHandle.dict('+dependId+')'
				}) :
				ajax
			)
			.done(function( data ){
				$.dictionary( dependId, data );
				deferred.resolve();
			});
		}
	});

	/*!BUILD(dict)*/

});

/* ---- Module:jQuery.expr ---- */

/*
 * @author			Emanuel Vitzthum
 * @copyright		© 2011 jQuery SDK v1.3.1
 * @info			http://www.jquerysdk.com
 *
 * @license			Dual licensed under the MIT (http://www.opensource.org/licenses/mit-license.php) and GPL (http://www.gnu.org/licenses/gpl.html)
 *
 * @plugin			jQuery.fn.expr
 */

jQuery.plugin( 'jQuery.expr', function( $, undefined ){

	var inputTextareaExp = /^(input|textarea)$/i,
		selectExp = /^select$/i,
		checkedExp = /^(radio|checkbox)$/i,
		onExp = /^(|on)$/i;

	// special selector
	$.extend( $.expr[":"],{
		'changed': function( elem ){
			return inputTextareaExp.test(elem.nodeName) ?
						checkedExp.test(elem.type) ?
							elem.defaultChecked !== elem.checked || (elem.defaultValue !== elem.value && !onExp.test(elem.defaultValue) && !onExp.test(elem.value) ) :
							elem.defaultValue !== elem.value :
						selectExp.test(elem.nodeName) ?
							!(elem.options[ elem.selectedIndex ] || {}).defaultSelected :
							false;
		},
		'readonly': function( elem ){
			return !!elem[ $.propFix.readonly ];
		}
	});

});

/* ---- Module:ep.fn.contextOrientation ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.fn.contextOrientation
 *
 * @revision		$Revision: 1.4 $
 */

jQuery.plugin( 'ep.fn.contextOrientation', 'ep.core', function( $, undefined ){

	var xExpr = /(left|center|right)/,
		yExpr = /(top|middle|bottom)/;

	ep.fn.extend({
		contextOrientation: function( context, orient, adjust ){
			adjust = adjust || [0,0];

			var orientX = xExpr.exec(orient),
				orientY = yExpr.exec(orient);

			orientX = orientX ? orientX[1] : '';
			orientY = orientY ? orientY[1] : '';

			if( context instanceof $.Event ){
				var contextO = { left:context.pageX, top:context.pageY },
					contextW = 0,
					contextH = 0;
			}
			else{
				context = $(context);
				var contextO = context.offset(),
					contextW = context.outerWidth(),
					contextH = context.outerHeight();
			}

			return this.each(function(){
					var elem = $(this),
						elemW = elem.outerWidth(),
						elemH = elem.outerHeight(),
						pos = contextO;

					switch( orientX ){
						case 'right':
							pos.left += contextW + adjust[0];
						break;
						case 'left':
							pos.left -= elemW + adjust[0];
						break;
						case 'center':
							pos.left += (contextW/2) - (elemW/2) + adjust[0];
						break;
						default:
							pos.left += adjust[0];
						break;
					}
					switch( orientY ){
						case 'bottom':
							pos.top += contextH + adjust[1];
						break;
						case 'top':
							pos.top -= elemH + adjust[1];
						break;
						case 'middle':
							pos.top += (contextH/2) - (elemH/2) + adjust[1];
						break;
						default:
							pos.top += adjust[1];
						break;
					}
					elem.css({
						'position':	'absolute',
						'top':		pos.top,
						'left':		pos.left
					});
				});
		}
	});

});

/* ---- Module:ep.ui.tooltip ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.ui.tooltip
 *
 * @revision		$Revision: 1.12 $
 */

jQuery.plugin( 'ep.ui.tooltip', ['ep.core', 'jQuery.ui.widget', 'ep.fn.sprite', 'ep.fn.contextOrientation'], function( $, undefined ){

	var EVENTS = {
			'focus': ['focus.uiTooltip click.uiTooltip','blur.uiTooltip'],
			'click': ['click.uiTooltip'],
			'hover': ['mouseenter.uiTooltip','mouseleave.uiTooltip']
		};

	$.widget( "ep.ui.Tooltip",/* my.parent.widget,*/ {

		options: {
			event:			'hover',
			context:		null,
			interactive:	false,
			orientation:	'',			// can be top,left,right,bottom,center,middle [empty = cursor]
			offsetAdjust:	[0,0],
			addClass:		'',
			showDelay:		200,
			hideDelay:		400,
			closeButton:	false
		},

		_create: function(){
			var o = this.options;

			this.elem = this.element
				.sub(ep)
				.removeClass('HideElement')
				.removeAttr('style');

			// add context + bind events
			this.context = $(o.context);

			// add wrapper around tooltip content
			this.wrap = ep('<div>')
				.addClass('ep-uiTooltip ' + o.addClass)
				.attr( 'style', this.elem.attr('style') || '' )
				.appendTo('body')
				.append(this.elem)
				.hide();

			if( o.closeButton ){
				this.closeButton = ep('<a>')
					.attr({
						'href': 'javascript:void(0)',
						'class': 'ep-uiTooltip-closeButton'
					})
					.text('x')
					.on( 'click', {}, this.Proxy('_hide') )
					.appendTo(this.wrap);
			}
		},

		_init: function(){
			this.wrap.off('.uiTooltip');
			this.context.off('.uiTooltip');

			// dojo.connect(this.contextNode,'onclick',this,'_onClick');
			this.wrap
				.on( 'mouseenter.uiTooltip', $.proxy(this,'_enter') )
				.on( 'mouseleave.uiTooltip', $.proxy(this,'_leave') );

			var e = EVENTS[this.options.event];
			if( e[0] ){
				this.context.on( e[0], $.proxy(this,'_show') );
			}
			if( e[1] ){
				this.context.on( e[1], $.proxy(this,'_hide') );
			}
		},

		_enter: function( event ){
			if( this.options.interactive ){
				this.cursorInside = true;
				this.wrap.stop(true,true);
			}
		},

		_leave: function( event ){
			this.cursorInside = false;
			this.hide();
		},

		_show: function( event, callback ){
			var o = this.options
				context = this.context,
				orient = o.orientation,
				add = o.offsetAdjust;

			if( event instanceof $.Event && !orient && o.event!=='focus' ){
				context = event;
			}
			else if( $.isArray(event) ){
				context = new $.Event({
					pageX: event[0],
					pageY: event[1]
				});
			}

			this.wrap
				.contextOrientation(context,orient,add)
				.stop(true,true)
				.delay(o.showDelay)
				.fadeIn( 'normal', callback );

			this.elem.triggerHandler('show');

			$('html').on( 'mouseup', $.proxy(this,'_hide') );
		},

		show: function(callback){
			this._show( {}, callback );
		},

		_hide: function( event ){
			if( !this.cursorInside || event.data ){
				this.hide();
			}
		},

		hide: function(callback){
			var o = this.options;

			this.wrap
				.stop(true,true)
				.delay( o.interactive ? o.hideDelay+400 : o.hideDelay )
				.fadeOut( 'normal', callback );

			this.elem.triggerHandler('hide');

			$('html').off( 'mouseup', $.proxy(this,'_hide') );
		},

		destroy: function(){
			this.wrap.off('.uiTooltip');
			this.elem.unwrap();
			this.context.off('.uiTooltip');

			$('html').off( 'mouseup', $.proxy(this,'_hide') );

			this.Inherited(arguments);
		}

	});

});


/* ---- Module:jQuery.fn.form ---- */

/*
 * @author			Emanuel Vitzthum
 * @copyright		© 2011 jQuery SDK v1.3.1
 * @info			http://www.jquerysdk.com
 *
 * @license			Dual licensed under the MIT (http://www.opensource.org/licenses/mit-license.php) and GPL (http://www.gnu.org/licenses/gpl.html)
 *
 * @plugin			jQuery.fn.form
 */

jQuery.plugin( 'jQuery.fn.form', 'jQuery.expr', function( $, undefined ){

	var _form = document.createElement('form');

	$.fn.extend({
		// find all associated inputs to the first matched (default selector ":radio")
		formGroup: function( selector ){
			var elem = this.filter( (selector = selector || ':radio') + ':first' )[0] || {},
				name = elem.name,
				form = elem.form,
				owner = elem.ownerDocument,
				elems = [];

			if( name && (form || owner) ){
				$.each( selector = selector.split(','), function( i, sel ){
					selector[i] = $.trim(sel) + "[name='" + name + "']";
				});
				selector = selector.join(',');

				elems = (
						form ?
							$(form).formInput().filter(selector) : 
							$( ':input', owner ).filter(selector).filter(function(){ return !this.form })
					)
					.get();
			}

			return this.pushStack( elems );
		},
		// find all inputs of the the first matched form
		formInput: function(){
			return this.pushStack( (this.filter('form:first')[0] || {}).elements || [] );
		},
		// reset all selected forms or formInputs
		formReset: function(){
			var stack = [],
				form = this
					.filter('form:first'),
				elems = this
					.filter(':input')
					.each(function(){
						var elem = $(this),
							spacer = elem
								.clone()
								.insertAfter(elem);

						_form.appendChild(this);
						stack.push( [ elem, spacer ] );
					});

			// first match form
			if( form.length ){
				form[0].reset();
				form.triggerHandler('reset');
			}

			// matched elements
			_form.reset();

			$.each( stack, function( i, data ){
				var elem = data[0],
					spacer = data[1];

				elem
					.insertBefore(spacer)
					.triggerHandler('reset');
				spacer.remove();
			});

			return this;
		},
		// clear all selected forms or formInputs
		formClear: function(){
			var inputs = $(this);
			
			inputs.push.apply( inputs, inputs.formInput().get()  );
			
			inputs.filter(':file').formReset();
			inputs.filter(':checked').removeProp('checked');
			inputs.not('select,:radio,:checkbox').removeProp('value');
			inputs.find('select').prop('selectedIndex',-1);
			inputs.find('option:selected').removeProp('selected');
			
			return this;
		}
	});

});

/* ---- Module:ep.debug ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.debug
 *
 * @revision		$Revision: 1.5 $
 */

jQuery.plugin( 'ep.debug', 'ep.core', function( $, undefined ){
	// set console (sometimes not set in time and hence throws an error)
	try{
		window.console =			window.console || {};
		window.console.debug =		window.console.debug || function(){return;};
		window.console.log =		window.console.log || function(){return;};
		window.console.warn =		window.console.warn || function(){return;};
	}
	catch(error){
	}
	if(ep.config && !ep.config.debugLevel){
		if(window.console){
			window.console.debug = function(){
				return;
			};
			window.console.log = function(){
				return;
			};
			window.console.warn = function(){
				return;
			};
		}
	}
	ep.extend( $.scope('ep.debug'),{
		statistic: function(/*string*/statId, /*func*/statFunc){
			var stats = ep.debug.statistic.data;
			if(arguments.length){
				//if there are arguments we take the statistic for a function
				var startTime = new Date();
				ep.debug.statistic.isRunning = true;
				statFunc();
				ep.debug.statistic.isRunning = false;

				var runningTime = new Date() - startTime;
				// sum, count, min, max, innersum
				if(!stats[statId]){
					stats[statId] = {
						"sum"      : 0,
						"count"    : 0,
						"min"      : 0,
						"max"      : 0,
						"innersum" : 0
					};
				}
				var currentStat = stats[statId];
				if(ep.debug.statistic.isRunning){
					currentStat.innersum += runningTime;
				}
				else{
					currentStat.sum += runningTime;
				}
				currentStat.count++;
				if(runningTime > currentStat.max){
					currentStat.max = runningTime;
				}
				if(runningTime < currentStat.min){
					currentStat.min = runningTime;
		}
			}
			else{
				//if there are no arguments we print the statistic to the console
				var sum = 0;
				console['log']('print statistic');
				$.each(stats,function(index,value){
					console['log']('statistic for id:',
						index,': sum: ',stats[index].sum,
						': count: ',stats[index].count,
						': min: ',stats[index].min,
						': max: ',stats[index].max,
						': innersum: ',stats[index].innersum);
				});
			}
		}
	});

	ep.extend(ep.debug.statistic,{
		data: {}, //define data-object for statistic function
		isRunning: false
	});

});

/* ---- Module:ep.ui.form ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.ui.form
 *
 * @revision		$Revision: 1.13.8.1 $
 */

jQuery.plugin( 'ep.ui.form', ['ep.core', 'ep.ajax', 'jQuery.fn.form', 'jQuery.ui.widget'], function( $, undefined ){

	$.widget('ep.ui.Form',{

		options: {
			compareDiff: false
		},

		_create: function(){
			this.elem = this.element.sub(ep);

			this.timeStamp = $.now();
		},

		_init: function(){
			this.elem
				.off('.uiForm')
				.on( 'submit.uiForm', this.Proxy('_submit') )
				.on( 'validate.uiForm', this.Proxy('_validate') )
				.on( 'reset.uiForm', this.Proxy('_reset') );
		},

		_validate: function(event){
			if( !this.elem.attr('formnovalidate') && event.target === this.elem[0] ){
				var elems = this.elem
					.formInput()
					.trigger('validate')
					.filter(':invalid:first')
					.focus()
					.trigger('validate');
			}
		},

		isValid: function(){
			return !this.elem[0].formInvalid;
		},

		setValid: function( stat ){
			this.elem[0].formInvalid = !stat;
		},

		_isValid: function( elems ){
			var valid = !elems
				.filter(':invalid')
				.length;

			this.elem[0].formInvalid = !valid;

			return valid;
		},

		_isChanged: function( elems ){
			return !!elems
				.filter(':changed')
				.length;
		},

		_submitCheck: function( event ){
			if( event.isDefaultPrevented() ){
				this.elem.trigger('submitFail');
			}
			this.elem.off('submit.uiForm', this.Proxy('_submitCheck'));
		},

		_submit: function( event ){
			// control last event handle of submit call
			if( !event.uiFormTriggert ){
				event.stopImmediatePropagation();
				event.preventDefault();
				// save autocomplete for IE
				if( window.external && typeof window.external.AutoCompleteSaveForm  === 'function'){
					window.external.AutoCompleteSaveForm(this.elem[0]);
				}
				this.elem
					.on('submit.uiForm', this.Proxy('_submitCheck'))
					.trigger({ type:'submit', uiFormTriggert:true });
				return;
			}

			// trigger validation
			this.elem.trigger('validate');

			var valid = this._isValid( this.elem.formInput() ),
				action = this.elem.attr('action'),
				ajax = this.options.ajax;

			if( !action || !valid || ajax || (event.timeStamp - this.timeStamp)<300 ){
				event.preventDefault();
			}
			this.timeStamp = event.timeStamp;

			if( !valid ){
				return;
			}

			if( ajax ){
				ep.ajax(
					$.extend(true,{
						url:		this.elem.attr('action') || '',
						type:	this.elem.attr('method') || 'post',
						data:		this.elem.serializeArray()
					},ajax)
				);
			}
		},

		_reset: function( event ){
			this.elem
					.formInput()
					.each(function(){
						$(this).triggerHandler('reset');
					});
		}

	});

});


/* ---- Module:jQuery.ui.core ---- */

/*!
 * jQuery UI 1.8.18
 *
 * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * http://docs.jquery.com/UI
 */
jQuery.plugin( 'jQuery.ui.core', function( $, undefined ){

// prevent duplicate loading
// this is only a problem because we proxy existing functions
// and we don't want to double proxy them
$.ui = $.ui || {};
if ( $.ui.version ) {
	return;
}

$.extend( $.ui, {
	version: "1.8.18",

	keyCode: {
		ALT: 18,
		BACKSPACE: 8,
		CAPS_LOCK: 20,
		COMMA: 188,
		COMMAND: 91,
		COMMAND_LEFT: 91, // COMMAND
		COMMAND_RIGHT: 93,
		CONTROL: 17,
		DELETE: 46,
		DOWN: 40,
		END: 35,
		ENTER: 13,
		ESCAPE: 27,
		HOME: 36,
		INSERT: 45,
		LEFT: 37,
		MENU: 93, // COMMAND_RIGHT
		NUMPAD_ADD: 107,
		NUMPAD_DECIMAL: 110,
		NUMPAD_DIVIDE: 111,
		NUMPAD_ENTER: 108,
		NUMPAD_MULTIPLY: 106,
		NUMPAD_SUBTRACT: 109,
		PAGE_DOWN: 34,
		PAGE_UP: 33,
		PERIOD: 190,
		RIGHT: 39,
		SHIFT: 16,
		SPACE: 32,
		TAB: 9,
		UP: 38,
		WINDOWS: 91 // COMMAND
	}
});

// plugins
$.fn.extend({
	propAttr: $.fn.prop || $.fn.attr,

	_focus: $.fn.focus,
	focus: function( delay, fn ) {
		return typeof delay === "number" ?
			this.each(function() {
				var elem = this;
				setTimeout(function() {
					$( elem ).focus();
					if ( fn ) {
						fn.call( elem );
					}
				}, delay );
			}) :
			this._focus.apply( this, arguments );
	},

	scrollParent: function() {
		var scrollParent;
		if (($.browser.msie && (/(static|relative)/).test(this.css('position'))) || (/absolute/).test(this.css('position'))) {
			scrollParent = this.parents().filter(function() {
				return (/(relative|absolute|fixed)/).test($.curCSS(this,'position',1)) && (/(auto|scroll)/).test($.curCSS(this,'overflow',1)+$.curCSS(this,'overflow-y',1)+$.curCSS(this,'overflow-x',1));
			}).eq(0);
		} else {
			scrollParent = this.parents().filter(function() {
				return (/(auto|scroll)/).test($.curCSS(this,'overflow',1)+$.curCSS(this,'overflow-y',1)+$.curCSS(this,'overflow-x',1));
			}).eq(0);
		}

		return (/fixed/).test(this.css('position')) || !scrollParent.length ? $(document) : scrollParent;
	},

	zIndex: function( zIndex ) {
		if ( zIndex !== undefined ) {
			return this.css( "zIndex", zIndex );
		}

		if ( this.length ) {
			var elem = $( this[ 0 ] ), position, value;
			while ( elem.length && elem[ 0 ] !== document ) {
				// Ignore z-index if position is set to a value where z-index is ignored by the browser
				// This makes behavior of this function consistent across browsers
				// WebKit always returns auto if the element is positioned
				position = elem.css( "position" );
				if ( position === "absolute" || position === "relative" || position === "fixed" ) {
					// IE returns 0 when zIndex is not specified
					// other browsers return a string
					// we ignore the case of nested elements with an explicit value of 0
					// <div style="z-index: -10;"><div style="z-index: 0;"></div></div>
					value = parseInt( elem.css( "zIndex" ), 10 );
					if ( !isNaN( value ) && value !== 0 ) {
						return value;
					}
				}
				elem = elem.parent();
			}
		}

		return 0;
	},

	disableSelection: function() {
		return this.bind( ( $.support.selectstart ? "selectstart" : "mousedown" ) +
			".ui-disableSelection", function( event ) {
				event.preventDefault();
			});
	},

	enableSelection: function() {
		return this.unbind( ".ui-disableSelection" );
	}
});

$.each( [ "Width", "Height" ], function( i, name ) {
	var side = name === "Width" ? [ "Left", "Right" ] : [ "Top", "Bottom" ],
		type = name.toLowerCase(),
		orig = {
			innerWidth: $.fn.innerWidth,
			innerHeight: $.fn.innerHeight,
			outerWidth: $.fn.outerWidth,
			outerHeight: $.fn.outerHeight
		};

	function reduce( elem, size, border, margin ) {
		$.each( side, function() {
			size -= parseFloat( $.curCSS( elem, "padding" + this, true) ) || 0;
			if ( border ) {
				size -= parseFloat( $.curCSS( elem, "border" + this + "Width", true) ) || 0;
			}
			if ( margin ) {
				size -= parseFloat( $.curCSS( elem, "margin" + this, true) ) || 0;
			}
		});
		return size;
	}

	$.fn[ "inner" + name ] = function( size ) {
		if ( size === undefined ) {
			return orig[ "inner" + name ].call( this );
		}

		return this.each(function() {
			$( this ).css( type, reduce( this, size ) + "px" );
		});
	};

	$.fn[ "outer" + name] = function( size, margin ) {
		if ( typeof size !== "number" ) {
			return orig[ "outer" + name ].call( this, size );
		}

		return this.each(function() {
			$( this).css( type, reduce( this, size, true, margin ) + "px" );
		});
	};
});

// selectors
function focusable( element, isTabIndexNotNaN ) {
	var nodeName = element.nodeName.toLowerCase();
	if ( "area" === nodeName ) {
		var map = element.parentNode,
			mapName = map.name,
			img;
		if ( !element.href || !mapName || map.nodeName.toLowerCase() !== "map" ) {
			return false;
		}
		img = $( "img[usemap=#" + mapName + "]" )[0];
		return !!img && visible( img );
	}
	return ( /input|select|textarea|button|object/.test( nodeName )
		? !element.disabled
		: "a" == nodeName
			? element.href || isTabIndexNotNaN
			: isTabIndexNotNaN)
		// the element and all of its ancestors must be visible
		&& visible( element );
}

function visible( element ) {
	return !$( element ).parents().andSelf().filter(function() {
		return $.curCSS( this, "visibility" ) === "hidden" ||
			$.expr.filters.hidden( this );
	}).length;
}

$.extend( $.expr[ ":" ], {
	data: function( elem, i, match ) {
		return !!$.data( elem, match[ 3 ] );
	},

	focusable: function( element ) {
		return focusable( element, !isNaN( $.attr( element, "tabindex" ) ) );
	},

	tabbable: function( element ) {
		var tabIndex = $.attr( element, "tabindex" ),
			isTabIndexNaN = isNaN( tabIndex );
		return ( isTabIndexNaN || tabIndex >= 0 ) && focusable( element, !isTabIndexNaN );
	}
});

// support
$(function() {
	var body = document.body,
		div = body.appendChild( div = document.createElement( "div" ) );

	// access offsetHeight before setting the style to prevent a layout bug
	// in IE 9 which causes the elemnt to continue to take up space even
	// after it is removed from the DOM (#8026)
	div.offsetHeight;

	$.extend( div.style, {
		minHeight: "100px",
		height: "auto",
		padding: 0,
		borderWidth: 0
	});

	$.support.minHeight = div.offsetHeight === 100;
	$.support.selectstart = "onselectstart" in div;

	// set display to none to avoid a layout bug in IE
	// http://dev.jquery.com/ticket/4014
	body.removeChild( div ).style.display = "none";
});





// deprecated
$.extend( $.ui, {
	// $.ui.plugin is deprecated.  Use the proxy pattern instead.
	plugin: {
		add: function( module, option, set ) {
			var proto = $.ui[ module ].prototype;
			for ( var i in set ) {
				proto.plugins[ i ] = proto.plugins[ i ] || [];
				proto.plugins[ i ].push( [ option, set[ i ] ] );
			}
		},
		call: function( instance, name, args ) {
			var set = instance.plugins[ name ];
			if ( !set || !instance.element[ 0 ].parentNode ) {
				return;
			}
	
			for ( var i = 0; i < set.length; i++ ) {
				if ( instance.options[ set[ i ][ 0 ] ] ) {
					set[ i ][ 1 ].apply( instance.element, args );
				}
			}
		}
	},
	
	// will be deprecated when we switch to jQuery 1.4 - use jQuery.contains()
	contains: function( a, b ) {
		return document.compareDocumentPosition ?
			a.compareDocumentPosition( b ) & 16 :
			a !== b && a.contains( b );
	},
	
	// only used by resizable
	hasScroll: function( el, a ) {
	
		//If overflow is hidden, the element might have extra content, but the user wants to hide it
		if ( $( el ).css( "overflow" ) === "hidden") {
			return false;
		}
	
		var scroll = ( a && a === "left" ) ? "scrollLeft" : "scrollTop",
			has = false;
	
		if ( el[ scroll ] > 0 ) {
			return true;
		}
	
		// TODO: determine which cases actually cause this to happen
		// if the element doesn't have the scroll set, see if it's possible to
		// set the scroll
		el[ scroll ] = 1;
		has = ( el[ scroll ] > 0 );
		el[ scroll ] = 0;
		return has;
	},
	
	// these are odd functions, fix the API or move into individual plugins
	isOverAxis: function( x, reference, size ) {
		//Determines when x coordinate is over "b" element axis
		return ( x > reference ) && ( x < ( reference + size ) );
	},
	isOver: function( y, x, top, left, height, width ) {
		//Determines when x, y coordinates is over "b" element
		return $.ui.isOverAxis( y, top, height ) && $.ui.isOverAxis( x, left, width );
	}
});

});


/* ---- Module:jQuery.ui.mouse ---- */

/*!
 * jQuery UI Mouse 1.8.18
 *
 * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * http://docs.jquery.com/UI/Mouse
 *
 * Depends:
 *	jquery.ui.widget.js
 */

jQuery.plugin( 'jQuery.ui.mouse', 'jQuery.ui.widget', function( $, undefined ){

var mouseHandled = false;
$( document ).mouseup( function( e ) {
	mouseHandled = false;
});

$.widget("ui.mouse", {
	options: {
		cancel: ':input,option',
		distance: 1,
		delay: 0
	},
	_mouseInit: function() {
		var self = this;

		this.element
			.on('mousedown.'+this.widgetName, function(event) {
				return self._mouseDown(event);
			})
			.on('click.'+this.widgetName, function(event) {
				if (true === $.data(event.target, self.widgetName + '.preventClickEvent')) {
				    $.removeData(event.target, self.widgetName + '.preventClickEvent');
					event.stopImmediatePropagation();
					return false;
				}
			});

		this.started = false;
	},

	// TODO: make sure destroying one instance of mouse doesn't mess with
	// other instances of mouse
	_mouseDestroy: function() {
		this.element.off('.'+this.widgetName);
	},

	_mouseDown: function(event) {
		// don't let more than one widget handle mouseStart
		if( mouseHandled ) { return };

		// we may have missed mouseup (out of window)
		(this._mouseStarted && this._mouseUp(event));

		this._mouseDownEvent = event;

		var self = this,
			btnIsLeft = (event.which == 1),
			// event.target.nodeName works around a bug in IE 8 with
			// disabled inputs (#7620)
			elIsCancel = (typeof this.options.cancel == "string" && event.target.nodeName ? $(event.target).closest(this.options.cancel).length : false);
		if (!btnIsLeft || elIsCancel || !this._mouseCapture(event)) {
			return true;
		}

		this.mouseDelayMet = !this.options.delay;
		if (!this.mouseDelayMet) {
			this._mouseDelayTimer = setTimeout(function() {
				self.mouseDelayMet = true;
			}, this.options.delay);
		}

		if (this._mouseDistanceMet(event) && this._mouseDelayMet(event)) {
			this._mouseStarted = (this._mouseStart(event) !== false);
			if (!this._mouseStarted) {
				event.preventDefault();
				return true;
			}
		}

		// Click event may never have fired (Gecko & Opera)
		if (true === $.data(event.target, this.widgetName + '.preventClickEvent')) {
			$.removeData(event.target, this.widgetName + '.preventClickEvent');
		}

		// these delegates are required to keep context
		this._mouseMoveDelegate = function(event) {
			return self._mouseMove(event);
		};
		this._mouseUpDelegate = function(event) {
			return self._mouseUp(event);
		};
		$(document)
			.on('mousemove.'+this.widgetName, this._mouseMoveDelegate)
			.on('mouseup.'+this.widgetName, this._mouseUpDelegate);

		event.preventDefault();
		
		mouseHandled = true;
		return true;
	},

	_mouseMove: function(event) {
		// IE mouseup check - mouseup happened when mouse was out of window
		if ($.browser.msie && !(document.documentMode >= 9) && !event.button) {
			return this._mouseUp(event);
		}

		if (this._mouseStarted) {
			this._mouseDrag(event);
			return event.preventDefault();
		}

		if (this._mouseDistanceMet(event) && this._mouseDelayMet(event)) {
			this._mouseStarted =
				(this._mouseStart(this._mouseDownEvent, event) !== false);
			(this._mouseStarted ? this._mouseDrag(event) : this._mouseUp(event));
		}

		return !this._mouseStarted;
	},

	_mouseUp: function(event) {
		$(document)
			.off('mousemove.'+this.widgetName, this._mouseMoveDelegate)
			.off('mouseup.'+this.widgetName, this._mouseUpDelegate);

		if (this._mouseStarted) {
			this._mouseStarted = false;

			if (event.target == this._mouseDownEvent.target) {
			    $.data(event.target, this.widgetName + '.preventClickEvent', true);
			}

			this._mouseStop(event);
		}

		return false;
	},

	_mouseDistanceMet: function(event) {
		return (Math.max(
				Math.abs(this._mouseDownEvent.pageX - event.pageX),
				Math.abs(this._mouseDownEvent.pageY - event.pageY)
			) >= this.options.distance
		);
	},

	_mouseDelayMet: function(event) {
		return this.mouseDelayMet;
	},

	// These are placeholder methods, to be overriden by extending plugin
	_mouseStart: function(event) {},
	_mouseDrag: function(event) {},
	_mouseStop: function(event) {},
	_mouseCapture: function(event) { return true; }
});

});


/* ---- Module:jQuery.effects.core ---- */

/*
 * jQuery UI Effects 1.8.18
 *
 * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * http://docs.jquery.com/UI/Effects/
 */
jQuery.plugin( 'jQuery.effects.core', function( $, undefined ){

$.effects = {};



/******************************************************************************/
/****************************** COLOR ANIMATIONS ******************************/
/******************************************************************************/

// override the animation for color styles
$.each(['backgroundColor', 'borderBottomColor', 'borderLeftColor',
	'borderRightColor', 'borderTopColor', 'borderColor', 'color', 'outlineColor'],
function(i, attr) {
	$.fx.step[attr] = function(fx) {
		if (!fx.colorInit) {
			fx.start = getColor(fx.elem, attr);
			fx.end = getRGB(fx.end);
			fx.colorInit = true;
		}

		fx.elem.style[attr] = 'rgb(' +
			Math.max(Math.min(parseInt((fx.pos * (fx.end[0] - fx.start[0])) + fx.start[0], 10), 255), 0) + ',' +
			Math.max(Math.min(parseInt((fx.pos * (fx.end[1] - fx.start[1])) + fx.start[1], 10), 255), 0) + ',' +
			Math.max(Math.min(parseInt((fx.pos * (fx.end[2] - fx.start[2])) + fx.start[2], 10), 255), 0) + ')';
	};
});

// Color Conversion functions from highlightFade
// By Blair Mitchelmore
// http://jquery.offput.ca/highlightFade/

// Parse strings looking for color tuples [255,255,255]
function getRGB(color) {
		var result;

		// Check if we're already dealing with an array of colors
		if ( color && color.constructor == Array && color.length == 3 )
				return color;

		// Look for rgb(num,num,num)
		if (result = /rgb\(\s*([0-9]{1,3})\s*,\s*([0-9]{1,3})\s*,\s*([0-9]{1,3})\s*\)/.exec(color))
				return [parseInt(result[1],10), parseInt(result[2],10), parseInt(result[3],10)];

		// Look for rgb(num%,num%,num%)
		if (result = /rgb\(\s*([0-9]+(?:\.[0-9]+)?)\%\s*,\s*([0-9]+(?:\.[0-9]+)?)\%\s*,\s*([0-9]+(?:\.[0-9]+)?)\%\s*\)/.exec(color))
				return [parseFloat(result[1])*2.55, parseFloat(result[2])*2.55, parseFloat(result[3])*2.55];

		// Look for #a0b1c2
		if (result = /#([a-fA-F0-9]{2})([a-fA-F0-9]{2})([a-fA-F0-9]{2})/.exec(color))
				return [parseInt(result[1],16), parseInt(result[2],16), parseInt(result[3],16)];

		// Look for #fff
		if (result = /#([a-fA-F0-9])([a-fA-F0-9])([a-fA-F0-9])/.exec(color))
				return [parseInt(result[1]+result[1],16), parseInt(result[2]+result[2],16), parseInt(result[3]+result[3],16)];

		// Look for rgba(0, 0, 0, 0) == transparent in Safari 3
		if (result = /rgba\(0, 0, 0, 0\)/.exec(color))
				return colors['transparent'];

		// Otherwise, we're most likely dealing with a named color
		return colors[$.trim(color).toLowerCase()];
}

function getColor(elem, attr) {
		var color;

		do {
				color = $.curCSS(elem, attr);

				// Keep going until we find an element that has color, or we hit the body
				if ( color != '' && color != 'transparent' || $.nodeName(elem, "body") )
						break;

				attr = "backgroundColor";
		} while ( elem = elem.parentNode );

		return getRGB(color);
};

// Some named colors to work with
// From Interface by Stefan Petre
// http://interface.eyecon.ro/

var colors = {
	aqua:[0,255,255],
	azure:[240,255,255],
	beige:[245,245,220],
	black:[0,0,0],
	blue:[0,0,255],
	brown:[165,42,42],
	cyan:[0,255,255],
	darkblue:[0,0,139],
	darkcyan:[0,139,139],
	darkgrey:[169,169,169],
	darkgreen:[0,100,0],
	darkkhaki:[189,183,107],
	darkmagenta:[139,0,139],
	darkolivegreen:[85,107,47],
	darkorange:[255,140,0],
	darkorchid:[153,50,204],
	darkred:[139,0,0],
	darksalmon:[233,150,122],
	darkviolet:[148,0,211],
	fuchsia:[255,0,255],
	gold:[255,215,0],
	green:[0,128,0],
	indigo:[75,0,130],
	khaki:[240,230,140],
	lightblue:[173,216,230],
	lightcyan:[224,255,255],
	lightgreen:[144,238,144],
	lightgrey:[211,211,211],
	lightpink:[255,182,193],
	lightyellow:[255,255,224],
	lime:[0,255,0],
	magenta:[255,0,255],
	maroon:[128,0,0],
	navy:[0,0,128],
	olive:[128,128,0],
	orange:[255,165,0],
	pink:[255,192,203],
	purple:[128,0,128],
	violet:[128,0,128],
	red:[255,0,0],
	silver:[192,192,192],
	white:[255,255,255],
	yellow:[255,255,0],
	transparent: [255,255,255]
};



/******************************************************************************/
/****************************** CLASS ANIMATIONS ******************************/
/******************************************************************************/

var classAnimationActions = ['add', 'remove', 'toggle'],
	shorthandStyles = {
		border: 1,
		borderBottom: 1,
		borderColor: 1,
		borderLeft: 1,
		borderRight: 1,
		borderTop: 1,
		borderWidth: 1,
		margin: 1,
		padding: 1
	};

function getElementStyles() {
	var style = document.defaultView
			? document.defaultView.getComputedStyle(this, null)
			: this.currentStyle,
		newStyle = {},
		key,
		camelCase;

	// webkit enumerates style porperties
	if (style && style.length && style[0] && style[style[0]]) {
		var len = style.length;
		while (len--) {
			key = style[len];
			if (typeof style[key] == 'string') {
				camelCase = key.replace(/\-(\w)/g, function(all, letter){
					return letter.toUpperCase();
				});
				newStyle[camelCase] = style[key];
			}
		}
	} else {
		for (key in style) {
			if (typeof style[key] === 'string') {
				newStyle[key] = style[key];
			}
		}
	}
	
	return newStyle;
}

function filterStyles(styles) {
	var name, value;
	for (name in styles) {
		value = styles[name];
		if (
			// ignore null and undefined values
			value == null ||
			// ignore functions (when does this occur?)
			$.isFunction(value) ||
			// shorthand styles that need to be expanded
			name in shorthandStyles ||
			// ignore scrollbars (break in IE)
			(/scrollbar/).test(name) ||

			// only colors or values that can be converted to numbers
			(!(/color/i).test(name) && isNaN(parseFloat(value)))
		) {
			delete styles[name];
		}
	}
	
	return styles;
}

function styleDifference(oldStyle, newStyle) {
	var diff = { _: 0 }, // http://dev.jquery.com/ticket/5459
		name;

	for (name in newStyle) {
		if (oldStyle[name] != newStyle[name]) {
			diff[name] = newStyle[name];
		}
	}

	return diff;
}

$.effects.animateClass = function(value, duration, easing, callback) {
	if ($.isFunction(easing)) {
		callback = easing;
		easing = null;
	}

	return this.queue(function() {
		var that = $(this),
			originalStyleAttr = that.attr('style') || ' ',
			originalStyle = filterStyles(getElementStyles.call(this)),
			newStyle,
			className = that.attr('class');

		$.each(classAnimationActions, function(i, action) {
			if (value[action]) {
				that[action + 'Class'](value[action]);
			}
		});
		newStyle = filterStyles(getElementStyles.call(this));
		that.attr('class', className);

		that.animate(styleDifference(originalStyle, newStyle), {
			queue: false,
			duration: duration,
			easing: easing,
			complete: function() {
				$.each(classAnimationActions, function(i, action) {
					if (value[action]) { that[action + 'Class'](value[action]); }
				});
				// work around bug in IE by clearing the cssText before setting it
				if (typeof that.attr('style') == 'object') {
					that.attr('style').cssText = '';
					that.attr('style').cssText = originalStyleAttr;
				} else {
					that.attr('style', originalStyleAttr);
				}
				if (callback) { callback.apply(this, arguments); }
				$.dequeue( this );
			}
		});
	});
};

$.fn.extend({
	_addClass: $.fn.addClass,
	addClass: function(classNames, speed, easing, callback) {
		return speed ? $.effects.animateClass.apply(this, [{ add: classNames },speed,easing,callback]) : this._addClass(classNames);
	},

	_removeClass: $.fn.removeClass,
	removeClass: function(classNames,speed,easing,callback) {
		return speed ? $.effects.animateClass.apply(this, [{ remove: classNames },speed,easing,callback]) : this._removeClass(classNames);
	},

	_toggleClass: $.fn.toggleClass,
	toggleClass: function(classNames, force, speed, easing, callback) {
		if ( typeof force == "boolean" || force === undefined ) {
			if ( !speed ) {
				// without speed parameter;
				return this._toggleClass(classNames, force);
			} else {
				return $.effects.animateClass.apply(this, [(force?{add:classNames}:{remove:classNames}),speed,easing,callback]);
			}
		} else {
			// without switch parameter;
			return $.effects.animateClass.apply(this, [{ toggle: classNames },force,speed,easing]);
		}
	},

	switchClass: function(remove,add,speed,easing,callback) {
		return $.effects.animateClass.apply(this, [{ add: add, remove: remove },speed,easing,callback]);
	}
});



/******************************************************************************/
/*********************************** EFFECTS **********************************/
/******************************************************************************/

$.extend($.effects, {
	version: "1.8.18",

	// Saves a set of properties in a data storage
	save: function(element, set) {
		for(var i=0; i < set.length; i++) {
			if(set[i] !== null) element.data("ec.storage."+set[i], element[0].style[set[i]]);
		}
	},

	// Restores a set of previously saved properties from a data storage
	restore: function(element, set) {
		for(var i=0; i < set.length; i++) {
			if(set[i] !== null) element.css(set[i], element.data("ec.storage."+set[i]));
		}
	},

	setMode: function(el, mode) {
		if (mode == 'toggle') mode = el.is(':hidden') ? 'show' : 'hide'; // Set for toggle
		return mode;
	},

	getBaseline: function(origin, original) { // Translates a [top,left] array into a baseline value
		// this should be a little more flexible in the future to handle a string & hash
		var y, x;
		switch (origin[0]) {
			case 'top': y = 0; break;
			case 'middle': y = 0.5; break;
			case 'bottom': y = 1; break;
			default: y = origin[0] / original.height;
		};
		switch (origin[1]) {
			case 'left': x = 0; break;
			case 'center': x = 0.5; break;
			case 'right': x = 1; break;
			default: x = origin[1] / original.width;
		};
		return {x: x, y: y};
	},

	// Wraps the element around a wrapper that copies position properties
	createWrapper: function(element) {

		// if the element is already wrapped, return it
		if (element.parent().is('.ui-effects-wrapper')) {
			return element.parent();
		}

		// wrap the element
		var props = {
				width: element.outerWidth(true),
				height: element.outerHeight(true),
				'float': element.css('float')
			},
			wrapper = $('<div></div>')
				.addClass('ui-effects-wrapper')
				.css({
					fontSize: '100%',
					background: 'transparent',
					border: 'none',
					margin: 0,
					padding: 0
				}),
			active = document.activeElement;

		element.wrap(wrapper);

		// Fixes #7595 - Elements lose focus when wrapped.
		if ( element[ 0 ] === active || $.contains( element[ 0 ], active ) ) {
			$( active ).focus();
		}
		
		wrapper = element.parent(); //Hotfix for jQuery 1.4 since some change in wrap() seems to actually loose the reference to the wrapped element

		// transfer positioning properties to the wrapper
		if (element.css('position') == 'static') {
			wrapper.css({ position: 'relative' });
			element.css({ position: 'relative' });
		} else {
			$.extend(props, {
				position: element.css('position'),
				zIndex: element.css('z-index')
			});
			$.each(['top', 'left', 'bottom', 'right'], function(i, pos) {
				props[pos] = element.css(pos);
				if (isNaN(parseInt(props[pos], 10))) {
					props[pos] = 'auto';
				}
			});
			element.css({position: 'relative', top: 0, left: 0, right: 'auto', bottom: 'auto' });
		}

		return wrapper.css(props).show();
	},

	removeWrapper: function(element) {
		var parent,
			active = document.activeElement;
		
		if (element.parent().is('.ui-effects-wrapper')) {
			parent = element.parent().replaceWith(element);
			// Fixes #7595 - Elements lose focus when wrapped.
			if ( element[ 0 ] === active || $.contains( element[ 0 ], active ) ) {
				$( active ).focus();
			}
			return parent;
		}
			
		return element;
	},

	setTransition: function(element, list, factor, value) {
		value = value || {};
		$.each(list, function(i, x){
			unit = element.cssUnit(x);
			if (unit[0] > 0) value[x] = unit[0] * factor + unit[1];
		});
		return value;
	}
});


function _normalizeArguments(effect, options, speed, callback) {
	// shift params for method overloading
	if (typeof effect == 'object') {
		callback = options;
		speed = null;
		options = effect;
		effect = options.effect;
	}
	if ($.isFunction(options)) {
		callback = options;
		speed = null;
		options = {};
	}
        if (typeof options == 'number' || $.fx.speeds[options]) {
		callback = speed;
		speed = options;
		options = {};
	}
	if ($.isFunction(speed)) {
		callback = speed;
		speed = null;
	}

	options = options || {};

	speed = speed || options.duration;
	speed = $.fx.off ? 0 : typeof speed == 'number'
		? speed : speed in $.fx.speeds ? $.fx.speeds[speed] : $.fx.speeds._default;

	callback = callback || options.complete;

	return [effect, options, speed, callback];
}

function standardSpeed( speed ) {
	// valid standard speeds
	if ( !speed || typeof speed === "number" || $.fx.speeds[ speed ] ) {
		return true;
	}
	
	// invalid strings - treat as "normal" speed
	if ( typeof speed === "string" && !$.effects[ speed ] ) {
		return true;
	}
	
	return false;
}

$.fn.extend({
	effect: function(effect, options, speed, callback) {
		var args = _normalizeArguments.apply(this, arguments),
			// TODO: make effects take actual parameters instead of a hash
			args2 = {
				options: args[1],
				duration: args[2],
				callback: args[3]
			},
			mode = args2.options.mode,
			effectMethod = $.effects[effect];
		
		if ( $.fx.off || !effectMethod ) {
			// delegate to the original method (e.g., .show()) if possible
			if ( mode ) {
				return this[ mode ]( args2.duration, args2.callback );
			} else {
				return this.each(function() {
					if ( args2.callback ) {
						args2.callback.call( this );
					}
				});
			}
		}
		
		return effectMethod.call(this, args2);
	},

	_show: $.fn.show,
	show: function(speed) {
		if ( standardSpeed( speed ) ) {
			return this._show.apply(this, arguments);
		} else {
			var args = _normalizeArguments.apply(this, arguments);
			args[1].mode = 'show';
			return this.effect.apply(this, args);
		}
	},

	_hide: $.fn.hide,
	hide: function(speed) {
		if ( standardSpeed( speed ) ) {
			return this._hide.apply(this, arguments);
		} else {
			var args = _normalizeArguments.apply(this, arguments);
			args[1].mode = 'hide';
			return this.effect.apply(this, args);
		}
	},

	// jQuery core overloads toggle and creates _toggle
	__toggle: $.fn.toggle,
	toggle: function(speed) {
		if ( standardSpeed( speed ) || typeof speed === "boolean" || $.isFunction( speed ) ) {
			return this.__toggle.apply(this, arguments);
		} else {
			var args = _normalizeArguments.apply(this, arguments);
			args[1].mode = 'toggle';
			return this.effect.apply(this, args);
		}
	},

	// helper functions
	cssUnit: function(key) {
		var style = this.css(key), val = [];
		$.each( ['em','px','%','pt'], function(i, unit){
			if(style.indexOf(unit) > 0)
				val = [parseFloat(style), unit];
		});
		return val;
	}
});



/******************************************************************************/
/*********************************** EASING ***********************************/
/******************************************************************************/

/*
 * jQuery Easing v1.3 - http://gsgd.co.uk/sandbox/jquery/easing/
 *
 * Uses the built in easing capabilities added In jQuery 1.1
 * to offer multiple easing options
 *
 * TERMS OF USE - jQuery Easing
 *
 * Open source under the BSD License.
 *
 * Copyright 2008 George McGinley Smith
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice, this list of
 * conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright notice, this list
 * of conditions and the following disclaimer in the documentation and/or other materials
 * provided with the distribution.
 *
 * Neither the name of the author nor the names of contributors may be used to endorse
 * or promote products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/

// t: current time, b: begInnIng value, c: change In value, d: duration
$.easing.jswing = $.easing.swing;

$.extend($.easing,
{
	def: 'easeOutQuad',
	swing: function (x, t, b, c, d) {
		//alert($.easing.default);
		return $.easing[$.easing.def](x, t, b, c, d);
	},
	easeInQuad: function (x, t, b, c, d) {
		return c*(t/=d)*t + b;
	},
	easeOutQuad: function (x, t, b, c, d) {
		return -c *(t/=d)*(t-2) + b;
	},
	easeInOutQuad: function (x, t, b, c, d) {
		if ((t/=d/2) < 1) return c/2*t*t + b;
		return -c/2 * ((--t)*(t-2) - 1) + b;
	},
	easeInCubic: function (x, t, b, c, d) {
		return c*(t/=d)*t*t + b;
	},
	easeOutCubic: function (x, t, b, c, d) {
		return c*((t=t/d-1)*t*t + 1) + b;
	},
	easeInOutCubic: function (x, t, b, c, d) {
		if ((t/=d/2) < 1) return c/2*t*t*t + b;
		return c/2*((t-=2)*t*t + 2) + b;
	},
	easeInQuart: function (x, t, b, c, d) {
		return c*(t/=d)*t*t*t + b;
	},
	easeOutQuart: function (x, t, b, c, d) {
		return -c * ((t=t/d-1)*t*t*t - 1) + b;
	},
	easeInOutQuart: function (x, t, b, c, d) {
		if ((t/=d/2) < 1) return c/2*t*t*t*t + b;
		return -c/2 * ((t-=2)*t*t*t - 2) + b;
	},
	easeInQuint: function (x, t, b, c, d) {
		return c*(t/=d)*t*t*t*t + b;
	},
	easeOutQuint: function (x, t, b, c, d) {
		return c*((t=t/d-1)*t*t*t*t + 1) + b;
	},
	easeInOutQuint: function (x, t, b, c, d) {
		if ((t/=d/2) < 1) return c/2*t*t*t*t*t + b;
		return c/2*((t-=2)*t*t*t*t + 2) + b;
	},
	easeInSine: function (x, t, b, c, d) {
		return -c * Math.cos(t/d * (Math.PI/2)) + c + b;
	},
	easeOutSine: function (x, t, b, c, d) {
		return c * Math.sin(t/d * (Math.PI/2)) + b;
	},
	easeInOutSine: function (x, t, b, c, d) {
		return -c/2 * (Math.cos(Math.PI*t/d) - 1) + b;
	},
	easeInExpo: function (x, t, b, c, d) {
		return (t==0) ? b : c * Math.pow(2, 10 * (t/d - 1)) + b;
	},
	easeOutExpo: function (x, t, b, c, d) {
		return (t==d) ? b+c : c * (-Math.pow(2, -10 * t/d) + 1) + b;
	},
	easeInOutExpo: function (x, t, b, c, d) {
		if (t==0) return b;
		if (t==d) return b+c;
		if ((t/=d/2) < 1) return c/2 * Math.pow(2, 10 * (t - 1)) + b;
		return c/2 * (-Math.pow(2, -10 * --t) + 2) + b;
	},
	easeInCirc: function (x, t, b, c, d) {
		return -c * (Math.sqrt(1 - (t/=d)*t) - 1) + b;
	},
	easeOutCirc: function (x, t, b, c, d) {
		return c * Math.sqrt(1 - (t=t/d-1)*t) + b;
	},
	easeInOutCirc: function (x, t, b, c, d) {
		if ((t/=d/2) < 1) return -c/2 * (Math.sqrt(1 - t*t) - 1) + b;
		return c/2 * (Math.sqrt(1 - (t-=2)*t) + 1) + b;
	},
	easeInElastic: function (x, t, b, c, d) {
		var s=1.70158;var p=0;var a=c;
		if (t==0) return b;  if ((t/=d)==1) return b+c;  if (!p) p=d*.3;
		if (a < Math.abs(c)) { a=c; var s=p/4; }
		else var s = p/(2*Math.PI) * Math.asin (c/a);
		return -(a*Math.pow(2,10*(t-=1)) * Math.sin( (t*d-s)*(2*Math.PI)/p )) + b;
	},
	easeOutElastic: function (x, t, b, c, d) {
		var s=1.70158;var p=0;var a=c;
		if (t==0) return b;  if ((t/=d)==1) return b+c;  if (!p) p=d*.3;
		if (a < Math.abs(c)) { a=c; var s=p/4; }
		else var s = p/(2*Math.PI) * Math.asin (c/a);
		return a*Math.pow(2,-10*t) * Math.sin( (t*d-s)*(2*Math.PI)/p ) + c + b;
	},
	easeInOutElastic: function (x, t, b, c, d) {
		var s=1.70158;var p=0;var a=c;
		if (t==0) return b;  if ((t/=d/2)==2) return b+c;  if (!p) p=d*(.3*1.5);
		if (a < Math.abs(c)) { a=c; var s=p/4; }
		else var s = p/(2*Math.PI) * Math.asin (c/a);
		if (t < 1) return -.5*(a*Math.pow(2,10*(t-=1)) * Math.sin( (t*d-s)*(2*Math.PI)/p )) + b;
		return a*Math.pow(2,-10*(t-=1)) * Math.sin( (t*d-s)*(2*Math.PI)/p )*.5 + c + b;
	},
	easeInBack: function (x, t, b, c, d, s) {
		if (s == undefined) s = 1.70158;
		return c*(t/=d)*t*((s+1)*t - s) + b;
	},
	easeOutBack: function (x, t, b, c, d, s) {
		if (s == undefined) s = 1.70158;
		return c*((t=t/d-1)*t*((s+1)*t + s) + 1) + b;
	},
	easeInOutBack: function (x, t, b, c, d, s) {
		if (s == undefined) s = 1.70158;
		if ((t/=d/2) < 1) return c/2*(t*t*(((s*=(1.525))+1)*t - s)) + b;
		return c/2*((t-=2)*t*(((s*=(1.525))+1)*t + s) + 2) + b;
	},
	easeInBounce: function (x, t, b, c, d) {
		return c - $.easing.easeOutBounce (x, d-t, 0, c, d) + b;
	},
	easeOutBounce: function (x, t, b, c, d) {
		if ((t/=d) < (1/2.75)) {
			return c*(7.5625*t*t) + b;
		} else if (t < (2/2.75)) {
			return c*(7.5625*(t-=(1.5/2.75))*t + .75) + b;
		} else if (t < (2.5/2.75)) {
			return c*(7.5625*(t-=(2.25/2.75))*t + .9375) + b;
		} else {
			return c*(7.5625*(t-=(2.625/2.75))*t + .984375) + b;
		}
	},
	easeInOutBounce: function (x, t, b, c, d) {
		if (t < d/2) return $.easing.easeInBounce (x, t*2, 0, c, d) * .5 + b;
		return $.easing.easeOutBounce (x, t*2-d, 0, c, d) * .5 + c*.5 + b;
	}
});

/*
 *
 * TERMS OF USE - EASING EQUATIONS
 *
 * Open source under the BSD License.
 *
 * Copyright 2001 Robert Penner
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice, this list of
 * conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright notice, this list
 * of conditions and the following disclaimer in the documentation and/or other materials
 * provided with the distribution.
 *
 * Neither the name of the author nor the names of contributors may be used to endorse
 * or promote products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

});


/* ---- Module:jQuery.effects.slide ---- */

/*
 * jQuery UI Effects Slide 1.8.18
 *
 * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * http://docs.jquery.com/UI/Effects/Slide
 *
 * Depends:
 *	jquery.effects.core.js
 */
jQuery.plugin( 'jQuery.effects.slide', 'jQuery.effects.core', function( $, undefined ){

$.effects.slide = function(o) {

	return this.queue(function() {

		// Create element
		var el = $(this), props = ['position','top','bottom','left','right'];

		// Set options
		var mode = $.effects.setMode(el, o.options.mode || 'show'); // Set Mode
		var direction = o.options.direction || 'left'; // Default Direction

		// Adjust
		$.effects.save(el, props); el.show(); // Save & Show
		$.effects.createWrapper(el).css({overflow:'hidden'}); // Create Wrapper
		var ref = (direction == 'up' || direction == 'down') ? 'top' : 'left';
		var motion = (direction == 'up' || direction == 'left') ? 'pos' : 'neg';
		var distance = o.options.distance || (ref == 'top' ? el.outerHeight({margin:true}) : el.outerWidth({margin:true}));
		if (mode == 'show') el.css(ref, motion == 'pos' ? (isNaN(distance) ? "-" + distance : -distance) : distance); // Shift

		// Animation
		var animation = {};
		animation[ref] = (mode == 'show' ? (motion == 'pos' ? '+=' : '-=') : (motion == 'pos' ? '-=' : '+=')) + distance;

		// Animate
		el.animate(animation, { queue: false, duration: o.duration, easing: o.options.easing, complete: function() {
			if(mode == 'hide') el.hide(); // Hide
			$.effects.restore(el, props); $.effects.removeWrapper(el); // Restore
			if(o.callback) o.callback.apply(this, arguments); // Callback
			el.dequeue();
		}});

	});

};

});


/* ---- Module:jQuery.support.cssprefix ---- */

/*
 * @author			Emanuel Vitzthum
 * @copyright		© 2011 jQuery SDK v1.3.1
 * @info			http://www.jquerysdk.com
 *
 * @license			Dual licensed under the MIT (http://www.opensource.org/licenses/mit-license.php) and GPL (http://www.gnu.org/licenses/gpl.html)
 *
 * @plugin			jQuery.support.cssprefix
 */

jQuery.plugin( 'jQuery.support.cssprefix', function( $, undefined ){

	var cssPrefix = '';

	// add browser engine name as class to html tag
	if( (/khtml/i).test(navigator.userAgent) )
		cssPrefix = '-khtml-';

	$.each( {'mozilla':'-moz-', 'msie':'-ms-', 'webkit':'-webkit-', 'opera':'-o-'}, function( i, name ){
		if( $.browser[i] ){
			cssPrefix = name;
			return false;
		}
	});

	$.support.cssPrefix = cssPrefix;
});

/* ---- Module:jQuery.css.borderradius ---- */

/*
 * @author			Emanuel Vitzthum
 * @copyright		© 2011 jQuery SDK v1.3.1
 * @info			http://www.jquerysdk.com
 *
 * @license			Dual licensed under the MIT (http://www.opensource.org/licenses/mit-license.php) and GPL (http://www.gnu.org/licenses/gpl.html)
 *
 * @plugin			jQuery.css.borderradius
 */

jQuery.plugin( 'jQuery.css.borderradius', 'jQuery.support.cssprefix', function( $, undefined ){

	var cssPrefix	= $.support.cssPrefix,
		radiusType	= [ 'border-radius', 'border-top-left-radius', 'border-top-right-radius', 'border-bottom-right-radius',  'border-bottom-left-radius' ];

	if( cssPrefix ){
		// set props and hooks for border radius
		$.each( radiusType, function( i, name ) {
			var origName = $.camelCase(name),
				hookName = $.camelCase(
					cssPrefix + (
						cssPrefix==='-moz-' && name!=='border-radius' ?
							'border-radius-'+name.split('-').splice(1,2).join('') :
							name
					)
				);
			// add to cssprops
			$.cssProps[ origName ] = hookName;
			// add to hooks
			$.cssHooks[ origName ] = {
				get: function( elem, computed, extra ){
					var ret = [];

					if( name==='border-radius' ){
						$.each( radiusType, function( j, type ){
							if( j>0 )
								ret.push( $.css( elem, type ) );
						});
					}
					else{
						var tmp = $.css( elem, hookName );
						ret.push( tmp ? tmp.split(' ')[0] : '0px' );
					}

					return ret.join(' ');
				},
				set: function( elem, value ){
					elem.style[ origName ] = value;
					elem.style[ hookName ] = value;
				}
			};
		});
	}

});

/* ---- Module:ep.fn.busy ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.fn.busy
 *
 * @revision		$Revision: 1.5.68.1 $
 */

jQuery.plugin( 'ep.fn.busy', ['ep.core', 'jQuery.css.borderradius'], function( $, undefined ){

	var stack = [];

	// remove all busy layers on page leave
	$(window)
		.on("unload", function(){
			$(stack)
				.remove();
			stack = [];
		});

	ep.fn.extend({
		busy: function( action ){
			return this.each(function(){
				var elem = $(this),
					layer = elem.find('> .ep-busy');

				if( action==='hide' ){
					var pos = $.data( this, 'epBusyOldposition');

					if( pos === 'static' ){
						$.removeData( this, 'epBusyOldposition' );
						elem.css('position','relative');
					}

					layer.remove();
				}
				else if( !layer.length ){
					var pos = elem.css('position');

					if( pos === 'static' ){
						$.data( this, 'ep-busy-oldposition', pos );
						elem.css('position','relative');
					}

					stack.push( $('<div>')
						.attr('class','ep-busy')
						.css( 'border-radius', elem.css('border-radius') )
						.appendTo( elem )[0] );
				}
			});
		}
	});

});

/* ---- Module:ep.dict ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.dict
 *
 * @revision		$Revision: 1.7 $
 */

jQuery.plugin( 'ep.dict', {
	plugin:	['ep.core', 'jQuery.dict', 'jQuery.tmpl'],
	dict:	['ep.dict']
}, function( $, undefined ){

	$.each( ['translate', 'parse'], function( i, name ){
		$.Dictionary.prototype[ name + 'Data' ] = function( key, data ){
			return $.tmpl( '<span>' + this[ name ](key) + '</span>', [data] )	// replace key marker in translated string with given data
				.html()															// get inner HTML
				.replace(/(^|[^ ])(&nbsp;)([^ ]|$)/g,"$1 $3");					// replace strange &nbsp; to regular space
		};
	});

	// set ep.dict as alias of $.dict
	ep.extend({
		dict: $.dict
	});
});

/* ---- Module:ep.ui.input ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.ui.input
 *
 * @revision		$Revision: 1.27.6.1 $
 */

jQuery.plugin( 'ep.ui.input',{
	plugin: [
		'ep.core',
		'ep.dict',
		'jQuery.support.placeholder',
		'jQuery.support.multipleUpload',
		'jQuery.fn.form',
		'jQuery.fn.class',
		'ep.ui.tooltip'
	],
	dict: [
		'ep.dict'
	]
}, function( $, undefined ){

/*
 * @dictionary		ep.dict
 *
 * @translation		{SelectFile}
 */

	$.widget('ep.ui.Input',{

		options: {
		//	placeholder:		'text',
		//	info:				'text',
			autofocus:			false,
			big:				false,
			orientation:	'right'
		},

		_create: function(){
			// get elem with ep API
			this.elem = this.element
				.data( 'ep-uiInput', this )
				.sub(ep);
			this.stack = $([]);

			// get instance of dict
			this.dict = ep.dict('ep.dict');

			// get type
			var type = this.elem[0].tagName.toLowerCase()+':';
			type = this.type = type==='input:' || type==='button:' ? type+this.elem[0].type : type;

			// create a label as wrap
			this.wrap = ep('<label>')
				.insertBefore(this.elem)
				.append(this.elem);
			// add wrap to stack
			this.stack.push(this.wrap[0]);

			var self = this,
				// state event
				activeStart = function(){
					self.addClass('active');
					self.wrap
						.on( 'mouseenter.uiInput', activeEnter )
						.on( 'mouseleave.uiInput', activeLeave );
					$('html').on( 'mouseup.uiInput', activeEnd );
				},
				activeEnter = function(){
					self.addClass('active');
				},
				activeLeave = function(){
					self.removeClass('active');
				},
				activeEnd = function(){
					self.removeClass('active');
					self.wrap
						.off( 'mouseenter.uiInput', activeEnter )
						.off( 'mouseleave.uiInput', activeLeave );
					$('html').off( 'mouseup.uiInput', activeEnd );
				},
				// classes
				elemClasses = '',
				wrapClasses = 'ep-uiInput-wrap'
					+ ' ep-uiInput-wrap'+$.camelCase( '-'+( /((?:[a-z]+$)|^(?:a|button|select|textarea))/.exec(type) || ['',''] )[1] )
					+ ( this.elem.is(':disabled') ? ' disabled' : '' )
					+ ( this.elem.is(':readonly') ? ' readonly' : '' )
					+ ( this.elem.is(':checked') ? ' checked' : '' );

			this.elem
				.on( 'changeAttr.uiInput', this.Proxy('_changeAttr') )
				.on( 'reset.uiInput', this.Proxy('_change') )
				.on( 'focusin.uiInput', this.Proxy(function(){
					this.addClass('focused');
					if( this.tooltip ){
						this.tooltip[ this.tooltip.is(':empty') ? 'hide' : 'show' ]();
					}
				}) )
				.on( 'focusout.uiInput', this.Proxy(function(){
					this.removeClass('focused'); this._leave();
					if( this.tooltip ){
						this.tooltip.hide();
					}
				}) );

			if( !(/hidden$/i).test(type) ){
				this.wrap
					.on( 'mousedown.uiInput', activeStart );
			}

			if( (/file$/i).test(type) ){
				elemClasses += ' ep-uiInput-hidden';
				// create a input to display selected file name
				this.fileText = $('<span>')
					.attr({
						'class':	'ep-uiInput ep-uiInput-base ep-uiInput-text epWidth140 epWidth-4',
						'text':		this.elem.val()
					},true)
					.insertBefore(this.elem);
				// insert no-break space if no content is available
				if(this.elem.val()==""){
					this.fileText.html('&nbsp;');
				}
				// create a button
				this.fileButton = ep('<span>')
					.attr({
						'class':	'ep-uiInput ep-uiInput-base ep-uiInput-button',
						'text':		this.dict.translate('SelectFile')+'...'
					},true)
					.insertBefore(this.elem);
				// add to stack
				this.stack.push( this.fileText[0], this.fileButton[0] );
			}

			if( this.options.big ){
				wrapClasses += ' ep-uiInput-big';
			}
			if( (/(^(textarea:|select:)|(text|password|email|url|tel|date|datetime|time|number)$)/).test(type) ){
				elemClasses += ' ep-uiInput ep-uiInput-base ep-uiInput-field';
			}

			if( (/checkbox$/).test(type) ){
				wrapClasses += ' ep-uiInput ep-uiInput-base ep-uiInput-field ep-uiInput-checkbox';
				elemClasses += ' ep-uiInput-hidden';
			}
			else if( (/radio$/).test(type) ){
				wrapClasses += ' ep-uiInput ep-uiInput-radio';
				elemClasses += ' ep-uiInput-hidden';
			}
			else if( (/^select:/).test(type) ){
				elemClasses += ' ep-uiInput-select ';
			}
			else if( (/(^(button:|a:)|(submit|reset|button|image)$)/).test(type) ){
				elemClasses +=		(/image$/).test(type) ? '' : ' ep-uiInput ep-uiInput-base ep-uiInput-button';
				// handle reset on form
				if( (/reset$/).test(type) ){
					this.elem
						.on('click.uiInput',function(event){
							event.preventDefault();
							$(this.form).formReset();
						});
				}
			}
			else if( (/^textarea:$/).test(type) ){
				elemClasses += ' ep-uiInput-textarea epWidth-2';
			}
			else if( (/(text|password|email|url|tel|date|datetime|time|number)$/i).test(type) ){
				elemClasses += ' ep-uiInput-text epWidth-4';
			}
			// change event
			if( (/(^(select:)|(file|checkbox|radio)$)/).test(type) ){
				this.elem.on( 'change.uiInput', this.Proxy('_change') );
			}
			// key event
			if( (/(^(textarea:)|(text|password|checkbox|radio|email|url|tel|date|datetime|time|number)$)/).test(type) ){
				this.elem.on( 'keyup.uiInput', this.Proxy('_change') );
			}

			// add classes for styling
			this.elem.addClass( elemClasses );
			this.wrap.addClass( wrapClasses );

			// save value state
			this.lastState = [ this.elem[0].value ,this.elem[0].checked, this.elem[0].selectedIndex ];
		},
		// init binds
		_init: function(){

			// init placholder
			this._placeholderInit();

			// init tooltip
			this._tooltipInit();

			// handle autofocus for this elem
			if( this.elem.attr('autofocus') || this.options.autofocus ){
				if( this.placeholder ) {
					this._placeholderHide();
				}
				this.elem[0].focus();
			}
		},
		// handle addClass to the wrap
		addClass: function( name ){
			if( !(/(hover|active|focused)/).test(name) || !this.elem.is(':disabled,:readonly') ){
				this.wrap.addClass(name);
			}
		},
		// handle removeClass to the wrap
		removeClass: function( name ){
			this.wrap.removeClass(name);
		},

		_placeholderInit: function(){
			if( (/(text|password|email|url|tel|date|datetime|time|number)$/i).test(this.type) ){
				var valOpt = this.options.placeholder,
					valAttr = this.elem.attr('placeholder'),
					val = valOpt || valAttr;

				if( !$.support.placeholder ){
					if( !this.placeholder && val ){
						// bind
						this.elem
							.on( 'focus.uiInput', this.Proxy('_placeholderHide'))
							.on( 'blur.uiInput', this.Proxy('_placeholderShow') );
						// create a placeholder if not support by browser
						this.placeholder = $('<input>') // <input type="text"> does not work for ie default of input is text
							.attr({
								'class': this.elem.attr('class') + ' ep-uiInput-placeholder',
								'style': this.elem.attr('style')
							})
							.hide()
							.on( 'focus.uiInput', this.Proxy('_placeholderHide') )
							.insertAfter(this.elem);
						// fix prev display status
						$['_data'](this.placeholder[0],'olddisplay','inline');
						// add to stack
						this.stack.push(this.placeholder[0]);
					}
					if( this.placeholder ){
						this.placeholder
							.prop({
								value:			val || '',
								defaultValue:	val || ''
							});
						this._placeholderShow();
					}
				}
				else{
					if( val !== valAttr ){
						this.elem.attr( 'placeholder', val );
					}
				}
			}
		},

		_placeholderHide: function( event ){
			var self = this;
			if( this.placeholder ){
				var hidden = this.elem.is(':hidden');
				this.placeholder
					.hide()
					.attr('disabled',true);
				this.elem.show();

				if( event && hidden ){
					// prevent conflict of event trigger with validate #EPG-18640
					setTimeout(function(){
						self.elem[0].focus();
					},1);
				}
			}
		},

		_placeholderShow: function( event ){
			if( this.placeholder && this.placeholder.is(':hidden') ){
				if( !this.elem.val() ){
					this.elem.hide();
					this.placeholder
						.attr('disabled',false)
						.show();
				}
				else{
					this._placeholderHide( event );
				}
			}
		},

		_tooltipInit: function( buildManual ){
			if( !this.tooltip && (this.options.info || buildManual) ){
				// create a placeholder if not support by browser
				this.tooltip = ep('<div>')
					.addClass('ep-uiInput-info')
					.uiTooltip({
						interactive:	true,
						event:			'focus',
						context:		this.elem,
						orientation:	this.options.orientation,
						offsetAdjust:	[3,-2]
					});
				if( this.options.info ){
					this.tooltip.html(this.options.info);
				}
				// add to stack
				this.stack.push(this.tooltip[0]);
			}
		},

		_setOption: function( key, value ) {
			if( key === 'placeholder' ){
				this.elem.attr( 'placeholder', value );
			}

			return this.Inherited(arguments);
		},

		_radioGroupCheck: function(){
			this.elem
				.formGroup(':radio')
				.uiInput('removeClass','checked')
				.filter(':checked')
					.uiInput('addClass','checked');
		},

		// actions if change attr by javascript
		_changeAttr: function( event, attr ){
			if( attr.hasOwnProperty('checked') ){
				// change class to all radios on the current set
				if( (/radio$/i).test(this.type) ){
					this._radioGroupCheck();
				}
				// change class for checkbox
				else{
					this[ this.elem.is(':checked') ? 'addClass' : 'removeClass' ]('checked');
				}
			}
			// change disabled class
			if( attr.hasOwnProperty('disabled') ){
				if( this.elem.is(':disabled') ){
					this.addClass('disabled');
					this.removeClass('focused');
				}
				else{
					this.removeClass('disabled');
				}
			}
			// change readonly class
			if( attr.hasOwnProperty('readonly') ){
				this[ this.elem.is(':readonly') ? 'addClass' : 'removeClass' ]('readonly');
			}
			if( attr.hasOwnProperty('placeholder') ){
				this._placeholderInit(true);
			}
			if( attr.hasOwnProperty('value') ){
				this._change({});
			}
		},

		_stateChanged: function(){
			var oldState = this.lastState,
				newState = [ this.elem[0].value ,this.elem[0].checked, this.elem[0].selectedIndex ],
				ret = !( oldState[0] === newState[0] && oldState[1] === newState[1] && oldState[2] === newState[2] );

			this.lastState = newState;

			return ret;
		},

		_change: function( event ){
			if( event.keyCode!==9 ){
				// special for checkbox
				if( (/checkbox$/i).test(this.type) ){
					this.elem
						.trigger( 'changeAttr', {'checked':this.elem.is(':checked')} );
				}
				// special for radios
				else if( (/radio$/i).test(this.type) ){
					this.elem
						.formGroup(':radio')
							.filter(':checked')
								.trigger( 'changeAttr', {'checked':false} )
							.end()
							.filter(':not(:checked)')
								.trigger( 'changeAttr', {'checked':true} );
				}
				// display selected file
				else if( (/file$/i).test(this.type) ){
					if(this.elem.val()!=""){
						this.fileText.text( this.elem.val().replace(/^.*?fakepath[\/\\]?/,'') );
					}else{
						this.fileText.html('&nbsp;');
					}
				}
			}

			this._leave();
		},

		_leave: function(){
			this[ this.elem.is(':changed') ? 'addClass' : 'removeClass']('changed');

			if( this._stateChanged() ){
				this.elem.trigger('changeValue');
				// trigger changed to form
				$(this.elem[0].form).trigger('change');
			}
		},

		destroy: function(){
			this.elem
				.insertBefore( this.wrap )
				.removeClass(/(ep-uiInput[\w\d-]*|epWidth-\d+)/g);
			this.stack.remove();

			return this.Inherited(arguments);
		}
	});

});


/* ---- Module:jQuery.ui.sortable ---- */

/*
 * jQuery UI Sortable 1.8.18
 *
 * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * http://docs.jquery.com/UI/Sortables
 *
 * Depends:
 *	jquery.ui.core.js
 *	jquery.ui.mouse.js
 *	jquery.ui.widget.js
 */
jQuery.plugin( 'jQuery.ui.sortable', [
	'jQuery.ui.core',
	'jQuery.ui.widget',
	'jQuery.ui.mouse'
], function( $, undefined ){

$.widget("ui.sortable", $.ui.mouse, {
	widgetEventPrefix: "sort",
	ready: false,
	options: {
		appendTo: "parent",
		axis: false,
		connectWith: false,
		containment: false,
		cursor: 'auto',
		cursorAt: false,
		dropOnEmpty: true,
		forcePlaceholderSize: false,
		forceHelperSize: false,
		grid: false,
		handle: false,
		helper: "original",
		items: '> *',
		opacity: false,
		placeholder: false,
		revert: false,
		scroll: true,
		scrollSensitivity: 20,
		scrollSpeed: 20,
		scope: "default",
		tolerance: "intersect",
		zIndex: 1000
	},
	_create: function() {

		var o = this.options;
		this.containerCache = {};
		this.element.addClass("ui-sortable");

		//Get the items
		this.refresh();

		//Let's determine if the items are being displayed horizontally
		this.floating = this.items.length ? o.axis === 'x' || (/left|right/).test(this.items[0].item.css('float')) || (/inline|table-cell/).test(this.items[0].item.css('display')) : false;

		//Let's determine the parent's offset
		this.offset = this.element.offset();

		//Initialize mouse events for interaction
		this._mouseInit();
		
		//We're ready to go
		this.ready = true

	},

	destroy: function() {
		$.Widget.prototype.destroy.call( this );
		this.element
			.removeClass("ui-sortable ui-sortable-disabled");
		this._mouseDestroy();

		for ( var i = this.items.length - 1; i >= 0; i-- )
			this.items[i].item.removeData(this.widgetName + "-item");

		return this;
	},

	_setOption: function(key, value){
		if ( key === "disabled" ) {
			this.options[ key ] = value;
	
			this.widget()
				[ value ? "addClass" : "removeClass"]( "ui-sortable-disabled" );
		} else {
			// Don't call widget base _setOption for disable as it adds ui-state-disabled class
			$.Widget.prototype._setOption.apply(this, arguments);
		}
	},

	_mouseCapture: function(event, overrideHandle) {
		var that = this;

		if (this.reverting) {
			return false;
		}

		if(this.options.disabled || this.options.type == 'static') return false;

		//We have to refresh the items data once first
		this._refreshItems(event);

		//Find out if the clicked node (or one of its parents) is a actual item in this.items
		var currentItem = null, self = this, nodes = $(event.target).parents().each(function() {
			if($.data(this, that.widgetName + '-item') == self) {
				currentItem = $(this);
				return false;
			}
		});
		if($.data(event.target, that.widgetName + '-item') == self) currentItem = $(event.target);

		if(!currentItem) return false;
		if(this.options.handle && !overrideHandle) {
			var validHandle = false;

			$(this.options.handle, currentItem).find("*").andSelf().each(function() { if(this == event.target) validHandle = true; });
			if(!validHandle) return false;
		}

		this.currentItem = currentItem;
		this._removeCurrentsFromItems();
		return true;

	},

	_mouseStart: function(event, overrideHandle, noActivation) {

		var o = this.options, self = this;
		this.currentContainer = this;

		//We only need to call refreshPositions, because the refreshItems call has been moved to mouseCapture
		this.refreshPositions();

		//Create and append the visible helper
		this.helper = this._createHelper(event);

		//Cache the helper size
		this._cacheHelperProportions();

		/*
		 * - Position generation -
		 * This block generates everything position related - it's the core of draggables.
		 */

		//Cache the margins of the original element
		this._cacheMargins();

		//Get the next scrolling parent
		this.scrollParent = this.helper.scrollParent();

		//The element's absolute position on the page minus margins
		this.offset = this.currentItem.offset();
		this.offset = {
			top: this.offset.top - this.margins.top,
			left: this.offset.left - this.margins.left
		};

		// Only after we got the offset, we can change the helper's position to absolute
		// TODO: Still need to figure out a way to make relative sorting possible
		this.helper.css("position", "absolute");
		this.cssPosition = this.helper.css("position");

		$.extend(this.offset, {
			click: { //Where the click happened, relative to the element
				left: event.pageX - this.offset.left,
				top: event.pageY - this.offset.top
			},
			parent: this._getParentOffset(),
			relative: this._getRelativeOffset() //This is a relative to absolute position minus the actual position calculation - only used for relative positioned helper
		});

		//Generate the original position
		this.originalPosition = this._generatePosition(event);
		this.originalPageX = event.pageX;
		this.originalPageY = event.pageY;

		//Adjust the mouse offset relative to the helper if 'cursorAt' is supplied
		(o.cursorAt && this._adjustOffsetFromHelper(o.cursorAt));

		//Cache the former DOM position
		this.domPosition = { prev: this.currentItem.prev()[0], parent: this.currentItem.parent()[0] };

		//If the helper is not the original, hide the original so it's not playing any role during the drag, won't cause anything bad this way
		if(this.helper[0] != this.currentItem[0]) {
			this.currentItem.hide();
		}

		//Create the placeholder
		this._createPlaceholder();

		//Set a containment if given in the options
		if(o.containment)
			this._setContainment();

		if(o.cursor) { // cursor option
			if ($('body').css("cursor")) this._storedCursor = $('body').css("cursor");
			$('body').css("cursor", o.cursor);
		}

		if(o.opacity) { // opacity option
			if (this.helper.css("opacity")) this._storedOpacity = this.helper.css("opacity");
			this.helper.css("opacity", o.opacity);
		}

		if(o.zIndex) { // zIndex option
			if (this.helper.css("zIndex")) this._storedZIndex = this.helper.css("zIndex");
			this.helper.css("zIndex", o.zIndex);
		}

		//Prepare scrolling
		if(this.scrollParent[0] != document && this.scrollParent[0].tagName != 'HTML')
			this.overflowOffset = this.scrollParent.offset();

		//Call callbacks
		this._trigger("start", event, this._uiHash());

		//Recache the helper size
		if(!this._preserveHelperProportions)
			this._cacheHelperProportions();


		//Post 'activate' events to possible containers
		if(!noActivation) {
			 for (var i = this.containers.length - 1; i >= 0; i--) { this.containers[i]._trigger("activate", event, self._uiHash(this)); }
		}

		//Prepare possible droppables
		if($.ui.ddmanager)
			$.ui.ddmanager.current = this;

		if ($.ui.ddmanager && !o.dropBehaviour)
			$.ui.ddmanager.prepareOffsets(this, event);

		this.dragging = true;

		this.helper.addClass("ui-sortable-helper");
		this._mouseDrag(event); //Execute the drag once - this causes the helper not to be visible before getting its correct position
		return true;

	},

	_mouseDrag: function(event) {

		//Compute the helpers position
		this.position = this._generatePosition(event);
		this.positionAbs = this._convertPositionTo("absolute");

		if (!this.lastPositionAbs) {
			this.lastPositionAbs = this.positionAbs;
		}

		//Do scrolling
		if(this.options.scroll) {
			var o = this.options, scrolled = false;
			if(this.scrollParent[0] != document && this.scrollParent[0].tagName != 'HTML') {

				if((this.overflowOffset.top + this.scrollParent[0].offsetHeight) - event.pageY < o.scrollSensitivity)
					this.scrollParent[0].scrollTop = scrolled = this.scrollParent[0].scrollTop + o.scrollSpeed;
				else if(event.pageY - this.overflowOffset.top < o.scrollSensitivity)
					this.scrollParent[0].scrollTop = scrolled = this.scrollParent[0].scrollTop - o.scrollSpeed;

				if((this.overflowOffset.left + this.scrollParent[0].offsetWidth) - event.pageX < o.scrollSensitivity)
					this.scrollParent[0].scrollLeft = scrolled = this.scrollParent[0].scrollLeft + o.scrollSpeed;
				else if(event.pageX - this.overflowOffset.left < o.scrollSensitivity)
					this.scrollParent[0].scrollLeft = scrolled = this.scrollParent[0].scrollLeft - o.scrollSpeed;

			} else {

				if(event.pageY - $(document).scrollTop() < o.scrollSensitivity)
					scrolled = $(document).scrollTop($(document).scrollTop() - o.scrollSpeed);
				else if($(window).height() - (event.pageY - $(document).scrollTop()) < o.scrollSensitivity)
					scrolled = $(document).scrollTop($(document).scrollTop() + o.scrollSpeed);

				if(event.pageX - $(document).scrollLeft() < o.scrollSensitivity)
					scrolled = $(document).scrollLeft($(document).scrollLeft() - o.scrollSpeed);
				else if($(window).width() - (event.pageX - $(document).scrollLeft()) < o.scrollSensitivity)
					scrolled = $(document).scrollLeft($(document).scrollLeft() + o.scrollSpeed);

			}

			if(scrolled !== false && $.ui.ddmanager && !o.dropBehaviour)
				$.ui.ddmanager.prepareOffsets(this, event);
		}

		//Regenerate the absolute position used for position checks
		this.positionAbs = this._convertPositionTo("absolute");

		//Set the helper position
		if(!this.options.axis || this.options.axis != "y") this.helper[0].style.left = this.position.left+'px';
		if(!this.options.axis || this.options.axis != "x") this.helper[0].style.top = this.position.top+'px';

		//Rearrange
		for (var i = this.items.length - 1; i >= 0; i--) {

			//Cache variables and intersection, continue if no intersection
			var item = this.items[i], itemElement = item.item[0], intersection = this._intersectsWithPointer(item);
			if (!intersection) continue;

			if(itemElement != this.currentItem[0] //cannot intersect with itself
				&&	this.placeholder[intersection == 1 ? "next" : "prev"]()[0] != itemElement //no useless actions that have been done before
				&&	!$.ui.contains(this.placeholder[0], itemElement) //no action if the item moved is the parent of the item checked
				&& (this.options.type == 'semi-dynamic' ? !$.ui.contains(this.element[0], itemElement) : true)
				//&& itemElement.parentNode == this.placeholder[0].parentNode // only rearrange items within the same container
			) {

				this.direction = intersection == 1 ? "down" : "up";

				if (this.options.tolerance == "pointer" || this._intersectsWithSides(item)) {
					this._rearrange(event, item);
				} else {
					break;
				}

				this._trigger("change", event, this._uiHash());
				break;
			}
		}

		//Post events to containers
		this._contactContainers(event);

		//Interconnect with droppables
		if($.ui.ddmanager) $.ui.ddmanager.drag(this, event);

		//Call callbacks
		this._trigger('sort', event, this._uiHash());

		this.lastPositionAbs = this.positionAbs;
		return false;

	},

	_mouseStop: function(event, noPropagation) {

		if(!event) return;

		//If we are using droppables, inform the manager about the drop
		if ($.ui.ddmanager && !this.options.dropBehaviour)
			$.ui.ddmanager.drop(this, event);

		if(this.options.revert) {
			var self = this;
			var cur = self.placeholder.offset();

			self.reverting = true;

			$(this.helper).animate({
				left: cur.left - this.offset.parent.left - self.margins.left + (this.offsetParent[0] == document.body ? 0 : this.offsetParent[0].scrollLeft),
				top: cur.top - this.offset.parent.top - self.margins.top + (this.offsetParent[0] == document.body ? 0 : this.offsetParent[0].scrollTop)
			}, parseInt(this.options.revert, 10) || 500, function() {
				self._clear(event);
			});
		} else {
			this._clear(event, noPropagation);
		}

		return false;

	},

	cancel: function() {

		var self = this;

		if(this.dragging) {

			this._mouseUp({ target: null });

			if(this.options.helper == "original")
				this.currentItem.css(this._storedCSS).removeClass("ui-sortable-helper");
			else
				this.currentItem.show();

			//Post deactivating events to containers
			for (var i = this.containers.length - 1; i >= 0; i--){
				this.containers[i]._trigger("deactivate", null, self._uiHash(this));
				if(this.containers[i].containerCache.over) {
					this.containers[i]._trigger("out", null, self._uiHash(this));
					this.containers[i].containerCache.over = 0;
				}
			}

		}

		if (this.placeholder) {
			//$(this.placeholder[0]).remove(); would have been the jQuery way - unfortunately, it unbinds ALL events from the original node!
			if(this.placeholder[0].parentNode) this.placeholder[0].parentNode.removeChild(this.placeholder[0]);
			if(this.options.helper != "original" && this.helper && this.helper[0].parentNode) this.helper.remove();

			$.extend(this, {
				helper: null,
				dragging: false,
				reverting: false,
				_noFinalSort: null
			});

			if(this.domPosition.prev) {
				$(this.domPosition.prev).after(this.currentItem);
			} else {
				$(this.domPosition.parent).prepend(this.currentItem);
			}
		}

		return this;

	},

	serialize: function(o) {

		var items = this._getItemsAsjQuery(o && o.connected);
		var str = []; o = o || {};

		$(items).each(function() {
			var res = ($(o.item || this).attr(o.attribute || 'id') || '').match(o.expression || (/(.+)[-=_](.+)/));
			if(res) str.push((o.key || res[1]+'[]')+'='+(o.key && o.expression ? res[1] : res[2]));
		});

		if(!str.length && o.key) {
			str.push(o.key + '=');
		}

		return str.join('&');

	},

	toArray: function(o) {

		var items = this._getItemsAsjQuery(o && o.connected);
		var ret = []; o = o || {};

		items.each(function() { ret.push($(o.item || this).attr(o.attribute || 'id') || ''); });
		return ret;

	},

	/* Be careful with the following core functions */
	_intersectsWith: function(item) {

		var x1 = this.positionAbs.left,
			x2 = x1 + this.helperProportions.width,
			y1 = this.positionAbs.top,
			y2 = y1 + this.helperProportions.height;

		var l = item.left,
			r = l + item.width,
			t = item.top,
			b = t + item.height;

		var dyClick = this.offset.click.top,
			dxClick = this.offset.click.left;

		var isOverElement = (y1 + dyClick) > t && (y1 + dyClick) < b && (x1 + dxClick) > l && (x1 + dxClick) < r;

		if(	   this.options.tolerance == "pointer"
			|| this.options.forcePointerForContainers
			|| (this.options.tolerance != "pointer" && this.helperProportions[this.floating ? 'width' : 'height'] > item[this.floating ? 'width' : 'height'])
		) {
			return isOverElement;
		} else {

			return (l < x1 + (this.helperProportions.width / 2) // Right Half
				&& x2 - (this.helperProportions.width / 2) < r // Left Half
				&& t < y1 + (this.helperProportions.height / 2) // Bottom Half
				&& y2 - (this.helperProportions.height / 2) < b ); // Top Half

		}
	},

	_intersectsWithPointer: function(item) {

		var isOverElementHeight = $.ui.isOverAxis(this.positionAbs.top + this.offset.click.top, item.top, item.height),
			isOverElementWidth = $.ui.isOverAxis(this.positionAbs.left + this.offset.click.left, item.left, item.width),
			isOverElement = isOverElementHeight && isOverElementWidth,
			verticalDirection = this._getDragVerticalDirection(),
			horizontalDirection = this._getDragHorizontalDirection();

		if (!isOverElement)
			return false;

		return this.floating ?
			( ((horizontalDirection && horizontalDirection == "right") || verticalDirection == "down") ? 2 : 1 )
			: ( verticalDirection && (verticalDirection == "down" ? 2 : 1) );

	},

	_intersectsWithSides: function(item) {

		var isOverBottomHalf = $.ui.isOverAxis(this.positionAbs.top + this.offset.click.top, item.top + (item.height/2), item.height),
			isOverRightHalf = $.ui.isOverAxis(this.positionAbs.left + this.offset.click.left, item.left + (item.width/2), item.width),
			verticalDirection = this._getDragVerticalDirection(),
			horizontalDirection = this._getDragHorizontalDirection();

		if (this.floating && horizontalDirection) {
			return ((horizontalDirection == "right" && isOverRightHalf) || (horizontalDirection == "left" && !isOverRightHalf));
		} else {
			return verticalDirection && ((verticalDirection == "down" && isOverBottomHalf) || (verticalDirection == "up" && !isOverBottomHalf));
		}

	},

	_getDragVerticalDirection: function() {
		var delta = this.positionAbs.top - this.lastPositionAbs.top;
		return delta != 0 && (delta > 0 ? "down" : "up");
	},

	_getDragHorizontalDirection: function() {
		var delta = this.positionAbs.left - this.lastPositionAbs.left;
		return delta != 0 && (delta > 0 ? "right" : "left");
	},

	refresh: function(event) {
		this._refreshItems(event);
		this.refreshPositions();
		return this;
	},

	_connectWith: function() {
		var options = this.options;
		return options.connectWith.constructor == String
			? [options.connectWith]
			: options.connectWith;
	},
	
	_getItemsAsjQuery: function(connected) {

		var self = this;
		var items = [];
		var queries = [];
		var connectWith = this._connectWith();

		if(connectWith && connected) {
			for (var i = connectWith.length - 1; i >= 0; i--){
				var cur = $(connectWith[i]);
				for (var j = cur.length - 1; j >= 0; j--){
					var inst = $.data(cur[j], this.widgetName);
					if(inst && inst != this && !inst.options.disabled) {
						queries.push([$.isFunction(inst.options.items) ? inst.options.items.call(inst.element) : $(inst.options.items, inst.element).not(".ui-sortable-helper").not('.ui-sortable-placeholder'), inst]);
					}
				};
			};
		}

		queries.push([$.isFunction(this.options.items) ? this.options.items.call(this.element, null, { options: this.options, item: this.currentItem }) : $(this.options.items, this.element).not(".ui-sortable-helper").not('.ui-sortable-placeholder'), this]);

		for (var i = queries.length - 1; i >= 0; i--){
			queries[i][0].each(function() {
				items.push(this);
			});
		};

		return $(items);

	},

	_removeCurrentsFromItems: function() {

		var list = this.currentItem.find(":data(" + this.widgetName + "-item)");

		for (var i=0; i < this.items.length; i++) {

			for (var j=0; j < list.length; j++) {
				if(list[j] == this.items[i].item[0])
					this.items.splice(i,1);
			};

		};

	},

	_refreshItems: function(event) {

		this.items = [];
		this.containers = [this];
		var items = this.items;
		var self = this;
		var queries = [[$.isFunction(this.options.items) ? this.options.items.call(this.element[0], event, { item: this.currentItem }) : $(this.options.items, this.element), this]];
		var connectWith = this._connectWith();

		if(connectWith && this.ready) { //Shouldn't be run the first time through due to massive slow-down
			for (var i = connectWith.length - 1; i >= 0; i--){
				var cur = $(connectWith[i]);
				for (var j = cur.length - 1; j >= 0; j--){
					var inst = $.data(cur[j], this.widgetName);
					if(inst && inst != this && !inst.options.disabled) {
						queries.push([$.isFunction(inst.options.items) ? inst.options.items.call(inst.element[0], event, { item: this.currentItem }) : $(inst.options.items, inst.element), inst]);
						this.containers.push(inst);
					}
				};
			};
		}

		for (var i = queries.length - 1; i >= 0; i--) {
			var targetData = queries[i][1];
			var _queries = queries[i][0];

			for (var j=0, queriesLength = _queries.length; j < queriesLength; j++) {
				var item = $(_queries[j]);

				item.data(this.widgetName + '-item', targetData); // Data for target checking (mouse manager)

				items.push({
					item: item,
					instance: targetData,
					width: 0, height: 0,
					left: 0, top: 0
				});
			};
		};

	},

	refreshPositions: function(fast) {

		//This has to be redone because due to the item being moved out/into the offsetParent, the offsetParent's position will change
		if(this.offsetParent && this.helper) {
			this.offset.parent = this._getParentOffset();
		}

		for (var i = this.items.length - 1; i >= 0; i--){
			var item = this.items[i];

			//We ignore calculating positions of all connected containers when we're not over them
			if(item.instance != this.currentContainer && this.currentContainer && item.item[0] != this.currentItem[0])
				continue;

			var t = this.options.toleranceElement ? $(this.options.toleranceElement, item.item) : item.item;

			if (!fast) {
				item.width = t.outerWidth();
				item.height = t.outerHeight();
			}

			var p = t.offset();
			item.left = p.left;
			item.top = p.top;
		};

		if(this.options.custom && this.options.custom.refreshContainers) {
			this.options.custom.refreshContainers.call(this);
		} else {
			for (var i = this.containers.length - 1; i >= 0; i--){
				var p = this.containers[i].element.offset();
				this.containers[i].containerCache.left = p.left;
				this.containers[i].containerCache.top = p.top;
				this.containers[i].containerCache.width	= this.containers[i].element.outerWidth();
				this.containers[i].containerCache.height = this.containers[i].element.outerHeight();
			};
		}

		return this;
	},

	_createPlaceholder: function(that) {

		var self = that || this, o = self.options;

		if(!o.placeholder || o.placeholder.constructor == String) {
			var className = o.placeholder;
			o.placeholder = {
				element: function() {

					var el = $(document.createElement(self.currentItem[0].nodeName))
						.addClass(className || self.currentItem[0].className+" ui-sortable-placeholder")
						.removeClass("ui-sortable-helper")[0];

					if(!className)
						el.style.visibility = "hidden";

					return el;
				},
				update: function(container, p) {

					// 1. If a className is set as 'placeholder option, we don't force sizes - the class is responsible for that
					// 2. The option 'forcePlaceholderSize can be enabled to force it even if a class name is specified
					if(className && !o.forcePlaceholderSize) return;

					//If the element doesn't have a actual height by itself (without styles coming from a stylesheet), it receives the inline height from the dragged item
					if(!p.height()) { p.height(self.currentItem.innerHeight() - parseInt(self.currentItem.css('paddingTop')||0, 10) - parseInt(self.currentItem.css('paddingBottom')||0, 10)); };
					if(!p.width()) { p.width(self.currentItem.innerWidth() - parseInt(self.currentItem.css('paddingLeft')||0, 10) - parseInt(self.currentItem.css('paddingRight')||0, 10)); };
				}
			};
		}

		//Create the placeholder
		self.placeholder = $(o.placeholder.element.call(self.element, self.currentItem));

		//Append it after the actual current item
		self.currentItem.after(self.placeholder);

		//Update the size of the placeholder (TODO: Logic to fuzzy, see line 316/317)
		o.placeholder.update(self, self.placeholder);

	},

	_contactContainers: function(event) {
		
		// get innermost container that intersects with item 
		var innermostContainer = null, innermostIndex = null;		
		
		
		for (var i = this.containers.length - 1; i >= 0; i--){

			// never consider a container that's located within the item itself 
			if($.ui.contains(this.currentItem[0], this.containers[i].element[0]))
				continue;

			if(this._intersectsWith(this.containers[i].containerCache)) {

				// if we've already found a container and it's more "inner" than this, then continue 
				if(innermostContainer && $.ui.contains(this.containers[i].element[0], innermostContainer.element[0]))
					continue;

				innermostContainer = this.containers[i]; 
				innermostIndex = i;
					
			} else {
				// container doesn't intersect. trigger "out" event if necessary 
				if(this.containers[i].containerCache.over) {
					this.containers[i]._trigger("out", event, this._uiHash(this));
					this.containers[i].containerCache.over = 0;
				}
			}

		}
		
		// if no intersecting containers found, return 
		if(!innermostContainer) return; 

		// move the item into the container if it's not there already
		if(this.containers.length === 1) {
			this.containers[innermostIndex]._trigger("over", event, this._uiHash(this));
			this.containers[innermostIndex].containerCache.over = 1;
		} else if(this.currentContainer != this.containers[innermostIndex]) { 

			//When entering a new container, we will find the item with the least distance and append our item near it 
			var dist = 10000; var itemWithLeastDistance = null; var base = this.positionAbs[this.containers[innermostIndex].floating ? 'left' : 'top']; 
			for (var j = this.items.length - 1; j >= 0; j--) { 
				if(!$.ui.contains(this.containers[innermostIndex].element[0], this.items[j].item[0])) continue; 
				var cur = this.items[j][this.containers[innermostIndex].floating ? 'left' : 'top']; 
				if(Math.abs(cur - base) < dist) { 
					dist = Math.abs(cur - base); itemWithLeastDistance = this.items[j]; 
				} 
			} 

			if(!itemWithLeastDistance && !this.options.dropOnEmpty) //Check if dropOnEmpty is enabled 
				return; 

			this.currentContainer = this.containers[innermostIndex]; 
			itemWithLeastDistance ? this._rearrange(event, itemWithLeastDistance, null, true) : this._rearrange(event, null, this.containers[innermostIndex].element, true); 
			this._trigger("change", event, this._uiHash()); 
			this.containers[innermostIndex]._trigger("change", event, this._uiHash(this)); 

			//Update the placeholder 
			this.options.placeholder.update(this.currentContainer, this.placeholder); 
		
			this.containers[innermostIndex]._trigger("over", event, this._uiHash(this)); 
			this.containers[innermostIndex].containerCache.over = 1;
		} 
	
		
	},

	_createHelper: function(event) {

		var o = this.options;
		var helper = $.isFunction(o.helper) ? $(o.helper.apply(this.element[0], [event, this.currentItem])) : (o.helper == 'clone' ? this.currentItem.clone() : this.currentItem);

		if(!helper.parents('body').length) //Add the helper to the DOM if that didn't happen already
			$(o.appendTo != 'parent' ? o.appendTo : this.currentItem[0].parentNode)[0].appendChild(helper[0]);

		if(helper[0] == this.currentItem[0])
			this._storedCSS = { width: this.currentItem[0].style.width, height: this.currentItem[0].style.height, position: this.currentItem.css("position"), top: this.currentItem.css("top"), left: this.currentItem.css("left") };

		if(helper[0].style.width == '' || o.forceHelperSize) helper.width(this.currentItem.width());
		if(helper[0].style.height == '' || o.forceHelperSize) helper.height(this.currentItem.height());

		return helper;

	},

	_adjustOffsetFromHelper: function(obj) {
		if (typeof obj == 'string') {
			obj = obj.split(' ');
		}
		if ($.isArray(obj)) {
			obj = {left: +obj[0], top: +obj[1] || 0};
		}
		if ('left' in obj) {
			this.offset.click.left = obj.left + this.margins.left;
		}
		if ('right' in obj) {
			this.offset.click.left = this.helperProportions.width - obj.right + this.margins.left;
		}
		if ('top' in obj) {
			this.offset.click.top = obj.top + this.margins.top;
		}
		if ('bottom' in obj) {
			this.offset.click.top = this.helperProportions.height - obj.bottom + this.margins.top;
		}
	},

	_getParentOffset: function() {


		//Get the offsetParent and cache its position
		this.offsetParent = this.helper.offsetParent();
		var po = this.offsetParent.offset();

		// This is a special case where we need to modify a offset calculated on start, since the following happened:
		// 1. The position of the helper is absolute, so it's position is calculated based on the next positioned parent
		// 2. The actual offset parent is a child of the scroll parent, and the scroll parent isn't the document, which means that
		//    the scroll is included in the initial calculation of the offset of the parent, and never recalculated upon drag
		if(this.cssPosition == 'absolute' && this.scrollParent[0] != document && $.ui.contains(this.scrollParent[0], this.offsetParent[0])) {
			po.left += this.scrollParent.scrollLeft();
			po.top += this.scrollParent.scrollTop();
		}

		if((this.offsetParent[0] == document.body) //This needs to be actually done for all browsers, since pageX/pageY includes this information
		|| (this.offsetParent[0].tagName && this.offsetParent[0].tagName.toLowerCase() == 'html' && $.browser.msie)) //Ugly IE fix
			po = { top: 0, left: 0 };

		return {
			top: po.top + (parseInt(this.offsetParent.css("borderTopWidth"),10) || 0),
			left: po.left + (parseInt(this.offsetParent.css("borderLeftWidth"),10) || 0)
		};

	},

	_getRelativeOffset: function() {

		if(this.cssPosition == "relative") {
			var p = this.currentItem.position();
			return {
				top: p.top - (parseInt(this.helper.css("top"),10) || 0) + this.scrollParent.scrollTop(),
				left: p.left - (parseInt(this.helper.css("left"),10) || 0) + this.scrollParent.scrollLeft()
			};
		} else {
			return { top: 0, left: 0 };
		}

	},

	_cacheMargins: function() {
		this.margins = {
			left: (parseInt(this.currentItem.css("marginLeft"),10) || 0),
			top: (parseInt(this.currentItem.css("marginTop"),10) || 0)
		};
	},

	_cacheHelperProportions: function() {
		this.helperProportions = {
			width: this.helper.outerWidth(),
			height: this.helper.outerHeight()
		};
	},

	_setContainment: function() {

		var o = this.options;
		if(o.containment == 'parent') o.containment = this.helper[0].parentNode;
		if(o.containment == 'document' || o.containment == 'window') this.containment = [
			0 - this.offset.relative.left - this.offset.parent.left,
			0 - this.offset.relative.top - this.offset.parent.top,
			$(o.containment == 'document' ? document : window).width() - this.helperProportions.width - this.margins.left,
			($(o.containment == 'document' ? document : window).height() || document.body.parentNode.scrollHeight) - this.helperProportions.height - this.margins.top
		];

		if(!(/^(document|window|parent)$/).test(o.containment)) {
			var ce = $(o.containment)[0];
			var co = $(o.containment).offset();
			var over = ($(ce).css("overflow") != 'hidden');

			this.containment = [
				co.left + (parseInt($(ce).css("borderLeftWidth"),10) || 0) + (parseInt($(ce).css("paddingLeft"),10) || 0) - this.margins.left,
				co.top + (parseInt($(ce).css("borderTopWidth"),10) || 0) + (parseInt($(ce).css("paddingTop"),10) || 0) - this.margins.top,
				co.left+(over ? Math.max(ce.scrollWidth,ce.offsetWidth) : ce.offsetWidth) - (parseInt($(ce).css("borderLeftWidth"),10) || 0) - (parseInt($(ce).css("paddingRight"),10) || 0) - this.helperProportions.width - this.margins.left,
				co.top+(over ? Math.max(ce.scrollHeight,ce.offsetHeight) : ce.offsetHeight) - (parseInt($(ce).css("borderTopWidth"),10) || 0) - (parseInt($(ce).css("paddingBottom"),10) || 0) - this.helperProportions.height - this.margins.top
			];
		}

	},

	_convertPositionTo: function(d, pos) {

		if(!pos) pos = this.position;
		var mod = d == "absolute" ? 1 : -1;
		var o = this.options, scroll = this.cssPosition == 'absolute' && !(this.scrollParent[0] != document && $.ui.contains(this.scrollParent[0], this.offsetParent[0])) ? this.offsetParent : this.scrollParent, scrollIsRootNode = (/(html|body)/i).test(scroll[0].tagName);

		return {
			top: (
				pos.top																	// The absolute mouse position
				+ this.offset.relative.top * mod										// Only for relative positioned nodes: Relative offset from element to offset parent
				+ this.offset.parent.top * mod											// The offsetParent's offset without borders (offset + border)
				- ($.browser.safari && this.cssPosition == 'fixed' ? 0 : ( this.cssPosition == 'fixed' ? -this.scrollParent.scrollTop() : ( scrollIsRootNode ? 0 : scroll.scrollTop() ) ) * mod)
			),
			left: (
				pos.left																// The absolute mouse position
				+ this.offset.relative.left * mod										// Only for relative positioned nodes: Relative offset from element to offset parent
				+ this.offset.parent.left * mod											// The offsetParent's offset without borders (offset + border)
				- ($.browser.safari && this.cssPosition == 'fixed' ? 0 : ( this.cssPosition == 'fixed' ? -this.scrollParent.scrollLeft() : scrollIsRootNode ? 0 : scroll.scrollLeft() ) * mod)
			)
		};

	},

	_generatePosition: function(event) {

		var o = this.options, scroll = this.cssPosition == 'absolute' && !(this.scrollParent[0] != document && $.ui.contains(this.scrollParent[0], this.offsetParent[0])) ? this.offsetParent : this.scrollParent, scrollIsRootNode = (/(html|body)/i).test(scroll[0].tagName);

		// This is another very weird special case that only happens for relative elements:
		// 1. If the css position is relative
		// 2. and the scroll parent is the document or similar to the offset parent
		// we have to refresh the relative offset during the scroll so there are no jumps
		if(this.cssPosition == 'relative' && !(this.scrollParent[0] != document && this.scrollParent[0] != this.offsetParent[0])) {
			this.offset.relative = this._getRelativeOffset();
		}

		var pageX = event.pageX;
		var pageY = event.pageY;

		/*
		 * - Position constraining -
		 * Constrain the position to a mix of grid, containment.
		 */

		if(this.originalPosition) { //If we are not dragging yet, we won't check for options

			if(this.containment) {
				if(event.pageX - this.offset.click.left < this.containment[0]) pageX = this.containment[0] + this.offset.click.left;
				if(event.pageY - this.offset.click.top < this.containment[1]) pageY = this.containment[1] + this.offset.click.top;
				if(event.pageX - this.offset.click.left > this.containment[2]) pageX = this.containment[2] + this.offset.click.left;
				if(event.pageY - this.offset.click.top > this.containment[3]) pageY = this.containment[3] + this.offset.click.top;
			}

			if(o.grid) {
				var top = this.originalPageY + Math.round((pageY - this.originalPageY) / o.grid[1]) * o.grid[1];
				pageY = this.containment ? (!(top - this.offset.click.top < this.containment[1] || top - this.offset.click.top > this.containment[3]) ? top : (!(top - this.offset.click.top < this.containment[1]) ? top - o.grid[1] : top + o.grid[1])) : top;

				var left = this.originalPageX + Math.round((pageX - this.originalPageX) / o.grid[0]) * o.grid[0];
				pageX = this.containment ? (!(left - this.offset.click.left < this.containment[0] || left - this.offset.click.left > this.containment[2]) ? left : (!(left - this.offset.click.left < this.containment[0]) ? left - o.grid[0] : left + o.grid[0])) : left;
			}

		}

		return {
			top: (
				pageY																// The absolute mouse position
				- this.offset.click.top													// Click offset (relative to the element)
				- this.offset.relative.top												// Only for relative positioned nodes: Relative offset from element to offset parent
				- this.offset.parent.top												// The offsetParent's offset without borders (offset + border)
				+ ($.browser.safari && this.cssPosition == 'fixed' ? 0 : ( this.cssPosition == 'fixed' ? -this.scrollParent.scrollTop() : ( scrollIsRootNode ? 0 : scroll.scrollTop() ) ))
			),
			left: (
				pageX																// The absolute mouse position
				- this.offset.click.left												// Click offset (relative to the element)
				- this.offset.relative.left												// Only for relative positioned nodes: Relative offset from element to offset parent
				- this.offset.parent.left												// The offsetParent's offset without borders (offset + border)
				+ ($.browser.safari && this.cssPosition == 'fixed' ? 0 : ( this.cssPosition == 'fixed' ? -this.scrollParent.scrollLeft() : scrollIsRootNode ? 0 : scroll.scrollLeft() ))
			)
		};

	},

	_rearrange: function(event, i, a, hardRefresh) {

		a ? a[0].appendChild(this.placeholder[0]) : i.item[0].parentNode.insertBefore(this.placeholder[0], (this.direction == 'down' ? i.item[0] : i.item[0].nextSibling));

		//Various things done here to improve the performance:
		// 1. we create a setTimeout, that calls refreshPositions
		// 2. on the instance, we have a counter variable, that get's higher after every append
		// 3. on the local scope, we copy the counter variable, and check in the timeout, if it's still the same
		// 4. this lets only the last addition to the timeout stack through
		this.counter = this.counter ? ++this.counter : 1;
		var self = this, counter = this.counter;

		window.setTimeout(function() {
			if(counter == self.counter) self.refreshPositions(!hardRefresh); //Precompute after each DOM insertion, NOT on mousemove
		},0);

	},

	_clear: function(event, noPropagation) {

		this.reverting = false;
		// We delay all events that have to be triggered to after the point where the placeholder has been removed and
		// everything else normalized again
		var delayedTriggers = [], self = this;

		// We first have to update the dom position of the actual currentItem
		// Note: don't do it if the current item is already removed (by a user), or it gets reappended (see #4088)
		if(!this._noFinalSort && this.currentItem.parent().length) this.placeholder.before(this.currentItem);
		this._noFinalSort = null;

		if(this.helper[0] == this.currentItem[0]) {
			for(var i in this._storedCSS) {
				if(this._storedCSS[i] == 'auto' || this._storedCSS[i] == 'static') this._storedCSS[i] = '';
			}
			this.currentItem.css(this._storedCSS).removeClass("ui-sortable-helper");
		} else {
			this.currentItem.show();
		}

		if(this.fromOutside && !noPropagation) delayedTriggers.push(function(event) { this._trigger("receive", event, this._uiHash(this.fromOutside)); });
		if((this.fromOutside || this.domPosition.prev != this.currentItem.prev().not(".ui-sortable-helper")[0] || this.domPosition.parent != this.currentItem.parent()[0]) && !noPropagation) delayedTriggers.push(function(event) { this._trigger("update", event, this._uiHash()); }); //Trigger update callback if the DOM position has changed
		if(!$.ui.contains(this.element[0], this.currentItem[0])) { //Node was moved out of the current element
			if(!noPropagation) delayedTriggers.push(function(event) { this._trigger("remove", event, this._uiHash()); });
			for (var i = this.containers.length - 1; i >= 0; i--){
				if($.ui.contains(this.containers[i].element[0], this.currentItem[0]) && !noPropagation) {
					delayedTriggers.push((function(c) { return function(event) { c._trigger("receive", event, this._uiHash(this)); };  }).call(this, this.containers[i]));
					delayedTriggers.push((function(c) { return function(event) { c._trigger("update", event, this._uiHash(this));  }; }).call(this, this.containers[i]));
				}
			};
		};

		//Post events to containers
		for (var i = this.containers.length - 1; i >= 0; i--){
			if(!noPropagation) delayedTriggers.push((function(c) { return function(event) { c._trigger("deactivate", event, this._uiHash(this)); };  }).call(this, this.containers[i]));
			if(this.containers[i].containerCache.over) {
				delayedTriggers.push((function(c) { return function(event) { c._trigger("out", event, this._uiHash(this)); };  }).call(this, this.containers[i]));
				this.containers[i].containerCache.over = 0;
			}
		}

		//Do what was originally in plugins
		if(this._storedCursor) $('body').css("cursor", this._storedCursor); //Reset cursor
		if(this._storedOpacity) this.helper.css("opacity", this._storedOpacity); //Reset opacity
		if(this._storedZIndex) this.helper.css("zIndex", this._storedZIndex == 'auto' ? '' : this._storedZIndex); //Reset z-index

		this.dragging = false;
		if(this.cancelHelperRemoval) {
			if(!noPropagation) {
				this._trigger("beforeStop", event, this._uiHash());
				for (var i=0; i < delayedTriggers.length; i++) { delayedTriggers[i].call(this, event); }; //Trigger all delayed events
				this._trigger("stop", event, this._uiHash());
			}
			return false;
		}

		if(!noPropagation) this._trigger("beforeStop", event, this._uiHash());

		//$(this.placeholder[0]).remove(); would have been the jQuery way - unfortunately, it unbinds ALL events from the original node!
		this.placeholder[0].parentNode.removeChild(this.placeholder[0]);

		if(this.helper[0] != this.currentItem[0]) this.helper.remove(); this.helper = null;

		if(!noPropagation) {
			for (var i=0; i < delayedTriggers.length; i++) { delayedTriggers[i].call(this, event); }; //Trigger all delayed events
			this._trigger("stop", event, this._uiHash());
		}

		this.fromOutside = false;
		return true;

	},

	_trigger: function() {
		if ($.Widget.prototype._trigger.apply(this, arguments) === false) {
			this.cancel();
		}
	},

	_uiHash: function(inst) {
		var self = inst || this;
		return {
			helper: self.helper,
			placeholder: self.placeholder || $([]),
			position: self.position,
			originalPosition: self.originalPosition,
			offset: self.positionAbs,
			item: self.currentItem,
			sender: inst ? inst.element : null
		};
	}

});

$.extend($.ui.sortable, {
	version: "1.8.18"
});

});


/* ---- Module:ep.ui.textedit ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.ui.textedit
 *
 * @revision		$Revision: 1.9 $
 */

jQuery.plugin( 'ep.ui.textedit', ['ep.core', 'ep.ajax', 'ep.ui.input', 'jQuery.ui.core'], function( $, undefined ){

	$.widget( "ep.ui.Textedit",/* my.parent.widget,*/ {
		MIN_WIDTH: 50,
		options: {
		//	validate: 			undefined,
			additional:			undefined,												// additional save parameters (e.g. CurrencyID)
			type:				'input',												// textarea or input
			action:				null,													// save action
			objectId:			ep.config.objectId !== 0 ? ep.config.objectId : null,	// object id for save
			name:				null,													// name for save
			convertLineBreaks:	false,													// new line to br
			stripHTML:			false,													// remove html tags
			xhrType:			'POST',													// request type
			onAfterClose:		null,
			onBeforeOpen:		null,
			onAfterOpen:		null,
			formatOnWriteBack:	null,
			preventDefaultOnEnter : false // Call *preventDefault()* on event *keypress* with key 'ENTER';
		},

		_create: function(){
			var o = this.options;

			this.elem = this.element.sub(ep);
			
			this.elem
				.on('click.uiTextedit', this.Proxy('_open'));
				/*.on( 'mouseover.uiTextedit', this.Proxy('_onmouseover') )
				.on( 'mouseout.uiTextedit', this.Proxy('_onmouseout') );*/
		},
		
		_build: function(){
			var self = this,
				o = self.options;

			this.elem
				.on( 'mouseover.uiTextedit', this.Proxy('_onmouseover') )
				.on( 'mouseout.uiTextedit', this.Proxy('_onmouseout') );

			this.uiInput = ep( o.type === 'textarea' ? '<textarea>' : '<input type="text">' )
				.hide()
				.insertAfter( this.elem );
			if(o.validate){
				this.uiInput.uiValidate(o.validate);
			}else{
				this.uiInput.uiInput();
			}
			this.uiInput
				//.uiInput()
				.uiInput('addClass', 'ep-uiTextedit-wrap')
				.on( 'blur.uiTextedit', this.Proxy('_close') )
				.on( 'keypress.uiTextedit', this.Proxy('_onkeypress') )
				.on( 'keyup.uiTextedit', this.Proxy('_onkeyup') );

			//if we have a action we also need a name to save content to the server
			if( o.action ){
				if( o.name || name ){
					this._name = o.name || name;
				}
				else{
					this._name = this.elem.attr('name');
					if( !this._name ){
						console.warn('ep.ui.textedit: unable to save: action is defined but no name is defined');
					}
				}
			}
		},

		_open:function( event ){
			// build textedit construct if necessary
			if(this.uiInput === undefined){
				this._build();
			}
			
			if((this.options.onBeforeOpen!=null) && (typeof this.options.onBeforeOpen=="function")){
				this.options.onBeforeOpen(this.uiInput);
			}


			this.content = this.elem.html();
			var content = this.content;

			this.uiInput.width( Math.max( this.elem.width(), this.MIN_WIDTH ) );
			this.elem.hide();
			this.uiInput
				.show()
				.css( 'display', this.elem.data("olddisplay") );

			if( this.options.convertLineBreaks ){
				content = content.replace(/(<br>|<br \/>)/g, '\n');
			}

			this.uiInput
				.attr({
					//'disabled': false,
					'value': content 
				})
				.focus()
				.select();
			
			if((this.options.onAfterOpen!=null) && (typeof this.options.onAfterOpen=="function")){
				this.options.onAfterOpen(this.uiInput);
			}

			event.stopPropagation();
		},

		_close:function(evt){
			var o = this.options;

			if(!this.uiInput.is(':disabled[disabled]') && !this.uiInput.is(':hidden')) {
			// Otherwise *_close()* has already been called by *_onkeypress()* ('Enter') or
			// *_writeContentBack()* was called by *_onkeyup* ('ESC').
				if(this.uiInput.is(':input:invalid')){
					evt.preventDefault();
					//this.uiInput.focus();
					return;
				}

				this._writeContentBack(evt);
				if (o.action && o.objectId && this._name) {
					this._saveContent();
				}
				//this.uiInput.attr('disabled', true);

				if((this.options.onAfterClose != null) && (typeof this.options.onAfterClose == "function")){
					this.options.onAfterClose(this.uiInput);
				}
			}
		},

		_onkeypress: function( event ){
			/*if( event.keyCode === 27 ){
				this.uiInput.attr( 'value', this.content );
				this._writeContentBack(event);
			}*/
			var o = this.options;
			if( o.type === 'input' && event.keyCode === 13 ){
				if (o.preventDefaultOnEnter) {
					event.preventDefault();
				}
				this._close(event);
			}
		},

		_onkeyup: function( event ){
			if( event.keyCode === 27 ){
				this.uiInput.attr( 'value', this.content );
				this._writeContentBack(event);
			}
		},

		_onmouseover: function(){
			this.elem.addClass('ep-uiTextedit-Hover');
		},

		_onmouseout: function(){
			this.elem.removeClass('ep-uiTextedit-Hover');
		},

		_writeContentBack: function(event){
			var o = this.options;

			this.elem.show();
			this.uiInput.hide();
			
			// FIRST
			if((o.formatOnWriteBack!=null) &&(typeof o.formatOnWriteBack=="function")){
				o.formatOnWriteBack(this.uiInput, event);
			}
			
			this.content = this.uiInput.attr('value');
			if( o.stripHTML){
				this.content = ep.stripTags(this.content);
			}
			if( o.convertLineBreaks){
				this.content = this.content.replace( /(\n)/g, '<br />' );
			}
			/*if((o.formatOnWriteBack!=null) &&(typeof o.formatOnWriteBack=="function")){
				o.formatOnWriteBack(this.uiInput, event);
			}*/
			this.elem.html(this.content);
		},

		_saveContent: function(){
			var o = this.options,
				jsonData = {
					'ViewAction':	'JSONViewResponse',
					'ObjectID':		o.objectId,
					'ChangeAction':	o.action
				};

			jsonData[this._name] = this.content;
			// add additional parameters (e.g. CurrencyID)
			if(o.additional!==undefined){
				$.extend(jsonData, o.additional);
			}

			ep.ajax({
				dataType:	'json',
				data:		jsonData,
				type:		o.xhrType,
				context:	this
			});
		},

		destroy: function(){
			this.uiInput.remove();
			this.elem
				.off('.uiTextedit')
				.show();

			this.Inherited();
		}

	});

});


/* ---- Module:jQuery.ui.position ---- */

/*
 * jQuery UI Position 1.8.18
 *
 * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * http://docs.jquery.com/UI/Position
 */
jQuery.plugin( 'jQuery.ui.position', function( $, undefined ){

$.ui = $.ui || {};

var horizontalPositions = /left|center|right/,
	verticalPositions = /top|center|bottom/,
	center = "center",
	support = {},
	_position = $.fn.position,
	_offset = $.fn.offset;

$.fn.position = function( options ) {
	if ( !options || !options.of ) {
		return _position.apply( this, arguments );
	}

	// make a copy, we don't want to modify arguments
	options = $.extend( {}, options );

	var target = $( options.of ),
		targetElem = target[0],
		collision = ( options.collision || "flip" ).split( " " ),
		offset = options.offset ? options.offset.split( " " ) : [ 0, 0 ],
		targetWidth,
		targetHeight,
		basePosition;

	if ( targetElem.nodeType === 9 ) {
		targetWidth = target.width();
		targetHeight = target.height();
		basePosition = { top: 0, left: 0 };
	// TODO: use $.isWindow() in 1.9
	} else if ( targetElem.setTimeout ) {
		targetWidth = target.width();
		targetHeight = target.height();
		basePosition = { top: target.scrollTop(), left: target.scrollLeft() };
	} else if ( targetElem.preventDefault ) {
		// force left top to allow flipping
		options.at = "left top";
		targetWidth = targetHeight = 0;
		basePosition = { top: options.of.pageY, left: options.of.pageX };
	} else {
		targetWidth = target.outerWidth();
		targetHeight = target.outerHeight();
		basePosition = target.offset();
	}

	// force my and at to have valid horizontal and veritcal positions
	// if a value is missing or invalid, it will be converted to center 
	$.each( [ "my", "at" ], function() {
		var pos = ( options[this] || "" ).split( " " );
		if ( pos.length === 1) {
			pos = horizontalPositions.test( pos[0] ) ?
				pos.concat( [center] ) :
				verticalPositions.test( pos[0] ) ?
					[ center ].concat( pos ) :
					[ center, center ];
		}
		pos[ 0 ] = horizontalPositions.test( pos[0] ) ? pos[ 0 ] : center;
		pos[ 1 ] = verticalPositions.test( pos[1] ) ? pos[ 1 ] : center;
		options[ this ] = pos;
	});

	// normalize collision option
	if ( collision.length === 1 ) {
		collision[ 1 ] = collision[ 0 ];
	}

	// normalize offset option
	offset[ 0 ] = parseInt( offset[0], 10 ) || 0;
	if ( offset.length === 1 ) {
		offset[ 1 ] = offset[ 0 ];
	}
	offset[ 1 ] = parseInt( offset[1], 10 ) || 0;

	if ( options.at[0] === "right" ) {
		basePosition.left += targetWidth;
	} else if ( options.at[0] === center ) {
		basePosition.left += targetWidth / 2;
	}

	if ( options.at[1] === "bottom" ) {
		basePosition.top += targetHeight;
	} else if ( options.at[1] === center ) {
		basePosition.top += targetHeight / 2;
	}

	basePosition.left += offset[ 0 ];
	basePosition.top += offset[ 1 ];

	return this.each(function() {
		var elem = $( this ),
			elemWidth = elem.outerWidth(),
			elemHeight = elem.outerHeight(),
			marginLeft = parseInt( $.curCSS( this, "marginLeft", true ) ) || 0,
			marginTop = parseInt( $.curCSS( this, "marginTop", true ) ) || 0,
			collisionWidth = elemWidth + marginLeft +
				( parseInt( $.curCSS( this, "marginRight", true ) ) || 0 ),
			collisionHeight = elemHeight + marginTop +
				( parseInt( $.curCSS( this, "marginBottom", true ) ) || 0 ),
			position = $.extend( {}, basePosition ),
			collisionPosition;

		if ( options.my[0] === "right" ) {
			position.left -= elemWidth;
		} else if ( options.my[0] === center ) {
			position.left -= elemWidth / 2;
		}

		if ( options.my[1] === "bottom" ) {
			position.top -= elemHeight;
		} else if ( options.my[1] === center ) {
			position.top -= elemHeight / 2;
		}

		// prevent fractions if jQuery version doesn't support them (see #5280)
		if ( !support.fractions ) {
			position.left = Math.round( position.left );
			position.top = Math.round( position.top );
		}

		collisionPosition = {
			left: position.left - marginLeft,
			top: position.top - marginTop
		};

		$.each( [ "left", "top" ], function( i, dir ) {
			if ( $.ui.position[ collision[i] ] ) {
				$.ui.position[ collision[i] ][ dir ]( position, {
					targetWidth: targetWidth,
					targetHeight: targetHeight,
					elemWidth: elemWidth,
					elemHeight: elemHeight,
					collisionPosition: collisionPosition,
					collisionWidth: collisionWidth,
					collisionHeight: collisionHeight,
					offset: offset,
					my: options.my,
					at: options.at
				});
			}
		});

		if ( $.fn.bgiframe ) {
			elem.bgiframe();
		}
		elem.offset( $.extend( position, { using: options.using } ) );
	});
};

$.ui.position = {
	fit: {
		left: function( position, data ) {
			var win = $( window ),
				over = data.collisionPosition.left + data.collisionWidth - win.width() - win.scrollLeft();
			position.left = over > 0 ? position.left - over : Math.max( position.left - data.collisionPosition.left, position.left );
		},
		top: function( position, data ) {
			var win = $( window ),
				over = data.collisionPosition.top + data.collisionHeight - win.height() - win.scrollTop();
			position.top = over > 0 ? position.top - over : Math.max( position.top - data.collisionPosition.top, position.top );
		}
	},

	flip: {
		left: function( position, data ) {
			if ( data.at[0] === center ) {
				return;
			}
			var win = $( window ),
				over = data.collisionPosition.left + data.collisionWidth - win.width() - win.scrollLeft(),
				myOffset = data.my[ 0 ] === "left" ?
					-data.elemWidth :
					data.my[ 0 ] === "right" ?
						data.elemWidth :
						0,
				atOffset = data.at[ 0 ] === "left" ?
					data.targetWidth :
					-data.targetWidth,
				offset = -2 * data.offset[ 0 ];
			position.left += data.collisionPosition.left < 0 ?
				myOffset + atOffset + offset :
				over > 0 ?
					myOffset + atOffset + offset :
					0;
		},
		top: function( position, data ) {
			if ( data.at[1] === center ) {
				return;
			}
			var win = $( window ),
				over = data.collisionPosition.top + data.collisionHeight - win.height() - win.scrollTop(),
				myOffset = data.my[ 1 ] === "top" ?
					-data.elemHeight :
					data.my[ 1 ] === "bottom" ?
						data.elemHeight :
						0,
				atOffset = data.at[ 1 ] === "top" ?
					data.targetHeight :
					-data.targetHeight,
				offset = -2 * data.offset[ 1 ];
			position.top += data.collisionPosition.top < 0 ?
				myOffset + atOffset + offset :
				over > 0 ?
					myOffset + atOffset + offset :
					0;
		}
	}
};

// offset setter from jQuery 1.4
if ( !$.offset.setOffset ) {
	$.offset.setOffset = function( elem, options ) {
		// set position first, in-case top/left are set even on static elem
		if ( /static/.test( $.curCSS( elem, "position" ) ) ) {
			elem.style.position = "relative";
		}
		var curElem   = $( elem ),
			curOffset = curElem.offset(),
			curTop    = parseInt( $.curCSS( elem, "top",  true ), 10 ) || 0,
			curLeft   = parseInt( $.curCSS( elem, "left", true ), 10)  || 0,
			props     = {
				top:  (options.top  - curOffset.top)  + curTop,
				left: (options.left - curOffset.left) + curLeft
			};
		
		if ( 'using' in options ) {
			options.using.call( elem, props );
		} else {
			curElem.css( props );
		}
	};

	$.fn.offset = function( options ) {
		var elem = this[ 0 ];
		if ( !elem || !elem.ownerDocument ) { return null; }
		if ( options ) { 
			return this.each(function() {
				$.offset.setOffset( this, options );
			});
		}
		return _offset.call( this );
	};
}

// fraction support test (older versions of jQuery don't support fractions)
(function () {
	var body = document.getElementsByTagName( "body" )[ 0 ], 
		div = document.createElement( "div" ),
		testElement, testElementParent, testElementStyle, offset, offsetTotal;

	//Create a "fake body" for testing based on method used in jQuery.support
	testElement = document.createElement( body ? "div" : "body" );
	testElementStyle = {
		visibility: "hidden",
		width: 0,
		height: 0,
		border: 0,
		margin: 0,
		background: "none"
	};
	if ( body ) {
		$.extend( testElementStyle, {
			position: "absolute",
			left: "-1000px",
			top: "-1000px"
		});
	}
	for ( var i in testElementStyle ) {
		testElement.style[ i ] = testElementStyle[ i ];
	}
	testElement.appendChild( div );
	testElementParent = body || document.documentElement;
	testElementParent.insertBefore( testElement, testElementParent.firstChild );

	div.style.cssText = "position: absolute; left: 10.7432222px; top: 10.432325px; height: 30px; width: 201px;";

	offset = $( div ).offset( function( _, offset ) {
		return offset;
	}).offset();

	testElement.innerHTML = "";
	testElementParent.removeChild( testElement );

	offsetTotal = offset.top + offset.left + ( body ? 2000 : 0 );
	support.fractions = offsetTotal > 21 && offsetTotal < 22;
})();

});


/* ---- Module:jQuery.ui.accordion ---- */

/*
 * jQuery UI Accordion 1.8.18
 *
 * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * http://docs.jquery.com/UI/Accordion
 *
 * Depends:
 *	jquery.ui.core.js
 *	jquery.ui.widget.js
 */
jQuery.plugin( 'jQuery.ui.accordion', [
	'jQuery.ui.core',
	'jQuery.ui.widget'
], function( $, undefined ){

$.widget( "ui.accordion", {
	options: {
		active: 0,
		animated: "slide",
		autoHeight: true,
		clearStyle: false,
		collapsible: false,
		event: "click",
		fillSpace: false,
		header: "> li > :first-child,> :not(li):even",
		icons: {
			header: "ui-icon-triangle-1-e",
			headerSelected: "ui-icon-triangle-1-s"
		},
		navigation: false,
		navigationFilter: function() {
			return this.href.toLowerCase() === location.href.toLowerCase();
		}
	},

	_create: function() {
		var self = this,
			options = self.options;

		self.running = 0;

		self.element
			.addClass( "ui-accordion ui-widget ui-helper-reset" )
			// in lack of child-selectors in CSS
			// we need to mark top-LIs in a UL-accordion for some IE-fix
			.children( "li" )
				.addClass( "ui-accordion-li-fix" );

		self.headers = self.element.find( options.header )
			.addClass( "ui-accordion-header ui-helper-reset ui-state-default ui-corner-all" )
			.on( "mouseenter.accordion", function() {
				if ( options.disabled ) {
					return;
				}
				$( this ).addClass( "ui-state-hover" );
			})
			.on( "mouseleave.accordion", function() {
				if ( options.disabled ) {
					return;
				}
				$( this ).removeClass( "ui-state-hover" );
			})
			.on( "focus.accordion", function() {
				if ( options.disabled ) {
					return;
				}
				$( this ).addClass( "ui-state-focus" );
			})
			.on( "blur.accordion", function() {
				if ( options.disabled ) {
					return;
				}
				$( this ).removeClass( "ui-state-focus" );
			});

		self.headers.next()
			.addClass( "ui-accordion-content ui-helper-reset ui-widget-content ui-corner-bottom" );

		if ( options.navigation ) {
			var current = self.element.find( "a" ).filter( options.navigationFilter ).eq( 0 );
			if ( current.length ) {
				var header = current.closest( ".ui-accordion-header" );
				if ( header.length ) {
					// anchor within header
					self.active = header;
				} else {
					// anchor within content
					self.active = current.closest( ".ui-accordion-content" ).prev();
				}
			}
		}

		self.active = self._findActive( self.active || options.active )
			.addClass( "ui-state-default ui-state-active" )
			.toggleClass( "ui-corner-all" )
			.toggleClass( "ui-corner-top" );
		self.active.next().addClass( "ui-accordion-content-active" );

/*
 * ePages: BEGIN
		self._createIcons();
 */
		if ( !options.prebuilt ) {
			self._createIcons();
		}
/*
 * ePages: END
 */
		self.resize();
		
		// ARIA
		self.element.attr( "role", "tablist" );

		self.headers
			.attr( "role", "tab" )
			.on( "keydown.accordion", function( event ) {
				return self._keydown( event );
			})
			.next()
				.attr( "role", "tabpanel" );

		self.headers
			.not( self.active || "" )
			.attr({
				"aria-expanded": "false",
				"aria-selected": "false",
				tabIndex: -1
			})
			.next()
				.hide();

		// make sure at least one header is in the tab order
		if ( !self.active.length ) {
			self.headers.eq( 0 ).attr( "tabIndex", 0 );
		} else {
			self.active
				.attr({
					"aria-expanded": "true",
					"aria-selected": "true",
					tabIndex: 0
				});
		}

		// only need links in tab order for Safari
		if ( !$.browser.safari ) {
			self.headers.find( "a" ).attr( "tabIndex", -1 );
		}

		if ( options.event ) {
			self.headers.on( options.event.split(" ").join(".accordion ") + ".accordion", function(event) {
				self._clickHandler.call( self, event, this );
				event.preventDefault();
			});
		}
	},

	_createIcons: function() {
		var options = this.options;
		if ( options.icons ) {
			$( "<span></span>" )
				.addClass( "ui-icon " + options.icons.header )
				.prependTo( this.headers );
			this.active.children( ".ui-icon" )
				.toggleClass(options.icons.header)
				.toggleClass(options.icons.headerSelected);
			this.element.addClass( "ui-accordion-icons" );
		}
	},

	_destroyIcons: function() {
		this.headers.children( ".ui-icon" ).remove();
		this.element.removeClass( "ui-accordion-icons" );
	},

	destroy: function() {
		var options = this.options;

		this.element
			.removeClass( "ui-accordion ui-widget ui-helper-reset" )
			.removeAttr( "role" );

		this.headers
			.off( ".accordion" )
			.removeClass( "ui-accordion-header ui-accordion-disabled ui-helper-reset ui-state-default ui-corner-all ui-state-active ui-state-disabled ui-corner-top" )
			.removeAttr( "role" )
			.removeAttr( "aria-expanded" )
			.removeAttr( "aria-selected" )
			.removeAttr( "tabIndex" );

		this.headers.find( "a" ).removeAttr( "tabIndex" );
		this._destroyIcons();
		var contents = this.headers.next()
			.css( "display", "" )
			.removeAttr( "role" )
			.removeClass( "ui-helper-reset ui-widget-content ui-corner-bottom ui-accordion-content ui-accordion-content-active ui-accordion-disabled ui-state-disabled" );
		if ( options.autoHeight || options.fillHeight ) {
			contents.css( "height", "" );
		}

		return $.Widget.prototype.destroy.call( this );
	},

	_setOption: function( key, value ) {
		$.Widget.prototype._setOption.apply( this, arguments );
			
		if ( key == "active" ) {
			this.activate( value );
		}
		if ( key == "icons" ) {
			this._destroyIcons();
			if ( value ) {
				this._createIcons();
			}
		}
		// #5332 - opacity doesn't cascade to positioned elements in IE
		// so we need to add the disabled class to the headers and panels
		if ( key == "disabled" ) {
			this.headers.add(this.headers.next())
				[ value ? "addClass" : "removeClass" ](
					"ui-accordion-disabled ui-state-disabled" );
		}
	},

	_keydown: function( event ) {
		if ( this.options.disabled || event.altKey || event.ctrlKey ) {
			return;
		}

		var keyCode = $.ui.keyCode,
			length = this.headers.length,
			currentIndex = this.headers.index( event.target ),
			toFocus = false;

		switch ( event.keyCode ) {
			case keyCode.RIGHT:
			case keyCode.DOWN:
				toFocus = this.headers[ ( currentIndex + 1 ) % length ];
				break;
			case keyCode.LEFT:
			case keyCode.UP:
				toFocus = this.headers[ ( currentIndex - 1 + length ) % length ];
				break;
			case keyCode.SPACE:
			case keyCode.ENTER:
				this._clickHandler( { target: event.target }, event.target );
				event.preventDefault();
		}

		if ( toFocus ) {
			$( event.target ).attr( "tabIndex", -1 );
			$( toFocus ).attr( "tabIndex", 0 );
			toFocus.focus();
			return false;
		}

		return true;
	},

	resize: function() {
		var options = this.options,
			maxHeight;

		if ( options.fillSpace ) {
			if ( $.browser.msie ) {
				var defOverflow = this.element.parent().css( "overflow" );
				this.element.parent().css( "overflow", "hidden");
			}
			maxHeight = this.element.parent().height();
			if ($.browser.msie) {
				this.element.parent().css( "overflow", defOverflow );
			}

			this.headers.each(function() {
				maxHeight -= $( this ).outerHeight( true );
			});

			this.headers.next()
				.each(function() {
					$( this ).height( Math.max( 0, maxHeight -
						$( this ).innerHeight() + $( this ).height() ) );
				})
				.css( "overflow", "auto" );
		} else if ( options.autoHeight ) {
			maxHeight = 0;
			this.headers.next()
				.each(function() {
					maxHeight = Math.max( maxHeight, $( this ).height( "" ).height() );
				})
				.height( maxHeight );
		}

		return this;
	},

	activate: function( index ) {
		// TODO this gets called on init, changing the option without an explicit call for that
		this.options.active = index;
		// call clickHandler with custom event
		var active = this._findActive( index )[ 0 ];
		this._clickHandler( { target: active }, active );

		return this;
	},

	_findActive: function( selector ) {
		return selector
			? typeof selector === "number"
				? this.headers.filter( ":eq(" + selector + ")" )
				: this.headers.not( this.headers.not( selector ) )
			: selector === false
				? $( [] )
				: this.headers.filter( ":eq(0)" );
	},

	// TODO isn't event.target enough? why the separate target argument?
	_clickHandler: function( event, target ) {
		var options = this.options;
		if ( options.disabled ) {
			return;
		}

		// called only when using activate(false) to close all parts programmatically
		if ( !event.target ) {
			if ( !options.collapsible ) {
				return;
			}
			this.active
				.removeClass( "ui-state-active ui-corner-top" )
				.addClass( "ui-state-default ui-corner-all" )
				.children( ".ui-icon" )
					.removeClass( options.icons.headerSelected )
					.addClass( options.icons.header );
			this.active.next().addClass( "ui-accordion-content-active" );
			var toHide = this.active.next(),
				data = {
					options: options,
					newHeader: $( [] ),
					oldHeader: options.active,
					newContent: $( [] ),
					oldContent: toHide
				},
				toShow = ( this.active = $( [] ) );
			this._toggle( toShow, toHide, data );
			return;
		}

		// get the click target
		var clicked = $( event.currentTarget || target ),
			clickedIsActive = clicked[0] === this.active[0];

		// TODO the option is changed, is that correct?
		// TODO if it is correct, shouldn't that happen after determining that the click is valid?
		options.active = options.collapsible && clickedIsActive ?
			false :
			this.headers.index( clicked );

		// if animations are still active, or the active header is the target, ignore click
		if ( this.running || ( !options.collapsible && clickedIsActive ) ) {
			return;
		}

		// find elements to show and hide
		var active = this.active,
			toShow = clicked.next(),
			toHide = this.active.next(),
			data = {
				options: options,
				newHeader: clickedIsActive && options.collapsible ? $([]) : clicked,
				oldHeader: this.active,
				newContent: clickedIsActive && options.collapsible ? $([]) : toShow,
				oldContent: toHide
			},
			down = this.headers.index( this.active[0] ) > this.headers.index( clicked[0] );

		// when the call to ._toggle() comes after the class changes
		// it causes a very odd bug in IE 8 (see #6720)
		this.active = clickedIsActive ? $([]) : clicked;
		this._toggle( toShow, toHide, data, clickedIsActive, down );

		// switch classes
		active
			.removeClass( "ui-state-active ui-corner-top" )
			.addClass( "ui-state-default ui-corner-all" )
			.children( ".ui-icon" )
				.removeClass( options.icons.headerSelected )
				.addClass( options.icons.header );
		if ( !clickedIsActive ) {
			clicked
				.removeClass( "ui-state-default ui-corner-all" )
				.addClass( "ui-state-active ui-corner-top" )
				.children( ".ui-icon" )
					.removeClass( options.icons.header )
					.addClass( options.icons.headerSelected );
			clicked
				.next()
				.addClass( "ui-accordion-content-active" );
		}

		return;
	},

	_toggle: function( toShow, toHide, data, clickedIsActive, down ) {
		var self = this,
			options = self.options;

		self.toShow = toShow;
		self.toHide = toHide;
		self.data = data;

		var complete = function() {
			if ( !self ) {
				return;
			}
			return self._completed.apply( self, arguments );
		};

		// trigger changestart event
		self._trigger( "changestart", null, self.data );

		// count elements to animate
		self.running = toHide.size() === 0 ? toShow.size() : toHide.size();

		if ( options.animated ) {
			var animOptions = {};

			if ( options.collapsible && clickedIsActive ) {
				animOptions = {
					toShow: $( [] ),
					toHide: toHide,
					complete: complete,
					down: down,
					autoHeight: options.autoHeight || options.fillSpace
				};
			} else {
				animOptions = {
					toShow: toShow,
					toHide: toHide,
					complete: complete,
					down: down,
					autoHeight: options.autoHeight || options.fillSpace
				};
			}

			if ( !options.proxied ) {
				options.proxied = options.animated;
			}

			if ( !options.proxiedDuration ) {
				options.proxiedDuration = options.duration;
			}

			options.animated = $.isFunction( options.proxied ) ?
				options.proxied( animOptions ) :
				options.proxied;

			options.duration = $.isFunction( options.proxiedDuration ) ?
				options.proxiedDuration( animOptions ) :
				options.proxiedDuration;

			var animations = $.ui.accordion.animations,
				duration = options.duration,
				easing = options.animated;

			if ( easing && !animations[ easing ] && !$.easing[ easing ] ) {
				easing = "slide";
			}
			if ( !animations[ easing ] ) {
				animations[ easing ] = function( options ) {
					this.slide( options, {
						easing: easing,
						duration: duration || 700
					});
				};
			}

			animations[ easing ]( animOptions );
		} else {
			if ( options.collapsible && clickedIsActive ) {
				toShow.toggle();
			} else {
				toHide.hide();
				toShow.show();
			}

			complete( true );
		}

		// TODO assert that the blur and focus triggers are really necessary, remove otherwise
		toHide.prev()
			.attr({
				"aria-expanded": "false",
				"aria-selected": "false",
				tabIndex: -1
			})
			.blur();
		toShow.prev()
			.attr({
				"aria-expanded": "true",
				"aria-selected": "true",
				tabIndex: 0
			})
			.focus();
	},

	_completed: function( cancel ) {
		this.running = cancel ? 0 : --this.running;
		if ( this.running ) {
			return;
		}

		if ( this.options.clearStyle ) {
			this.toShow.add( this.toHide ).css({
				height: "",
				overflow: ""
			});
		}

		// other classes are removed before the animation; this one needs to stay until completed
		this.toHide.removeClass( "ui-accordion-content-active" );
		// Work around for rendering bug in IE (#5421)
		if ( this.toHide.length ) {
			this.toHide.parent()[0].className = this.toHide.parent()[0].className;
		}

		this._trigger( "change", null, this.data );
	}
});

$.extend( $.ui.accordion, {
	version: "1.8.18",
	animations: {
		slide: function( options, additions ) {
			options = $.extend({
				easing: "swing",
				duration: 300
			}, options, additions );
			if ( !options.toHide.size() ) {
				options.toShow.animate({
					height: "show",
					paddingTop: "show",
					paddingBottom: "show"
				}, options );
				return;
			}
			if ( !options.toShow.size() ) {
				options.toHide.animate({
					height: "hide",
					paddingTop: "hide",
					paddingBottom: "hide"
				}, options );
				return;
			}
			var overflow = options.toShow.css( "overflow" ),
				percentDone = 0,
				showProps = {},
				hideProps = {},
				fxAttrs = [ "height", "paddingTop", "paddingBottom" ],
				originalWidth;
			// fix width before calculating height of hidden element
			var s = options.toShow;
			originalWidth = s[0].style.width;
			s.width( s.parent().width()
				- parseFloat( s.css( "paddingLeft" ) )
				- parseFloat( s.css( "paddingRight" ) )
				- ( parseFloat( s.css( "borderLeftWidth" ) ) || 0 )
				- ( parseFloat( s.css( "borderRightWidth" ) ) || 0 ) );

			$.each( fxAttrs, function( i, prop ) {
				hideProps[ prop ] = "hide";

				var parts = ( "" + $.css( options.toShow[0], prop ) ).match( /^([\d+-.]+)(.*)$/ );
				showProps[ prop ] = {
					value: parts[ 1 ],
					unit: parts[ 2 ] || "px"
				};
			});
			options.toShow.css({ height: 0, overflow: "hidden" }).show();
			options.toHide
				.filter( ":hidden" )
					.each( options.complete )
				.end()
				.filter( ":visible" )
				.animate( hideProps, {
				step: function( now, settings ) {
					// only calculate the percent when animating height
					// IE gets very inconsistent results when animating elements
					// with small values, which is common for padding
					if ( settings.prop == "height" ) {
						percentDone = ( settings.end - settings.start === 0 ) ? 0 :
							( settings.now - settings.start ) / ( settings.end - settings.start );
					}

					options.toShow[ 0 ].style[ settings.prop ] =
						( percentDone * showProps[ settings.prop ].value )
						+ showProps[ settings.prop ].unit;
				},
				duration: options.duration,
				easing: options.easing,
				complete: function() {
					if ( !options.autoHeight ) {
						options.toShow.css( "height", "" );
					}
					options.toShow.css({
						width: originalWidth,
						overflow: overflow
					});
					options.complete();
				}
			});
		},
		bounceslide: function( options ) {
			this.slide( options, {
				easing: options.down ? "easeOutBounce" : "swing",
				duration: options.down ? 1000 : 200
			});
		}
	}
});

});


/* ---- Module:jQuery.effects.clip ---- */

/*
 * jQuery UI Effects Clip 1.8.18
 *
 * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * http://docs.jquery.com/UI/Effects/Clip
 *
 * Depends:
 *	jquery.effects.core.js
 */
jQuery.plugin( 'jQuery.effects.clip', 'jQuery.effects.core', function( $, undefined ){

$.effects.clip = function(o) {

	return this.queue(function() {

		// Create element
		var el = $(this), props = ['position','top','bottom','left','right','height','width'];

		// Set options
		var mode = $.effects.setMode(el, o.options.mode || 'hide'); // Set Mode
		var direction = o.options.direction || 'vertical'; // Default direction

		// Adjust
		$.effects.save(el, props); el.show(); // Save & Show
		var wrapper = $.effects.createWrapper(el).css({overflow:'hidden'}); // Create Wrapper
		var animate = el[0].tagName == 'IMG' ? wrapper : el;
		var ref = {
			size: (direction == 'vertical') ? 'height' : 'width',
			position: (direction == 'vertical') ? 'top' : 'left'
		};
		var distance = (direction == 'vertical') ? animate.height() : animate.width();
		if(mode == 'show') { animate.css(ref.size, 0); animate.css(ref.position, distance / 2); } // Shift

		// Animation
		var animation = {};
		animation[ref.size] = mode == 'show' ? distance : 0;
		animation[ref.position] = mode == 'show' ? 0 : distance / 2;

		// Animate
		animate.animate(animation, { queue: false, duration: o.duration, easing: o.options.easing, complete: function() {
			if(mode == 'hide') el.hide(); // Hide
			$.effects.restore(el, props); $.effects.removeWrapper(el); // Restore
			if(o.callback) o.callback.apply(el[0], arguments); // Callback
			el.dequeue();
		}});

	});

};

});


/* ---- Module:jQuery.ui.dialog ---- */

/*
 * jQuery UI Dialog 1.8.18
 *
 * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * http://docs.jquery.com/UI/Dialog
 *
 * Depends:
 *	jquery.ui.core.js
 *	jquery.ui.widget.js
 *  jquery.ui.button.js
 *	jquery.ui.draggable.js
 *	jquery.ui.mouse.js
 *	jquery.ui.position.js
 *	jquery.ui.resizable.js
 */
jQuery.plugin( 'jQuery.ui.dialog', [
	'jQuery.ui.core',
	'jQuery.ui.widget',
//	'jQuery.ui.button',
//	'jQuery.ui.draggable',
//	'jQuery.ui.resizable',
	'jQuery.ui.mouse',
	'jQuery.ui.position'
], function( $, undefined ){

var uiDialogClasses =
		'ui-dialog ' +
		'ui-widget ' +
		'ui-widget-content ' +
		'ui-corner-all ',
	sizeRelatedOptions = {
		buttons: true,
		height: true,
		maxHeight: true,
		maxWidth: true,
		minHeight: true,
		minWidth: true,
		width: true
	},
	resizableRelatedOptions = {
		maxHeight: true,
		maxWidth: true,
		minHeight: true,
		minWidth: true
	},
	// support for jQuery 1.3.2 - handle common attrFn methods for dialog
	attrFn = $.attrFn || {
		val: true,
		css: true,
		html: true,
		text: true,
		data: true,
		width: true,
		height: true,
		offset: true,
		click: true
	};

$.widget("ui.dialog", {
	options: {
		autoOpen: true,
		buttons: {},
		closeOnEscape: true,
		closeText: 'close',
		dialogClass: '',
		draggable: true,
		hide: null,
		height: 'auto',
		maxHeight: false,
		maxWidth: false,
		minHeight: 150,
		minWidth: 150,
		modal: false,
		position: {
			my: 'center',
			at: 'center',
			collision: 'fit',
			// ensure that the titlebar is never outside the document
			using: function(pos) {
				var topOffset = $(this).css(pos).offset().top;
				if (topOffset < 0) {
					$(this).css('top', pos.top - topOffset);
				}
			}
		},
		resizable: true,
		show: null,
		stack: true,
		title: '',
		width: 300,
		zIndex: 1000
	},

	_create: function() {
		this.originalTitle = this.element.attr('title');
		// #5742 - .attr() might return a DOMElement
		if ( typeof this.originalTitle !== "string" ) {
			this.originalTitle = "";
		}

		this.options.title = this.options.title || this.originalTitle;
		var self = this,
			options = self.options,

			title = options.title || '&#160;',
			titleId = $.ui.dialog.getTitleId(self.element),

			uiDialog = (self.uiDialog = $('<div></div>'))
				.appendTo(document.body)
				.hide()
				.addClass(uiDialogClasses + options.dialogClass)
				.css({
					zIndex: options.zIndex
				})
				// setting tabIndex makes the div focusable
				// setting outline to 0 prevents a border on focus in Mozilla
				.attr('tabIndex', -1).css('outline', 0).keydown(function(event) {
					if (options.closeOnEscape && !event.isDefaultPrevented() && event.keyCode &&
						event.keyCode === $.ui.keyCode.ESCAPE) {
						
						self.close(event);
						event.preventDefault();
					}
				})
				.attr({
					role: 'dialog',
					'aria-labelledby': titleId
				})
				.mousedown(function(event) {
					self.moveToTop(false, event);
				}),

			uiDialogContent = self.element
				.show()
				.removeAttr('title')
				.addClass(
					'ui-dialog-content ' +
					'ui-widget-content')
				.appendTo(uiDialog),

			uiDialogTitlebar = (self.uiDialogTitlebar = $('<div></div>'))
				.addClass(
					'ui-dialog-titlebar ' +
					'ui-widget-header ' +
					'ui-corner-all ' +
					'ui-helper-clearfix'
				)
				.prependTo(uiDialog),

			uiDialogTitlebarClose = $('<a href="#"></a>')
				.addClass(
					'ui-dialog-titlebar-close ' +
					'ui-corner-all'
				)
				.attr('role', 'button')
				.hover(
					function() {
						uiDialogTitlebarClose.addClass('ui-state-hover');
					},
					function() {
						uiDialogTitlebarClose.removeClass('ui-state-hover');
					}
				)
				.focus(function() {
					uiDialogTitlebarClose.addClass('ui-state-focus');
				})
				.blur(function() {
					uiDialogTitlebarClose.removeClass('ui-state-focus');
				})
				.click(function(event) {
					self.close(event);
					return false;
				})
				.appendTo(uiDialogTitlebar),

			uiDialogTitlebarCloseText = (self.uiDialogTitlebarCloseText = $('<span></span>'))
				.addClass(
					'ui-icon ' +
					'ui-icon-closethick'
				)
				.text(options.closeText)
				.appendTo(uiDialogTitlebarClose),

			uiDialogTitle = $('<span></span>')
				.addClass('ui-dialog-title')
				.attr('id', titleId)
				.html(title)
				.prependTo(uiDialogTitlebar);

		//handling of deprecated beforeclose (vs beforeClose) option
		//Ticket #4669 http://dev.jqueryui.com/ticket/4669
		//TODO: remove in 1.9pre
		if ($.isFunction(options.beforeclose) && !$.isFunction(options.beforeClose)) {
			options.beforeClose = options.beforeclose;
		}

		uiDialogTitlebar.find("*").add(uiDialogTitlebar).disableSelection();

		if (options.draggable && $.fn.draggable) {
			self._makeDraggable();
		}
		if (options.resizable && $.fn.resizable) {
			self._makeResizable();
		}

		self._createButtons(options.buttons);
		self._isOpen = false;

		if ($.fn.bgiframe) {
			uiDialog.bgiframe();
		}
	},

	_init: function() {
		if ( this.options.autoOpen ) {
			this.open();
		}
	},

	destroy: function() {
		var self = this;
		
		if (self.overlay) {
			self.overlay.destroy();
		}
		self.uiDialog.hide();
		self.element
			.off('.dialog')
			.removeData('dialog')
			.removeClass('ui-dialog-content ui-widget-content')
			.hide().appendTo('body');
		self.uiDialog.remove();

		if (self.originalTitle) {
			self.element.attr('title', self.originalTitle);
		}

		return self;
	},

	widget: function() {
		return this.uiDialog;
	},

	close: function(event) {
		var self = this,
			maxZ, thisZ;
		
		if (false === self._trigger('beforeClose', event)) {
			return;
		}

		if (self.overlay) {
			self.overlay.destroy();
		}
		self.uiDialog.off('keypress.ui-dialog');

		self._isOpen = false;

		if (self.options.hide) {
			self.uiDialog.hide(self.options.hide, function() {
				self._trigger('close', event);
			});
		} else {
			self.uiDialog.hide();
			self._trigger('close', event);
		}

		$.ui.dialog.overlay.resize();

		// adjust the maxZ to allow other modal dialogs to continue to work (see #4309)
		if (self.options.modal) {
			maxZ = 0;
			$('.ui-dialog').each(function() {
				if (this !== self.uiDialog[0]) {
					thisZ = $(this).css('z-index');
					if(!isNaN(thisZ)) {
						maxZ = Math.max(maxZ, thisZ);
					}
				}
			});
			$.ui.dialog.maxZ = maxZ;
		}

		return self;
	},

	isOpen: function() {
		return this._isOpen;
	},

	// the force parameter allows us to move modal dialogs to their correct
	// position on open
	moveToTop: function(force, event) {
		var self = this,
			options = self.options,
			saveScroll;

		if ((options.modal && !force) ||
			(!options.stack && !options.modal)) {
			return self._trigger('focus', event);
		}

		if (options.zIndex > $.ui.dialog.maxZ) {
			$.ui.dialog.maxZ = options.zIndex;
		}
		if (self.overlay) {
			$.ui.dialog.maxZ += 1;
			self.overlay.$el.css('z-index', $.ui.dialog.overlay.maxZ = $.ui.dialog.maxZ);
		}

		//Save and then restore scroll since Opera 9.5+ resets when parent z-Index is changed.
		//  http://ui.jquery.com/bugs/ticket/3193
		saveScroll = { scrollTop: self.element.scrollTop(), scrollLeft: self.element.scrollLeft() };
		$.ui.dialog.maxZ += 1;
		self.uiDialog.css('z-index', $.ui.dialog.maxZ);
		self.element.attr(saveScroll);
		self._trigger('focus', event);

		return self;
	},

	open: function() {
		if (this._isOpen) { return; }

		var self = this,
			options = self.options,
			uiDialog = self.uiDialog;

		self.overlay = options.modal ? new $.ui.dialog.overlay(self) : null;
		self._size();
		self._position(options.position);
		uiDialog.show(options.show);
		self.moveToTop(true);

		// prevent tabbing out of modal dialogs
		if ( options.modal ) {
			uiDialog.on( "keydown.ui-dialog", function( event ) {
				if ( event.keyCode !== $.ui.keyCode.TAB ) {
					return;
				}

				var tabbables = $(':tabbable', this),
					first = tabbables.filter(':first'),
					last  = tabbables.filter(':last');

				if (event.target === last[0] && !event.shiftKey) {
					first.focus(1);
					return false;
				} else if (event.target === first[0] && event.shiftKey) {
					last.focus(1);
					return false;
				}
			});
		}

		// set focus to the first tabbable element in the content area or the first button
		// if there are no tabbable elements, set focus on the dialog itself
		$(self.element.find(':tabbable').get().concat(
			uiDialog.find('.ui-dialog-buttonpane :tabbable').get().concat(
				uiDialog.get()))).eq(0).focus();

		self._isOpen = true;
		self._trigger('open');

		return self;
	},

	_createButtons: function(buttons) {
		var self = this,
			hasButtons = false,
			uiDialogButtonPane = $('<div></div>')
				.addClass(
					'ui-dialog-buttonpane ' +
					'ui-widget-content ' +
					'ui-helper-clearfix'
				),
			uiButtonSet = $( "<div></div>" )
				.addClass( "ui-dialog-buttonset" )
				.appendTo( uiDialogButtonPane );

		// if we already have a button pane, remove it
		self.uiDialog.find('.ui-dialog-buttonpane').remove();

		if (typeof buttons === 'object' && buttons !== null) {
			$.each(buttons, function() {
				return !(hasButtons = true);
			});
		}
		if (hasButtons) {
			$.each(buttons, function(name, props) {
				props = $.isFunction( props ) ?
					{ click: props, text: name } :
					props;
				var button = $('<button type="button"></button>')
					.click(function() {
						props.click.apply(self.element[0], arguments);
					})
					.appendTo(uiButtonSet);
				// can't use .attr( props, true ) with jQuery 1.3.2.
				$.each( props, function( key, value ) {
					if ( key === "click" ) {
						return;
					}
					if ( key in attrFn ) {
						button[ key ]( value );
					} else {
						button.attr( key, value );
					}
				});
				if ($.fn.button) {
					button.button();
				}
			});
			uiDialogButtonPane.appendTo(self.uiDialog);
		}
	},

	_makeDraggable: function() {
		var self = this,
			options = self.options,
			doc = $(document),
			heightBeforeDrag;

		function filteredUi(ui) {
			return {
				position: ui.position,
				offset: ui.offset
			};
		}

		self.uiDialog.draggable({
			cancel: '.ui-dialog-content, .ui-dialog-titlebar-close',
			handle: '.ui-dialog-titlebar',
			containment: 'document',
			start: function(event, ui) {
				heightBeforeDrag = options.height === "auto" ? "auto" : $(this).height();
				$(this).height($(this).height()).addClass("ui-dialog-dragging");
				self._trigger('dragStart', event, filteredUi(ui));
			},
			drag: function(event, ui) {
				self._trigger('drag', event, filteredUi(ui));
			},
			stop: function(event, ui) {
				options.position = [ui.position.left - doc.scrollLeft(),
					ui.position.top - doc.scrollTop()];
				$(this).removeClass("ui-dialog-dragging").height(heightBeforeDrag);
				self._trigger('dragStop', event, filteredUi(ui));
				$.ui.dialog.overlay.resize();
			}
		});
	},

	_makeResizable: function(handles) {
		handles = (handles === undefined ? this.options.resizable : handles);
		var self = this,
			options = self.options,
			// .ui-resizable has position: relative defined in the stylesheet
			// but dialogs have to use absolute or fixed positioning
			position = self.uiDialog.css('position'),
			resizeHandles = (typeof handles === 'string' ?
				handles	:
				'n,e,s,w,se,sw,ne,nw'
			);

		function filteredUi(ui) {
			return {
				originalPosition: ui.originalPosition,
				originalSize: ui.originalSize,
				position: ui.position,
				size: ui.size
			};
		}

		self.uiDialog.resizable({
			cancel: '.ui-dialog-content',
			containment: 'document',
			alsoResize: self.element,
			maxWidth: options.maxWidth,
			maxHeight: options.maxHeight,
			minWidth: options.minWidth,
			minHeight: self._minHeight(),
			handles: resizeHandles,
			start: function(event, ui) {
				$(this).addClass("ui-dialog-resizing");
				self._trigger('resizeStart', event, filteredUi(ui));
			},
			resize: function(event, ui) {
				self._trigger('resize', event, filteredUi(ui));
			},
			stop: function(event, ui) {
				$(this).removeClass("ui-dialog-resizing");
				options.height = $(this).height();
				options.width = $(this).width();
				self._trigger('resizeStop', event, filteredUi(ui));
				$.ui.dialog.overlay.resize();
			}
		})
		.css('position', position)
		.find('.ui-resizable-se').addClass('ui-icon ui-icon-grip-diagonal-se');
	},

	_minHeight: function() {
		var options = this.options;

		if (options.height === 'auto') {
			return options.minHeight;
		} else {
			return Math.min(options.minHeight, options.height);
		}
	},

	_position: function(position) {
		var myAt = [],
			offset = [0, 0],
			isVisible;

		if (position) {
			// deep extending converts arrays to objects in jQuery <= 1.3.2 :-(
	//		if (typeof position == 'string' || $.isArray(position)) {
	//			myAt = $.isArray(position) ? position : position.split(' ');

			if (typeof position === 'string' || (typeof position === 'object' && '0' in position)) {
				myAt = position.split ? position.split(' ') : [position[0], position[1]];
				if (myAt.length === 1) {
					myAt[1] = myAt[0];
				}

				$.each(['left', 'top'], function(i, offsetPosition) {
					if (+myAt[i] === myAt[i]) {
						offset[i] = myAt[i];
						myAt[i] = offsetPosition;
					}
				});

				position = {
					my: myAt.join(" "),
					at: myAt.join(" "),
					offset: offset.join(" ")
				};
			} 

			position = $.extend({}, $.ui.dialog.prototype.options.position, position);
		} else {
			position = $.ui.dialog.prototype.options.position;
		}

		// need to show the dialog to get the actual offset in the position plugin
		isVisible = this.uiDialog.is(':visible');
		if (!isVisible) {
			this.uiDialog.show();
		}
		this.uiDialog
			// workaround for jQuery bug #5781 http://dev.jquery.com/ticket/5781
			.css({ top: 0, left: 0 })
			.position($.extend({ of: window }, position));
		if (!isVisible) {
			this.uiDialog.hide();
		}
	},

	_setOptions: function( options ) {
		var self = this,
			resizableOptions = {},
			resize = false;

		$.each( options, function( key, value ) {
			self._setOption( key, value );
			
			if ( key in sizeRelatedOptions ) {
				resize = true;
			}
			if ( key in resizableRelatedOptions ) {
				resizableOptions[ key ] = value;
			}
		});

		if ( resize ) {
			this._size();
		}
		if ( this.uiDialog.is( ":data(resizable)" ) ) {
			this.uiDialog.resizable( "option", resizableOptions );
		}
	},

	_setOption: function(key, value){
		var self = this,
			uiDialog = self.uiDialog;

		switch (key) {
			//handling of deprecated beforeclose (vs beforeClose) option
			//Ticket #4669 http://dev.jqueryui.com/ticket/4669
			//TODO: remove in 1.9pre
			case "beforeclose":
				key = "beforeClose";
				break;
			case "buttons":
				self._createButtons(value);
				break;
			case "closeText":
				// ensure that we always pass a string
				self.uiDialogTitlebarCloseText.text("" + value);
				break;
			case "dialogClass":
				uiDialog
					.removeClass(self.options.dialogClass)
					.addClass(uiDialogClasses + value);
				break;
			case "disabled":
				if (value) {
					uiDialog.addClass('ui-dialog-disabled');
				} else {
					uiDialog.removeClass('ui-dialog-disabled');
				}
				break;
			case "draggable":
				var isDraggable = uiDialog.is( ":data(draggable)" );
				if ( isDraggable && !value ) {
					uiDialog.draggable( "destroy" );
				}
				
				if ( !isDraggable && value ) {
					self._makeDraggable();
				}
				break;
			case "position":
				self._position(value);
				break;
			case "resizable":
				// currently resizable, becoming non-resizable
				var isResizable = uiDialog.is( ":data(resizable)" );
				if (isResizable && !value) {
					uiDialog.resizable('destroy');
				}

				// currently resizable, changing handles
				if (isResizable && typeof value === 'string') {
					uiDialog.resizable('option', 'handles', value);
				}

				// currently non-resizable, becoming resizable
				if (!isResizable && value !== false) {
					self._makeResizable(value);
				}
				break;
			case "title":
				// convert whatever was passed in o a string, for html() to not throw up
				$(".ui-dialog-title", self.uiDialogTitlebar).html("" + (value || '&#160;'));
				break;
		}

		$.Widget.prototype._setOption.apply(self, arguments);
	},

	_size: function() {
		/* If the user has resized the dialog, the .ui-dialog and .ui-dialog-content
		 * divs will both have width and height set, so we need to reset them
		 */
		var options = this.options,
			nonContentHeight,
			minContentHeight,
			isVisible = this.uiDialog.is( ":visible" );

		// reset content sizing
		this.element.show().css({
			width: 'auto',
			minHeight: 0,
			height: 0
		});

		if (options.minWidth > options.width) {
			options.width = options.minWidth;
		}

		// reset wrapper sizing
		// determine the height of all the non-content elements
		nonContentHeight = this.uiDialog.css({
				height: 'auto',
				width: options.width
			})
			.height();
		minContentHeight = Math.max( 0, options.minHeight - nonContentHeight );
		
		if ( options.height === "auto" ) {
			// only needed for IE6 support
			if ( $.support.minHeight ) {
				this.element.css({
					minHeight: minContentHeight,
					height: "auto"
				});
			} else {
				this.uiDialog.show();
				var autoHeight = this.element.css( "height", "auto" ).height();
				if ( !isVisible ) {
					this.uiDialog.hide();
				}
				this.element.height( Math.max( autoHeight, minContentHeight ) );
			}
		} else {
			this.element.height( Math.max( options.height - nonContentHeight, 0 ) );
		}

		if (this.uiDialog.is(':data(resizable)')) {
			this.uiDialog.resizable('option', 'minHeight', this._minHeight());
		}
	}
});

$.extend($.ui.dialog, {
	version: "1.8.18",

	uuid: 0,
	maxZ: 0,

	getTitleId: function($el) {
		var id = $el.attr('id');
		if (!id) {
			this.uuid += 1;
			id = this.uuid;
		}
		return 'ui-dialog-title-' + id;
	},

	overlay: function(dialog) {
		this.$el = $.ui.dialog.overlay.create(dialog);
	}
});

$.extend($.ui.dialog.overlay, {
	instances: [],
	// reuse old instances due to IE memory leak with alpha transparency (see #5185)
	oldInstances: [],
	maxZ: 0,
	events: $.map('focus,mousedown,mouseup,keydown,keypress,click'.split(','),
		function(event) { return event + '.dialog-overlay'; }).join(' '),
	create: function(dialog) {
		if (this.instances.length === 0) {
			// prevent use of anchors and inputs
			// we use a setTimeout in case the overlay is created from an
			// event that we're going to be cancelling (see #2804)
			setTimeout(function() {
				// handle $(el).dialog().dialog('close') (see #4065)
				if ($.ui.dialog.overlay.instances.length) {
					$(document).on($.ui.dialog.overlay.events, function(event) {
						// stop events if the z-index of the target is < the z-index of the overlay
						// we cannot return true when we don't want to cancel the event (#3523)
						if ($(event.target).zIndex() < $.ui.dialog.overlay.maxZ) {
							return false;
						}
					});
				}
			}, 1);

			// allow closing by pressing the escape key
			$(document).on('keydown.dialog-overlay', function(event) {
				if (dialog.options.closeOnEscape && !event.isDefaultPrevented() && event.keyCode &&
					event.keyCode === $.ui.keyCode.ESCAPE) {
					
					dialog.close(event);
					event.preventDefault();
				}
			});

			// handle window resize
			$(window).on('resize.dialog-overlay', $.ui.dialog.overlay.resize);
		}

		var $el = (this.oldInstances.pop() || $('<div></div>').addClass('ui-widget-overlay'))
			.appendTo(document.body)
			.css({
				width: this.width(),
				height: this.height()
			});

		if ($.fn.bgiframe) {
			$el.bgiframe();
		}

		this.instances.push($el);
		return $el;
	},

	destroy: function($el) {
		var indexOf = $.inArray($el, this.instances);
		if (indexOf != -1){
			this.oldInstances.push(this.instances.splice(indexOf, 1)[0]);
		}

		if (this.instances.length === 0) {
			$([document, window]).off('.dialog-overlay');
		}

		$el.remove();
		
		// adjust the maxZ to allow other modal dialogs to continue to work (see #4309)
		var maxZ = 0;
		$.each(this.instances, function() {
			maxZ = Math.max(maxZ, this.css('z-index'));
		});
		this.maxZ = maxZ;
	},

	height: function() {
		var scrollHeight,
			offsetHeight;
		// handle IE 6
		if ($.browser.msie && $.browser.version < 7) {
			scrollHeight = Math.max(
				document.documentElement.scrollHeight,
				document.body.scrollHeight
			);
			offsetHeight = Math.max(
				document.documentElement.offsetHeight,
				document.body.offsetHeight
			);

			if (scrollHeight < offsetHeight) {
				return $(window).height() + 'px';
			} else {
				return scrollHeight + 'px';
			}
		// handle "good" browsers
		} else {
			return $(document).height() + 'px';
		}
	},

	width: function() {
		var scrollWidth,
			offsetWidth;
		// handle IE
		if ( $.browser.msie ) {
			scrollWidth = Math.max(
				document.documentElement.scrollWidth,
				document.body.scrollWidth
			);
			offsetWidth = Math.max(
				document.documentElement.offsetWidth,
				document.body.offsetWidth
			);

			if (scrollWidth < offsetWidth) {
				return $(window).width() + 'px';
			} else {
				return scrollWidth + 'px';
			}
		// handle "good" browsers
		} else {
			return $(document).width() + 'px';
		}
	},

	resize: function() {
		/* If the dialog is draggable and the user drags it past the
		 * right edge of the window, the document becomes wider so we
		 * need to stretch the overlay. If the user then drags the
		 * dialog back to the left, the document will become narrower,
		 * so we need to shrink the overlay to the appropriate size.
		 * This is handled by shrinking the overlay before setting it
		 * to the full document size.
		 */
		var $overlays = $([]);
		$.each($.ui.dialog.overlay.instances, function() {
			$overlays = $overlays.add(this);
		});

		$overlays.css({
			width: 0,
			height: 0
		}).css({
			width: $.ui.dialog.overlay.width(),
			height: $.ui.dialog.overlay.height()
		});
	}
});

$.extend($.ui.dialog.overlay.prototype, {
	destroy: function() {
		$.ui.dialog.overlay.destroy(this.$el);
	}
});

});


/* ---- Module:ep.ui.dialog ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.ui.dialog
 *
 * @revision		$Revision: 1.15.16.3 $
 */

jQuery.plugin( 'ep.ui.dialog', [ 'ep.core', 'ep.ui.form', 'ep.ui.input', 'jQuery.ui.dialog'], function( $, undefined ){

	$.widget('ep.ui.Dialog',$.ui.dialog,{

		options: {
			resizable:	'se',
			zIndex:		20000
		},

		_create: function(){
			this.Inherited(arguments);

			var self = this,
				o = self.options;

			if( o.form ){
				self._createForm(o.form);
			}

			self.uiDialog
				.removeClass('ui-corner-all')
				.addClass('epDialog');
			self.uiDialogTitlebar
				.removeClass('ui-corner-all')
				.addClass('epDialogTitleBar');

			self._setOption( "closeText", o.closeText );
		},

		_setOption: function( key, value ){
			var self = this;

			switch (key) {
				case 'form':
					if( !self.uiForm ){
						self._createForm(value);
					}
					else{
						self.uiForm.uiForm(value);
					}
				break;
				case 'title':
					$(".ui-dialog-title", self.uiDialogTitlebar)
						.empty()
						.append( self.options.title = (value || '&#160;') );
				break;
				case 'closeText':
					self.uiDialogTitlebar.find(".ui-dialog-titlebar-close").toggle(value !== false);
					value = value === true ? "close" : (value || "");
				default:
					self.Inherited(arguments);
				break;
			}
		},

		_createForm: function( form ){
			this.uiForm = this.options.form = ep('<form>')
				.attr(this.options.form)
				.insertBefore(this.uiDialog)
				.append(this.uiDialog)
				.uiForm();
		},

		_createButtons: function( buttons ) {
			var self = this,
				hasButtons = false,
				uiDialogButtonPane = $('<div>')
					.addClass(
						'ui-dialog-buttonpane ' +
						'ui-widget-content ' +
						'ui-helper-clearfix ' +
						'epDialogButtonBar'
					),
				uiButtonSet = $( "<div>" )
					.addClass( "ui-dialog-buttonset" )
					.appendTo( uiDialogButtonPane );

			// if we already have a button pane, remove it
			self.uiDialog.find('.ui-dialog-buttonpane').remove();

			if( typeof buttons === 'object' && buttons !== null ){
				$.each(buttons, function() {
					return !(hasButtons = true);
				});
			}
			if( hasButtons ){
				$.each(buttons, function(name, props) {
					props = $.extend({
						'type':		'button',
						'text':		name,
						'click':	function(){}
					}, $.isFunction( props ) ? { click: props, text: name } : props );

					// type cann't set with .attr()
					var type = props.type;
					delete(props.type);

					buttons[name] = ep('<button type="'+type+'">')
						.attr( props, true )
						.off('click')
						.appendTo(uiButtonSet)
						.uiInput()
						.on( 'click', function(){
							props.click.apply(self.element[0], arguments);
						});
				});
				uiDialogButtonPane.appendTo(self.uiDialog);
			}
		},

		open: function(){
			this.options.modal && $('body').css('overflow', 'hidden');
			this.Inherited(arguments);
		},

		close: function(){
			this.options.modal && $('body').css('overflow', 'auto');
			this.Inherited(arguments);
		},

		destroy: function(){
			this.Inherited(arguments);

			if( this.uiForm ){
				this.uiForm.remove();
			}
		}

	});

 var overlayCreate = $.ui.dialog.overlay.create;

 $.ui.dialog.overlay.create = function( dialog ){
  var length = this.instances.length,
   ret = overlayCreate.apply( this, arguments );

  if( length === 0 ){
   // allow closing by click the overlay
   $(document).on('click.dialog-overlay', function(event) {
    if( dialog.options.closeOnClickOut && event.originalTarget == dialog.overlay.$el[0] ){
     dialog.close(event);
     event.preventDefault();
    }
   });
  }
  return ret;
 };

});

/* ---- Module:jQuery.i18n ---- */

/*
 * @author			Emanuel Vitzthum
 * @copyright		© 2011 jQuery SDK v1.3.1
 * @info			http://www.jquerysdk.com
 *
 * @license			Dual licensed under the MIT (http://www.opensource.org/licenses/mit-license.php) and GPL (http://www.gnu.org/licenses/gpl.html)
 *
 * @based			Microsoft Open Source jQuery Globalization Plugin (http://github.com/nje/jquery-glob)
 *
 * @plugin			jQuery.i18n
 */

(function( $, undefined ){

		// map of format shortcuts
	var typeMap = {
			'date':					'd',
			'dateLong':				'D',
			'dateLong-time':		'f',
			'dateLong-timeLong':	'F',
			'date-time':			'l',
			'date-timeLong':		'L',
			'time':					't',
			'timeLong':				'T',
			'currency':				'c',
			'number':				'n',
			'percent':				'p'
		},

		// local to string mathod
		toString =					Object.prototype.toString,

		shortTypeExp =				/[dDfFlLtTcnp]/,

		nTypeExp =					/[cnp]/,

		curSymbolExp =				/\$/,

		i18nTypeExp =				/^[A-Z]+$/,

		escRegexpExp =				/([\.$?*|{}\(\)\[\]\\\/\+^])/g,

		dayPartRegExp =				/([^d]|^)(d|dd)([^d]|$)/g,

		infinityExp =				/^[+-]?infinity$/i,

		hexExp =					/^0x[a-f0-9]+$/i,

		parseFloatExp =				/^[+-]?\d*\.?\d*(e[+-]?\d+)?$/,

		// regular expression for matching date and time tokens in format strings.
		tokenDateExp =				/\/|dddd|ddd|dd|d|MMMM|MMM|MM|M|yyyy|yy|y|hh|h|HH|H|mm|m|ss|s|tt|t|fff|ff|f|W|zzz|zz|z|gg|g/g,

		// regular expression for matching number tokens in format strings.
		tokenNumberExp =			/(c\d*|n\d*|p\d*)/g,

		expandFormatExp =			/([\^\$\.\*\+\?\|\[\]\(\)\{\}])/g,

		expandSplitExp =			/e/i,

		numberTypeExp =				/(c|n|p)(\d*)/,

		whiteSpaceExp =				/\s+/g,

		cSymbolStrictExp =			/(\s*)(\\\$)(\s*)/g,

		cSymbolExp =				/\\\$/g,

		pSymbolStrictExp =			/(\s*)(%)(\s*)/g,

		pSymbolExp =  				/%/g,

		nSymbolExp =				/n/,

		positiveNumberExp =			/[1-9]/,

		altGroupExp =				/\u00A0/g,

		patternPartsExp =			/n|\$|-|%/g,

		// get additional informations of i18n module name
		i18nInfo = function( name ){
			var info = {
					type:	i18nTypeExp.test(name) ? 'currencies' : 'regions',
					name:	name
				};

			info.id = info.type+':'+info.name;

			return info;
		},

		// local scope of dependencies controller settings
		dependSettings = $.dependSettings;

		// jQuery.i18n()
	var i18n = $.i18n = function( type, value, options ){
			type = typeMap[type] || type;
			if( !shortTypeExp.test(type) ){
				return null;
			}
			else if( typeof value==='string' ){
				if( nTypeExp.test(type) ){
					return i18n.parseNumber( value, 10, options );
				}
				else{
					return i18n.parseDate( value, type, options );
				}
			}
			else{
				return i18n[ nTypeExp.test(type) ? 'formatNumber' : 'formatDate' ]( value, type, options );
			}
		},

		// build region data object
		regionBuild = function( options ){
			var o = $.extend( {}, i18n.settings, options ),
				region = i18n.regions[ o.region ] || i18n.regions.en,
				currencies = region.numberFormat.currencies;

			// if a special currency selected
			if( o.currency ){
				var cGlob = i18n.currencies[ o.currency ],
					cExtd = currencies[ o.currency ];

				// merge special currency with standart currency
				if( !cExtd && cGlob ){
					cExtd = region.numberFormat.currencies[ o.currency ] = $.extend( {}, currencies[''] );
/*
 * ePages: BEGIN
					cExtd.pattern = $.merge( $.merge( [], cExtd.pattern ), cGlob.pattern );
 */
					cExtd.pattern = $.merge( $.merge( [], cGlob.pattern ), cExtd.pattern );
/*
 * ePages: END
 */
					cExtd.symbol = cGlob.symbol;
					cExtd.decimals = cGlob.decimals;
				}
			}

			// set current used currency and calendar
			region.numberFormat.currency = currencies[ o.currency ] || currencies[''];
			region.calendar = region.calendars[ o.calendar ] || region.calendars.standart;

			return region;
		};

	$.extend(i18n,{

		// jQuery.i18n.expStrDate()
		expStrDate: function( format, strict, options ){
			if( typeof strict !== 'boolean' ){
				options = strict;
				strict = false;
			}
			var region = regionBuild(options),
				ret = getParseRegExp( region.calendar, format, strict ).regExp;
			return ret.substr(1,ret.length-2);
		},

		// jQuery.i18n.expStrNumber()
		expStrNumber: function( format, strict, options ){
			if( typeof strict !== 'boolean' ){
				options = strict;
				strict = false;
			}
			var region = regionBuild(options),
				ret = getNumberRegExp( [ region.numberFormat, (options || {}).currency ], format, strict ).regExp;
			return ret.substr( 1, ret.length-2 );
		},

		// jQuery.i18n.formatNumber()
		formatNumber: function( value, format, options ) {
			var region = regionBuild(options);
			return formatNumber( value, format, region );
		},

		// jQuery.i18n.formatDate()
		formatDate: function( value, format, options ) {
			var region = regionBuild(options);
			return formatDate( value, format, region );
		},

		// jQuery.i18n.parseNumber()
		parseNumber: function( value, radix, options ) {
			if( isNaN(radix) ){
				options = radix;
				radix = 10;
			}
			var region = regionBuild(options),
				ret = parseNumber( value, radix, region );
			return ret;
		},

		// jQuery.i18n.parseDate()
		parseDate: function( value, formats, options ) {
			var region = regionBuild(options),
				ret = parseDate( value, formats, region );
			return ret;
		},

		// jQuery.i18n.settings
		settings: $.extend(
			{
				region:		'en',
				currency:	'',
				calendar:	'standard'
			},
			$.config.i18n
		),

		// jQuery.i18n.regions
		regions: {

		},

		// jQuery.i18n.currencies
		currencies: {

		}
	});

	// 1.	When defining a region, all fields are required except the ones stated as optional.
	// 2.	You can use $.extend to copy an existing region and provide only the differing values,
	//			a good practice since most regions do not differ too much from the 'default' region.
	//			DO use the 'default' region if you do this, as it is the only one that definitely
	//			exists.
	// 3.	Other plugins may add to the region information provided by extending it. However,
	//			that plugin may extend it prior to the region being defined, or after. Therefore,
	//			do not overwrite values that already exist when defining the baseline for a region,
	//			by extending your region object with the existing one.
	// 4.	Each region should have a ".calendars" object with at least one calendar named "standard"
	//			which serves as the default calendar in use by that region.
	// 5.	Each region should have a ".calendar" object which is the current calendar being used,
	//			it may be dynamically changed at any time to one of the calendars in ".calendars".

	// To define a region, use the following pattern, which handles defining the region based
	// on the 'default region, extending it with the existing region if it exists, and defining
	// it if it does not exist.
	// i18n.regions.foo = $.extend(true, $.extend(true, {}, i18n.regions['default'], fooRegion), i18n.regions.foo)

	var regions = i18n.regions;
	var en = regions.en = $.extend(true, {
		// A unique name for the region in the form <language code>-<country/region code>
		name: "en",
		// the name of the region in the english language
		englishName: "English",
		// the name of the region in its own language
		nativeName: "English",
		// whether the region uses right-to-left text
		isRTL: false,
		// 'language' is used for so-called "specific" regions.
		// For example, the region "es-CL" means "Spanish, in Chili".
		// It represents the Spanish-speaking region as it is in Chili,
		// which might have different formatting rules or even translations
		// than Spanish in Spain. A "neutral" region is one that is not
		// specific to a region. For example, the region "es" is the generic
		// Spanish region, which may be a more generalized version of the language
		// that may or may not be what a specific region expects.
		// For a specific region like "es-CL", the 'language' field refers to the
		// neutral, generic region information for the language it is using.
		// This is not always a simple matter of the string before the dash.
		// For example, the "zh-Hans" region is netural (Simplified Chinese).
		// And the 'zh-SG' region is Simplified Chinese in Singapore, whose lanugage
		// field is "zh-CHS", not "zh".
		// This field should be used to navigate from a specific region to it's
		// more general, neutral region. If a region is already as general as it
		// can get, the language may refer to itself.
		language: "en",
		// numberFormat defines general number formatting rules, like the digits in
		// each grouping, the group separator, and how negative numbers are displayed.
		numberFormat: {
			_parseRegExp:{},
			// [negativePattern]
			// Note, numberFormat.pattern has no 'positivePattern' unlike percent and currency,
			// but is still defined as an array for consistency with them.
			//  negativePattern: one of "(n)|-n|- n|n-|n -"
			pattern: ["-n"],
			// number of decimal places normally shown
			decimals: 2,
			// string that separates number groups, as in 1,000,000
			',': ",",
			// string that separates a number from the fractional portion, as in 1.99
			'.': ".",
			// array of numbers indicating the size of each number group.
			// TODO: more detailed description and example
			groupSizes: [3],
			// symbol used for positive numbers
			'+': "+",
			// symbol used for negative numbers
			'-': "-",
			percent: {
				// [negativePattern, positivePattern]
				//		negativePattern: one of "-n %|-n%|-%n|%-n|%n-|n-%|n%-|-% n|n %-|% n-|% -n|n- %"
				//		positivePattern: one of "n %|n%|%n|% n"
				pattern: ["-n %","n %"],
				// number of decimal places normally shown
				decimals: 2,
				// array of numbers indicating the size of each number group.
				// TODO: more detailed description and example
				groupSizes: [3],
				// string that separates number groups, as in 1,000,000
				',': ",",
				// string that separates a number from the fractional portion, as in 1.99
				'.': ".",
				// symbol used to represent a percentage
				symbol: "%"
			},
			currencies: {'':{
				// [negativePattern, positivePattern]
				//		negativePattern: one of "($n)|-$n|$-n|$n-|(n$)|-n$|n-$|n$-|-n $|-$ n|n $-|$ n-|$ -n|n- $|($ n)|(n $)"
				//		positivePattern: one of "$n|n$|$ n|n $"
				pattern: ["($n)","$n"],
				// number of decimal places normally shown
				decimals: 2,
				// array of numbers indicating the size of each number group.
				// TODO: more detailed description and example
				groupSizes: [3],
				// string that separates number groups, as in 1,000,000
				',': ",",
				// string that separates a number from the fractional portion, as in 1.99
				'.': ".",
				// symbol used to represent currency
				symbol: "$"
			}}
		},
		// calendars defines all the possible calendars used by this region.
		// There should be at least one defined with name 'standard', and is the default
		// calendar used by the region.
		// A calendar contains information about how dates are formatted, information about
		// the calendar's eras, a standard set of the date formats,
		// translations for day and month names, and if the calendar is not based on the Gregorian
		// calendar, conversion functions to and from the Gregorian calendar.
		calendars: {
			standard: {
				// name that identifies the type of calendar this is
				name: "Gregorian_USEnglish",
				// separator of parts of a date (e.g. '/' in 11/05/1955)
				'/': "/",
				// separator of parts of a time (e.g. ':' in 05:44 PM)
				':': ":",
				// the first day of the week (0 = Sunday, 1 = Monday, etc)
				firstDay: 0,
				days: {
					// full day names
					names: ["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],
					// abbreviated day names
					namesAbbr: ["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],
					// shortest day names
					namesShort: ["Su","Mo","Tu","We","Th","Fr","Sa"]
				},
				months: {
					// full month names (13 months for lunar calendards -- 13th month should be "" if not lunar)
					names: ["January","February","March","April","May","June","July","August","September","October","November","December",""],
					// abbreviated month names
					namesAbbr: ["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec",""]
				},
				// AM and PM designators in one of these forms:
				// The usual view, and the upper and lower case versions
				//		[standard,lowercase,uppercase]
				// The region does not use AM or PM (likely all standard date formats use 24 hour time)
				//		null
				AM: ["AM", "am", "AM"],
				PM: ["PM", "pm", "PM"],
				eras: [
					// eras in reverse chronological order.
					// name: the name of the era in this region (e.g. A.D., C.E.)
					// start: when the era starts in ticks (gregorian, gmt), null if it is the earliest supported era.
					// offset: offset in years from gregorian calendar
					{ "name": "A.D.", "start": null, "offset": 0 }
				],
				// minimum of days in the first week of a year
				firstWeekMin: 1,
				// when a two digit year is given, it will never be parsed as a four digit
				// year greater than this year (in the appropriate era for the region)
				// Set it as a full year (e.g. 2031) or use an offset format starting from
				// the current year: "+19" would correspond to 2031 if the current year 2012.
				twoDigitYearMax: 2031,
				// set of predefined date and time patterns used by the region
				// these represent the format someone in this region would expect
				// to see given the portions of the date that are shown.
				patterns: {
					// short date pattern
					d: "M/d/yyyy",
					// long date pattern
					D: "dddd, MMMM dd, yyyy",
					// short time pattern
					t: "h:mm tt",
					// long time pattern
					T: "h:mm:ss tt",
					// short date, short time pattern
					l: "M/d/yyyy h:mm tt",
					// short date, long time pattern
					L: "M/d/yyyy h:mm:ss tt",
					// long date, short time pattern
					f: "dddd, MMMM dd, yyyy h:mm tt",
					// long date, long time pattern
					F: "dddd, MMMM dd, yyyy h:mm:ss tt",
					// month/day pattern
					M: "MMMM dd",
					// month/year pattern
					Y: "yyyy MMMM",
					// S is a sortable format that does not vary by region
					S: "yyyy'/'MM'/'dd' 'HH':'mm':'ss"
				}
				// optional fields for each calendar:
				/*
				monthsGenitive:
					Same as months but used when the day preceeds the month.
					Omit if the region has no genitive distinction in month names.
					For an explaination of genitive months, see http://blogs.msdn.com/michkap/archive/2004/12/25/332259.aspx
				convert:
					Allows for the support of non-gregorian based calendars. This convert object is used to
					to convert a date to and from a gregorian calendar date to handle parsing and formatting.
					The two functions:
						fromGregorian(date)
							Given the date as a parameter, return an array with parts [year, month, day]
							corresponding to the non-gregorian based year, month, and day for the calendar.
						toGregorian(year, month, day)
							Given the non-gregorian year, month, and day, return a new Date() object
							set to the corresponding date in the gregorian calendar.
				*/
			}
		}
	}, regions.en);
	en.calendar = en.calendars.standard;
	en.numberFormat.currency = en.numberFormat.currencies[''];

	// save en as defaults
	i18n.defaults = $.extend({},en);

	function startsWith(value, pattern) {
		return value.indexOf( pattern ) === 0;
	}

	function endsWith(value, pattern) {
		return value.substr( value.length - pattern.length ) === pattern;
	}

	function zeroPad(str, count, left) {
		for (var l=str.length; l < count; l++) {
			str = (left ? ('0' + str) : (str + '0'));
		}
		return str;
	}

	function escRegexpStr( string, except ){
		return string.replace( escRegexpExp, function(ch){
			if(except && except.indexOf(ch) !== -1){
				return ch;
			}
			return "\\" + ch;
		});
	}

	// *************************************** Numbers ***************************************

	function parseNumber( value, radix, region ) {
		var ret = NaN,
			nf = region.numberFormat,
			pattern = nf.pattern[0];

		// parse currncy and percent also
		if( new RegExp(escRegexpStr(nf.currency.symbol),"").test(value) ){
			nf = nf.currency;
			pattern = $.trim(nf.pattern[0].replace(curSymbolExp,""));
			value = value.replace(new RegExp(escRegexpStr(nf.symbol),""),"");
		}
		else if( new RegExp(escRegexpStr(nf.percent.symbol),"").test(value) ){
			nf = nf.percent;
			pattern = $.trim(nf.pattern[0].replace(curSymbolExp,""));
			value = value.replace(new RegExp(escRegexpStr(nf.symbol),""),"");
		}

		// $.trim leading and trailing whitespace
		value = $.trim( value );
		nf['+'] = region.numberFormat['+'];
		nf['-'] = region.numberFormat['-'];

		// allow infinity or hexidecimal
		if (infinityExp.test(value)) {
			ret = parseFloat(value, radix);
		}
		else if (!radix && hexExp.test(value)) {
			ret = parseInt(value, 16);
		}
		else {
			var signInfo = parseNegativePattern( value, nf, pattern );
			// determine sign and number
			if ( signInfo[0] === "" && pattern !== "-n" && nf.pattern[2] ) {
				pattern = $.trim(nf.pattern[0].replace(curSymbolExp,""));
				signInfo = parseNegativePattern( value, nf, pattern );
			}
			// determine sign and number
			if ( signInfo[0] === "" && pattern !== "-n" ) {
				signInfo = parseNegativePattern( value, nf, "-n" );
			}
			var sign = signInfo[0],
				num = signInfo[1];

			sign = sign || "+";
			// determine exponent and number
			var exponent,
				intAndFraction,
				exponentPos = num.indexOf( 'e' );
			if ( exponentPos < 0 )
				exponentPos = num.indexOf( 'E' );
			if ( exponentPos < 0 ) {
				intAndFraction = num;
				exponent = null;
			}
			else {
				intAndFraction = num.substr( 0, exponentPos );
				exponent = num.substr( exponentPos + 1 );
			}
			// determine decimal position
			var integer,
				fraction,
				decSep = nf['.'],
				decimalPos = intAndFraction.indexOf( decSep );
			if ( decimalPos < 0 ) {
				integer = intAndFraction;
				fraction = null;
			}
			else {
				integer = intAndFraction.substr( 0, decimalPos );
				fraction = intAndFraction.substr( decimalPos + decSep.length );
			}
			// handle groups (e.g. 1,000,000)
			var groupSep = nf[","];
			integer = integer.split(groupSep).join('');
			var altGroupSep = groupSep.replace(altGroupExp, " ");
			if ( groupSep !== altGroupSep ) {
				integer = integer.split(altGroupSep).join('');
			}
			// build a natively parsable number string
			var p = sign + integer;
			if ( fraction !== null ) {
				p += '.' + fraction;
			}
			if ( exponent !== null ) {
				// exponent itself may have a number patternd
				var expSignInfo = parseNegativePattern( exponent, nf, "-n" );
				p += 'e' + (expSignInfo[0] || "+") + expSignInfo[1];
			}
			if ( parseFloatExp.test( p ) ) {
				ret = parseFloat( p );
			}
		}
		return ret;
	}

	function regexpNumber( format, length, strict ){
		var lengthInt = parseInt( length, 10 );
		length = isNaN(lengthInt) ? format.decimals : lengthInt;

		var num = "\\d+(?:",
			patterns = format.pattern;


		for( var i=format.groupSizes.length-1,l=i ; i>=0 ; i-- ){
			var size = format.groupSizes[i];
			num += size===0 ? "\\d*" : "(?:" + escRegexpStr(format[","]) + "?\\d{" + size + "})" + (i===l ?"*":(i===0?"{1}|(?:" + escRegexpStr(format[","]) + "?\\d{" + size + "})?":"?"));
		}
		num += ")";

		if(length===0){
			num += "";
		}
		else{
			num +=		strict ? ( escRegexpStr(format["."]) + "{1}\\d{"+length+"}") : ("(?:"+ escRegexpStr(format["."]) + "{1}\\d{0,"+length+"})?");
		}

		var ret = [];
		$.each(patterns,function( i, name ){
			ret.push( escRegexpStr(name).replace(nSymbolExp,num) );
		});
		if( patterns.length===1 ){
			ret.push( ("n").replace(nSymbolExp,num) );
		}

		return "("+ret.join("|")+")";
	}

	function getNumberRegExp( nf, format, strict ){
		var c = nf[1] || '';
		nf = nf[0];
		var re = nf._parseRegExp[c];
		if ( !re ) {
			re = nf._parseRegExp[c] = {};
		}
		else {
			var reFormat = re[ format ];
			if ( reFormat && reFormat.strict === strict ) {
				return reFormat;
			}
		}

		var expFormat = format.replace( expandFormatExp, "\\\\$1" ),
			groups = [],
			regexp = ["^"],
			index = 0,
			quoteCount = 0,
			match;

		// iterate through each date token found.
		while ( (match = tokenNumberExp.exec( expFormat )) !== null ) {
			var preMatch = expFormat.slice( index, match.index );
			index = tokenNumberExp.lastIndex;

			// don't replace any matches that occur inside a string literal.
			quoteCount += appendPreOrPostMatch( preMatch, regexp );
			if ( quoteCount % 2 ) {
				regexp.push( match[ 0 ] );
				continue;
			}
			var m = numberTypeExp.exec(match[0]),
				add;

			switch( m[1] ){
				case 'c':
					add = regexpNumber( nf.currency, m[2], strict )
						.replace( cSymbolStrictExp, strict ? "$1$2$3" : "\\s*$2\\s*")
						.replace( cSymbolExp, "(?:"+escRegexpStr(nf.currency.symbol)+")" + (strict ? "" : "?") );
					break;
				case 'n':
					add = regexpNumber( nf, m[2], strict );
					break;
				case 'p':
					add = regexpNumber( nf.percent, m[2], strict )
						.replace( pSymbolStrictExp, strict ? "$1$2$3" : "\\s*$2\\s*")
						.replace( pSymbolExp, "(?:"+escRegexpStr(nf.percent.symbol)+")" + (strict ? "" : "?") );
					break;
			}

			if ( add ) {
				regexp.push( add );
			}
			groups.push( match[ 0 ] );
		}
		appendPreOrPostMatch( expFormat.slice( index ), regexp );
		regexp.push( "$" );

		var regexpStr = regexp.join( '' ).replace( whiteSpaceExp, "\\s+" ),					// allow whitespace to differ when matching formats.
			parseRegExp = {'regExp': regexpStr, 'groups': groups, strict: strict},
			ret = re[ format ] = parseRegExp;											// cache the regex for this format.
		return ret;
	}

	function expandNumber(number, precision, formatInfo) {
		var groupSizes = formatInfo.groupSizes,
			curSize = groupSizes[ 0 ],
			curGroupIndex = 1,
			factor = Math.pow( 10, precision ),
			rounded = Math.round( number * factor ) / factor;
		if ( !isFinite(rounded) ) {
			rounded = number;
		}
		number = rounded;

		var numberString = number+"",
			right = "",
			split = numberString.split(expandSplitExp),
			exponent = split.length > 1 ? parseInt( split[ 1 ], 10 ) : 0;
		numberString = split[ 0 ];
		split = numberString.split( "." );
		numberString = split[ 0 ];
		right = split.length > 1 ? split[ 1 ] : "";

		var l;
		if ( exponent > 0 ) {
			right = zeroPad( right, exponent, false );
			numberString += right.slice( 0, exponent );
			right = right.substr( exponent );
		}
		else if ( exponent < 0 ) {
			exponent = -exponent;
			numberString = zeroPad( numberString, exponent + 1 );
			right = numberString.slice( -exponent, numberString.length ) + right;
			numberString = numberString.slice( 0, -exponent );
		}

		if ( precision > 0 ) {
			right = formatInfo['.'] +
				((right.length > precision) ? right.slice( 0, precision ) : zeroPad( right, precision ));
		}
		else {
			right = "";
		}

		var stringIndex = numberString.length - 1,
			sep = formatInfo[","],
			ret = "";

		while ( stringIndex >= 0 ) {
			if ( curSize === 0 || curSize > stringIndex ) {
				return numberString.slice( 0, stringIndex + 1 ) + ( ret.length ? ( sep + ret + right ) : right );
			}
			ret = numberString.slice( stringIndex - curSize + 1, stringIndex + 1 ) + ( ret.length ? ( sep + ret ) : "" );

			stringIndex -= curSize;

			if ( curGroupIndex < groupSizes.length ) {
				curSize = groupSizes[ curGroupIndex ];
				curGroupIndex++;
			}
		}
		return numberString.slice( 0, stringIndex + 1 ) + sep + ret + right;
	}

	function parseNegativePattern(value, nf, negativePattern) {
		var neg = nf["-"],
			pos = nf["+"],
			ret;
		switch (negativePattern) {
			case "n -":
				neg = ' ' + neg;
				pos = ' ' + pos;
				// fall through
			case "n-":
				if ( endsWith( value, neg ) ) {
					ret = [ '-', value.substr( 0, value.length - neg.length ) ];
				}
				else if ( endsWith( value, pos ) ) {
					ret = [ '+', value.substr( 0, value.length - pos.length ) ];
				}
				break;
			case "- n":
				neg += ' ';
				pos += ' ';
				// fall through
			case "-n":
				if ( startsWith( value, neg ) ) {
					ret = [ '-', value.substr( neg.length ) ];
				}
				else if ( startsWith(value, pos) ) {
					ret = [ '+', value.substr( pos.length ) ];
				}
				break;
			case "(n)":
				if ( startsWith( value, '(' ) && endsWith( value, ')' ) ) {
					ret = [ '-', value.substr( 1, value.length - 2 ) ];
				}
				break;
		}
		return ret || [ '', value ];
	}

	function formatNumber(value, format, region) {
		if ( !format || format === 'i' ) {
			return region.name.length ? value.toLocaleString() : value.toString();
		}
		format = format || "D";

		var nf = region.numberFormat,
			number = Math.abs(value),
			precision = -1,
			pattern;
		if (format.length > 1) precision = parseInt( format.slice( 1 ), 10 );

		var current = format.charAt( 0 ).toUpperCase(),
			formatInfo;

		switch (current) {
			case "D":
				pattern = 'n';
				if (precision !== -1) {
					number = zeroPad( ""+number, precision, true );
				}
				if (value < 0) number = -number;
				break;
			case "N":
				formatInfo = nf;
				// fall through
			case "C":
				formatInfo = formatInfo || nf.currency;
				// fall through
			case "P":
				formatInfo = formatInfo || nf.percent;
				pattern = value < 0 ? formatInfo.pattern[0] : (formatInfo.pattern[1] || "n");
				if (precision === -1) precision = formatInfo.decimals;
				number = expandNumber( number , precision, formatInfo );
				break;
			default:
				throw "Bad number format specifier: " + current;
		}

		var ret = "";
		for (;;) {
			var index = patternPartsExp.lastIndex,
				ar = patternPartsExp.exec(pattern);

			ret += pattern.slice( index, ar ? ar.index : pattern.length );

			if (!ar) {
				break;
			}

			switch (ar[0]) {
				case "n":
					ret += number;
					break;
				case "$":
					ret += nf.currency.symbol;
					break;
				case "-":
					// don't make 0 negative
					if ( positiveNumberExp.test( number ) ) {
						ret += nf["-"];
					}
					break;
				case "%":
					ret += nf.percent.symbol;
					break;
			}
		}

		return ret;
	}

	// *************************************** Dates ***************************************

	function parseDate( value, formats, region ) {
		var date,
			prop,
			patterns;

		if ( formats ) {
			if ( typeof formats === "string" ) {
				formats = [ formats ];
			}
			if ( formats.length ) {
				for ( var i = 0, l = formats.length; i < l; i++ ) {
					var format = formats[ i ];
					if ( format ) {
						date = parseExact( value, format, region );
						if ( date ) {
							break;
						}
					}
				}
			}
		}
		else {
			patterns = region.calendar.patterns;
			for ( prop in patterns ) {
				date = parseExact( value, patterns[prop], region );
				if ( date ) {
					break;
				}
			}
		}
		return date || null;
	}

	function outOfRange(value, low, high) {
		return value < low || value > high;
	}

	function expandYear(cal, year) {
		// expands 2-digit year into 4 digits.
		var now = new Date(),
			era = getEra(now);
		if ( year < 100 ) {
			var twoDigitYearMax = cal.twoDigitYearMax;
			twoDigitYearMax = typeof twoDigitYearMax === 'string' ? new Date().getFullYear() % 100 + parseInt( twoDigitYearMax, 10 ) : twoDigitYearMax;
			var curr = getEraYear( now, cal, era );
			year += curr - ( curr % 100 );
			if ( year > twoDigitYearMax ) {
				year -= 100;
			}
		}
		return year;
	}

	function getEra(date, eras) {
		if ( !eras ) return 0;
		var start, ticks = date.getTime();
		for ( var i = 0, l = eras.length; i < l; i++ ) {
			start = eras[ i ].start;
			if ( start === null || ticks >= start ) {
				return i;
			}
		}
		return 0;
	}

	function toUpper(value) {
		// 'he-IL' has non-breaking space in weekday names.
		return value.split( "\u00A0" ).join(' ').toUpperCase();
	}

	function toUpperArray(arr) {
		var results = [];
		for ( var i = 0, l = arr.length; i < l; i++ ) {
			results[i] = toUpper(arr[i]);
		}
		return results;
	}

	function getEraYear(date, cal, era, sortable) {
		var year = date.getFullYear();
		if ( !sortable && cal.eras ) {
			// convert normal gregorian year to era-shifted gregorian
			// year by subtracting the era offset
			year -= cal.eras[ era ].offset;
		}
		return year;
	}

	function getDayIndex(cal, value, abbr) {
		var ret,
			days = cal.days,
			upperDays = cal._upperDays;
		if ( !upperDays ) {
			cal._upperDays = upperDays = [
				toUpperArray( days.names ),
				toUpperArray( days.namesAbbr ),
				toUpperArray( days.namesShort )
			];
		}
		value = toUpper( value );
		if ( abbr ) {
			ret = $.inArray( value, upperDays[ 1 ] );
			if ( ret === -1 ) {
				ret = $.inArray( value, upperDays[ 2 ] );
			}
		}
		else {
			ret = $.inArray( value, upperDays[ 0 ] );
		}
		return ret;
	}

	function getMonthIndex(cal, value, abbr) {
		var months = cal.months,
			monthsGen = cal.monthsGenitive || cal.months,
			upperMonths = cal._upperMonths,
			upperMonthsGen = cal._upperMonthsGen;
		if ( !upperMonths ) {
			cal._upperMonths = upperMonths = [
				toUpperArray( months.names ),
				toUpperArray( months.namesAbbr )
			];
			cal._upperMonthsGen = upperMonthsGen = [
				toUpperArray( monthsGen.names ),
				toUpperArray( monthsGen.namesAbbr )
			];
		}
		value = toUpper( value );
		var i = $.inArray( value, abbr ? upperMonths[ 1 ] : upperMonths[ 0 ] );
		if ( i < 0 ) {
			i = $.inArray( value, abbr ? upperMonthsGen[ 1 ] : upperMonthsGen[ 0 ] );
		}
		return i;
	}

	function appendPreOrPostMatch(preMatch, strings) {
		// appends pre- and post- token match strings while removing escaped characters.
		// Returns a single quote count which is used to determine if the token occurs
		// in a string literal.
		var quoteCount = 0,
			escaped = false;
		for ( var i = 0, il = preMatch.length; i < il; i++ ) {
			var c = preMatch.charAt( i );
			switch ( c ) {
				case '\'':
					if ( escaped ) {
						strings.push( "'" );
					}
					else {
						quoteCount++;
					}
					escaped = false;
					break;
				case '\\':
					if ( escaped ) {
						strings.push( "\\" );
					}
					escaped = !escaped;
					break;
				default:
					strings.push( c );
					escaped = false;
					break;
			}
		}
		return quoteCount;
	}

	function expandFormat(cal, format) {
		// expands unspecified or single character date formats into the full pattern.
		format = format || "F";
		var pattern,
			patterns = cal.patterns,
			len = format.length;
		if ( len === 1 ) {
			pattern = patterns[ format ];
			if ( !pattern ) {
				throw "Invalid date format string '" + format + "'.";
			}
			format = pattern;
		}
		else if ( len === 2  && format.charAt(0) === "%" ) {
			// %X escape format -- intended as a custom format string that is only one character, not a built-in format.
			format = format.charAt( 1 );
		}
		return format;
	}

	function getParseRegExp(cal, format, strict) {
		// converts a format string into a regular expression with groups that
		// can be used to extract date fields from a date string.
		// check for a cached parse regex.
		var re = cal._parseRegExp;
		if ( !re ) {
			cal._parseRegExp = re = {};
		}
		else {
			var reFormat = re[ format ];
			if ( reFormat && reFormat.strict === strict ) {
				return reFormat;
			}
		}


		// expand single digit formats, then escape regular expression characters.
		var expFormat = expandFormat( cal, format ).replace( expandFormatExp, "\\\\$1" ),
			regexp = ["^"],
			groups = [],
			index = 0,
			quoteCount = 0,
			match;

		// iterate through each date token found.
		while ( (match = tokenDateExp.exec( expFormat )) !== null ) {
			var preMatch = expFormat.slice( index, match.index );
			index = tokenDateExp.lastIndex;

			// don't replace any matches that occur inside a string literal.
			quoteCount += appendPreOrPostMatch( preMatch, regexp );
			if ( quoteCount % 2 ) {
				regexp.push( match[ 0 ] );
				continue;
			}

			// add a regex group for the token.
			var m = match[ 0 ],
				len = m.length,
				add,
				lastSpace = function(){
					var last = regexp.length-1;
							if( regexp[last]===" " && !strict ){
		 					regexp[last]="\\s?";
					}
				},
				each = function(array,deep){
					var arr = [];
					$.each(array,function( i, val ){
						if( deep )
							val = val[deep];
						if( val && $.type(val)=='string' )
							arr.push( escRegexpStr(val) );

					});
					return arr.length>0 ? "("+arr.join("|")+")" : "";
				};

			switch ( m ) {
				case "dddd":
					add = strict ? each(cal.days.names) : each( $.merge(cal.days.names,cal.days.namesAbbr) );
					break;
				case "ddd":
					add = strict ? each(cal.days.namesAbbr) : each( $.merge(cal.days.names,cal.days.namesAbbr) );
					break;
				case "MMMM":
					add = strict ? each(cal.months.names) : each( $.merge(cal.months.names,cal.months.namesAbbr) );
					break;
				case "MMM":
					add = strict ? each(cal.months.namesAbbr) : each( $.merge(cal.months.names,cal.months.namesAbbr) );
					break;
				case "gg":
				case "g":
					lastSpace();
					add = each(cal.eras,"name");
					break;
				case "tt":
				case "t":
					lastSpace();
					add = each( $.merge( cal.AM || [], cal.PM || [] ) );
					break;
				case "f":
				case "ff":
				case "fff":
					add = "(\\d{" + len + "})";
					break;
				case "d":
					add =  strict ? "([1-9]{1}|[1-2]{1}\\d{1}|3[0-1]{1})" : "(0?[1-9]{1}|[1-2]{1}\\d{1}|3[0-1]{1})";
					break;
				case "dd":
					add =  strict ? "(0[1-9]{1}|[1-2]{1}\\d{1}|3[0-1]{1})" : "(0?[1-9]{1}|[1-2]{1}\\d{1}|3[0-1]{1})";
					break;
				case "M":
					add =  strict ? "([1-9]{1}|1[0-2]{1})" : "(0?[1-9]{1}|1[0-2]{1})";
					break;
				case "MM":
					add =  strict ? "(0[1-9]{1}|1[0-2]{1})" : "(0?[1-9]{1}|1[0-2]{1})";
					break;
				case "y":
				case "yy":
					add =  strict ? "(\\d{2})" : "(\\d{2}|\\d{4})";
					break;
				case "yyyy":
					add = "(\\d{4})";
					break;
				case "h":
					add =  strict ? "([1-9]{1}|1[0-2]{1})" : "(0?[1-9]{1}|1[0-2]{1})";
					break;
				case "hh":
					add =  strict ? "(0[1-9]{1}|1[0-2]{1})" : "(0?[1-9]{1}|1[0-2]{1})";
					break;
				case "H":
					add =  strict ? "(\\d{1}|1\\d{1}|2[0-3]{1})" : "([0-1]?\\d{1}|2[0-3]{1})";
					break;
				case "HH":
					add =  strict ? "(0\\d{1}|1\\d{1}|2[0-3]{1})" : "([0-1]?\\d{1}|2[0-3]{1})";
					break;
				case "m":
					add =  strict ? "(\\d{1}|[1-5]{1}\\d{1})" : "([0-5]?\\d{1})";
					break;
				case "mm":
					add =  strict ? "([0-5]{1}\\d{1})" : "([0-5]?\\d{1})";
					break;
				case "s":
					add =  strict ? "(\\d{1}|[1-5]{1}\\d{1})" : "([0-5]?\\d{1})";
					break;
				case "ss":
					add =  strict ? "([0-5]{1}\\d{1})" : "([0-5]?\\d{1})";
					break;
				case "zz": case "z":
					add = "([+-]?\\d\\d?)";
					break;
				case "zzz":
					add = "([+-]?\\d\\d?:\\d{2})";
					break;
				case "W":
					add = "([1-9]{1}|[2-4]{1}\\d{1}|5[0-3]{1})";
					break;
				case "/":
					add = "(\\" + cal["/"] + ")";
					break;
				default:
					throw "Invalid date format pattern '" + m + "'.";
					break;
			}
			if ( add ) {
				regexp.push( add );
			}
			groups.push( match[ 0 ] );
		}
		appendPreOrPostMatch( expFormat.slice( index ), regexp );
		regexp.push( "$" );

		var regexpStr = regexp.join( '' ).replace( whiteSpaceExp, "\\s+" ),					// allow whitespace to differ when matching formats.
			parseRegExp = {'regExp': regexpStr, 'groups': groups, strict: strict},
			ret = re[ format ] = parseRegExp;											// cache the regex for this format.
		return ret;
	}

	function parseExact(value, format, region) {
		// try to parse the date string by matching against the format string
		// while using the specified region for date field names.
		value = $.trim( value );
		var cal = region.calendar,
			// convert date formats into regular expressions with groupings.
			// use the regexp to determine the input format and extract the date fields.
			parseInfo = getParseRegExp(cal, format),
			match = new RegExp(parseInfo.regExp).exec(value);
		if (match === null) {
			return null;
		}
		// found a date format that matches the input.
		var groups = parseInfo.groups,
			era = null, year = null, month = null, date = null, weekDay = null,
			hour = 0, hourOffset, min = 0, sec = 0, msec = 0, tzMinOffset = null,
			pmHour = false;
		// iterate the format groups to extract and set the date fields.
		for ( var j = 0, jl = groups.length; j < jl; j++ ) {
			var matchGroup = match[ j + 1 ];
			if ( matchGroup ) {
				var current = groups[ j ],
					clength = current.length,
					matchInt = parseInt( matchGroup, 10 );
				switch ( current ) {
					case 'dd': case 'd':
						// Day of month.
						date = matchInt;
						// check that date is generally in valid range, also checking overflow below.
						if ( outOfRange( date, 1, 31 ) ) return null;
						break;
					case 'MMM':
					case 'MMMM':
						month = getMonthIndex( cal, matchGroup, clength === 3 );
						if ( outOfRange( month, 0, 11 ) ) return null;
						break;
					case 'M': case 'MM':
						// Month.
						month = matchInt - 1;
						if ( outOfRange( month, 0, 11 ) ) return null;
						break;
					case 'y': case 'yy':
					case 'yyyy':
						year = clength < 4 ? expandYear( cal, matchInt ) : matchInt;
						if ( outOfRange( year, 0, 9999 ) ) return null;
						break;
					case 'h': case 'hh':
						// Hours (12-hour clock).
						hour = matchInt;
						if ( hour === 12 ) hour = 0;
						if ( outOfRange( hour, 0, 11 ) ) return null;
						break;
					case 'H': case 'HH':
						// Hours (24-hour clock).
						hour = matchInt;
						if ( outOfRange( hour, 0, 23 ) ) return null;
						break;
					case 'm': case 'mm':
						// Minutes.
						min = matchInt;
						if ( outOfRange( min, 0, 59 ) ) return null;
						break;
					case 's': case 'ss':
						// Seconds.
						sec = matchInt;
						if ( outOfRange( sec, 0, 59 ) ) return null;
						break;
					case 'tt': case 't':
						// AM/PM designator.
						// see if it is standard, upper, or lower case PM. If not, ensure it is at least one of
						// the AM tokens. If not, fail the parse for this format.
						pmHour = cal.PM && ( matchGroup === cal.PM[0] || matchGroup === cal.PM[1] || matchGroup === cal.PM[2] );
						if ( !pmHour && ( !cal.AM || (matchGroup !== cal.AM[0] && matchGroup !== cal.AM[1] && matchGroup !== cal.AM[2]) ) ) return null;
						break;
					case 'f':
						// Deciseconds.
					case 'ff':
						// Centiseconds.
					case 'fff':
						// Milliseconds.
						msec = matchInt * Math.pow( 10, 3-clength );
						if ( outOfRange( msec, 0, 999 ) ) return null;
						break;
					case 'ddd':
						// Day of week.
					case 'dddd':
						// Day of week.
						weekDay = getDayIndex( cal, matchGroup, clength === 3 );
						if ( outOfRange( weekDay, 0, 6 ) ) return null;
						break;
					case 'zzz':
						// Time zone offset in +/- hours:min.
						var offsets = matchGroup.split( /:/ );
						if ( offsets.length !== 2 ) return null;
						hourOffset = parseInt( offsets[ 0 ], 10 );
						if ( outOfRange( hourOffset, -12, 13 ) ) return null;
						var minOffset = parseInt( offsets[ 1 ], 10 );
						if ( outOfRange( minOffset, 0, 59 ) ) return null;
						tzMinOffset = (hourOffset * 60) + (startsWith( matchGroup, '-' ) ? -minOffset : minOffset);
						break;
					case 'z': case 'zz':
						// Time zone offset in +/- hours.
						hourOffset = matchInt;
						if ( outOfRange( hourOffset, -12, 13 ) ) return null;
						tzMinOffset = hourOffset * 60;
						break;
					case 'g': case 'gg':
						var eraName = matchGroup;
						if ( !eraName || !cal.eras ) return null;
						eraName = $.trim( eraName.toLowerCase() );
						for ( var i = 0, l = cal.eras.length; i < l; i++ ) {
							if ( eraName === cal.eras[ i ].name.toLowerCase() ) {
								era = i;
								break;
							}
						}
						// could not find an era with that name
						if ( era === null ) return null;
						break;
				}
			}
		}
		var result = new Date(), defaultYear, convert = cal.convert;
		defaultYear = convert ? convert.fromGregorian( result )[ 0 ] : result.getFullYear();
		if ( year === null ) {
			year = defaultYear;
		}
		else if ( cal.eras ) {
			// year must be shifted to normal gregorian year
			// but not if year was not specified, its already normal gregorian
			// per the main if clause above.
			year += cal.eras[ (era || 0) ].offset;
		}
		// set default day and month to 1 and January, so if unspecified, these are the defaults
		// instead of the current day/month.
		if ( month === null ) {
			month = 0;
		}
		if ( date === null ) {
			date = 1;
		}
		// now have year, month, and date, but in the region's calendar.
		// convert to gregorian if necessary
		if ( convert ) {
			result = convert.toGregorian( year, month, date );
			// conversion failed, must be an invalid match
			if ( result === null ) return null;
		}
		else {
			// have to set year, month and date together to avoid overflow based on current date.
			result.setFullYear( year, month, date );
			// check to see if date overflowed for specified month (only checked 1-31 above).
			if ( result.getDate() !== date ) return null;
			// invalid day of week.
			if ( weekDay !== null && result.getDay() !== weekDay ) {
				return null;
			}
		}
		// if pm designator token was found make sure the hours fit the 24-hour clock.
		if ( pmHour && hour < 12 ) {
			hour += 12;
		}
		result.setHours( hour, min, sec, msec );
		if ( tzMinOffset !== null ) {
			// adjust timezone to utc before applying local offset.
			var adjustedMin = result.getMinutes() - ( tzMinOffset + result.getTimezoneOffset() );
			// Safari limits hours and minutes to the range of -127 to 127.  We need to use setHours
			// to ensure both these fields will not exceed this range.  adjustedMin will range
			// somewhere between -1440 and 1500, so we only need to split this into hours.
			result.setHours( result.getHours() + parseInt( adjustedMin / 60, 10 ), adjustedMin % 60 );
		}
		return result;
	}

	function formatDate(value, format, region) {
		var cal = region.calendar,
			convert = cal.convert,
			ret;
		if ( !format || !format.length || format === 'i' ) {
			if ( region && region.name.length ) {
				if ( convert ) {
					// non-gregorian calendar, so we cannot use built-in toLocaleString()
					ret = formatDate( value, cal.patterns.F, region );
				}
				else {
					var eraDate = new Date( value.getTime() ),
						era = getEra( value, cal.eras );
					eraDate.setFullYear( getEraYear( value, cal, era ) );
					ret = eraDate.toLocaleString();
				}
			}
			else {
				ret = value.toString();
			}
			return ret;
		}

		var eras = cal.eras,
			sortable = format === "s";
		format = expandFormat( cal, format );

		// Start with an empty string
		ret = [];
		var hour,
			zeros = ['0','00','000'],
			foundDay,
			checkedDay,
			quoteCount = 0,
			converted;

		function padZeros(num, c) {
			var r, s = num+'';
			if ( c > 1 && s.length < c ) {
				r = ( zeros[ c - 2 ] + s);
				return r.substr( r.length - c, c );
			}
			else {
				r = s;
			}
			return r;
		}

		function hasDay() {
			if ( foundDay || checkedDay ) {
				return foundDay;
			}
			foundDay = dayPartRegExp.test( format );
			checkedDay = true;
			return foundDay;
		}

		function getPart( date, part ) {
			if ( converted ) {
				return converted[ part ];
			}
			switch ( part ) {
				case 0: return date.getFullYear();
				case 1: return date.getMonth();
				case 2: return date.getDate();
			}
		}

		if ( !sortable && convert ) {
			converted = convert.fromGregorian( value );
		}

		for (;;) {
			// Save the current index
			var index = tokenDateExp.lastIndex,
				// Look for the next pattern
				ar = tokenDateExp.exec( format );

			// Append the text before the pattern (or the end of the string if not found)
			var preMatch = format.slice( index, ar ? ar.index : format.length );
			quoteCount += appendPreOrPostMatch( preMatch, ret );

			if ( !ar ) {
				break;
			}

			// do not replace any matches that occur inside a string literal.
			if ( quoteCount % 2 ) {
				ret.push( ar[ 0 ] );
				continue;
			}

			var current = ar[ 0 ],
				clength = current.length;

			switch ( current ) {
				case "ddd":
					//Day of the week, as a three-letter abbreviation
				case "dddd":
					// Day of the week, using the full name
					names = (clength === 3) ? cal.days.namesAbbr : cal.days.names;
					ret.push( names[ value.getDay() ] );
					break;
				case "d":
					// Day of month, without leading zero for single-digit days
				case "dd":
					// Day of month, with leading zero for single-digit days
					foundDay = true;
					ret.push( padZeros( getPart( value, 2 ), clength ) );
					break;
				case "MMM":
					// Month, as a three-letter abbreviation
				case "MMMM":
					// Month, using the full name
					var part = getPart( value, 1 );
					ret.push(
						(cal.monthsGenitive && hasDay()) ?
							cal.monthsGenitive[ clength === 3 ? "namesAbbr" : "names" ][ part ] :
							cal.months[ clength === 3 ? "namesAbbr" : "names" ][ part ]
					);
					break;
				case "M":
					// Month, as digits, with no leading zero for single-digit months
				case "MM":
					// Month, as digits, with leading zero for single-digit months
					ret.push( padZeros( getPart( value, 1 ) + 1, clength ) );
					break;
				case "y":
					// Year, as two digits, but with no leading zero for years less than 10
				case "yy":
					// Year, as two digits, with leading zero for years less than 10
				case "yyyy":
					// Year represented by four full digits
					part = converted ? converted[ 0 ] : getEraYear( value, cal, getEra( value, eras ), sortable );
					if ( clength < 4 ) {
						part = part % 100;
					}
					ret.push( padZeros( part, clength ) );
					break;
				case "h":
					// Hours with no leading zero for single-digit hours, using 12-hour clock
				case "hh":
					// Hours with leading zero for single-digit hours, using 12-hour clock
					hour = value.getHours() % 12;
					if ( hour === 0 ) hour = 12;
					ret.push( padZeros( hour, clength ) );
					break;
				case "H":
					// Hours with no leading zero for single-digit hours, using 24-hour clock
				case "HH":
					// Hours with leading zero for single-digit hours, using 24-hour clock
					ret.push( padZeros( value.getHours(), clength ) );
					break;
				case "m":
					// Minutes with no leading zero  for single-digit minutes
				case "mm":
					// Minutes with leading zero  for single-digit minutes
					ret.push( padZeros( value.getMinutes(), clength ) );
					break;
				case "s":
					// Seconds with no leading zero for single-digit seconds
				case "ss":
					// Seconds with leading zero for single-digit seconds
					ret.push( padZeros(value .getSeconds(), clength ) );
					break;
				case "t":
					// One character am/pm indicator ("a" or "p")
				case "tt":
					// Multicharacter am/pm indicator
					part = value.getHours() < 12 ? (cal.AM ? cal.AM[0] : " ") : (cal.PM ? cal.PM[0] : " ");
					ret.push( clength === 1 ? part.charAt( 0 ) : part );
					break;
				case "f":
					// Deciseconds
				case "ff":
					// Centiseconds
				case "fff":
					// Milliseconds
					ret.push( padZeros( value.getMilliseconds(), 3 ).substr( 0, clength ) );
					break;
				case "z":
					// Time zone offset, no leading zero
				case "zz":
					// Time zone offset with leading zero
					hour = value.getTimezoneOffset() / 60;
					ret.push( (hour <= 0 ? '+' : '-') + padZeros( Math.floor( Math.abs( hour ) ), clength ) );
					break;
				case "zzz":
					// Time zone offset with leading zero
					hour = value.getTimezoneOffset() / 60;
					ret.push( (hour <= 0 ? '+' : '-') + padZeros( Math.floor( Math.abs( hour ) ), 2 ) +
						// Hard coded ":" separator, rather than using cal.TimeSeparator
						// Repeated here for consistency, plus ":" was already assumed in date parsing.
						":" + padZeros( Math.abs( value.getTimezoneOffset() % 60 ), 2 ) );
					break;
				case "g":
				case "gg":
					if ( cal.eras ) {
						ret.push( cal.eras[ getEra(value, eras) ].name );
					}
					break;
				case "/":
					ret.push( cal["/"] );
					break;
				case "W":
					var Y = value.getYear(),
						M = value.getMonth(),
						d = value.getDate(),
						dateObj = new Date(Y, M, d),
						Wd = dateObj.getDay()||7,
						Wmin = cal.firstWeekMin;

					if( M===11 && d>=(35-Wmin) && Wd<d-(35-Wmin) ) {
						return 1;
					}
					else if(M===0 && d<=Wmin && Wd<=d+(Wmin-1) ) {
						return 1;
					}
					else if( M===0 && d<=Wmin ) {
						Y -= 1;
					}

					ret.push( Math.floor( ( dateObj - new Date(Y, 0, (Wmin+1)-(new Date(Y, 0, Wmin).getDay()||7)) ) / 604800000 ) + 1 );
					break;
				default:
					throw "Invalid date format pattern '" + current + "'.";
					break;
			}
		}
		return ret.join( '' );
	}

	// set i18n root directory
	if( !dependSettings.i18nRoot )
		dependSettings.i18nRoot = $.dependSettings.pluginRoot+'/jQuery/i18n';

	// register i18n for dependencies control
	$.dependRegister( 'i18n', function( depend, deferred ){
		var info = i18nInfo(depend);

		if( i18n[ info.type ][ depend ] ){
			deferred.resolve();
		}
		else{
			var ajax = {
					url:		dependSettings.i18nRoot+'/'+depend+(dependSettings.minify?'.min':'')+'.js',
					dataType:	dependSettings.jsonp ? 'jsonp' :'script',
					type:		'get',
					asnyc:		true,
					cache:		true
				};

			$.ajax(
				dependSettings.jsonp ?
				$.extend(ajax,{
					dataType:		'jsonp',
					jsonp:			dependSettings.jsonp!==true ? dependSettings.jsonp : undefined,
					jsonpCallback:	'jsonp.dependHandle.i18n('+depend+')'
				}) :
				ajax
			)
			.done(function(){
				deferred.resolve();
			});
		}
	});


	/*!BUILD(i18n)*/


	// provide jQuery.i18n
	var depend = { i18n: [] },
		config = i18n.settings;

	$.each( {region:config.region, currency:config.currency}, function( type, config ){
		if( config ){
			if( $.type(config) == 'array')
				i18n.settings[type] = config[0];
			else
				config = [config];

			$.merge( depend.i18n, config );
		}
	});

	$.plugin( 'jQuery.i18n', depend );

})(jQuery);

/* ---- Module:ep.validate ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.validate
 *
 * @revision		$Revision: 1.16.6.3 $
 */

jQuery.plugin( 'ep.validate', ['ep.core', 'ep.color', 'jQuery.mime', 'ep.i18n'], function( $, undefined ){

/*
 * @dictionary			ep.dict
 *
 * @translation			{NOT_VALID}
 *						{REQUIRED}
 *						{NOT_IN_RANGELENGTH}
 *						{LOWER_THAN_MINLENGTH}
 *						{GREATER_THAN_MAXLENGTH}
 *						{NOT_IN_RANGE}
 *						{LOWER_THAN_MIN}
 *						{GREATER_THAN_MAX}
 *						{NO_EMAIL}
 *						{NO_URL}
 *						{NO_MIME}
 *						{MIME_NOT_ACCEPT}
 *						{NO_CREDITCARD_NUMBER}
 *						{NO_NUMBER}
 *						{NO_CURRENCY}
 *						{NO_PERCENT}
 *						{NO_DATE}
 *						{NO_DATETIME}
 *						{NO_TIME}
 *						{NO_COLOR_VALUE}
 *						{NO_UNIT}
 *						{NO_UNIT_VALUE}
 *						{NO_CSS_NUMBER}
 *						{FLOAT_NOT_ALLOWED}
 *						{UNKOWN_UNIT}
 */

	var invalid = 'NOT_VALID',
		
		isN = function( value ){
			return !isNaN(value);
		},

		pattern = function( value, pattern ) {
			return pattern ? ( new RegExp( ((/^\^/).test(pattern)?'':'^') + pattern + ((/\$$/).test(pattern)?'':'$') , '' ).test( value ) || invalid ) : true;
		},

		required = function( value, req ) {
			return !value && req ? 'REQUIRED' : true;
		},

		rangelength = function( value, min, max ) {
			min = min<0 ? 0 : min;
			max = max<0 ? 0 : max;

			var val = $.trim(value).length;

			if( isN(min) && min>val ){
				return isN(max) ? 'NOT_IN_RANGELENGTH' : 'LOWER_THAN_MINLENGTH';
			}
			if( isN(max) && val>max ){
				return isN(min) ? 'NOT_IN_RANGELENGTH' : 'GREATER_THAN_MAXLENGTH';
			}
			return true;
		},

		range = function( value, min, max ) {
			var val = typeof value !== 'number' ? parseFloat(value,10) : value;
			
			if( isN(min) && min>val ){
				return isN(max) ? 'NOT_IN_RANGE' : 'LOWER_THAN_MIN';
			}
			if( isN(max) && val>max ){
				return isN(min) ? 'NOT_IN_RANGE' : 'GREATER_THAN_MAX';
			}
			return true;
		},

		i18nMap = {
			'date':					'd',
			'dateLong':				'D',
			'dateLong-time':		'f',
			'dateLong-timeLong':	'F',
			'date-time':			'l',
			'date-timeLong':		'L',
			'time':					't',
			'timeLong':				'T',
			'currency':				'c',
			'number':				'n',
			'percent':				'p'
		};

	$.extend( $.scope('ep.validate'), {

		email: function( value, options ){
			value = $.trim(value);

			var opt = $.extend({},options||{}),
				valid = required( value, opt.required );

			if( value && valid===true ){
				valid = /^((([a-z]|\d|[!#\$%&'\*\+\-\/=\?\^_`{\|}~]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])+(\.([a-z]|\d|[!#\$%&'\*\+\-\/=\?\^_`{\|}~]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])+)*)|((\x22)((((\x20|\x09)*(\x0d\x0a))?(\x20|\x09)+)?(([\x01-\x08\x0b\x0c\x0e-\x1f\x7f]|\x21|[\x23-\x5b]|[\x5d-\x7e]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(\\([\x01-\x09\x0b\x0c\x0d-\x7f]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]))))*(((\x20|\x09)*(\x0d\x0a))?(\x20|\x09)+)?(\x22)))@((([a-z]|\d|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(([a-z]|\d|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])([a-z]|\d|-|\.|_|~|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])*([a-z]|\d|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])))\.)+(([a-z]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(([a-z]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])([a-z]|\d|-|\.|_|~|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])*([a-z]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])))\.?$/i.test(value) || 'NO_EMAIL';
				// EPG-24121: check the local part of an email address for non-ASCII characters
				if( valid===true ){
					var localatoms = value.split('@')[0].split('.');
					$.each(localatoms, function(index) {
						valid = /^[\x00-\x7F]+$/.test(localatoms[index]) || 'NO_EMAIL';
						return valid=='NO_EMAIL' ? false : true;
					});
				}
			}
			return valid===true ? range( value, opt.minlength, opt.maxlength ) : valid;
		},
		// url must be absolute
		url: function( value, options ){
			value = $.trim(value);

			var opt = $.extend({},options||{}),
				valid = required( value, opt.required );

			if( value && valid===true ){
				valid = /^((https?|ftp):\/\/)?(((([a-z]|\d|-|\.|_|~|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(%[\da-f]{2})|[!\$&'\(\)\*\+,;=]|:)*@)?(((\d|[1-9]\d|1\d\d|2[0-4]\d|25[0-5])\.(\d|[1-9]\d|1\d\d|2[0-4]\d|25[0-5])\.(\d|[1-9]\d|1\d\d|2[0-4]\d|25[0-5])\.(\d|[1-9]\d|1\d\d|2[0-4]\d|25[0-5]))|((([a-z]|\d|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(([a-z]|\d|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])([a-z]|\d|-|\.|_|~|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])*([a-z]|\d|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])))\.)+(([a-z]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(([a-z]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])([a-z]|\d|-|\.|_|~|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])*([a-z]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])))\.?)(:\d*)?)(\/((([a-z]|\d|-|\.|_|~|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(%[\da-f]{2})|[!\$&'\(\)\*\+,;=]|:|@)+(\/(([a-z]|\d|-|\.|_|~|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(%[\da-f]{2})|[!\$&'\(\)\*\+,;=]|:|@)*)*)?)?(\?((([a-z]|\d|-|\.|_|~|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(%[\da-f]{2})|[!\$&'\(\)\*\+,;=]|:|@)|[\uE000-\uF8FF]|\/|\?)*)?(\#((([a-z]|\d|-|\.|_|~|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(%[\da-f]{2})|[!\$&'\(\)\*\+,;=]|:|@)|\/|\?)*)?$/i.test(value) || 'NO_URL';
			}
			return valid===true ? range( value, opt.minlength, opt.maxlength ) : valid;
		},

		mimetype: function( value, options ){
			value = $.trim(value);

			var opt = $.extend({
					accept: undefined
				},options||{}),
				valid = required( value, opt.required );

			if( value && valid===true ){
				valid = /^[a-z]+\/[a-z\d\.-]+$/i.test(value) || 'NO_MIME';
			}
			if( value && opt.accept && valid===true ){
				valid = $.mime( value, opt.accept ) || 'MIME_NOT_ACCEPT';
			}
			return valid;
		},

		creditcard: function( value, options ) {
			value = $.trim(value);

			var opt = $.extend({},options||{}),
				valid = required( value, opt.required );

			if( value && valid===true ){
				if( /[^0-9-]+/.test(value) ){
					return false;
				}

				var nCheck = 0,
					nDigit = 0,
					bEven = false,
					cDigit;

				value = value.replace(/\D/g, "");

				for( var n=value.length-1 ; n>=0 ; n-- ){
					cDigit = value.charAt(n);
					nDigit = parseInt(cDigit, 10);
					if( bEven ){
						if( (nDigit *= 2) > 9 ){
							nDigit -= 9;
						}
					}
					nCheck += nDigit;
					bEven = !bEven;
				}

				valid = (nCheck % 10) === 0 || 'NO_CREDITCARD_NUMBER';
			}
			return valid;
		},

		date: function( value, options ){
			value = $.trim(value);

			var opt = $.extend({
					format: 'd',
					strict: false
				},options||{}),
				region = {region:opt.region},
				valid = required( value, opt.required );

			opt.format = i18nMap[opt.format] || opt.format;

			if( value && valid===true ){
				switch(true){
					case (/^(d|D)$/).test(opt.format):
						valid = 'NO_DATE';
					break;
					case (/^(f|F|l|L)$/).test(opt.format):
						valid = 'NO_DATETIME';
					break;
					case (/^(t|T)$/).test(opt.format):
						valid = 'NO_TIME';
					break;
					default:
						valid = invalid;
					break;
				}
				valid = new RegExp( '^' + $.i18n.expStrDate( opt.format, opt.strict, region ) + '$', '' ).test(value) || valid;

				if( valid===true && value ){
					var date = $.i18n.parseDate( value, opt.format, region );

					valid = date instanceof Date ? range( date.getTime(), opt.min, opt.max ) : invalid;
				}
			}
			return valid;
		},

		number: function( value, options ){
			value = $.trim(value);

			var opt = $.extend({
					format: 'n',
					strict: false
				},options||{}),
				region = {region:opt.region,currency:opt.currency},
				valid = required( value, opt.required );

			opt.format = i18nMap[opt.format] || opt.format;

			if( value && valid===true ){
				var msg = {
					n:'NO_NUMBER',
					c:'NO_CURRENCY',
					p:'NO_PERCENT'
				};
				opt.format.replace(/^(n|c|p)\d*$/,function(str,$1){
					valid = msg[$1] || invalid;
				});
				valid = new RegExp( '^' + $.i18n.expStrNumber( opt.format, opt.strict, region ) + '$', '' ).test(value) || valid;
			}
			if( value && valid===true ){
				var num = $.i18n.parseNumber( value, 10, region );

				valid = isNaN(num) ? invalid : range( num, opt.min, opt.max );
			}
			return valid;
		},

		cssColor: function( value ){
			value = $.trim(value);
			return ep.color.stringToHex(value, true)!==undefined || 'NO_COLOR_VALUE';
		},

		cssSize: function( value, options ){
			value = $.trim(value);

			var opt = $.extend({},options||{}),
				valid = required( value, opt.required );

			if( value && valid===true ){
				switch(true){
					case (/^[0-9]+(px|pt)$/i).test(value) || /^[0-9]*\.?[0-9]+(pc|%|mm|cm|em|in|ex)$/i.test(value) || /^[0]+$/.test(value):
						valid = true;
					break;
					case (/^[0-9]+$/).test(value):
						valid = 'NO_UNIT';
					break;
					case value === "":
						valid = 'NO_UNIT_VALUE';
					break;
					case (/^[^0-9]*\.?[^0-9]/).test(value):
						valid = 'NO_CSS_NUMBER';
					break;
					case (/^[0-9]*\.[0-9]+(?:px|pt)$/i).test(value):
						valid = 'FLOAT_NOT_ALLOWED';
					break;
					case (/^[0-9]*\.[0-9]$/).test(value):
						valid = 'NO_UNIT';
					break;
					case (/^[0-9]*\.?[0-9]+[a-z]+$/).test(value):
						valid = 'UNKNOWN_UNIT';
					break;
					default:
						valid = invalid;
					break;
				}
			}
			if( value && valid===true ){
				var num = parseFloat(value.replace(/\W+$/,''),10);

				valid = isNaN(num) ? invalid : range( num, opt.min, opt.max );
			}
			return valid;
		},

		basic: function( value, options ){
			var opt = $.extend({},options||{}),
				valid = required( value, opt.required );

			if( value && valid===true ){
				valid = pattern( value, opt.pattern);
			}

			if( value && valid===true ){
				valid = rangelength( value, opt.minlength, opt.maxlength );
			}

			return valid;
		}
/* TODO: validate by server,
		ajax: function( value, options ){

		}
*/
	});

});

/* ---- Module:ep.ui.validate ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.ui.validate
 *
 * @revision		$Revision: 1.27 $
 */


jQuery.plugin( 'ep.ui.validate', ['ep.validate', 'ep.ui.input'], function( $, undefined ){

	// formular felder
	$.widget('ep.ui.Validate',ep.ui.Input,{

		options: {
	// ep.ui.Input
		//	big:				true,
		//	autofocus:			false,
		//	placeholder:		'text',
		//	info:				'text',

	// ep.ui.Validate
		//	accept:				'',
		//	min:				1,
		//	max:				20,
		//	minlength:			1,
		//	maxlength:			4,
		//	pattern:			[\w]+,
		//	required:			true,
		//	format:				'n0',
		//	currency:			'EUR',
			valid:				true,
			type:				'basic'
		},

		_create: function(){
			this.Inherited(arguments);

			this.options = $.extend({
					accept:		this.elem.attr('accept'),
					min:			parseInt( this.elem.attr('min'), 10 ),
					max:			parseInt( this.elem.attr('max'), 10 ),
					minlength:		parseInt( this.elem.attr('minlength'), 10 ),
					maxlength:		parseInt( this.elem.attr('maxlength'), 10 ),
					pattern:		this.elem.attr('pattern'),
					required:		this.elem.attr('required')
				},this.options);

			// wrap is also wrap of uiInput
			this.wrap.addClass('ep-uiValidate');
			// make .uiValidate as .uiInput also available to fix addClass for type radio
			this.elem
				.on( 'validate.uiValidate blur.uiValidate', this.Proxy('_validate') );

			// validate if invalid on default
			if( !this.options.valid ){
				this._setInstantly();
				this._setValidStatus(false);
			}

		},

		_init: function(){
			// init uiInput
			this.Inherited(arguments);
		},

		_setInstantly: function(){
			this._instantly = true;
			this.elem.on( 'changeValue.uiValidate', this.Proxy('_validate') );
		},

		_radioGroupCheck: function(){
			this.elem
				.formGroup(':radio')
				.trigger('validate')
				.uiInput('removeClass','checked')
				.filter(':checked')
					.uiInput('addClass','checked');
		},

		_changeAttr: function( event, attr ){
			var self = this;

			this.Inherited(arguments);

			$.each( attr, function( name, value ){
				if( (/^(accept|pattern|required)$/i).test(name) ){
					self.options[ name ] = value;
				}
				else if( (/^(min|max|minlength|maxlength)$/i).test(name) ){
					self.options[ name ] = parseInt( value, 10 );
				}
			});
		},

		_setOption: function( name, value ){
			if( name=='valid' && value!==undefined ){
				this._setValidStatus(value);
			}
			return this.Inherited(arguments);
		},
		
		_setValidStatus: function( valid ){
			this.valid = valid===false ? ep.validate.basic("") : valid;
			valid = valid!==true;
			this.elem[0].formInvalid = valid;
			if( this.placeholder ){
				this.placeholder[0].formInvalid = valid;
			}
			this[ valid ? 'addClass' : 'removeClass' ]('invalid');

			this._tooltipShow();
		},

		_validate: function( event ){
			if( event.keyCode!==9 ){

				var val = this.elem.val(),
					valid;

				if( this.elem.is(':radio') ){
					val = this.elem
						.formGroup(':radio')
						.filter(':checked')
						.val() || '';
				}
				else if( this.elem.is(':checkbox') ){
					val = this.elem
						.filter(':checked')
						.val() || '';
				}

				valid = ep.validate[ this.options.type ]( val, this.options );

				if( valid!==true && !this._instantly ){
					this._setInstantly();
				}

				this._setValidStatus(valid);

				if( event.type!=='changeAttr' ){
					$(this.elem[0].form).trigger('change');
				}
			}
		},

		_tooltipShow: function(){
			if( this.valid!==true ){
				// create tooltip if not exists
				if( !this.tooltip ){
					this._tooltipInit(true);
					this.tooltip.on( 'show', this.Proxy('_tooltipHide') );
				}
				if( !this.errormsg ){
					this.errormsg = $('<div>')
						.addClass('ep-uiValidate-message')
						.insertBefore(this.tooltip);
					this.stack.push(this.errormsg[0]);
				}
				// options for errer msg
				var options = {
						min: this.options.min,
						max: this.options.max,
						minlength: this.options.minlength,
						maxlength: this.options.maxlength
					},
					format = this.options.format,
					opts = {region:this.options.region};

				// i18n for min + max
				if( this.options.type === 'number' ){
					opts.currency = this.options.currency;

					options.example = $.i18n.formatNumber( 21.45923, format, opts );

					if( options.min || options.max ){
						options.min = $.i18n.formatNumber( options.min, format, opts );
						options.max = $.i18n.formatNumber( options.max, format, opts );
					}
				}
				else if( this.options.type === 'date' ){
					options.example = $.i18n.formatDate( new Date(), format, opts );

					if( options.min || options.max ){
						options.min = $.i18n.formatDate( new Date(options.min), format, opts );
						options.max = $.i18n.formatDate( new Date(options.max), format, opts );
					}
				}
				// set tooltip msg
				this.errormsg.text( this.dict.translateData( this.valid, options ) );
				this.errormsg.show();

				if( this.elem.is(':focus') ){
					this.tooltip.uiTooltip('show');
				}
			}
			else{
				this._tooltipHide();
			}
		},

		_tooltipHide: function(){
			var self = this,
				hidemsg = function(){
					if( self.errormsg ){
						self.errormsg.hide();
					}
				};

			if( this.tooltip && this.valid===true ){
				if( !this.options.info ){
					this.tooltip.uiTooltip('hide',hidemsg);
				}
				else{
					hidemsg();
				}
			}
		},

		destroy: function(){
			this.elem
				.off('.uiValidate');
			this.wrap
				.removeClass(/ep-uiValidate[\w\d-]*/g);

			this.Inherited(arguments);
		}
	});

});


/* ---- Module:ep.ui.contentlist ---- */

/*
 * @copyright		© Copyright 2006-2011, epages GmbH, All Rights Reserved.
 *
 * @module			ep.ui.contentlist
 *
 * @revision		$Revision: 1.22.2.1 $
 */
jQuery.plugin('ep.ui.contentlist',
	['ep.core', 'jQuery.ui.widget', 'jQuery.event.special.load', 'ep.fn.contextOrientation', 'ep.ui.textedit', 'ep.ui.validate'],
	function($, undefined){

	$.widget('ep.ui.contentlist', {
		STR_EDIT_ICON: '<i class="Sprite ico_s_edit"></i>',

		options: {
		//	grossPrice:	'c2',						// format for net/gross prices
			editIcon: 	true,						// indicator if a edit icon should be shown
			alterIcon: 	false,						// flag if the edit icon should be shown always right (false) or depending by align (true)
			region:		$.i18n.settings.region,		// region string
			currency:	$.i18n.settings.currency,	// currency acronym
			saveAction: 'Save'						// save method
		},

		_create: function(){
			var self = this,
				o = self.options;

			if(self.element[0]===undefined){
				return;
			}

			// get the currency format (default 'c2': two decimal places)
			o.grossPrice = (o.grossPrice===undefined)? 'c2' : o.grossPrice;

			self._rows = self.element[0].rows;
			self.element.addClass('RowSelection');

			// iterate over all rows
			for(var i=0, iLength=self._rows.length; i<iLength; i++){
				var aCells = self._rows[i].cells || [];

				// check all cell
				if((i==0) && (self._rows[i].parentNode.tagName.toLowerCase()=="thead")){
					$('input', aCells[0]).on('change.uiContentlist', $.proxy(self._checkAll, $('input', aCells[0])));
					$('label', aCells[0]).live('click', $.proxy(self._checkAll, $('input', aCells[0])));
					continue;
				}

				// bind click handler for the current row
				ep(self._rows[i]).on('click.uiContentlist', $.proxy(self._handleRowClick, self._rows[i]));

				//$(self._rows[i]).find('input.Checkbox').on('click',$.proxy(self._handleCheckboxClick, self._rows[i]));
        $(self._rows[i]).find('td.Checkbox input').on('click',$.proxy(self._handleCheckboxClick, self._rows[i]));

				// iterate over all cells
				for(var j=0, jLength=aCells.length; j<jLength; j++){
					var $cell = $(aCells[j]);

					// if checkbox-cell -> add class
					if($cell.hasClass('Checkbox') && ($('input:checkbox, input.Checkbox', $cell).length>0)){
						$cell.addClass('RowSelectionInputCell');
					}

					// if the current cells content should be editable
					if($cell.data('epEditable')==true){
						// element which should be editable
						var $oEditWrapper = ep('*[data-ep-attribute]', $cell);

						if($oEditWrapper.length>0){
							$oEditWrapper.addClass('epEditWrapper ClickIcon');
							// if an edit icon should be shown
							if(o.editIcon){
								if(!o.alterIcon || $cell.css('text-align')!="right"){
									$oEditWrapper
										.append(self.STR_EDIT_ICON)
										.data('epTextAlign', 'left');
									if($cell.css('text-align')=="right"){
										$cell.addClass('ep-Textedit-right');
									}
								}else{
									$oEditWrapper
										.prepend(self.STR_EDIT_ICON)
										.data('epTextAlign', 'right');
									$cell.addClass('ep-Textedit-right');
								}
							}
							switch($oEditWrapper.data('epAttribute').toLowerCase()){
								case "name":
									$oEditWrapper.css({
										display: 'inline-block'
									});
									break;
								// if price and stocklevel wrapper need special formatting later
								/*case "price":
									break;
								case "stocklevel":
									break;*/
							}
						}
					}

					// bind a click handler to the current cell
					$cell.on('click.uiContentlist', $.proxy(self._handleCellClick, {cell: $cell, _this: self}));
				}
			}
		},

		_handleCellClick: function(evt){
		// this: object/hash {cell: current cell, _this: reference to the widget}

			var $widget = this._this,
				o = $widget.options,
				$cell = this.cell,
				$currentRow = $cell.parent();

			// if the cell contents an editable element
			if($cell.data('epEditable')){
				if( $(evt.target).is('input') ){
					evt.stopPropagation();
					return;
				}

				// element which should be editable
				var $span = ep(".epEditWrapper", $cell);

				// if the element is not editable yet
				if(ep('input', $cell).length==0){
					// object/hash for the uiValidate widget
					var oValidate = {
						valid: false
					};
					// mark that the element is just created
					$span.prop('justCreated', true);

					switch($span.data('epAttribute')){
						case 'Name':						// value of the data-ep-attribute correlate to the Save attribute
							oValidate.maxlength = 100;
							break;
						case 'Price':						// value of the data-ep-attribute correlate to the Save attribute
							oValidate.type = 'number';
							oValidate.format = o.grossPrice;
							oValidate.region = o.region;
							oValidate.currency = o.currency;
							oValidate.min = -2147483648;
							oValidate.max = 2147483647;
							oValidate.needFormat = true;
							break;
						case 'StockLevel':					// value of the data-ep-attribute correlate to the Save attribute
							oValidate.type = 'number';
							oValidate.format = 'n2';
							oValidate.region = o.region;
							oValidate.min = -2147483648;
							oValidate.max = 2147483647;
							break;
					}

					// object/hash for the uiTextedit widget
					var oTextEditOptions = {
						action		: $widget.options.saveAction, //'Save',																	// SaveAction
						objectId	: $cell.parent().find('td.Checkbox input:checkbox').val(),							// objectId
						name			: $span.data('epAttribute'),																							// name/value pair (from data-ep-attribute)
						stripHTML	: true,
						validate	: oValidate,
						preventDefaultOnEnter : true,

						// callback called before element becomes editable
						onBeforeOpen: function(input){
							// remove edit icon if necessary
							if($widget.options.editIcon){
								ep('.Sprite', $span).remove();
							}
							// show label element
							input.parent().show();
							input.attr('disabled', false);

							$span.css('width','98%');
							$cell.find('*.hideOnEditable').hide();
						},

						onAfterOpen: function(input){
							// if element was just created
							if($span.prop('justCreated')){
								$span.prop('justCreated', false);
								// prevent an invalid message if input is empty
								if(input.val().length==0){
									input[0].formInvalid = false;
									input.blur();
									$span.trigger('click.uiTextedit');
									//input.focus();
								}
							}
						},

						// Called before data gets written to *$span*.
						formatOnWriteBack: function(input, evt) {
							// Format input value.
							var value = (oValidate.needFormat===true && oValidate.type=="number" && !isNaN( $.i18n.parseNumber(input.val())))
								? $.i18n.formatNumber($.i18n.parseNumber(input.val()), oValidate.format, {currency: $widget.options.currency, region: $widget.options.region})
								: input.val();
							input.val(value);

							if ((typeof evt!="undefined") && evt.keyCode==27) {
							// On 'ESC' *onAfterClose* will not be called.
								$span.hide();
								var invalid = input.is(':input:invalid');
								// short delay for webkit-engines to prevent default action
								window.setTimeout(function(){
							 		$widget['_setContent'](input, $span, true);
									if (!invalid) {
										$span.show();
										input.parent().hide();
									}
									else {
										$span.hide();
										input.show();
									}
									$span.css('width','');
									$cell.find('*.hideOnEditable').show();
								},10);
							}
						},

						// Called after element becomes uneditable and data has been saved to server.
						onAfterClose: function(input){
							$widget['_setContent'](input, $span, true);

							// If HasSubOwnPrices has just been set,
							// update the DOM and the corresponding server action.
							var ownpriceWasSet = $span.data('epOwnprice');
							if (ownpriceWasSet !== undefined) {
								// Update style and title of *$span* enclosing *$cell*.
								$cell.removeClass('InheritedValue');
								$cell.attr('title', $span.data('epOwnpriceTitle'));

								// Update *additional* option of *uiTextedit*.
								var additional = $span.uiTextedit('option','additional');
								delete additional[ownpriceWasSet];
								$span.uiTextedit('option','additional',additional);

								// Update DOM of *$span*.
								$span
									.removeData(['epOwnprice','epOwnpriceTitle'])
									.removeAttr('data-ep-ownprice')
									.removeAttr('data-ep-ownprice-title');
							}

							// Hide label element.
							input.parent().hide();

							$span.css('width','');
							$cell.find('*.hideOnEditable').show();
						}
					};

					// if additional parameters are needed for the SaveAction
					if($span.data('epAdditional')!==undefined){
						oTextEditOptions.additional = {};
						// e.g. oTextEditOptions.additional['CurrencyID'] = "EUR"
						oTextEditOptions.additional[$span.data('epAdditional')] = this._this.options.currency;
					}

					// if additional parameters are needed for the SaveAction
					if($span.data('epOwnprice')!==undefined){
						oTextEditOptions.additional = (oTextEditOptions.additional===undefined)? {} : oTextEditOptions.additional;
						// e.g. oTextEditOptions.additional['HasSubOwnPrices'] = 1
						oTextEditOptions.additional[$span.data('epOwnprice')] = 1;
					}

					// build the uiTextedit widget
					var textEdit = $span.uiTextedit(oTextEditOptions);

				}

				// trigger click event to show the editable element
				$span.trigger('click.uiTextedit');

				evt.stopPropagation();
			}
		},

		_handleRowClick: function(evt){
			// this: current table row
			var $row = ep(this)
				realTargetTag = evt.target.tagName.toLowerCase(),
				$evtTarget = ep(evt.target);

			if(realTargetTag=="label" && ($evtTarget.children!==undefined) && $evtTarget.children("input[type=checkbox]") && $evtTarget.parent("td.Checkbox")){
				evt.preventDefault();
			}

			$row.toggleClass('RowSelected');
			if(($evtTarget.hasClass("RowSelector") && !$evtTarget.hasClass("NoRowSelector")) || (
				//!someThingSelected &&
				realTargetTag != "a" &&
				realTargetTag != "input" &&
				realTargetTag != "select" &&
				realTargetTag != "option" &&
				realTargetTag != "textarea" &&
				realTargetTag != "img" &&
				//realTargetTag != "label" &&
				!$evtTarget.hasClass("NoRowSelector") &&
				!$evtTarget.hasClass("Sprite"))
			){
				var $checkbox = ep('input:checkbox, input.Checkbox', $row);
				// if checkbox is not disabled -> toggle check attribute
				if(!$checkbox.prop('disabled')){
					$checkbox.attr({'checked': ($row.hasClass('RowSelected')? true : false)});
				}
			}
		},

		_handleCheckboxClick: function(evt){
			evt.stopPropagation();
			var $row = ep(this);
			$row.toggleClass('RowSelected');
		},

		_setContent: function(input, $span, isDisabled){
			var self = this;

			input.attr({
				'disabled': isDisabled
			});
			// if an edit icons should be shown
			if(self.options.editIcon){
				if(!self.options.alterIcon || $span.data('epTextAlign')!="right"){
					$span.append(self.STR_EDIT_ICON);
				}else{
					$span.prepend(self.STR_EDIT_ICON);
				}
			}
		},

		_checkAll: function(evt){
			// this: table cell which fires the event
			var form = ep(this)[0].form,
				isChecked = ep(this).prop('checked');

			// if an label is the event source, a click event is fired
			// -> the checkbox is checked/unchecked a moment later
			// -> therefore the checked property has to be toggled
			isChecked = (evt.target.tagName.toLowerCase().match(/label/))? !isChecked : isChecked;

			ep(form).find('tbody:first td.Checkbox input[type=checkbox]').attr({
				checked: isChecked
			});
			//toggle row highlight class
			ep('tbody:first>tr[class!=NewEntry]', form)[(isChecked? 'addClass' : 'removeClass')]('RowSelected');
		}
	});
});

/* ---- Module:ep.date ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.date
 *
 * @revision		$Revision: 1.9 $
 */

jQuery.plugin( 'ep.date', ['ep.core', 'jQuery.i18n', 'jQuery.class'], function( $, undefined ){

	var noGetExp = /^(UnixTime)/,
		noSetExp = /^(Day|UnixTime)$/,
		noAddExp = /^UTC/,
		proto = {};

	// advanced
	$.extend(proto,{
		Constructor: function( a, b, c, d, e, f, g ){
			switch( arguments.length ) {
				case 1:
					this.date = new Date( (/^-?\d+$/).test(a) ? parseInt(a,10) : a instanceof Date || a instanceof ep.Date ? a.getTime() : a );
				break;
				case 3:
					this.date = new Date( a, b, c );
				break;
				case 6:
					this.date = new Date( a, b, c, d, e, f );
				break;
				case 7:
					this.date = new Date( a, b, c, d, e, f, g );
				break;
				default:
					this.date = new Date();
				break;
			}
		},
		// clone
		clone: function(){
			return new ep.Date( this.getTime() );
		},
		// i18n format
		getFormat: function( format, options ){
			return $.i18n.formatDate( this.date, format, options );
		},
		setFormat: function( value, format, options ){
			var date = $.i18n.parseDate( value, format,  options );

			if( date ){
				this.setTime( date.getTime() );
			}
			return this;
		},
		// leap year
		isLeapYear: function(){
			var year = this.getFullYear();
			return !(year%400) || (!(year%4) && !!(year%100));
		},
		// days of month
		getMonthLength: function(){
			var month = this.getMonth(),
				days = [31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31];

			if( month===1 && this.isLeapYear() ){
				return 29;
			}
			return days[month];
		},
		setFirstMonthDay: function(){
			this.setDate( 1 );
			return this;
		},
		setLastMonthDay: function(){
			this.setDate( this.getMonthLength() );
			return this;
		},
		// day of week
		setDay: function( set ){
			this.setDate( this.getDate() + ( set - this.getDay() ) );
			return this;
		},
		// unix time
		getUnixTime: function(){
			return Math.round( this.getTime() / 1000 );
		},
		setUnixTime: function( set ){
			this.setTime( set * 1000 );
			return this;
		},
		// UTC unix time
		getUTCUnixTime: function(){
			return this.getUnixTime() - this.getTimezoneOffset()*60;
		},
		setUTCUnixTime: function( set ){
			this.setUnixTime(set);
			this.addTime( this.getTimezoneOffset()*60000 );
			return this;
		}
	});

	// compare
	$.each({
		'Date': 'Hours',
		'Time': 'FullYear'
	},function( name, set ){
		proto[ 'compare' + name ] = function( date ){
			if( !date){
				date = new Date();
			}
			var thisDate = new Date( this.getTime() ),
				compDate = new Date( date.getTime() );

			thisDate[ 'set' + set ](0,0,0,0);
			compDate[ 'set' + set ](0,0,0,0);

			var thisTime = thisDate.getTime(),
				compTime = compDate.getTime();

			if( thisTime > compTime ){
				return 1;
			}
			else if( thisTime < compTime ){
				return -1;
			}
			else{
				return 0;
			}
		};
	});

	// get only
	$.each([
		'toGMTString',
		'toLocaleString',
		'getTimezoneOffset'
	],function( i, name ){
		proto[ name ] = function(){
			return this.date[ name ]();
		};
	});

	// add, get, set, diff
	$.each({
		'FullYear':			31536000000,
		'Month':			2592000000,
		'Day':				604800000,
		'Date':				86400000,
		'Hours':			3600000,
		'Minutes':			60000,
		'Seconds':			1000,
		'Milliseconds':		1,
		'Time':				1,
		'UTCDate':			0,
		'UTCFullYear':		0,
		'UTCHours':			0,
		'UTCMilliseconds':	0,
		'UTCMinutes':		0,
		'UTCMonth':			0,
		'UTCSeconds':		0,
		'UnixTime':			1000
	},function( name, math ){
		// get methods
		if( !noGetExp.test(name) ){
			proto[ 'get' + name ] = function(){
				return this.date[ 'get' + name ]();
			};
		}
		// set methods
		if( !noSetExp.test(name) ){
			proto[ 'set' + name ] = function(){
				this.date[ 'set' + name ].apply( this.date, arguments );
				return this;
			};
		}
		if( !noAddExp.test(name) ){
		// add methods
			proto[ 'add' + name ] = function( add ){
				this[ 'set' + name ]( this[ 'get' + name ]() + add );
				return this;
			};
		// diff methods
			proto[ 'diff' + name ] = function( date ){
				if( !date){
					date = new Date();
				}
				return Math.round( ( date.getTime() - this.getTime() ) / math );
			};
		}
	});

	$.Class('ep.Date',proto);

});


/* ---- Module:ep.ui.spinner ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.ui.spinner
 *
 * @revision		$Revision: 1.18 $
 */

jQuery.plugin( 'ep.ui.spinner', ['ep.core', 'ep.ui.validate', 'ep.date', 'ep.sprite'], function( $, undefined ){

	var is = function( val ){
			return !!( val===0 || (!isNaN(val) && val) );
		},
		html = $('html');

	$.widget('ep.ui.Spinner',ep.ui.Validate,{

		options: {
	// ep.ui.Input
		//	big:				true,
		//	autofocus:			false,
		//	placeholder:		'text',
		//	info:				'text',

	// ep.ui.Validate
		//	accept:				'',
		//	min:				1,
		//	max:				20,
		//	minlength:			1,
		//	maxlength:			4,
		//	pattern:			[\w]+,
		//	required:			true,
		//	tooltipOffset:		[0,-7],
		//	valid:				true,
		//	type:				'basic',
		//	format:				'',

	// ep.ui.Spinner
		//	unit:				'GByte',
			type:				'number',
			format:				'n0',
			step:				1,
			stepType:			'hours'
		},

		_create: function(){
			this.Inherited();

			var self = this;

			this.options = $.extend({
					step:			parseInt( this.elem.attr('step'), 10 )
				},this.options);

			this.wrap.addClass('ep-uiSpinner');

			this.elem
				.addClass('epWidth-29')
				.on( 'keydown', function(event){
					if( event.keyCode === 38 || event.keyCode === 40 ){
						event.preventDefault();
						if( !self._interval ){
							self._start( event.keyCode === 38 ? 1 : -1 );
						}
					}
				})
				.on( 'keyup', function(event){
					if( event.keyCode === 38 || event.keyCode === 40 ){
						event.preventDefault();
						self._stop();
					}
				});

//#JSCOVERAGE_IF false
			if( this.placeholder ){
				this.placeholder.addClass('epWidth-29');
			}
//#JSCOVERAGE_ENDIF

			this.stepper = $('<span>')
				.addClass('ep-uiInput ep-uiInput-base ep-uiInput-button ep-uiSpinner-stepper')
				.appendTo(this.wrap);
			this.stepUp = ep( this.dict.parse('<a href="javascript:;">+</a>') )
				.addClass('ep-uiSpinner-stepUp')
				.attr({
					'tabIndex': -1
				})
				.on( 'mousedown.uiSpinner', function(){
					self._start(1);
				})
				.appendTo(this.stepper);
			this.stepDown = ep( this.dict.parse('<a href="javascript:;">&ndash;</a>') )
				.addClass('ep-uiSpinner-stepDown')
				.attr({
					'tabIndex': -1
				})
				.on( 'mousedown.uiSpinner', function(){
					self._start(-1);
				})
				.appendTo(this.stepper);

			this.stack.push( this.stepper[0], this.stepUp[0], this.stepDown[0] );
		},

		_init: function(){
			this.Inherited();
			this._unitInit();

			var o = this.options;

			if( o.type!=='date' ){
				var format = (/(c|n|p)(\d{0,})/).exec(o.format),
					step = (o.step+'').split('.'),
					fDecimals = parseInt( format[2] || 0,10 ),
					sDecimals = step[1] ? step[1].length : 0;
				this.options.format = format[1]+Math.max(fDecimals,sDecimals);
			}
		},

		_unitInit: function(){
			if( !this.unit && this.options.unit ){
				this.unit = $('<span>')
					.addClass('ep-uiSpinner-unit')
					.insertBefore(this.stepper);
				this.stack.push(this.unit[0]);
			}
			if( this.unit ){
				this.unit.text(this.options.unit);
				var padding = (this.unit.width()+4)+'px';
				this.elem.css( 'padding-right', padding );
				if( this.placeholder ){
					this.placeholder.css( 'padding-right', padding );
				}
			}
		},

		_tooltipInit: function(){
			this.Inherited(arguments);
			if( this.tooltip ){
				this.tooltip.uiTooltip( 'option', 'offsetAdjust', [30,-1] );
			}
		},

		_changeAttr: function( event, attr ){
			var self = this;
			$.each( attr, function( name, value ){
				if( (/^(accept|pattern|required)$/i).test(name) ){
					self.options[ name ] = value;
				}
				else if( (/^(min|max|minlength|maxlength|step)$/i).test(name) ){
					self.options[ name ] = parseInt( value, 10 );
				}
			});
		},

		_parseValue: function(){
			var val = this.elem.attr('value'),
				o = this.options,
				region = {region: o.region};

			if( o.type === 'date' ){
				if( !is(this._val) ){
					this._val = is(o.min) ? new ep.Date(o.min) : new ep.Date();
				}
				val = $.i18n.parseDate( val, o.format, region );
				this._val = is(val) ? new ep.Date(val) : this._val;
			}
			else{
				if( !is(this._val) ){
					this._val = is(o.min) ? o.min : 0;
				}
				region.currency = o.currency;

				val = $.i18n.parseNumber( val, 10, region );
				this._val = is(val) ? val : this._val;
			}
		},

		_start: function( inc ){
			html.on( 'mouseup.uiSpinner', this.Proxy('_stop') );

			this._placeholderHide();
			this._parseValue();

			this._type = '_spin' + (this.options.type==='date' ? 'Date' : 'Number');
			this._step = this.options.step * inc;
			this._count = 0;
			this[this._type]();
			// set interval for auto count up/down
			this._interval = setInterval( this.Proxy('_spin'), 250 );
		},

		_spin: function(){
			this._count++;
			if( (/^(10|20|30)$/).test(this._count+'') ){
				clearInterval(this._interval);
				// update interval speed for auto count up/down
				this._interval = setInterval( this.Proxy('_spin'), 150/this._count );
			}
			this[this._type]();
		},

		_spinNumber: function(){
			var o = this.options;

			this._val += this._step;

			if( is(o.min) && o.min > this._val ){
				this._val = o.min;
				this._stop();
			}
			else if( is(o.max) && o.max < this._val ){
				this._val = o.max;
				this._stop();
			}

			this.elem.val( $.i18n.formatNumber( this._val , o.format, {region:o.region,currency:o.currency} ) );
		},

		_spinDate: function( add ){
			var o = this.options;

			this._val[ $.camelCase('add-'+o.stepType) ]( this._step );

			if( is(o.min) && o.min > this._val.getTime() ){
				this._val = new ep.Date(o.min);
				this._stop();
			}
			else if( is(o.max) && o.max < this._val.getTime() ){
				this._val = new ep.Date(o.max);
				this._stop();
			}

			this.elem.val( $.i18n.formatDate( this._val, o.format, {region:o.region} ) );
		},

		_stop: function(){
			html.off( 'mouseup.uiSpinner', this.Proxy('_stop') );

			this._interval = clearInterval(this._interval);

			this._placeholderShow();

			this.elem
				.filter(':visible')
					.focus()
				.end()
				.trigger('changeValue');
		},

		destroy: function(){
			this.elem
				.removeClass('epWidth-29')
				.off('.uiSpinner');
			this.wrap
				.removeClass(/ep-uiSpinner[\w\d-]*/g);

			this.Inherited(arguments);
		}
	});

});


/* ---- Module:ep.ui.datepicker ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.ui.datepicker
 *
 * @revision		$Revision: 1.24.4.2 $
 */

jQuery.plugin( 'ep.ui.datepicker', {
	plugin: [
		'ep.core',
		'ep.date',
		'ep.sprite',
		'ep.fn.busy',
		'ep.ui.spinner',
		'jQuery.tmpl'
	],
	tmpl: [
		'ep.ui.datepicker'
	]
}, function( $, undefined ){

/*
 * @dictionary		ep.dict
 *
 * @translation		{Today}
 *					{Done}
 */

	$.widget('ep.ui.Datepicker',ep.ui.Validate,{

		options: {
	// ep.ui.Input
		//	big:				true,
		//	autofocus:			false,
		//	placeholder:		'text',
		//	info:				'text',

	// ep.ui.Validate
		//	accept:				'',
		//	min:				1,
		//	max:				20,
		//	minlength:			1,
		//	maxlength:			4,
		//	pattern:			[\w]+,
		//	required:			true,
		//	valid:				true,
		//	type:				'basic',
		//	format:				'',

	// ep.ui.Datepicker
		//	onAfterSetValue:	undefined					// callback called after value was set
			type:				'date',
			format:				'l',						// format for i18n
			showOn:				'button',					// show datepicker on 'focus' || 'button' || 'both' or 'inline'
			duration:			'normal',					// duration for show and hide effect
			show:				'fadeIn',					// show effect 'show' || 'fadeIn' || 'slideIn'
			hide:				'fadeOut',					// hide effect 'hide' || 'fadeOut' || 'slideOut'
			weekDaysAvailable:	[1,1,1,1,1,1,1],			// which days ar avaible boolean in array
			numberOfMonths:		1,							// display number of month
			showOtherMonth:		true,						// show days from other month
			selectOtherMonth:	false,						// days from other month ar clickable
			changeMonth:		true,						// enable select month
			changeYear:			true,						// enable select year
			region:				$.config.i18n.region,		// region for i18n
			time:				true,						// use as date and time picker
			timeStep:			15,							// step for time spinner in minutes
			min:				undefined,					// min for range miliseconds || dateObj
			max:				undefined					// max for range miliseconds || dateObj
		},

		_create: function(){
			this.Inherited();

			var currentDate = this.options.currentDate,
				date;

			date = currentDate ? new ep.Date(currentDate.year, currentDate.month, currentDate.day) : new ep.Date();
			date
				.setMinutes(30)
				.setSeconds(0)
				.setMilliseconds(0);

			this._date =			date.clone().setHours(0,0,0,0);
			this._dateNow =			this._date.clone();
			this._dateSelected =	this._date.clone();
			this._timeSelected =	date.clone().setFullYear(0,0,0);

			this.domCache = $('<div>');
			this.cal = $.i18n.regions[ this.options.region ].calendar;

			this.elem.on( 'changeValue.uiDatepicker', this.Proxy('_changeElemVal') );

			this.showButton = $('<span>')
				.attr({
					'class':	'ep-uiInput ep-uiInput-base ep-uiInput-button ep-uiDatepicker-showButton'
				})
				.html(
					ep.sprite('calendar','s').addClass('ep-uiInput-buttonSpriteOnly')
				)
				.on( 'click.uiDatepicker', this.Proxy('show') )
				.appendTo( this.domCache );

			this.stack.push( this.domCache[0], this.showButton[0] );

			this._changeElemVal();
		},

		_init: function(){
			this.Inherited();

			var o = this.options;

			if( (/^(focus|both)$/).test(o.showOn) ){
				this.elem
					.off('focus.uiDatepicker')
					.on( 'focus.uiDatepicker', this.Proxy('show') );
			}
			if( (/^(button|both)$/).test(o.showOn) ){
				this.elem.addClass('epWidth-29');

				if( this.placeholder ){
					this.placeholder.addClass('epWidth-29');
				}

				this.showButton
					.insertAfter( this.placeholder || this.elem );
			}
			else{
				this.elem.removeClass('epWidth-29');
				if( this.placeholder ){
					this.placeholder.removeClass('epWidth-29');
				}
				this.showButton
					.appendTo( this.domCache );
			}

			if( this.container ){
				this._initCalCache();

				if( o.time && !this.timeBar ){
					this._createTimeBar();
				}
			}

			this._tooltipInit();

			if( o.showOn === 'inline' ){
				this.show();
			}
		},

		_initCalCache: function(){
			this._calCache = {
				weekDays: arrayRotate( $.merge([],this.cal.days.namesShort), this.cal.firstDay),
				months: $.merge([],this.cal.months.names)
			};
		},

		_tooltipInit: function(){
			this.Inherited(arguments);
			if( this.tooltip && (/^(button|both)$/).test(this.options.showOn) ){
				this.tooltip.uiTooltip( 'option', 'offsetAdjust', [30,-1] );
			}
			else if( this.tooltip ){
				this.tooltip.uiTooltip( 'option', 'offsetAdjust', [3,-2] );
			}
		},

		_createBase: function(){
			var self = this;
			// the datepicker
			this.container = ep('<form>')
				.addClass('epDialog ep-uiDatepicker-container')
				.hide();
			// go to previous month
			this.prevButton = ep('<button type="button">')
				.append( ep.sprite('arrow-l','s').addClass('ep-uiInput-buttonSpriteOnly') )
				.uiInput()
				.uiInput('addClass','ep-uiDatepicker-prev')
				.on( 'click.uiDatepicker', function(){
					self._changeMonth(-1);
				});
			// go to next month
			this.nextButton = ep('<button type="button">')
				.append( ep.sprite('arrow-r','s').addClass('ep-uiInput-buttonSpriteOnly') )
				.uiInput()
				.uiInput('addClass','ep-uiDatepicker-next')
				.on( 'click.uiDatepicker', function(){
					self._changeMonth(1);
				});
			// bar on the bottom
			this.buttonBar = $('<div>')
				.addClass('epDialogButtonBar ep-uiDatepicker-buttonBar')
				.appendTo( this.container );
			// select the current day
			this.todayButton = ep('<button type="button">')
				.text( this.dict.translate('Today') )
				.appendTo( this.buttonBar )
				.uiInput()
				.uiInput('addClass','ep-uiDatepicker-today')
				.on( 'click.uiDatepicker', function(){
					self._date = self._dateNow.clone().setHours(0,0,0,0);
					self._changeDay( self._date.getTime() );
					self._createCalendars();
				});
			// close the datepicker
			this.doneButton = ep('<button type="button">')
				.text( this.dict.translate('Done') )
				.appendTo( this.buttonBar )
				.uiInput()
				.uiInput('addClass','ep-uiDatepicker-done')
				.on( 'click.uiDatepicker', this.Proxy('hide') );
			// live click handler to select a day on click
			this.container
				.on( 'click', 'a.ep-uiDatepicker-dayClick', this.Proxy('_selectDay') )
				.on( 'change', 'select.ep-uiDatepicker-monthSelect,select.ep-uiDatepicker-yearSelect', function(){
					self._changeMonth(parseInt(this.value,10));
				});
			// stack for calendars
			this.calendars = $();
			// reinit
			this._init();
			// add to DOM
			this.container.appendTo('body');
			// save in stack
			this.stack.push(
				this.container[0],
				this.prevButton[0],
				this.nextButton[0],
				this.doneButton[0],
				this.todayButton[0],
				this.buttonBar[0]
			);
		},

		_createTimeBar: function(){
			this.timeBar = $('<div>')
				.addClass('ep-uiDatepicker-timeBar')
				.insertBefore( this.buttonBar );

			this.stack.push( this.timeBar[0] );

			this._createTimeSelect();
		},

		_createTimeSelect: function(){
			this.timeSelect = ep('<input>')
				.attr({
					'class': 'epWidth100',
					'placeholder': '00:00'
				})
				.appendTo( this.timeBar )
				.uiSpinner({
					type:		'date',
					step:		15,
					stepType:	'minutes',
					format:		't',
					region:		this.options.region
				})
				.uiInput('addClass','ep-uiDatepicker-time')
				.on( 'changeValue.uiDatepicker', this.Proxy('_changeTimeVal') );

			this._setTimeVal();

			this.stack.push( this.timeSelect[0]	);
		},

		_createCalendars: function(){
			// set busy layer
			this.container.busy('show');
			// vars
			var o				= this.options,
				calendarsData	= this._calendarData(),
				calendars;
			// build weeks
			$.each( calendarsData, function( i, calendarData){
				while( calendarData.days.length >= 7 ){
					calendarData.weeks.push({days:calendarData.days.splice(0,7)});
				}
			});
			// build calendars
			calendars = $.tmpl( 'ep.ui.datepicker', calendarsData );
			calendars
				.not(':first,:last')
				.addClass('ep-uiDatepicker-calendarMiddle');
			calendars
				.not(':last')
				.first()
				.addClass('ep-uiDatepicker-calendarFirst');
			calendars
				.not(':first')
				.last()
				.addClass('ep-uiDatepicker-calendarLast');
			// place prev button to new calendars and handle range
			this.prevButton
				.attr( 'disabled', !inRange( o.min, this._date.clone().setFirstMonthDay().setHours(0,0,0,-1).getTime() ) )
				.parent()
				.prependTo( calendars.filter(':first').find('.ep-uiDatepicker-titleBar') );
			// place next button to new calendars and handle range
			this.nextButton
				.attr( 'disabled', !inRange( undefined, this._date.clone().setLastMonthDay().setHours(0,0,0,0).addDate(1).getTime(), o.max ) )
				.parent()
				.appendTo( calendars.filter(':last').find('.ep-uiDatepicker-titleBar') );
			// remove old calendars
			this.calendars
				.html('')
				.remove();
			// show new calendars in datepicker
			this.container.prepend(calendars)
				.busy('hide');
			// set new calendars
			this.calendars = calendars;
		},

		_calendarData: function(){
			var o				= this.options,
				baseDate		= this._date.clone().addMonth( - Math.ceil(o.numberOfMonths/2) ),
				nowTime			= this._dateNow.getTime(),
				selectedTime	= this._dateSelected.getTime(),
				region			= {region: this.options.region},
				baseMonth		= this._date.getMonth(),
				changeMonth		= null,
				changeYear		= null,
				data			= [],
				i;

			if( o.changeMonth ){
				changeMonth = [];
				$.each( this._calCache.months, function( i, name ){
					if( name ){
						changeMonth.push({ value: (baseMonth-i)*-1, name: name, currentMonth: baseMonth===i });
					}
				});
			}

			if( o.changeYear ){
				var yDate = this._date.clone();

				changeYear = [{ value: 0, name: yDate.getFormat( "yyyy", region ), currentYear: true }];

				for( i=1 ; i<=10 ; i++ ){
					yDate.addFullYear(-1);
					changeYear.unshift({ value: i*-12, name: yDate.getFormat( "yyyy", region ), currentYear: false });
				}
				yDate.addFullYear(10);
				for( i=1 ; i<=10 ; i++ ){
					yDate.addFullYear(1);
					changeYear.push({ value: i*12, name: yDate.getFormat( "yyyy", region ), currentYear: false });
				}
			}

			for( i=0,iLength=o.numberOfMonths ; i<iLength ; i++ ){
				var date =			baseDate.addMonth(1),
					iDate =			date.clone().setDate(0),
					iFirstDate =	date.clone().setFirstMonthDay(),
					iFirstTime =	iFirstDate.getTime(),
					iLastTime =		date.clone().setLastMonthDay().getTime(),
					iDays =			iFirstDate.getMonthLength(),
					iWeekDay =		iFirstDate.getDay() - this.cal.firstDay,
					add =			{
										year:		iFirstDate.getFormat( "yyyy", region ),
										years:		changeYear,
										month:		iFirstDate.getFormat( "MMMM", region ),
										months:		changeMonth,
										weekDays:	this._calCache.weekDays,
										weeks:		[],
										days:		[]
									};

				if( iWeekDay<0 ){
					iWeekDay = iWeekDay+7;
				}

				iDate.addDate( - iWeekDay );

				for( var j=1,jLength=(Math.ceil( (iWeekDay+iDays) / 7) * 7 ) ; j<=jLength ; j++ ){
					var jDate =			iDate.addDate(1),
						jTime =			jDate.getTime(),
						currentMonth =	inRange( iFirstTime, jTime, iLastTime ),
						clickable =		inRange( o.min, jTime, o.max ) && o.weekDaysAvailable[ jDate.getDay() ];

					add.days.push({
						'date':				jDate.clone(),
						'tstamp':			jTime,
						'day':				jDate.getDate(),
						'currentMonth':		!!currentMonth,
						'clickable':		(currentMonth || o.selectOtherMonth) && clickable,
						'visible':			!!(currentMonth || o.selectOtherMonth || o.showOtherMonth),
						'selected':			jTime===selectedTime,
						'now':				jTime===nowTime
					});
				}

				data.push(add);
			}

			return data;
		},

		_setElemVal: function( noBubbling ){
			var val = new ep.Date(
							this._dateSelected.getFullYear(),
							this._dateSelected.getMonth(),
							this._dateSelected.getDate(),
							isNaN(this._timeSelected.getHours()) ? 0 : this._timeSelected.getHours(),
							isNaN(this._timeSelected.getMinutes()) ? 0 : this._timeSelected.getMinutes(),
							isNaN(this._timeSelected.getSeconds()) ? 0 : this._timeSelected.getSeconds()
						)
						.getFormat(
							this.options.format,
							{region:this.options.region}
						);

			if( noBubbling ){
				this.elem.val( val );
			}
			else{
				this.elem.attr( 'value', val );
			}

			// callback called after value was set
			if(this.options.onAfterSetValue !== undefined){
				this.options.onAfterSetValue(this.elem);
			}
		},

		_getElemVal: function(){
			var date = $.i18n.parseDate( this.elem.val(), this.options.format, {region:this.options.region} );
			return date ? new ep.Date( date.getTime() ) : null;
		},

		_changeElemVal: function(){
			var o = this.options,
				date = this._getElemVal();

			if( date && inRange( o.min, date.clone().setLastMonthDay().getTime() ) && inRange( undefined, date.clone().setFirstMonthDay().getTime(), o.max ) ){
				if( this.elem.is(':focus') ){
					this._date = date.clone().setHours(0,0,0,0);
				}
				this._dateSelected = date.clone().setHours(0,0,0,0);
				this._timeSelected = date.clone().setFullYear(0,0,0);

				if( this.timeSelect ){
					this._setTimeVal();
				}
			}
			if( this.container && this.container.filter(':visible').length ){
				this._createCalendars();
			}
		},

		_setTimeVal: function(){
			if( !this.timeSelect.is(':focus') ){
				this.timeSelect.val( this._timeSelected.getFormat( 't', {region:this.options.region} ) );
			}
		},

		_getTimeVal: function(){
			var date = $.i18n.parseDate( this.timeSelect.val(), 't', {region:this.options.region} );
			return date ? new ep.Date( date.getTime() ) : null;
		},

		_changeTimeVal: function(event){
			var date = this._getTimeVal();

			if( date ){
				this._timeSelected = date.setFullYear(0,0,0);
				this._setElemVal();
			}
		},

		_changeMonth: function( inc ){
			this._date.addMonth(inc);
			this._createCalendars();
		},

		_changeDay: function( tstamp ){
			this._dateSelected = new ep.Date(tstamp);
			this._setElemVal();
		},

		_selectDay: function( event ){
			this._changeDay( parseInt( $(event.target).attr('data-tstamp'), 10 ) );
		},

		_show: function(){
			var o = this.options;

			if( o.showOn !== 'inline' ){
				this.container.contextOrientation( this.elem, 'bottom', [-1,1] ).focus();
				this.container
					.stop(true,true)
					[ $.fn[o.show] ? o.show : 'show' ](o.duration);

				$('html').on( 'keyup', $.proxy(this,'_hide') );
			}
			else{
				this.buttonBar
					.hide();
				this.container
					.insertAfter( this.wrap )
					.css('position','relative')
					.show();
			}
			this.elem.blur();
		},

		show: function(){
			var self = this;

			if( this.elem.is(":disabled") ){
				return;
			}
			if( !this.container ){
				this._createBase();
			}

			this._show();
			this._changeElemVal();
			this._setValidStatus(true);
		},

		_hide: function( event ){
			if( event.keyCode===27 ){
				this.hide();
				this._validate(event);
			}
		},

		hide: function(){
			var o = this.options;

			if( o.showOn !== 'inline' ){
				this.container
					.stop(true,true)
					[ $.fn[o.hide] ? o.hide : 'hide' ](o.duration);

				$('html').off( 'keyup', $.proxy(this,'_hide') );
			}
		},

		getDate: function(){
			return new ep.Date(
							this._dateSelected.getFullYear(),
							this._dateSelected.getMonth(),
							this._dateSelected.getDate(),
							this._timeSelected.getHours(),
							this._timeSelected.getMinutes(),
							this._timeSelected.getSeconds()
						);
		}
	});

	var arrayRotate = function( array, size ){
			var tmp = array.splice( 0, size );

			return array.concat( tmp );
		},

		inRange = function( min, val, max ){
			min = new ep.Date(typeof min === 'object' && min.getTime ? min.getTime() : min).setHours(0,0,0,0).getTime();
			max = new ep.Date(typeof max === 'object' && max.getTime ? max.getTime() : max).setHours(0,0,0,0).getTime();
			return !min || val >= min ? !max || val <= max ? true : false : false;
		};

});


/* ---- Module:ep.alert ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.alert
 *
 * @revision		$Revision: 1.11 $
 */

jQuery.plugin( 'ep.alert', ['ep.core','ep.ui.dialog','ep.sprite'], function( $, undefined ){

	/*
	 * @dictionary		ep.dict
	 *
	 * @translation		{Notification}
	 *					{Ok}
	 *					{Cancel}
	 */

	ep.extend({
		alert: function( settings ){
			settings = $.extend( {}, ep.alertSettings, settings );

			var dict = ep.dict('ep.dict'),
				dialog = ep('<div>')
					.addClass('ep-uiDialog-alert')
					.append( ep.sprite( 'ico_'+settings.size+'_'+settings.type, settings.size ) )
					.append( '<span class="dialog-content">'+settings.content+'</span>' ),
				options = {
					title:		dict.parse(settings.title),
					modal:		true,
					resizable:	false,
					minWidth:	350,
					buttons:	{},
					close:		function( event ){
						if( settings.close ){
							settings.close(event);
						}
						var originalEvent = event.originalEvent,
							originalTarget = originalEvent ? originalEvent.originalTarget : event.originalTarget,
							buttons = ep(this).uiDialog('option','buttons');

						if( settings.ok && buttons.ok && originalTarget===buttons.ok[0] ){
							settings.ok(event);
						}
						else if( settings.cancel ){
							settings.cancel(event);
						}
					}
				};

			$.each( ['Ok', 'Cancel'], function( i, Name ){
				var name = Name.toLowerCase();
				var buttonName = settings[ name + 'Title' ];
				if( settings[ name ] ){
					options.buttons[ name ] = {
						text:	buttonName ? buttonName : dict.translate( Name ),
						click:	function( event ){
							event.originalTarget = event.target;
							ep(this).uiDialog('close',event);
						}
					};
				}
			});

			return dialog.uiDialog(options);
		},
		alertSettings: {
			title:		'{Notification}',
			type:		'notification',
			size:		'xl',
			content:	'',
			ok:			null,
			cancel:		null,
			close:		null
		}
	});

});


/* ---- Module:de_epages.core ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			de_epages.core
 *
 * @revision		$Revision: 1.6 $
 */

jQuery.plugin( 'de_epages.core', 'ep.core', function( $, undefined ){

	var de_epages = ep.sub();

	$.extend(de_epages,{
		// similar to $.extend; if only 1 hash in arguments de_epages will extend with this hash
		extend: function() {
			return $.extend.apply( this, arguments );
		},
		// similar to $.mixin; if only 1 hash in arguments de_epages will mixin with this hash
		mixin: function() {
			return $.mixin.apply( this, arguments );
		}
	});

	// Expose ep to the global object
	window.de_epages = de_epages;

});

/* ---- Module:jQuery.ui.progressbar ---- */

/*
 * jQuery UI Progressbar 1.8.18
 *
 * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * http://docs.jquery.com/UI/Progressbar
 *
 * Depends:
 *   jquery.ui.core.js
 *   jquery.ui.widget.js
 */
jQuery.plugin( 'jQuery.ui.progressbar', [
	'jQuery.ui.core',
	'jQuery.ui.widget'
], function( $, undefined ){

$.widget( "ui.progressbar", {
	options: {
		value: 0,
		max: 100
	},

	min: 0,

	_create: function() {
		this.element
			.addClass( "ui-progressbar ui-widget ui-widget-content ui-corner-all" )
			.attr({
				role: "progressbar",
				"aria-valuemin": this.min,
				"aria-valuemax": this.options.max,
				"aria-valuenow": this._value()
			});

		this.valueDiv = $( "<div class='ui-progressbar-value ui-widget-header ui-corner-left'></div>" )
			.appendTo( this.element );

		this.oldValue = this._value();
		this._refreshValue();
	},

	destroy: function() {
		this.element
			.removeClass( "ui-progressbar ui-widget ui-widget-content ui-corner-all" )
			.removeAttr( "role" )
			.removeAttr( "aria-valuemin" )
			.removeAttr( "aria-valuemax" )
			.removeAttr( "aria-valuenow" );

		this.valueDiv.remove();

		$.Widget.prototype.destroy.apply( this, arguments );
	},

	value: function( newValue ) {
		if ( newValue === undefined ) {
			return this._value();
		}

		this._setOption( "value", newValue );
		return this;
	},

	_setOption: function( key, value ) {
		if ( key === "value" ) {
			this.options.value = value;
			this._refreshValue();
			if ( this._value() === this.options.max ) {
				this._trigger( "complete" );
			}
		}

		$.Widget.prototype._setOption.apply( this, arguments );
	},

	_value: function() {
		var val = this.options.value;
		// normalize invalid value
		if ( typeof val !== "number" ) {
			val = 0;
		}
		return Math.min( this.options.max, Math.max( this.min, val ) );
	},

	_percentage: function() {
		return 100 * this._value() / this.options.max;
	},

	_refreshValue: function() {
		var value = this.value();
		var percentage = this._percentage();

		if ( this.oldValue !== value ) {
			this.oldValue = value;
			this._trigger( "change" );
		}

		this.valueDiv
			.toggle( value > this.min )
			.toggleClass( "ui-corner-right", value === this.options.max )
			.width( percentage.toFixed(0) + "%" );
		this.element.attr( "aria-valuenow", value );
	}
});

$.extend( $.ui.progressbar, {
	version: "1.8.18"
});

});


/* ---- Module:de_epages.presentation.ajaxTransport ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			de_epages.presentation.ajaxTransport
 *
 * @revision		$Revision: 1.15 $
 */

jQuery.plugin( 'de_epages.presentation.ajaxTransport', ['jQuery.support.multipleUpload', 'jQuery.uid', 'jQuery.mime'], function( $, undefined ){

	// extend the ajax settings
	if( !$.ajaxSettings.fileSizeMax ){
		$.ajaxSettings.fileSizeMax = 2097152;	// set max size of files default: 2MB
	}

		// use html5 as default
	var html5 = $.support.multipleUpload && typeof(XMLHttpRequestUpload) !== "undefined",
		// url query params
		rquery = /\?/,
		// to string method
		toString = Object.prototype.toString,
		// map of advanced errors
		statusMap = {
			102: { status:102, errorThrown:'Processing' },
			200: { status:200, errorThrown:'Ok' },
			290: { status:290, errorThrown:'Ok' },							// Item
			408: { status:408, errorThrown:'Request Timeout' },
			489: { status:489, errorThrown:'Invalid Image Size' },			// Item
			490: { status:490, errorThrown:'Bad Item Request' },
			491: { status:491, errorThrown:'Items of Request Failed' },
			492: { status:492, errorThrown:'Empty Request' },				// Item
			493: { status:493, errorThrown:'Mimetype Not Accept Error' },	// Item
			494: { status:494, errorThrown:'File Size Limit Error' },		// Item
			495: { status:495, errorThrown:'Feature Limit Exceeded' },		// Item
			496: { status:496, errorThrown:'Invalid Image File' },			// Item
			497: { status:497, errorThrown:'Image Exceeds Megapixels' },	// Item
			498: { status:498, errorThrown:'Invalid MP3 File' },			// Item
			499: { status:499, errorThrown:'Virus Found Error' },			// Item
			500: { status:500, errorThrown:'Internal Server Error' },
			590: { status:590, errorThrown:'Internal Server Error' },		// Item
			599: { status:599, errorThrown:'Unknow Error' }
		},
		// local Error handle
		errorGet = function( extended, code, errorThrown ){
			if( extended!==true ){
				errorThrown = code;
				code = extended;
				extended = false;
			}

			var data = statusMap[ code ] || { status:code, errorThrown: errorThrown || 'Unknow Error' },
				text;

			text = '{"status":'+data.code+',"errorThrown":"'+data.errorThrown+'"}}';

			return extended ? {text:'{"ERROR":'+text+'}',data:{ERROR: data}} : {text:text,data:	data};
		},
		// upload single file with ajax
		singleAJAX = function( o, originalOptions, jqXHR, progressCallback ){
			var xhr = o.xhr(),
				send = xhr.send,
				fileObj = o.file;

			// modify options
			o.data = null;
			o.type = 'post';
			o.async = true;
			o.xhr = function(){
				return xhr;
			};
			// add progress handle
			if( xhr.upload ){
				xhr.upload.onprogress = function(event){
					progressCallback(event);
				};
			}
			// modify send xhr
			xhr.send = function(){
				xhr.setRequestHeader( 'Content-Type', 'application/octet-stream' );
				xhr.setRequestHeader( 'If-Modified-Since', 'Mon, 26 Jul 1997 05:00:00 GMT' );
				xhr.setRequestHeader( 'Cache-Control', 'no-cache' );
				xhr.setRequestHeader( 'content-disposition', 'attachment; filename="'+encodeURIComponent(fileObj.fileName||fileObj.name)+'"; name="'+o['_inputName']+'"' );

				if(xhr.sendAsBinary && typeof fileObj.getAsBinary  == "function") {
					xhr.sendAsBinary(fileObj.getAsBinary());
				}
				else{
					send.call(xhr,fileObj);
				}
			};
		},
		// handle multiple files to upload with ajax
		multiAJAX = function( o, originalOptions, jqXHR, progressCallback ){
			// state whether xhr abort
			var isAbort = false,
			// state whether error-caused
				isError = false;
			// results send and abort handle
			return {
				send: function( headers, completeCallback ){
					var inputName = o['_inputName'],
						fileStack = $.merge([],o.file.files),
						fileStackLength = fileStack.length,
						// response data store
						responseText = [],
						responseData = [],
						headerStack = [],
						// completeCallback
						nextItem = function( i ){
							if( i<fileStackLength ){
								var fileObj = fileStack[i],
									fileItem = {
										name:		inputName,
										fileName:	fileObj.name || fileObj.fileName,
										fileSize:	fileObj.size || fileObj.fileSize,
										fileType:	fileObj.type
									},
									xhrItemProgress = function( event ){
										if( isAbort ){
											// abort item if main xhr is abort
											xhrItem.abort();
										}
										else{
											// set status of main xhr
											jqXHR.status = 102;
											jqXHR.statusText = 'progress-item';
											// call progress handle
											progressCallback(
												// modify progress event object
												$.extend(event,{
													item:				i+1,
													itemTotal:			fileStackLength,
													itemLoaded:			i,
													data:				{item:fileItem}
												}),
												jqXHR.statusText,
												jqXHR
											);
										}
									},
									xhrItemDone = function( data, textStatus, xhrItem ){
										// overwrite original status
										textStatus = 'success-item';
										var status = 290;

										if( isAbort ){
											// abort item if main xhr is abort
											xhrItem.abort();
										}
										else{
											if( data.ERROR ){
												data = {
													item: fileItem,
													ERROR: errorGet(data.ERROR.status || 590, data.ERROR.errorThrown).data
												};
												// set error status
												isError = true;
												status = data.ERROR.status;
												textStatus = 'error-item';
											}
											else{
												// store data
												responseText.push(xhrItem.responseText);
												responseData.push(data);
												data = {success:data, item:fileItem};
											}
											// set status of main xhr
											jqXHR.status = status;
											jqXHR.statusText = textStatus;
											// call progress handle
											progressCallback(
												// simulate progress event object
												$.extend($.Event(),{
													type:				'progress',
													lengthComputable:	true,
													position:			fileItem.fileSize,
													total:				fileItem.fileSize,
													loaded:				fileItem.fileSize,
													item:				i+1,
													itemTotal:			fileStackLength,
													itemLoaded:			i+1,
													data:				data
												}),
												textStatus,
												jqXHR
											);
										}
									},
									xhrItemFail = function( xhrItem, textStatus, errorThrown ){
										// use the advanced error handling from success callback
										var error = errorGet( true, xhrItem.status, errorThrown );
										xhrItem.responseText = error.text;
										xhrItemDone.call(xhrItem, error.data, textStatus, xhrItem );
									},
									xhrItemAlways = function(){
										if( isAbort ){
											xhrItem.abort();
										}
										else{
											// store responseHeaders
											headerStack.push( xhrItem.getAllResponseHeaders() );
											// start xhr for next item
											nextItem(i+1);
										}
									},
									// setup options for AJAX item
									xhrItemOptions = $.extend( {}, originalOptions, {
										_inputName:	inputName,
										file:		fileObj
									}),
									// xhr object for current item
									xhrItem;

								// check accept mimetype of file
								if( !$.mime(fileItem.fileType,o.fileMimeAccept) ){
									xhrItemOptions.dataType = 'ERROR';
									xhrItemOptions.ERROR = errorGet(493).data;
								}
								else if( (fileItem.fileSize) > o.fileSizeMax ){
									xhrItemOptions.dataType = 'ERROR';
									xhrItemOptions.ERROR = errorGet(494).data;
								}
								// call AJAX
								xhrItem = $.ajax(xhrItemOptions);
								xhrItem
									.progress(xhrItemProgress)
									.done(xhrItemDone)
									.fail(xhrItemFail)
									.always(xhrItemAlways);
							}
							else{
								var status = 200,
									statusText = 'success';
								if(	isError ){
									status = 491;
									statusText = errorGet(491).data.errorThrown;
								}
								else if( !responseData.length ){
									status = 492;
									statusText = errorGet(492).data.errorThrown;
								}
								// build responseText from all responses
								jqXHR.responseText = '['+responseText.join(',')+']';
								jqXHR.responseXML = null;
								// execute callback
								completeCallback(
									status,
									statusText,
									{
										json:	responseData,
										text:	jqXHR.responseText
									},
									headerStack.join('')
								);
							}
						};

					// start first xhr for first item
					nextItem(0);
				},
				abort: function( statusText ){
					// set abort state
					isAbort = true;
				}
			};
		};
//#JSCOVERAGE_IF false
		// container for iframes
	var	container,
		// handle single file upload with iframe
		singleIFRAME = function( o, originalOptions, jqXHR, progressCallback ){
			o.url = originalOptions.url + (rquery.test(originalOptions.url) ? '&' : '?') + $.param( originalOptions.data );
			// state whether xhr abort
			var isAbort = false,
				isTimeout = false,
				isComplete = false,
				isSuccess = false;
			// results send and abort handle
			return {
				send: function( headers, completeCallback ){
					var id = $.uid('upload'),
						// iframe
						io,
						ioNode,
						// form
						form,
						formNode,
						// file input
						file = $(o.file),
						fileNode = o.file,
						fileNodeName = file.attr('name'),
						filePlaceholder,
						// simulate fileObj
						fileItem = {
							fileName: file.val(),
							fileSize: 204800,
							name: fileNodeName || 'NewFile'
						};
						// get mime type of file
						var temp = /\.([^.]+)$/.exec(fileItem.fileName);
						fileItem.fileType = $.mime(temp ? temp[1] : '');

						// complete handle
					var	complete = function( event, responseText ){
							clearInterval(interval);
							if( !isAbort && !isComplete ){
								isComplete = true;

								var status,
									statusText,
									responseData;

								// get response text
								if( !responseText ){
									if( isTimeout ){
										responseText = errorGet(true,408).text;
									}
									else if( ioNode.contentWindow && ioNode.contentWindow.document ){
										responseText = ioNode.contentWindow.document.body ? ioNode.contentWindow.document.body.innerHTML : '';
									}
									else if( ioNode.contentDocument && ioNode.contentDocument.document ){
										responseText = ioNode.contentDocument.document.body ? ioNode.contentDocument.document.body.innerHTML : '';
									}
									if( !responseText ){
										responseText = errorGet(true,408).text;
									}
								}

								// try to parse JSON from response text
								try{
									responseText = responseText.replace(/^(<pre[^>]*>)([^]*?)(<[^<]*pre>)$/,"$2");
									responseData = $.parseJSON(responseText);
								}
								catch(error){
									error = errorGet( true, 490 );
									responseText = error.text;
									responseData = error.data;
								}

								// set status
								if( responseData && !responseData.ERROR ){
									status = 200;
									statusText = 'success';
								}
								else{
									var error = errorGet(490);
									status = responseData.ERROR.status || error.data.status;
									statusText = responseData.ERROR.errorThrown || error.data.errorThrown;
								}

								// set success state
								isSuccess = status===200;

								// handle progress item success/error
								// set date for progress event
								var progressEventData = {item:fileItem};
								if( responseData.ERROR ){
									progressEventData.ERROR = responseData.ERROR;
								}
								else{
									progressEventData.success = responseData;
								}
								// set status of main xhr
								jqXHR.status =		isSuccess ? 290 : status;
								jqXHR.statusText =	isSuccess ? 'success-item' : 'error-item';
								// call progress handle
								progressCallback(
									// simulate progress event object
									$.extend($.Event(),{
										type:				'progress',
										lengthComputable:	true,
										position:			204800,
										total:				204800,
										loaded:				204800,
										item:				1,
										itemTotal:			1,
										itemLoaded:			1,
										data:				progressEventData
									}),
									jqXHR.statusText,
									jqXHR
								);

								// set status of main xhr
								if( isSuccess ){
									jqXHR.status =		290;
									jqXHR.statusText =	'success';
								}
								else{
									jqXHR.status =		491;
									jqXHR.statusText =	errorGet(491).data.errorThrown;
								}
								// build responseText from all responses
								jqXHR.responseText = '['+responseText+']';
								jqXHR.responseXML = null;
								// execute callback
								completeCallback(
									jqXHR.status,
									jqXHR.statusText,
									{
										json:	responseData ? [responseData] : [],
										text:	jqXHR.responseText
									},
									''
								);
							}
						},
						// progress handle
						interval,
						progressLoaded = 0,
						progress = function(){
							if( !isAbort ){
								jqXHR.status = 102;
								var textStatus = jqXHR.statusText = 'progress-item';

								progressLoaded += 2048;

								if( progressLoaded > 203776 ){
									clearInterval(interval);
									progressLoaded = 203776;
								}

								progressCallback(
									// simulate progress event object
									$.extend($.Event(),{
										type:				'progress',
										lengthComputable:	true,
										position:			progressLoaded,
										total:				204800,
										loaded:				progressLoaded,
										item:				1,
										itemTotal:			1,
										itemLoaded:			0,
										data:				{item:fileItem}
									}),
									textStatus,
									jqXHR
								);
							}
						};

					// check accept mimetype of file
					if( $.mime(fileItem.fileName,o.fileMimeAccept) ){
						complete( {}, errorGet(true,493).text );
					}
					else{
						// iframe container
						container = container || $('<div>')
							.css('display','none')
							.appendTo( document.body );
						// iframe to send form
						io = $('<iframe name="'+id+'"></iframe>').appendTo( container );

						ioNode = io[0];
						// bind success/error callback event
						if( window.attachEvent ){
							ioNode.attachEvent( 'onload', complete);
						}
						else{
							ioNode.addEventListener( 'load', function(){
								var self = this,
									args = arguments,
									look = function(){
										var body = (ioNode.contentDocument || ioNode.contentWindow && ioNode.contentWindow.document || {}).body;
										if( (body && body.innerHTML) || loop >= 100 ){
											clearInterval(interval);
											complete.apply(self,args);
										}
									},
									loop = 0,
									// fix bug in load event, use own check of load after load is triggered
									interval = setInterval(look,10);
								look();
							}, false );
						}
						// form
						form = $('<form>')
							.attr({
								target:		id,
								method:		'POST',
								action:		o.url + '&handleashtml=1',
								enctype:	'multipart/form-data',
								encoding:	'multipart/form-data'
							})
							.appendTo( container );
						formNode = form[0];

						if( o.timeout > 0 ){
							// Timeout checker
							setTimeout(function(){
								// Check to see if the request is still happening
								if( !isAbort ){
									isTimeout = true;
									complete();
								}
							}, o.timeout);
						}

						// run progress if defined
						if( o.progress ){
							// simulate xhr progress interval
							interval = setInterval(progress,25);
						}

						// send file
						filePlaceholder = file.clone().insertAfter(file).attr('disabled',true);
						if( !fileNodeName ){
							file.attr('name','NewFile');
						}
						form.append(file);
						formNode.submit();
						if( !fileNodeName ){
							file.removeAttr('name');
						}
						file.insertBefore(filePlaceholder);
						filePlaceholder.remove();
						form.remove();
					}
				},
				abort: function( statusText ){
					// set abort state
					isAbort = true;
				}
			};
		};
//#JSCOVERAGE_ENDIF
	$.ajaxTransport( 'json', function( o, originalOptions, jqXHR ){
		var progressHook = function(){
				var context = o.context || jqXHR,
					progress = jqXHR.progress,
					deferred = $.Deferred();

				jqXHR.progress = function(){
					deferred.progress.apply( deferred, arguments );
					return jqXHR;
				}

				if( o.progress ){
					jqXHR.progress(o.progress);
				}

				return (function(){
						deferred.notifyWith( context, arguments );
					});
			};

		// transport file
		if( o.file ){
				// be sure o.file is not modified
			var fileData = o.file = originalOptions.file,
				fileObj  = toString.call(fileData)==='[object File]',
				fileElem = fileObj ? $() : $(fileData);

			if( fileElem.is(':file') ){
				// prepare options
				o['_inputName'] = fileElem.attr('name') || 'NewFile';
				o.fileMimeAccept = o.fileMimeAccept || fileElem.attr('accept') || '*/*';
				originalOptions.data = $.extend( true, {ErrorAction:'JSONAjaxTransportFileError'}, originalOptions.data );
				if( html5 ){
					return multiAJAX( o, originalOptions, jqXHR, progressHook() );
				}
				else{
					return singleIFRAME( o, originalOptions, jqXHR, progressHook() );
				}
			}
			else if( fileObj && o['_inputName'] ){
				return singleAJAX( o, originalOptions, jqXHR, progressHook() );
			}
		}
	});

	// handle client error to prevent call a real xhr
	$.ajaxTransport( 'ERROR', function( o, originalOptions, jqXHR ){
		return {
			send: function( headers, completeCallback ){
				var error = o.ERROR || errorGet(490).data;
				completeCallback( error.status, error.errorThrown, {}, '' );
			}
		};
	});

});

/* ---- Module:de_epages.presentation.ui.uploader ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			de_epages.presentation.ui.uploader
 *
 * @revision		$Revision: 1.31.2.8 $
 */

jQuery.plugin( 'de_epages.presentation.ui.uploader', {
	plugin: ['jQuery.dict', 'jQuery.tmpl','jQuery.i18n', 'jQuery.expr', 'jQuery.fn.form', 'jQuery.ui.widget', 'jQuery.ui.progressbar', 'ep.ui.dialog', 'de_epages.core', 'de_epages.presentation.ajaxTransport'],
	dict:	['ep.dict', 'de_epages.presentation.dictionary'],
	tmpl:	['de_epages.presentation.ui.uploaderProgress','de_epages.presentation.ui.uploaderError', 'de_epages.presentation.ui.uploaderReplace']
}, function( $, undefined ){

/*
 * @dictionary		ep.dict
 *
 * @translation		{Cancel}
 *					{Ignore}
 *					{Replace}
 *
 * @dictionary		de_epages.presentation.dictionary
 *
 * @translation		{FileUploadSingle}
 *					{FileUploadMultiple}
 *					{UploaderError}
 *					{UploaderReplace}
 *					{FixErrors}
 *					{FilesUploaded}
 *					{FileSizeLimitError}
 *					{InternalServerError}
 *					{MimetypeNotAcceptError}
 *					{UnknownError}
 *					{FeatureLimitExceeded}
 *					{InvalidMP3File}
 *					{InvalidImageFile}
 *					{ImageExceedsMegapixels}
 *					{VirusFoundError}
 *					{FileAlreadyExistsOnServer}
 *					{InvalidImageSize}
 */

	var epDict				= $.dict('ep.dict'),
		presentationDict	= $.dict('de_epages.presentation.dictionary'),
		tCancel				= epDict.translate('Cancel'),
		tIgnore				= epDict.translate('Ignore'),
		tReplace			= presentationDict.translate('ReplaceFiles'),
		tUploadFile			= presentationDict.translate('FileUploadSingle'),
		tUploadFiles		= presentationDict.translate('FileUploadMultiple'),
		tUploaderError		= presentationDict.translate('UploaderError'),
		tUploaderReplace	= presentationDict.translate('FileUploadMultiple'),
		tFixErrors			= presentationDict.translate('FixErrors'),
		tFilesUploaded		= presentationDict.translate('FilesUploaded'),
		tAlreadyExists    = presentationDict.translate('FileAlreadyExistsOnServer'),

		tmplHelper			= function(){
			return {
				i: 0,
				even: function(){
					return (this.i++)%2==0;
				},
				scrunch: function( string ){
					return ep.scrunch( string, 40, {ratio:0.5} );
				},
				translate: function( string ){
					var before = string.replace(/ /g,''),
						after = presentationDict.translate( before );

					return after!==before ? after : presentationDict.translate('UnknownError');
				}
			};
		};

	$.widget( "de_epages.presentation.ui.Uploader", {
		options: {
		//	multiple:	false,
		//	accept:		'*/*',
			exists:		[],
			style:		'normal',
			big:		false,
			callback:	$.noop,
			url:		'?',
			data:		{
				'ViewAction':	'JSONViewResponse'
			}
		},

		_create: function(){
			var self = this,
				o = self.options;

			self.elem = self.element
				.attr("size","1")
				.sub(ep)
				.addClass('ep-uiInput-hidden');
			// create a label as wrap
			self.wrap = ep('<label>')
				.addClass(
					'ep-uiInput-wrap de_epages-presentationUiUploader-button'
					+ ( self.elem.is(':disabled') ? ' disabled' : '' )
					+ ( self.elem.is(':readonly') ? ' readonly' : '' )
					+ ( self.elem.is(':checked') ? ' checked' : '' )
				)
				.insertBefore(self.elem)
				.append(self.elem);
			// create pseudo button
			self.button = ep('<span></span>')
				.addClass('ep-uiInput ep-uiInput-base ep-uiInput-button');

			// insert button depending on browser engine
			self.button[$.browser.msie ? 'insertAfter' : 'insertBefore'](this.elem);
			// init options
			self.option({
				'accept':	$.mime(o.accept || self.elem.attr('accept') || '*/*'),
				'multiple':	o.multiple || self.elem.attr('multiple') || false,
				'style':	o.big ? 'big' : o.style
			});

			// set wrapper to fixed width and hide overlapping content
			// for IE7, see EPG-22791
			if ($.browser.msie) {
				self.wrap
					.css({
						overflow: 'hidden',
						width: self.button.outerWidth(true) + 'px'
					});
			}

			// bind upload handle
			self.elem
				.on( 'focus.presentationUiUploader', function(){
					self.addClass("focused");
				})
				.on( 'blur.presentationUiUploader', function(){
					self.removeClass("focused");
				})
				.on( 'change.presentationUiUploader', self.Proxy('_upload') )
				.on( 'changeAttr.presentationUiUploader', self.Proxy('_changeAttr') );
			// stack of item data
			self.dataStack = [];
		},

		_setOption: function( name, value ){
			var o = this.options;

			if( value!==undefined ){
				switch( name ){
					case 'accept':
						this.elem.attr( name, $.mime(value) );
					break;
					case 'multiple':
						this.elem.attr( name, value );
						this._setOption( 'style', o.style );
					break;
					case 'big':
						this._setOption( 'style', 'big' );
					break;
					case 'style':
						switch( value ){
							case 'big':
								this.button
									.html( '<span class="ep-sprite ep-sprite-s ico_s_fileupload"></span>'+(o.multiple ? tUploadFiles : tUploadFile) )
									.addClass('ep-uiInput-big');
							break;
							case 'icon':
								this.button
									.html( '<span class="ep-sprite ep-sprite-s ico_s_fileupload ep-uiInput-buttonSpriteOnly"></span>' )
									.removeClass('ep-uiInput-big');
							break;
							case 'big-icon':
								this.button
									.html( '<span class="ep-sprite ep-sprite-m ico_m_fileupload ep-uiInput-buttonSpriteOnly"></span>' )
									.addClass('ep-uiInput-big');
							break;
							default:
								this.button
									.html( '<span class="ep-sprite ep-sprite-s ico_s_fileupload"></span>'+(o.multiple ? tUploadFiles : tUploadFile) )
									.removeClass('ep-uiInput-big');
							break;
						}
					break;
				}
			}
			return this.Inherited( arguments );
		},

		// handle addClass to the wrap
		addClass: function( name ){
			if( !(/(hover|active|focused)/).test(name) || !this.elem.is(':disabled,:readonly') ){
				this.wrap.addClass(name);
			}
		},
		// handle removeClass to the wrap
		removeClass: function( name ){
			this.wrap.removeClass(name);
		},

		// actions if change attr by javascript
		_changeAttr: function( event, attr ){
			// change disabled class
			if( attr.hasOwnProperty('disabled') ){
				if( this.elem.is(':disabled') ){
					this.addClass('disabled');
					this.removeClass('focused');
				}
				else{
					this.removeClass('disabled');
				}
			}
		},

		_upload: function( event, doReplace ){
			var self = this,
				o = self.options,
				files = self.elem[0].files,
				filesCheck = [],
				filesExists = [];

			self.statusText = '';

			self._errorClose({
				close: $.noop
			});

			for( var i=0,iLength=self.dataStack.length ; i<iLength ; i++ ){
				if( self.dataStack[i].ERROR ){
					self.dataStack.splice(i,1);
					iLength--;
					i--;
				}
			}

			// ask for replace exixting files
			if( !doReplace && o.exists.length ){
				if( !files ){
					files = [{name:self.elem.val()}];
				}

				filesCheck = $.map( files, function( file, i ){
					return file.name || file.fileName;
				});

				ep.ajax({
					async		: false,
					dataType	: 'json',
					data		: {
						ViewAction	: "JSONUnicodeConverter",
						ObjectID	: ep.config.siteId,
						Type		: "File",
						Strings		: filesCheck
					}
				})
				.done(function(data){
					filesCheck = data.Strings;
				});

				filesExists = $.map( filesCheck, function( name, i ){
					return $.inArray(name,o.exists)>=0 ? name : null;
				});

				if( filesExists.length ){
					self._uploadReplace( filesExists );
					return;
				}
			}

			self._progressOpen({
				close: function( event ){
					self._uploadCancel();
				}
			});

			// provide a flag for the server
			o.data.ReplaceExistingFiles = doReplace ? 1 : 0;

			self.uploadXHR = $.ajax({
				url:			o.url,
				data:			o.data,
				dataType:		'json',
				file:			self.elem[0],
				fileMimeAccept:	o.accept
			})
			.progress(self.Proxy('_uploadProgress'))
			.done(self.Proxy('_uploadSuccess'))
			.fail(self.Proxy('_uploadError'));
		},

		_uploadReplace: function( filesReplace ){
			this._replaceCreate();
			this.replace
				.element
				.html( $.tmpl('de_epages.presentation.ui.uploaderReplace', [{items:filesReplace, tAlreadyExists:tAlreadyExists}], tmplHelper()) );
			this._replaceOpen();
		},

		_uploadCancel: function(){
			this.uploadXHR.abort();
			this._errorClose();
		},

		_uploadProgress: function( event, statusText, jqXHR ){
			var valueItem = event.loaded * 100 / event.total,
				valueAll = event.itemLoaded * 100 / event.itemTotal;

			this.progressbarItem.progressbar( 'value', valueItem );
			this.progresstextItem.text( ep.scrunch( event.data.item.fileName, {ratio:0.5,length:65} ) );
			this.progressbarAll.progressbar( 'value', valueAll );
			this.progresstextAll.text( tFilesUploaded+': '+event.itemLoaded+' / '+event.itemTotal );

			if( /(success|error)/.test(statusText) ){
				this.dataStack.push( event.data );
			}
		},

		_uploadSuccess: function( data, statusText, jqXHR ){
			this.statusText = statusText;
			this._progressClose({
				close: $.noop
			});
			this._uploadComplete();
		},

//#JSCOVERAGE_IF 0
		_uploadError: function( jqXHR, statusText, errorThrown ){
			var self = this;
			self.statusText = statusText;
			self._errorCreate();
			self.error
				.element
				.html( $.tmpl('de_epages.presentation.ui.uploaderError', [{items: self.dataStack}], tmplHelper()) );
			self._progressClose({
				close: $.noop
			});
			self._errorOpen({
				close: function(){
					self.elem.appendTo(self.wrap);
					self._uploadComplete();
				}
			});
		},
//#JSCOVERAGE_ENDIF

		_uploadComplete: function(){
			var o			= this.options,
				dataStack	= this.dataStack,
				statusText	= this.statusText;

			this.elem.formReset();
			this.dataStack = [];
			this.statusText = '';

			if( $.type(o.callback)=='string' ){
				location.href = o.callback;
			}
			else{
				o.callback( dataStack, statusText );
			}
		},

		_progressOpen: function( options ){
			if( !this.progress ){
				this._progressCreate();
			}
			if( options ){
				this.progress.option(options);
			}
			this.progress.open();
		},

		_progressClose: function( options ){
			if( this.progress ){
				if( options ){
					this.progress.option(options);
				}
				this.progress.close();
			}
		},

		_progressCreate: function(){
			if( !this.progress ){
				var self = this;

				this.progress = ep('<div class="de_epages-presentationUiUploader">')
					.html( $.tmpl('de_epages.presentation.ui.uploaderProgress') )
					.uiDialog({
						width:		350,
						modal:		true,
						autoOpen:	false,
						title:		self.options.multiple ? tUploadFiles : tUploadFile,
						buttons:	{
							cancel:	{text:tCancel,	click:function(){ self._progressClose(); }}
						}
					})
					.find('.de_epages-presentationUiUploader-progressBar')
						.progressbar()
						.each(function(i){
							var elem = $(this);
							self[ i ? 'progressbarAll' : 'progressbarItem'] = elem;
							self[ i ? 'progresstextAll' : 'progresstextItem'] = elem.next();
						})
					.end()
					.uiDialog('Instance');
			}
		},

		_errorOpen: function( options ){
			if( !this.error ){
				this._errorCreate();
			}
			if( options ){
				this.error.option(options);
			}
			this.error.open();
		},

		_errorClose: function( options ){
			this.elem.appendTo(this.wrap);
			if( this.error ){
				if( options ){
					this.error.option(options);
				}
				this.error.close();
			}
		},

		_errorCreate: function(){
			if( !this.error ){
				var self = this;

				this.error = ep('<div class="de_epages-presentationUiUploader">')
					.html( $.tmpl('de_epages.presentation.ui.uploaderError') )
					.uiDialog({
						width:		350,
						modal:		true,
						autoOpen:	false,
						open:		function(){
							self.elem.insertAfter(self.error.options.buttons.fixit);
						},
						title:		tUploaderError,
						buttons:	{
							fixit:	{text: tFixErrors,'class':'epWidth-160'},
							ignore:	{text: tCancel,	click:function(){ self._errorClose(); }}
						}
					})
					.uiDialog('Instance');
			}
		},

		_replaceOpen: function( options ){
			if( !this.replace ){
				this._replaceCreate();
			}
			if( options ){
				this.replace.option(options);
			}

			this.replace.open();
		},

		_replaceClose: function( options ){
			if( this.replace ){
				if( options ){
					this.replace.option(options);
				}
				this.replace.close();
			}
		},

		_replaceCreate: function(){
			if( !this.replace ){
				var self = this;

				this.replace = ep('<div class="de_epages-presentationUiUploader">')
					.html( $.tmpl('de_epages.presentation.ui.uploaderError') )
					.uiDialog({
						width:		350,
						modal:		true,
						autoOpen:	false,
						title:		tUploaderReplace,
						buttons:	{
							replace:	{text: tReplace, click:function(){ self._replaceClose(); self._upload({},true); }},
							cancel:		{text: tCancel,	click:function(){ self._replaceClose(); self.statusText = "abort"; self._uploadComplete(); }}
						}
					})
					.uiDialog('Instance');
			}
		},

		destroy: function(){
			var self = this;

			if(self.error){
				ep(self.error).uiDialog('destroy');
			}
			if(self.progress){
				ep(self.progress).uiDialog('destroy');
			}

			self.elem.off('.presentationUiUploader');

			self.Inherited();
		}

	});

});


/* ---- Module:de_epages.presentation.rss ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			de_epages.presentation.rss
 *
 * @revision		$Revision: 1.11.2.2 $
 */

jQuery.plugin( 'de_epages.presentation.rss', ['de_epages.core', 'jQuery.class', 'ep.ajax'], function( $, undefined ){

	var mediaExpr = /(audio|image|video)/;

	$.Class( 'de_epages.presentation.Rss', {
		RSSCallbackFunc: null,
		Constructor: function( url, callbackFunc, fullPath ){
			//if fullPath is given we dont need to change the rss path
			this.RSSCallbackFunc = callbackFunc;
			this.requestFile(url,fullPath);
		},
		requestFile: function(url,fullPath){
			//check if file is already stored on server
			var fileURL = url;
			if(!fullPath){
				fileURL = '/WebRoot/RssFeeds/'+url.replace(/[^A-Za-z0-9]/g,"_")+'.xml';
			}

			ep.ajax({
				dataType:	'xml',
				url:		fileURL,
				type: 'GET',
				context:	this
			})
			.done(function(data, textStatus, XMLHttpRequest){
				this.readResponse(data);
			})
			.fail(function(data, textStatus, XMLHttpRequest){
				this.requestFeed(url);
			});
		},

		requestFeed: function(url){
			//file is not stored on server ask server to fetch it
			ep.ajax({
				dataType:	'xml',
				data: {
					'ObjectID' : ep.config.siteId,
					'ChangeAction': 'GetFeed',
					'feedurl': url
				},
				context:	this
			})
			.done(function(data, textStatus, XMLHttpRequest){
				this.readResponse(data);
			})
			.fail(function(data, textStatus, XMLHttpRequest){
				//if the second request although fails we do nothing
			});
		},

		readResponse: function(data){
			var itemname,
				subtitle,
				content,
				logo,
				date,
				xmlData = $(data);
			var feedData = {
				'version': null,
				'name': null,
				'description': null,
				'pageLink': null,
				'pubDate': null,
				'logo': {
					'src': null,
					'link': null,
					'title': null
				},
				'items': null
			};
			//rss feed type detection
			if(xmlData.find('rss').length){
				//RSS
				feedData.version = 'RSS';
				itemname = 'item';
				subtitle = 'description';
				content = 'description';
				logo = 'image';
				date = 'pubDate';
			}
			else if(xmlData.find('feed').length){
				//ATOM
				feedData.version = 'ATOM';
				itemname = 'entry';
				subtitle = 'subtitle';
				content = 'summary';
				logo = 'logo';
				date = 'updated';
			}
			//jquery has problems with xml namespaces see: http://bugs.jquery.com/ticket/155
			else if(xmlData.find('rdf\\:RDF').length || xmlData.find('RDF').length){
				//RDF
				feedData.version = 'RDF';
				itemname = 'item';
				subtitle = 'description';
				content = 'description';
				logo = 'image';
				//date = 'date'; //dc\\:date is the correct tag but we have to use only date because of the bug http://bugs.jquery.com/ticket/155
				date = (xmlData.find('dc\\:date')[0] !== undefined)? "dc\\:date" : "date";
			}
			else{
				//no valid feed
				return false;
			}

			//detect name of feed
			feedData.name = xmlData.find('title:first').text();
			//detect description
			var feedDesciption = xmlData.find(subtitle + ':first');
			feedData.description = feedDesciption.length ? feedDesciption.text() : xmlData.find('tagline:first').text();
			//detect link to feeds source page
			var firstLink = xmlData.find('link:first');
			feedData.pageLink = firstLink.text();
			if(!feedData.pageLink){
				var pageLink =  xmlData.find('link[rel="alternate"]:first');
				feedData.pageLink = pageLink.length ? pageLink.attr('href') : firstLink.attr('href');
			}
			//detect logo of feed
			var firstLogoNode = xmlData.find(logo+':first');
			var logoNode = firstLogoNode.length ? firstLogoNode : xmlData.find('icon:first');
			if(logoNode.length){
				var logoSrc = logoNode.find('url');
				feedData.logo.src = logoSrc.length ? logoSrc.text() : logoNode.text();
				if(!feedData.logo.src && logoNode[0].attributes[0]){
					feedData.logo.src = logoNode[0].attributes[0].value;
				}
				var logoTitle = logoNode.find('title');
				feedData.logo.title = logoTitle.length? logoTitle.text() : feedData.name;
				var logoLink = logoNode.find('link');
				feedData.logo.link = logoLink.length ? logoLink.text() : feedData.pageLink;
			}
			//detect date
			feedData.pubDate = xmlData.find(date + ':first').text();
			if(feedData.pubDate){
				var pareDateString = feedData.pubDate;
				feedData.pubDate = new Date(feedData.pubDate);
				//internet explorers date function can not pare ISO 8601 strings so we have to do it on our own
				if(isNaN(feedData.pubDate)){
					feedData.pubDate = new Date(pareDateString.substr(0,19).replace(/-/g,"/").replace(/[TZ]/g," "));
				}
			}
			var items = [];
			xmlData.find(itemname).each(function(index, elm){
				var item = {};
				var tmpElm = $(elm);
				//get title of news
				item.title = tmpElm.find('title:first').text();
				//get link of news
				if(feedData.version == 'ATOM'){
					var linkNode = tmpElm.find('link[rel="alternate"]:first');
					item.link = linkNode.length ? linkNode.attr('href') : tmpElm.find('link:first').attr('href');
				}
				else{
					var linkNode =tmpElm.find('link:first');
					item.link = linkNode.length ? linkNode.text() : feedData.pageLink;
				}
				//get content of news
				var textNode = tmpElm.find(content + ':first');
				item.text = textNode.length ? textNode.text() : tmpElm.find('content:first').text();
				if(!item.text){
					textNode = tmpElm.find('content\\:encoded:first');
					item.text = textNode.length ? textNode.text() : '';
				}
				else{
					textEncodedNode = tmpElm.find('content\\:encoded:first');
					item.textEncoded = textEncodedNode.length ? textEncodedNode.text(): tmpElm.find('encoded').text();
				}

				//get media elements of news
				item.audio = [];
				item.image = [];
				item.video = [];
				if(feedData.version == 'RSS'){
					tmpElm
						.find('enclosure')
						.each(function(){
							var elem = $(this),
								type = elem
									.attr('type')
									.replace(/\/.*$/,'');

							if( mediaExpr.test(type) ){
								item[ type ].push( elem.attr('url') );
							}
						});
				}

				//get pubDate if given
				var pubDateNode = tmpElm.find('pubDate:first');
				item.pubDate = pubDateNode.length ? pubDateNode.text() : tmpElm.find('published:first').text();
				if(item.pubDate){
					item.pubDate = new Date(item.pubDate);
				}
				items.push(item);
			});
			feedData.items = items;

			//give data to callback function
			this.RSSCallbackFunc(feedData);
			return true;
		}
	});

});

/* ---- Module:de_epages.shop.ui.dashboardWidget ---- */

/*
 * @copyright		Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @odule			de_epages.shop.ui.dashboardWidget
 *
 * @evision		$Revision: 1.16 $
 */
jQuery.plugin( 'de_epages.shop.ui.dashboardWidget', [
	'de_epages.core',
	'jQuery.effects.slide',
	'jQuery.ui.widget',
	'ep.fn.busy'
], function( $, undefined ){

	$.widget( "de_epages.shop.ui.DashboardWidget", {
		_buttonsNode: null,
		_deleteButtonNode: null,
		_addButtonNode: null,
		_titleNode: null,
		_previewLayerNode: null,
		_previewLayerAddNode: null,
		_contentNode: null,
		_bindStack: null,
		_dashboard: null,

		options: { //define options of widget formally know as widget properties in dojo
			dashboard: null,
			status: null,
			reload: null,
			action: null,
			objectId: null,
			widgetTypeId: null

		},

		_create: function(){
			this.element = this.element.sub(ep);
			this._dashboard = $(this.options.dashboard);
			this._bindStack = $();
			this._deleteButtonNode = this.element.find('.ep-DeleteButtonNode');
			this._addButtonNode = this.element.find('.ep-AddButtonNode');
			this._buttonsNode = this.element.find('.ep-ButtonsNode');
			this._titleNode = this.element.find('.ep-TitleNode');
			this._previewLayerNode = this.element.find('.ep-PreviewLayerNode');
			this._previewLayerAddNode = this.element.find('.ep-PreviewLayerAddNode');
			this._contentNode = this.element.find('.ep-ContentNode');

			//bind events
			this._bindStack.push(
				this._deleteButtonNode[0],//first Element in jQuery array like object is dom node it self
				this._addButtonNode[0],
				this._buttonsNode[0],
				this._titleNode[0],
				this.element[0]
			);

			if(this._previewLayerNode.length){
				this._bindStack.push(this._previewLayerNode[0]);
			}
			if(this._previewLayerAddNode.length){
				this._bindStack.push(this._previewLayerAddNode[0]);
			}

			this.setStatus(this.options.status);

			if(this.options.reload && this.options.action){
				this._contentNode.busy();
			}
			de_epages(this._dashboard).shopUiDashboard('registerWidget',this);
		},

		_showButtons: function(evt){
			this._buttonsNode.stop(true,true).fadeIn();
		},

		_hideButtons: function(evt){
			this._buttonsNode.stop(true,true).fadeOut();
		},

		_onClickDeleteButtonNode: function(evt){
			this._dashboard.trigger('deleteWidget',[this]);
		},

		_onClickAddButtonNode: function(evt){
			this._dashboard.trigger('addWidget',[this]);
		},

		setStatus: function(status){
			this.options.status = status;
			this._buttonsNode.hide();
			this._bindStack.off();

			if(this._previewLayerNode.length){
				this._previewLayerNode.hide();
			}

			if(this._previewLayerAddNode.length){
				this._previewLayerAddNode.hide();
			}

			this._deleteButtonNode.hide();
			this._addButtonNode.hide();

			switch(status){
				case "preview":
					this._addButtonNode.show();
					this._addButtonNode
						.one("click.dashboardWidget",$.proxy(this,'_onClickAddButtonNode'));
					this._previewLayerAddNode
						.show()
						.on("mouseover.dashboardWidget",$.proxy(this,'_showButtons'))
						.one("click.dashboardWidget",$.proxy(this,'_onClickAddButtonNode'));
					this.element
						.on("mouseleave.dashboardWidget",$.proxy(this,'_hideButtons'));
				break;
				case "used":
						this._previewLayerNode.show();
				break;
				default:
					this._deleteButtonNode.show();
					this._titleNode
						.on("mouseover.dashboardWidget",$.proxy(this,'_showButtons'))
						.on("mouseleave.dashboardWidget",$.proxy(this,'_hideButtons'));
					this._deleteButtonNode
						.on('mousedown.dashboardWidget',function( event ){ event.stopPropagation(); })
						.one("click.dashboardWidget",$.proxy(this,'_onClickDeleteButtonNode'));
				break;
			}
		},

		destroy: function(){
			this._bindStack.off();
			this.element.remove(undefined, true);
		}

	});

});


/* ---- Module:de_epages.shop.ui.dashboard ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.dashboard
 *
 * @revision		$Revision: 1.35 $
 */

jQuery.plugin( 'de_epages.shop.ui.dashboard', [
	'de_epages.core',
	'jQuery.effects.clip',
	'jQuery.ui.widget',
	'jQuery.ui.sortable',
	'jQuery.metaparse',
	'ep.ajax',
	'ep.dict',
	'ep.alert',
	'ep.ui.dialog',
	'de_epages.shop.ui.dashboardWidget',
	'ep.fn.busy'
], function( $, undefined ){

	/*
	 * @dictionary				ep.dict
	 *
	 * @translation				{Close}

	 */
	$.widget( "de_epages.shop.ui.Dashboard",/* my.parent.widget,*/ {
		_widgetCount: 0,
		_reloadWidgetStack: [],
		SIMULTAN_REQUESTS: 2,
		_runningRequests: 0,
		_dict: ep.dict('ep.dict'),
		_dialogDiv: null,

		options: { //define options of widget formally know as widget properties in dojo
			userId: undefined
		},

		_create: function(){
			this.element.sortable({
				placeholder: 'ep-PlaceholderNode ep-gradient',
				handle: '.ep-TitleNode',
				opacity: 0.9,
				containment: '.ContentSpacer',
				revert: 'true',
				items: 'li:not(.ep-FixedNode)',
				//cancel: '.ep-FixedNode', //apply this class to elements that should not be draggable
				stop: function(evt,ui){
					de_epages(this).shopUiDashboard('saveWidgetPositions');
				}
			});
			var self = this;
			this.element
				.sub(de_epages)
				.find('.ep-DashboardWidget')
				.each(function(index,value){
					if(value){
						var widgetInstance = de_epages(value).shopUiDashboardWidget('Instance');
						if(widgetInstance){
							self.registerWidget(de_epages(value).shopUiDashboardWidget('Instance'));
							self._widgetCount++;
						}
					}
				});
				if(this._widgetCount == 0){
					this.element.trigger('dashboardEmpty',[this]);
				}
				else{
					this.element.trigger('dashboardUsed',[this]);
				}

			//bind events
			this.element
				.on('deleteWidget.dashboard',$.proxy(this,'_onDeleteWidget'))
				.on('addWidget.dashboard',$.proxy(this,'_onAddWidget'))
				.on('showAddWidgetDialog.dashboard',$.proxy(this,'_onShowAddWidgetDialog'));
			for(var i = 0; i < this.SIMULTAN_REQUESTS;i++){
				this._reloadWidgetContent();
			}
		},

		registerWidget: function(dashboardWidget){
			var widgetData = dashboardWidget.options;
			if(widgetData && widgetData.reload && widgetData.action){
				var reloadWidget = {
					element: dashboardWidget.element,
					action: widgetData.action,
					objectId: widgetData.objectId
				};
				this._reloadWidgetStack.push(reloadWidget);
			}
			this._reloadWidgetContent();
		},

		_reloadWidgetContent: function(){
			if(this._reloadWidgetStack.length){
				if(this._runningRequests < this.SIMULTAN_REQUESTS){
					this._runningRequests++;
					var reloadWidget = this._reloadWidgetStack.shift();
					ep.ajax({
						data: {
							'ViewAction': reloadWidget.action,
							'ChangeAction': 'BlockMonitor',
							'ObjectID': ep.config.siteId
						},
						url : ep.config.baseUrl,
						type: 'GET',
						cache: false,
						context: this
					})
					.done(function(data, textStatus, XMLHttpRequest){
						this._runningRequests--;
						this._reloadWidgetContent();
						reloadWidget.element.find('.ep-ContentNode').html(data);
					})
					.fail(function(data, textStatus, XMLHttpRequest){
						this._runningRequests--;
						this._reloadWidgetContent();
					});
				}
			}
		},

		_onDeleteWidget: function(evt,dashboardWidget){
			var deleteObjectId = dashboardWidget.options.objectId;
			if(deleteObjectId){
				//Do async request to server
				ep.ajax({
					dataType : 'json',
					data: {
						'ViewAction': 'JSONViewResponse',
						'ChangeAction': 'JSONRemoveWidget',
						'ObjectID': deleteObjectId,
						'ViewObjectID': this.options.userId
					},
					context: this
				})
				.done(function(data, textStatus, XMLHttpRequest){
					var dashboardWidgetData = dashboardWidget.options;

					var widgetTypeId = dashboardWidgetData.widgetTypeId;
					var placeholderWidget = $('#DashboardWidget_'+widgetTypeId,this._dialogDiv);

					var animationPlaceHolder = dashboardWidget.element.clone(false);
					animationPlaceHolder.insertBefore(dashboardWidget.element);
					animationPlaceHolder.hide('clip',{},500,
					function() {
						$(this).remove();
					});

					if(placeholderWidget.length){
						dashboardWidget.element.insertBefore(placeholderWidget);
						placeholderWidget.remove();
					}
					else{
						dashboardWidget.destroy();
					}

					dashboardWidgetData.objectId = dashboardWidgetData.widgetTypeId;
					dashboardWidget.setStatus('preview');
					this._widgetCount--;
					if(this._widgetCount == 0){
						this.element.trigger('dashboardEmpty',[this]);//trigger empty event when nomore widgets are available
					}
				});
			}
			else{
				dashboardWidget.destroy();
			}

		},

		_onAddWidget: function(evt,dashboardWidget){
			var dialogNode = ep(this._dialogDiv).uiDialog('widget');
			ep(dialogNode).busy('show');
			var newWidgetTypeId = dashboardWidget.options.widgetTypeId;
			ep.ajax({
				dataType: 'json',
				data: {
					'ViewAction': 'JSONViewResponse',
					'ChangeAction': 'JSONAddWidget',
					'ObjectID': this.options.userId,
					'WidgetTypeId': newWidgetTypeId
				},
				context: this
			})
			.done(function(data, textStatus, XMLHttpRequest){
				var dashboardWidgetData = dashboardWidget.options;
				var placeholderWidget = dashboardWidget.element.clone(false);
				placeholderWidget.attr('id','DashboardWidget_'+dashboardWidgetData.widgetTypeId);

				placeholderWidget.insertBefore(dashboardWidget.element);

				dashboardWidgetData.objectId = data.widgetId;
				dashboardWidget.element.attr('id',data.widgetId);
				if(this.element.find('.ep-DashboardWidget:first').length){
					dashboardWidget.element.insertBefore(this.element.find('.ep-DashboardWidget:first'));
				}
				else{
					this.element.append(dashboardWidget.element);
				}
				this.element.sortable('refresh');

				de_epages(placeholderWidget).shopUiDashboardWidget({
					'dashboard': this.element,
					'status': 'used',
					'reload': dashboardWidgetData.reload,
					'objectId': dashboardWidgetData.widgetTypeId,
					'widgetTypeId': dashboardWidgetData.widgetTypeId
				});
				de_epages(placeholderWidget).shopUiDashboardWidget('refresh');

				this._widgetCount++;
				if(this._widgetCount == 1){
					this.element.trigger('dashboardUsed',[this]);//trigger used event when widgets are available
				}

				dashboardWidget.setStatus();
				this.saveWidgetPositions();
				ep(dialogNode).busy('hide');
			})
			.fail(function(){
				ep(dialogNode).busy('hide');
			});
		},

		_onShowAddWidgetDialog: function(evt){
			if(this._dialogDiv){
				ep(this._dialogDiv).uiDialog('open');
			}
			else{
			var closeButtonText = this._dict.translate('Close');
				ep.ajax({
				  dataType : 'json',
				  cache: false,
					data: {
						'ViewAction': 'JSONSnippet',
						'ObjectID': ep.config.siteId,
						'TemplateAction': 'MBO-ViewAddWidgetDialogSnippet',
						'TemplateLanguageID': ep.config.languageId,
						'TemplateName': 'Page'
					},
					context: this
				})
				.done(function(data, textStatus, XMLHttpRequest){
					this._dialogDiv = $('<div>')
						.html(data.snippet);
					var dialogTitle = $(this._dialogDiv).children().first().attr('title');
					$(this._dialogDiv).children().first().removeAttr('title');
					ep(this._dialogDiv).uiDialog({
						autoOpen: false,
						title: dialogTitle,
						modal: true,
						width: '980',
						height: '550',
						buttons: { "Close": {
							text: closeButtonText,
							click: function() { ep(this).uiDialog("close");}
						}}
					});
					ep(this._dialogDiv).find('.ep-metaparse').metaparse();
					// TODO: call custom event on body to build djo widgets inside dashboard widgets
					// please remove this call if there are no longer dojo widgets inside dashboard
					$('body').trigger('DashboardDialogReadyDojoConnector');
					//TODO END
					ep(this._dialogDiv).uiDialog('open');

					// add initial css-"Active"-class and trigger a click for showing widgets of the first widget-group
					ep(this._dialogDiv).find('.dashboardBoxWidgets ul:gt(0)')
					  .hide();
					ep(this._dialogDiv).find('.dashboardBoxGroups li:first')
						.addClass('Active')
						.children()
						.addClass('Active')
						.trigger('click');

				});
			}
		},

		saveWidgetPositions: function(){
			if(this.options.userId){
				var positionsString = '';
				this.element.find('.ep-DashboardWidget').each(function(index,elm){
					var widgetInstance = de_epages(elm).shopUiDashboardWidget('Instance');
					if(widgetInstance && widgetInstance.options && widgetInstance.options.objectId){
						var objectId = widgetInstance.options.objectId;
						positionsString += objectId + ';';
					}
				});

				ep.ajax({
					dataType : 'json',
					type: 'POST',
					data: {
						'ViewAction': 'JSONViewResponse',
						'ChangeAction': 'JSONSaveWidgetPositions',
						'ObjectID': this.options.userId,
						'Positions': positionsString
					},
					context: this
				});
			}
		},

		destroy: function(){
			this.element.off('.dashboard');
			$(this).remove();
		}

	});

});

/* ---- Module:de_epages.shop.ui.userBlogWidget ---- */

/*
 * @copyright		Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @odule			de_epages.shop.ui.userBlogWidget
 *
 * @evision		$Revision: 1.10 $
 */

jQuery.plugin( 'de_epages.shop.ui.userBlogWidget', {
	plugin:	['de_epages.core', 'jQuery.tmpl', 'jQuery.i18n', 'ep.date', 'ep.ui.tooltip', 'de_epages.presentation.rss','ep.fn.busy'],
	tmpl:	'de_epages.shop.ui.userBlogWidget'
}, function( $, undefined ){

	$.widget( "de_epages.shop.ui.UserBlogWidget", {

		options: { //define options of widget formally know as widget properties in dojo
			url: null,
			visibleEntrys: 3,
			entryLength: 50
		},

		_create: function(){
			if(!this.options.url){
				return;
			}
			ep(this.element.parent()).busy();
			//getFeedData
			var rss = new de_epages.presentation.Rss(this.options.url, $.proxy(this,'_readFeedData'));
		},

		_readFeedData: function(feedData){
			var o = this.options,
				items = feedData.items.slice( 0, o.visibleEntrys );

			$.each( items, function(){
				this.tooltipTitle = this.title;
				this.tooltipText = this.text;
				//if(this.textEncoded){
					//var textEncoded = this.textEncoded;
					//this.tooltipText = textEncoded; //textEncoded.substring(0,textEncoded.search(/<span[\w\s"=]*id="more/)) + '</p>';
				//}

				this.tooltipDate = $.i18n.formatDate( this.pubDate, 'd', {region:ep.config.region} );
				this.title = ep.scrunch( this.title, {length: o.entryLength, cut: false});
				this.text = ep.scrunch( this.text, {length: o.entryLength, cut: false} );
			});

			entrys = $.tmpl( 'de_epages.shop.ui.userBlogWidget', {'items':items} )
				.appendTo(this.element);

			this.element
				.find('.ep-shopUiUserBlogWidget-item')
				.each(function(){
					var elem = ep(this);
					elem.find('.ep-shopUiUserBlogWidget-itemTooltip')
						.uiTooltip({
							context:	elem.find('.ep-shopUiUserBlogWidget-itemContent'),
							interactive:true,
							addClass:	'ep-shopUiUserBlogWidget-itemTooltip',
							showDelay:	1000,
							hideDelay:	200
						});
				});
				ep(this.element.parent()).busy('hide');
		},

		destroy: function(){
			this.element.remove();
		}

	});

});


/* ---- Module:de_epages.shop.ui.userCommunityWidget ---- */

/*
 * @copyright		Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @odule			de_epages.shop.ui.userCommunityWidget
 *
 * @evision		$Revision: 1.4 $
 */

jQuery.plugin( 'de_epages.shop.ui.userCommunityWidget', {
	plugin:	['de_epages.core', 'jQuery.tmpl', 'jQuery.i18n', 'ep.date', 'ep.ui.tooltip', 'ep.fn.busy', 'de_epages.presentation.rss'],
	tmpl:	'de_epages.shop.ui.userCommunityWidget'
}, function( $, undefined ){

	$.widget( "de_epages.shop.ui.userCommunityWidget", {

		_feedData: null,

		options: { //define options of widget formally know as widget properties in dojo
			url: null,
			visibleEntrys: 3,
			entryLength: 50
		},

		_create: function(){
			if(!this.options.url){
				return;
			}
			ep(this.element.parent()).busy();
			//getFeedData
			var rss = new de_epages.presentation.Rss(this.options.url, $.proxy(this,'_readFeedData'));
		},

		_readFeedData: function(feedData){
			var items = feedData.items.slice(0,this.options.visibleEntrys);
			for(var i = 0, iLength = items.length; i < iLength; i++){
				var item = items[i];
				item.title = ep.scrunch(item.title,this.options.entryLength);
				item.text = ep.scrunch(item.text,this.options.entryLength);
			}
			var entrys = $.tmpl( 'de_epages.shop.ui.userCommunityWidget', {'items': items});
			entrys.appendTo(this.element);
			ep(this.element.parent()).busy('hide');
		},

		destroy: function(){
			this.element.remove();
		}

	});

});


/* ---- Module:de_epages.seo.ui.seoGaugeWidget ---- */

/*
 * @copyright		Copyright 2006-2011, epages GmbH, All Rights Reserved.
 *
 * @module			de_epages.seo.ui.seoGaugeWidget
 *
 * @revision		$Revision: 1.5 $
 */

jQuery.plugin( 'de_epages.seo.ui.seoGaugeWidget', {
	plugin:	['de_epages.core', 'jQuery.ui.widget', 'jQuery.tmpl'],
	tmpl:	'de_epages.seo.ui.seoGaugeWidget'
}, function( $, undefined ){
	$.widget( "de_epages.seo.ui.seoGaugeWidget", {

		options: {
			seoQuality: 0,				// SEO quality attribute of the object [ 0 .. 100 ]. 0 means no SEO check has been done yet.
			showStatusImage: true,
			caption : 'SEO:',
			deactivated : false
		},

		_create: function() {
			this._applyTmpl();
		},

		_applyTmpl: function() {
			var percentage = this.options.seoQuality;
      var percentageClass;

	    if(percentage < 33) {
	        percentageClass = 'red';
	    } else if(percentage < 66) {
	        percentageClass = 'orange';
	    } else if(percentage < 100) {
	        percentageClass = 'yellow';
	    } else {
	        percentageClass = 'green';
	    }

			var statusClass;
			if(this.options.deactivated) {
				statusClass = 'de_epages-seoUiSeoGaugeWidget-itemStatusDeactivated';
			} else if(percentage === 0) {
				statusClass = 'de_epages-seoUiSeoGaugeWidget-itemStatusUnknown';
			} else {
				statusClass = 'de_epages-seoUiSeoGaugeWidget-itemStatusKnown';
			}

			this.element.empty().append(
				$.tmpl( 'de_epages.seo.ui.seoGaugeWidget',[{
					statusClass : statusClass,
					caption : this.options.caption,
					percentage : percentage,
          percentageClass : percentageClass,
					statusDisplay : this.options.showStatusImage ? '' : 'HideElement'
				}])
			);
		},

		showStatusImage: function(state) {
			this.options.showStatusImage = state;
			this._applyTmpl();
		},

		setPercentage: function(newValue) {
			this.options.seoQuality = newValue;
			this._applyTmpl();
		},

		setDeactivated: function(newValue) {
			this.options.deactivated = newValue;
			this._applyTmpl();
		}

	});
});


/* ---- Module:de_epages.seo.ui.seoCheckWidget ---- */

/*
 * @copyright		Copyright 2006-2011, epages GmbH, All Rights Reserved.
 *
 * @module			de_epages.seo.ui.seoCheckWidget
 *
 * @revision		$Revision: 1.7 $
 */

jQuery.plugin( 'de_epages.seo.ui.seoCheckWidget', {
	plugin:	['de_epages.core', 'ep.ui.dialog', 'ep.ajax', 'jQuery.ui.tabs', 'de_epages.seo.ui.seoGaugeWidget', 'jQuery.metaparse']
}, function( $, undefined ){
	$.widget( "de_epages.seo.ui.seoCheckWidget", {

		_gaugeWidget : undefined,

		options : {
			caption : '{SEOCheck}',
			currentSEOQuality : 0,
			objectId : ep.config.objectId,
			languageId : ep.config.languageId
		},

		_create : function() {
			this.elem = this.element.sub(ep);
			this.elem.uiDialog('option', 'width', 920);
			this.elem.uiDialog('option', 'height', 550);
			this.elem.uiDialog('option', 'modal', true);
		},

		_init : function() {
			this.element.html('');
			this._getDialogContent();
			this._buildTitleGauge();
		},

		_getDialogContent : function() {
			ep.ajax({
				data: {
					'ViewAction': 'MBO-ViewSEOCheck',
					'ObjectID': this.options.objectId,
					'LanguageID': this.options.languageId
				},
				context: this
			})
			.done(function(data, textStatus, XMLHttpRequest) {
				data = this._sortTestsBySeverity(data);
				this.element.empty().append(data).find('.ep-metaparse').metaparse();
				var newQual = this.elem.children('.seoCheck').data('newseoquality');
				if(newQual && newQual != this.options.currentSEOQuality) {
					this.elem.trigger("SEOCheckNewQuality", newQual);
					this._refreshTitleGauge(newQual);
				}
			});
		},

		_sortTestsBySeverity : function(data) {
			var cache = jQuery(data);
			cache.find('ul.seoTest').each(function() {
				var ul = $(this);
				ul.children('.yellow').prependTo(ul);
				ul.children('.orange').prependTo(ul);
				ul.children('.red').prependTo(ul);
			});
			return cache;
		},

		_buildTitleGauge : function() {
			this._gaugeWidget = de_epages('<div>').seoUiSeoGaugeWidget({
				'caption' : this.options.caption,
				'showStatusImage' : false,
				'seoQuality' : this.options.currentSEOQuality
			})
			.seoUiSeoGaugeWidget('Instance');
			this.elem.uiDialog('option','title', this._gaugeWidget.element );
		},

		_refreshTitleGauge : function(newValue) {
			if(this._gaugeWidget) {
				this._gaugeWidget.setPercentage(newValue);
			}
		}

	});
});


/* ---- Module:jQuery.metaparse ---- */

/*
 * @author			Emanuel Vitzthum
 * @copyright		© 2011 jQuery SDK v1.3.1
 * @info			http://www.jquerysdk.com
 *
 * @license			Dual licensed under the MIT (http://www.opensource.org/licenses/mit-license.php) and GPL (http://www.gnu.org/licenses/gpl.html)
 *
 * @plugin			jQuery.metaparse
 */

jQuery.plugin( "jQuery.metaparse", function( $, undefined ){

	var doc = document,

		metaExp = /(?:(?:^|\s+)((?:[\$\w]+)?)((?:\.ready\([^\)]*\))?)(\.[\$\w]+\(.*\)))/,
		readyExp = /^\.ready/,

		doneDepend = $.Deferred().resolve().promise(),
		failDepend = $.Deferred().reject().promise(),

		metaparse = function( data ){
			var meta = {};

			meta.data = data.replace( metaExp, function( m, m1, m2, m3 ){
				meta.depend = m2;
				meta.execute = (m1 || "jQuery") + "(elem)" + m3;

				return "";
			});

			return meta;
		},

		// set internal already parsed status
		isMetaparsed = function( elem, set ){
			return set === undefined ? $._data(elem).metaparsed : ($._data(elem).metaparsed = set);
		},
		
		// run metaparse automatically on dom ready if defined in config
		runAutoparse = function(){
			$.ready(function(){
				$( autoparse.selector || (typeof autoparse == "string" ? autoparse : ".metaparse") )
					.metaparse({},true);
			});
		},

		autoparse;

	$.extend({
		metaparse: function( elem, settings /*internal*/,isEach ){
			// check whether elem is already parsed
			if( !isMetaparsed(elem) ){
				var s = isEach ? settings : $.extend( {}, $.metaparseSettings, settings ),
					type = s.type,
					name = s.name,
					meta = {},
					execute,
					depend,
					temp;
	
				if( type === "class" ){
					meta = metaparse(elem.className);
					elem.className = meta.data;
				}
				else if( type === "elem" ){
					if( !elem.getElementsByTagName )
						return;
	
					if( temp = elem.getElementsByTagName(name)[0] ){
						meta = metaparse(temp.innerHTML);
						temp.innerHTML = meta.data;
					}
				}
				else if( elem.getAttribute != undefined ){
					if( type==="html5" || type==="data" )
						name = "data-"+name;
	
					if( temp = elem.getAttribute(name) ){
						meta = metaparse(temp);
						elem.setAttribute(name,meta.data);
					}
				}
	
				// $.globalEval isn't faster then eval this short string
				if( execute = meta.execute ){
					temp = function(){
						isMetaparsed(elem,true);
						eval(execute);
					};
	
					if(	depend = ((depend = meta.depend) && depend.replace(readyExp,"")) )
						return $.ready( eval(depend), temp );
	
					temp();
					return doneDepend;
				}
			}

			return failDepend;
		},
		metaparseSettings: $.extend(
			{
				type: "class",
				name: "metaparse"
			},
			$.config.metaparse
		)
	});

	$.fn.extend({
		metaparse: function( settings /*internal*/,isAutoparse ){
			var s = $.extend( {}, $.metaparseSettings, settings ),
				self = this,
				stack = [],
				depend;

			self.each(function(){
					if( !( depend = $.metaparse(this, s, true) ).isRejected() )
						stack.push( depend );
				});

			$.when
				.apply($, stack)
				.done(function(){
					self.each(function(){
						$.event.trigger( "metaparse", null, this, true );
					});

					if( isAutoparse ){
						isMetaparsed(doc,true);
						$(doc).triggerHandler("metaparse");
					}

				});

			return self;
		}
	});

	$.event.special.metaparse = {
		// don't add real event
		setup	: $.noop,
		
		// add special handler
		add		: function( bind ) {
			// execute handler immediately if elem is already parsed
			if( isMetaparsed(this) )
				bind.handler.call(this,$.Event("metaparse"));

		}
	};

	if( autoparse = $.metaparseSettings.autoparse ){
		if( autoparse.ready )
			$.ready( autoparse.ready, runAutoparse );
		else
			runAutoparse();

		delete $.metaparseSettings.autoparse;
	}

});